@@ -3,9 +3,7 @@
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -36,7 +34,7 @@ class KADUAPI AccountDetails : public Details<AccountShared>
 {
 
 public:
-	explicit AccountDetails(AccountShared *mainData);
+	explicit AccountDetails(AccountShared *mainData, QObject *parent = nullptr);
 	virtual ~AccountDetails();
 
 };
