@@ -2,10 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,38 +21,29 @@
  */
 
 #include "accounts/accounts-aware-object.h"
+#include "accounts/account-storage.h"
 #include "buddies/buddy-manager.h"
 #include "chat/chat-manager.h"
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/widgets/dialog/password-dialog-widget.h"
 #include "gui/windows/kadu-dialog.h"
 #include "identities/identity.h"
-#include "protocols/connection-error-notification.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
-#include "protocols/services/roster/roster-service.h"
+#include "roster/roster-service.h"
 #include "debug.h"
 
 #include "account-manager.h"
 
-AccountManager * AccountManager::Instance = 0;
-
-AccountManager * AccountManager::instance()
-{
-	if (0 == Instance)
-	{
-		Instance = new AccountManager();
-		Instance->init();
-	}
-
-	return Instance;
-}
-
-AccountManager::AccountManager()
+AccountManager::AccountManager(QObject *parent) :
+		Manager<Account>{parent}
 {
 }
 
@@ -62,10 +51,56 @@ AccountManager::~AccountManager()
 {
 }
 
+void AccountManager::setAccountStorage(AccountStorage *accountStorage)
+{
+	m_accountStorage = accountStorage;
+}
+
+void AccountManager::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void AccountManager::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void AccountManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void AccountManager::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void AccountManager::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void AccountManager::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
 void AccountManager::init()
 {
 	// needed for QueuedConnection
 	qRegisterMetaType<Account>("Account");
+	m_configurationManager->registerStorableObject(this);
+}
+
+void AccountManager::done()
+{
+	m_configurationManager->unregisterStorableObject(this);
+}
+
+Account AccountManager::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+{
+	return m_accountStorage->loadStubFromStorage(storagePoint);
 }
 
 void AccountManager::itemAdded(Account item)
@@ -98,14 +133,7 @@ void AccountManager::itemRegistered(Account item)
 
 	AccountsAwareObject::notifyAccountRegistered(item);
 
-	/* NOTE: We need QueuedConnection here so when the protocol emits the signal, it can cleanup
-	 * itself before we do something (e.g., reset connection data after invalidPassword, so when
-	 * we try to log in after entering new password, a new connection can be estabilished instead
-	 * of giving up because of already existing connection).
-	 */
-	connect(item.protocolHandler(), SIGNAL(connectionError(Account, const QString &, const QString &)),
-			this, SLOT(connectionError(Account, const QString &, const QString &)), Qt::QueuedConnection);
-	connect(item.protocolHandler(), SIGNAL(invalidPassword(Account)),
+	connect(protocol(item), SIGNAL(invalidPassword(Account)),
 			this, SLOT(providePassword(Account)), Qt::QueuedConnection);
 
 	emit accountRegistered(item);
@@ -116,7 +144,7 @@ void AccountManager::itemAboutToBeUnregisterd(Account item)
 	QMutexLocker locker(&mutex());
 
 	AccountsAwareObject::notifyAccountUnregistered(item);
-	disconnect(item.protocolHandler(), 0, this, 0);
+	disconnect(protocol(item), 0, this, 0);
 
 	emit accountAboutToBeUnregistered(item);
 }
@@ -198,30 +226,22 @@ void AccountManager::accountDataUpdated()
 		emit accountUpdated(account);
 }
 
-void AccountManager::connectionError(Account account, const QString &server, const QString &message)
-{
-	QMutexLocker locker(&mutex());
-
-	ConnectionErrorNotification::notifyConnectionError(account, server, message);
-}
-
 void AccountManager::removeAccountAndBuddies(Account account)
 {
 	StatusContainer *statusContainer = account.statusContainer();
 	if (statusContainer)
 		statusContainer->setStatus(Status(), SourceUser); // user removed account
 
-	Protocol *protocolHandler = account.protocolHandler();
-	if (protocolHandler)
-		delete protocolHandler->rosterService();
+	if (auto p = protocol(account))
+		delete p->rosterService();
 
 	removeItem(account);
 
-	QVector<Contact> contacts = ContactManager::instance()->contacts(account);
+	QVector<Contact> contacts = m_contactManager->contacts(account);
 	foreach (const Contact &contact, contacts)
-		BuddyManager::instance()->clearOwnerAndRemoveEmptyBuddy(contact);
+		m_buddyManager->clearOwnerAndRemoveEmptyBuddy(contact);
 
-	QVector<Chat> chats = ChatManager::instance()->chats(account);
+	QVector<Chat> chats = m_chatManager->chats(account);
 	foreach (const Chat &chat, chats)
 		chat.setDisplay(QString());
 }
@@ -238,8 +258,8 @@ void AccountManager::passwordProvided(const QVariant& data, const QString& passw
 
 	// inform protocol that we have password
 	// maybe this should be in other place, but for now it is enough
-	if (account.protocolHandler())
-		account.protocolHandler()->passwordProvided();
+	if (auto p = protocol(account))
+		p->passwordProvided();
 }
 
 void AccountManager::providePassword(Account account)
@@ -250,7 +270,7 @@ void AccountManager::providePassword(Account account)
 			.arg(account.accountIdentity().name())
 			.arg(account.id());
 
-	PasswordDialogWidget *passwordWidget = new PasswordDialogWidget(message, account, 0);
+	auto passwordWidget = m_injectedFactory->makeInjected<PasswordDialogWidget>(message, account, nullptr);
 	connect(passwordWidget, SIGNAL(passwordEntered(const QVariant &, const QString &, bool)), this, SLOT(passwordProvided(const QVariant &, const QString &, bool)));
 	KaduDialog *window = new KaduDialog(passwordWidget, 0);
 	window->exec();
@@ -261,7 +281,7 @@ void AccountManager::loaded()
 	Manager<Account>::loaded();
 
 	foreach (const Account &account, allItems())
-		account.accountContact().setOwnerBuddy(Core::instance()->myself());
+		account.accountContact().setOwnerBuddy(m_myself->buddy());
 }
 
 #include "moc_account-manager.cpp"
