@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,8 +24,10 @@
 #include "accounts/account-details.h"
 #include "accounts/account-manager.h"
 #include "accounts/account-status-container.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
+#include "core/injected-factory.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity-manager.h"
 #include "identities/identity.h"
@@ -34,50 +36,20 @@
 #include "network/proxy/network-proxy-manager.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
-#include "protocols/services/roster/roster-service.h"
+#include "roster/roster-service-tasks.h"
+#include "roster/roster-service.h"
+#include "roster/roster-task-collection-storage.h"
 #include "status/status-setter.h"
 
 #include "account-shared.h"
 
-AccountShared * AccountShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	AccountShared *result = loadFromStorage(storagePoint);
-	result->loadStub();
-
-	return result;
-}
-
-AccountShared * AccountShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	AccountShared *result = new AccountShared();
-	result->setStorage(storagePoint);
-
-	return result;
-}
-
-AccountShared::AccountShared(const QString &protocolName) :
-		QObject(), Shared(QUuid()), ProtocolName(protocolName),
-		ProtocolHandler(0), MyStatusContainer(new AccountStatusContainer(this)), Details(0),
+AccountShared::AccountShared(const QString &protocolName, QObject *parent) :
+		Shared(QUuid(), parent), ProtocolName(protocolName),
+		ProtocolHandler(0), Details(0),
 		RememberPassword(false), HasPassword(false), UseDefaultProxy(true), PrivateStatus(true)
 {
 	AccountIdentity = new Identity();
 	AccountContact = new Contact();
-
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
-	        this, SLOT(protocolRegistered(ProtocolFactory*)));
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
-	        this, SLOT(protocolUnregistered(ProtocolFactory*)));
-
-	// ProtocolName is not empty here only if a new Account has just been created
-	// it that case load() method will not be called so we need to call triggerAllProtocolsRegistered here
-	if (!ProtocolName.isEmpty())
-	{
-		ProtocolFactory *factory = ProtocolsManager::instance()->byName(ProtocolName);
-		if (factory)
-			protocolRegistered(factory);
-	}
-
-	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
 }
 
 AccountShared::~AccountShared()
@@ -86,7 +58,7 @@ AccountShared::~AccountShared()
 
 	if (!ProtocolName.isEmpty())
 	{
-		ProtocolFactory *factory = ProtocolsManager::instance()->byName(ProtocolName);
+		ProtocolFactory *factory = m_protocolsManager->byName(ProtocolName);
 		if (factory)
 			protocolUnregistered(factory);
 	}
@@ -101,14 +73,75 @@ AccountShared::~AccountShared()
 	delete AccountIdentity;
 }
 
+void AccountShared::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void AccountShared::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void AccountShared::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void AccountShared::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void AccountShared::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void AccountShared::setNetworkProxyManager(NetworkProxyManager *networkProxyManager)
+{
+	m_networkProxyManager = networkProxyManager;
+}
+
+void AccountShared::setProtocolsManager(ProtocolsManager *protocolsManager)
+{
+	m_protocolsManager = protocolsManager;
+}
+
+void AccountShared::setStatusSetter(StatusSetter *statusSetter)
+{
+	m_statusSetter = statusSetter;
+}
+
+void AccountShared::init()
+{
+	MyStatusContainer = m_injectedFactory->makeInjected<AccountStatusContainer>(this);
+
+	connect(m_protocolsManager, SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
+	        this, SLOT(protocolRegistered(ProtocolFactory*)));
+	connect(m_protocolsManager, SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
+	        this, SLOT(protocolUnregistered(ProtocolFactory*)));
+
+	// ProtocolName is not empty here only if a new Account has just been created
+	// it that case load() method will not be called so we need to call triggerAllProtocolsRegistered here
+	if (!ProtocolName.isEmpty())
+	{
+		ProtocolFactory *factory = m_protocolsManager->byName(ProtocolName);
+		if (factory)
+			protocolRegistered(factory);
+	}
+
+	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
+}
+
 StorableObject * AccountShared::storageParent()
 {
-	return AccountManager::instance();
+	return m_accountManager;
 }
 
 QString AccountShared::storageNodeName()
 {
-	return QLatin1String("Account");
+	return QStringLiteral("Account");
 }
 
 void AccountShared::importNetworkProxy()
@@ -129,7 +162,7 @@ void AccountShared::importNetworkProxy()
 	NetworkProxy importedProxy;
 
 	if (!address.isEmpty())
-		importedProxy = NetworkProxyManager::instance()->byConfiguration(
+		importedProxy = m_networkProxyManager->byConfiguration(
 		            address, port, user, password, ActionCreateAndAdd);
 
 	if (loadValue<bool>("UseProxy"))
@@ -143,33 +176,13 @@ void AccountShared::importNetworkProxy()
 	removeValue("ProxyPassword");
 }
 
-void AccountShared::loadRosterTasks()
+QVector<RosterTask> AccountShared::loadRosterTasks()
 {
 	if (!isValidStorage())
-		return;
+		return {};
 
-	if (!protocolHandler() || !protocolHandler()->rosterService())
-		return;
-
-	XmlConfigFile *configurationStorage = storage()->storage();
-	QDomElement rosterTasksNode = configurationStorage->getNode(storage()->point(), "RosterTasks");
-
-	QDomNodeList rosterTaskNodes = rosterTasksNode.childNodes();
-	const int rosterTaskCount = rosterTaskNodes.count();
-
-	for (int i = 0; i < rosterTaskCount; i++)
-	{
-		QDomElement rosterTaskElement = rosterTaskNodes.at(i).toElement();
-		if (rosterTaskElement.isNull() || rosterTaskElement.text().isEmpty())
-			continue;
-
-		if (rosterTaskElement.nodeName() == "Add")
-			protocolHandler()->rosterService()->addTask(RosterTask(RosterTaskAdd, rosterTaskElement.text()));
-		else if (rosterTaskElement.nodeName() == "Delete")
-			protocolHandler()->rosterService()->addTask(RosterTask(RosterTaskDelete, rosterTaskElement.text()));
-		else if (rosterTaskElement.nodeName() == "Update")
-			protocolHandler()->rosterService()->addTask(RosterTask(RosterTaskUpdate, rosterTaskElement.text()));
-	}
+	auto tasksStorage = RosterTaskCollectionStorage{storage()};
+	return tasksStorage.loadRosterTasks();
 }
 
 void AccountShared::load()
@@ -179,9 +192,9 @@ void AccountShared::load()
 
 	Shared::load();
 
-	Identity identity = IdentityManager::instance()->byUuid(loadValue<QString>("Identity"));
-	if (identity.isNull() && !IdentityManager::instance()->items().isEmpty())
-		identity = IdentityManager::instance()->items().at(0);
+	Identity identity = m_identityManager->byUuid(loadValue<QString>("Identity"));
+	if (identity.isNull() && !m_identityManager->items().isEmpty())
+		identity = m_identityManager->items().at(0);
 	doSetAccountIdentity(identity);
 
 	ProtocolName = loadValue<QString>("Protocol");
@@ -202,51 +215,29 @@ void AccountShared::load()
 	{
 		UseDefaultProxy = loadValue<bool>("UseDefaultProxy", true);
 		if (!UseDefaultProxy)
-			Proxy = NetworkProxyManager::instance()->byUuid(loadValue<QString>("Proxy"));
+			Proxy = m_networkProxyManager->byUuid(loadValue<QString>("Proxy"));
 	}
 
 	PrivateStatus = loadValue<bool>("PrivateStatus", true);
 
 	if (!ProtocolName.isEmpty())
 	{
-		ProtocolFactory *factory = ProtocolsManager::instance()->byName(ProtocolName);
+		ProtocolFactory *factory = m_protocolsManager->byName(ProtocolName);
 		if (factory)
 			protocolRegistered(factory);
 	}
 
-	loadRosterTasks();
+	if (auto t = rosterServiceTasks(this))
+		t->addTasks(loadRosterTasks());
 }
 
-void AccountShared::storeRosterTasks()
+void AccountShared::storeRosterTasks(const QVector<RosterTask> &tasks)
 {
 	if (!isValidStorage())
 		return;
 
-	if (!protocolHandler() || !protocolHandler()->rosterService())
-		return;
-
-	XmlConfigFile *configurationStorage = storage()->storage();
-	QDomElement rosterTasksNode = configurationStorage->getNode(storage()->point(), "RosterTasks");
-
-	while (!rosterTasksNode.childNodes().isEmpty())
-		rosterTasksNode.removeChild(rosterTasksNode.childNodes().at(0));
-
-	QVector<RosterTask> tasks = protocolHandler()->rosterService()->tasks();
-	foreach (const RosterTask &task, tasks)
-		switch (task.type())
-		{
-			case RosterTaskAdd:
-				configurationStorage->createTextNode(rosterTasksNode, "Add", task.id());
-				break;
-			case RosterTaskDelete:
-				configurationStorage->createTextNode(rosterTasksNode, "Delete", task.id());
-				break;
-			case RosterTaskUpdate:
-				configurationStorage->createTextNode(rosterTasksNode, "Update", task.id());
-				break;
-			default:
-				break;
-		}
+	auto tasksStorage = RosterTaskCollectionStorage{storage()};
+	tasksStorage.storeRosterTasks(tasks);
 }
 
 void AccountShared::store()
@@ -277,7 +268,8 @@ void AccountShared::store()
 	if (Details)
 		Details->ensureStored();
 
-	storeRosterTasks();
+	if (protocolHandler() && protocolHandler()->rosterService() && protocolHandler()->rosterService()->tasks())
+		storeRosterTasks(protocolHandler()->rosterService()->tasks()->tasks());
 }
 
 bool AccountShared::shouldStore()
@@ -297,7 +289,7 @@ void AccountShared::aboutToBeRemoved()
 		Details = 0;
 	}
 
-	AccountManager::instance()->unregisterItem(this);
+	m_accountManager->unregisterItem(this);
 	setAccountIdentity(Identity::null);
 }
 
@@ -313,18 +305,18 @@ void AccountShared::setDisconnectStatus()
 	if (!ProtocolHandler->isConnected() && !ProtocolHandler->isDisconnecting())
 		return;
 
-	bool disconnectWithCurrentDescription = config_file.readBoolEntry("General", "DisconnectWithCurrentDescription");
-	QString disconnectDescription = config_file.readEntry("General", "DisconnectDescription");
+	auto disconnectWithCurrentDescription = m_configuration->deprecatedApi()->readBoolEntry("General", "DisconnectWithCurrentDescription");
+	auto disconnectDescription = m_configuration->deprecatedApi()->readEntry("General", "DisconnectDescription");
 
 	Status disconnectStatus;
-	disconnectStatus.setType(StatusTypeOffline);
+	disconnectStatus.setType(StatusType::Offline);
 
 	if (disconnectWithCurrentDescription)
 		disconnectStatus.setDescription(MyStatusContainer->status().description());
 	else
 		disconnectStatus.setDescription(disconnectDescription);
 
-	StatusSetter::instance()->setStatus(MyStatusContainer, disconnectStatus);
+	m_statusSetter->setStatusManually(MyStatusContainer, disconnectStatus);
 }
 
 void AccountShared::protocolRegistered(ProtocolFactory *factory)
@@ -337,27 +329,30 @@ void AccountShared::protocolRegistered(ProtocolFactory *factory)
 	if (ProtocolHandler || (factory->name() != ProtocolName) || Details)
 		return;
 
-	ProtocolHandler = factory->createProtocolHandler(this);
-	if (!ProtocolHandler)
-		return;
-
 	Details = factory->createAccountDetails(this);
 	if (Details)
 		details()->ensureLoaded();
 
+	ProtocolHandler = factory->createProtocolHandler(this);
+	if (!ProtocolHandler)
+		return;
+
 	connect(ProtocolHandler, SIGNAL(statusChanged(Account, Status)), MyStatusContainer, SLOT(triggerStatusUpdated()));
 	connect(ProtocolHandler, SIGNAL(contactStatusChanged(Contact, Status)),
 			this, SIGNAL(buddyStatusChanged(Contact, Status)));
+	connect(ProtocolHandler, &Protocol::remoteStatusChangeRequest, this, &AccountShared::remoteStatusChangeRequest);
 	connect(ProtocolHandler, SIGNAL(connected(Account)), this, SIGNAL(connected()));
 	connect(ProtocolHandler, SIGNAL(disconnected(Account)), this, SIGNAL(disconnected()));
 
-	loadRosterTasks();
+	if (protocolHandler() && protocolHandler()->rosterService() && protocolHandler()->rosterService()->tasks())
+		protocolHandler()->rosterService()->tasks()->addTasks(loadRosterTasks());
 
 	MyStatusContainer->triggerStatusUpdated();
 
-	AccountManager::instance()->registerItem(this);
+	m_accountManager->registerItem(this);
 
 	emit updated();
+	emit protocolHandlerChanged();
 }
 
 void AccountShared::protocolUnregistered(ProtocolFactory* factory)
@@ -370,7 +365,8 @@ void AccountShared::protocolUnregistered(ProtocolFactory* factory)
 	if (!ProtocolHandler || (factory->name() != ProtocolName) || !Details)
 		return;
 
-	storeRosterTasks();
+	if (protocolHandler() && protocolHandler()->rosterService() && protocolHandler()->rosterService()->tasks())
+		storeRosterTasks(protocolHandler()->rosterService()->tasks()->tasks());
 
 	disconnect(ProtocolHandler, SIGNAL(statusChanged(Account, Status)), MyStatusContainer, SLOT(triggerStatusUpdated()));
 	disconnect(ProtocolHandler, 0, this, 0);
@@ -383,12 +379,13 @@ void AccountShared::protocolUnregistered(ProtocolFactory* factory)
 
 	// dont get deleted in next line
 	Account guard(this);
-	AccountManager::instance()->unregisterItem(this);
+	m_accountManager->unregisterItem(this);
 
 	delete ProtocolHandler;
 	ProtocolHandler = 0;
 
 	emit updated();
+	emit protocolHandlerChanged();
 }
 
 void AccountShared::doSetAccountIdentity(const Identity &accountIdentity)
@@ -439,7 +436,7 @@ Contact AccountShared::accountContact()
 	ensureLoaded();
 
 	if (!*AccountContact)
-		*AccountContact = ContactManager::instance()->byId(this, Id, ActionCreateAndAdd);
+		*AccountContact = m_contactManager->byId(this, Id, ActionCreateAndAdd);
 
 	return *AccountContact;
 }
@@ -460,14 +457,13 @@ void AccountShared::setPrivateStatus(bool isPrivate)
 		ProtocolHandler->changePrivateMode();
 }
 
-void AccountShared::fileTransferServiceChanged(FileTransferService *service)
-{
-	if (service)
-		emit fileTransferServiceRegistered();
-	else
-		emit fileTransferServiceUnregistered();
-}
-
 KaduShared_PropertyPtrReadDef(AccountShared, Identity, accountIdentity, AccountIdentity)
 
+Protocol * protocol(AccountShared *account)
+{
+	return account
+			? account->protocolHandler()
+			: nullptr;
+}
+
 #include "moc_account-shared.cpp"
