@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,31 +21,50 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ACCOUNT_SHARED_H
-#define ACCOUNT_SHARED_H
-
-#include <QtNetwork/QHostAddress>
+#pragma once
 
 #include "network/proxy/network-proxy.h"
 #include "status/status.h"
 #include "storage/shared.h"
 
+#include <QtCore/QPointer>
+#include <QtNetwork/QHostAddress>
+#include <injeqt/injeqt.h>
+
 class AccountDetails;
+class AccountManager;
 class AccountStatusContainer;
+class Account;
+class Configuration;
+class ContactManager;
 class Contact;
 class FileTransferService;
+class IdentityManager;
 class Identity;
-class Protocol;
+class InjectedFactory;
+class NetworkProxyManager;
 class ProtocolFactory;
+class ProtocolsManager;
+class Protocol;
+class RosterTask;
 class StatusContainer;
+class StatusSetter;
 
-class KADUAPI AccountShared : public QObject, public Shared
+class KADUAPI AccountShared : public Shared
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(AccountShared)
 
 	friend class AccountStatusContainer;
 
+	QPointer<AccountManager> m_accountManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<IdentityManager> m_identityManager;
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<NetworkProxyManager> m_networkProxyManager;
+	QPointer<ProtocolsManager> m_protocolsManager;
+	QPointer<StatusSetter> m_statusSetter;
+
 	QString ProtocolName;
 	Protocol *ProtocolHandler;
 	AccountStatusContainer *MyStatusContainer;
@@ -74,10 +93,20 @@ class KADUAPI AccountShared : public QObject, public Shared
 
 	void importNetworkProxy();
 
-	void loadRosterTasks();
-	void storeRosterTasks();
+	QVector<RosterTask> loadRosterTasks();
+	void storeRosterTasks(const QVector<RosterTask> &tasks);
 
 private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setIdentityManager(IdentityManager *identityManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setNetworkProxyManager(NetworkProxyManager *networkProxyManager);
+	INJEQT_SET void setProtocolsManager(ProtocolsManager *protocolsManager);
+	INJEQT_SET void setStatusSetter(StatusSetter *statusSetter);
+	INJEQT_INIT void init();
+
 	void protocolRegistered(ProtocolFactory *protocolHandler);
 	void protocolUnregistered(ProtocolFactory *protocolHandler);
 
@@ -92,10 +121,7 @@ protected:
 	void forceEmitUpdated();
 
 public:
-	static AccountShared * loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint);
-	static AccountShared * loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint);
-
-	explicit AccountShared(const QString &protocolName = QString());
+	explicit AccountShared(const QString &protocolName = QString(), QObject *parent = nullptr);
 	virtual ~AccountShared();
 
 	virtual StorableObject * storageParent();
@@ -126,23 +152,17 @@ public:
 	KaduShared_Property(bool, useDefaultProxy, UseDefaultProxy)
 	KaduShared_Property(const NetworkProxy &, proxy, Proxy)
 
-	// TODO: 0.11, find better API
-	// this is only for GG now
-	void fileTransferServiceChanged(FileTransferService *service);
-
 signals:
 	void buddyStatusChanged(const Contact &contact, const Status &oldStatus);
 
 	void connected();
 	void disconnected();
 
-	void updated();
+	void remoteStatusChangeRequest(Account account, Status requestedStatus);
 
-	// TODO: 0.11, find better API
-	// this is only for GG now
-	void fileTransferServiceRegistered();
-	void fileTransferServiceUnregistered();
+	void updated();
+	void protocolHandlerChanged();
 
 };
 
-#endif // ACCOUNT_SHARED_H
+KADUAPI Protocol * protocol(AccountShared *account);
