@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -36,16 +35,13 @@ class Identity;
 class NetworkProxy;
 class Protocol;
 class ProtocolFactory;
-class XmlConfigFile;
+class ConfigurationApi;
 
 class KADUAPI Account : public SharedBase<AccountShared>
 {
 	KaduSharedBaseClass(Account)
 
 public:
-	static Account create(const QString &protocolName);
-	static Account loadStubFromStorage(const std::shared_ptr<StoragePoint> &accountStoragePoint);
-	static Account loadFromStorage(const std::shared_ptr<StoragePoint> &accountStoragePoint);
 	static Account null;
 
 	Account();
@@ -72,6 +68,8 @@ public:
 
 };
 
+KADUAPI Protocol * protocol(Account account);
+
 Q_DECLARE_METATYPE(Account)
 
 #endif // ACCOUNT_H
