@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -46,48 +46,48 @@ void AccountsAwareObject::accountUnregistered(Account account)
 
 void AccountsAwareObject::notifyAccountAdded(Account account)
 {
-	foreach (AccountsAwareObject *object, Objects)
+	for (AccountsAwareObject *object : Objects)
 		object->accountAdded(account);
 }
 
 void AccountsAwareObject::notifyAccountRemoved(Account account)
 {
-	foreach (AccountsAwareObject *object, Objects)
+	for (AccountsAwareObject *object : Objects)
 		object->accountRemoved(account);
 }
 
 void AccountsAwareObject::notifyAccountRegistered(Account account)
 {
-	foreach (AccountsAwareObject *object, Objects)
+	for (AccountsAwareObject *object : Objects)
 		object->accountRegistered(account);
 }
 
 void AccountsAwareObject::notifyAccountUnregistered(Account account)
 {
-	foreach (AccountsAwareObject *object, Objects)
+	for (AccountsAwareObject *object : Objects)
 		object->accountUnregistered(account);
 }
 
-void AccountsAwareObject::triggerAllAccountsAdded()
+void AccountsAwareObject::triggerAllAccountsAdded(AccountManager *accountManager)
 {
-	foreach (const Account &account, AccountManager::instance()->items())
+	for (auto const &account : accountManager->items())
 		accountAdded(account);
 }
 
-void AccountsAwareObject::triggerAllAccountsRemoved()
+void AccountsAwareObject::triggerAllAccountsRemoved(AccountManager *accountManager)
 {
-	foreach (const Account &account, AccountManager::instance()->items())
+	for (auto const &account : accountManager->items())
 		accountRemoved(account);
 }
 
-void AccountsAwareObject::triggerAllAccountsRegistered()
+void AccountsAwareObject::triggerAllAccountsRegistered(AccountManager *accountManager)
 {
-	foreach (const Account &account, AccountManager::instance()->items())
+	for (auto const &account : accountManager->items())
 		accountRegistered(account);
 }
 
-void AccountsAwareObject::triggerAllAccountsUnregistered()
+void AccountsAwareObject::triggerAllAccountsUnregistered(AccountManager *accountManager)
 {
-	foreach (const Account &account, AccountManager::instance()->items())
+	for (auto const &account : accountManager->items())
 		accountUnregistered(account);
 }
