@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,13 +20,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ACCOUNTS_AWARE_OBJECT
-#define ACCOUNTS_AWARE_OBJECT
-
-#include <QtCore/QList>
+#pragma once
 
 #include "aware-object.h"
 
+#include <QtCore/QList>
+
+class AccountManager;
 class Account;
 
 class KADUAPI AccountsAwareObject : public AwareObject<AccountsAwareObject>
@@ -46,11 +44,9 @@ public:
 	static void notifyAccountRegistered(Account account);
 	static void notifyAccountUnregistered(Account account);
 
-	void triggerAllAccountsAdded();
-	void triggerAllAccountsRemoved();
-	void triggerAllAccountsRegistered();
-	void triggerAllAccountsUnregistered();
+	void triggerAllAccountsAdded(AccountManager *accountManager);
+	void triggerAllAccountsRemoved(AccountManager *accountManager);
+	void triggerAllAccountsRegistered(AccountManager *accountManager);
+	void triggerAllAccountsUnregistered(AccountManager *accountManager);
 
 };
-
-#endif // ACCOUNTS_AWARE_OBJECT
