@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,6 +24,7 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity.h"
 #include "model/roles.h"
@@ -31,24 +32,30 @@
 
 #include "accounts-model.h"
 
-AccountsModel::AccountsModel(QObject *parent) :
-		QAbstractListModel(parent), IncludeIdInDisplay(false)
+AccountsModel::AccountsModel(AccountManager *accountManager, QObject *parent) :
+		QAbstractListModel{parent},
+		m_accountManager{accountManager},
+		m_includeIdInDisplay{}
 {
-	connect(AccountManager::instance(), SIGNAL(accountUpdated(Account)),
+	connect(m_accountManager, SIGNAL(accountUpdated(Account)),
 			this, SLOT(accountUpdated(Account)));
-	connect(AccountManager::instance(), SIGNAL(accountAboutToBeRegistered(Account)),
+	connect(m_accountManager, SIGNAL(accountAboutToBeRegistered(Account)),
 			this, SLOT(accountAboutToBeRegistered(Account)));
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)),
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)),
 			this, SLOT(accountRegistered(Account)));
-	connect(AccountManager::instance(), SIGNAL(accountAboutToBeUnregistered(Account)),
+	connect(m_accountManager, SIGNAL(accountAboutToBeUnregistered(Account)),
 			this, SLOT(accountAboutToBeUnregistered(Account)));
-	connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)),
+	connect(m_accountManager, SIGNAL(accountUnregistered(Account)),
 			this, SLOT(accountUnregistered(Account)));
 }
 
 AccountsModel::~AccountsModel()
 {
-	disconnect(AccountManager::instance(), 0, this, 0);
+}
+
+void AccountsModel::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
 }
 
 int AccountsModel::columnCount(const QModelIndex &parent) const
@@ -58,7 +65,7 @@ int AccountsModel::columnCount(const QModelIndex &parent) const
 
 int AccountsModel::rowCount(const QModelIndex &parent) const
 {
-	return parent.isValid() ? 0 : AccountManager::instance()->count();
+	return parent.isValid() ? 0 : m_accountManager->count();
 }
 
 QVariant AccountsModel::data(const QModelIndex &index, int role) const
@@ -70,13 +77,13 @@ QVariant AccountsModel::data(const QModelIndex &index, int role) const
 	switch (role)
 	{
 		case Qt::DisplayRole:
-			if (IncludeIdInDisplay)
+			if (m_includeIdInDisplay)
 				return QString("%1 (%2)").arg(acc.accountIdentity().name(), acc.id());
 			else
 				return acc.accountIdentity().name();
 		case Qt::DecorationRole:
 			return acc.protocolHandler()
-					? acc.protocolHandler()->icon().icon()
+					? m_iconsManager->iconByPath(acc.protocolHandler()->icon())
 					: QVariant();
 
 		case AccountRole:
@@ -98,12 +105,12 @@ Account AccountsModel::account(const QModelIndex &index) const
 	if (index.row() < 0 || index.row() >= rowCount())
 		return Account::null;
 
-	return AccountManager::instance()->byIndex(index.row());
+	return m_accountManager->byIndex(index.row());
 }
 
 int AccountsModel::accountIndex(Account account) const
 {
-	return AccountManager::instance()->indexOf(account);
+	return m_accountManager->indexOf(account);
 }
 
 QModelIndexList AccountsModel::indexListForValue(const QVariant &value) const
@@ -154,10 +161,10 @@ void AccountsModel::accountUnregistered(Account account)
 
 void AccountsModel::setIncludeIdInDisplay(bool includeIdInDisplay)
 {
-	if (IncludeIdInDisplay == includeIdInDisplay)
+	if (m_includeIdInDisplay == includeIdInDisplay)
 		return;
 
-	IncludeIdInDisplay = includeIdInDisplay;
+	m_includeIdInDisplay = includeIdInDisplay;
 	emit dataChanged(index(0, 0), index(rowCount() - 1, 0));
 }
 
