@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,44 +19,51 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ACCOUNTS_MODEL
-#define ACCOUNTS_MODEL
-
-#include <QtCore/QAbstractListModel>
-#include <QtCore/QModelIndex>
+#pragma once
 
 #include "accounts/account.h"
 #include "model/kadu-abstract-model.h"
 
+#include <QtCore/QAbstractListModel>
+#include <QtCore/QModelIndex>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
+class IconsManager;
+
 class AccountsModel : public QAbstractListModel, public KaduAbstractModel
 {
 	Q_OBJECT
 
-	bool IncludeIdInDisplay;
-
-private slots:
-	void accountUpdated(Account account);
-	void accountAboutToBeRegistered(Account account);
-	void accountRegistered(Account account);
-	void accountAboutToBeUnregistered(Account account);
-	void accountUnregistered(Account account);
-
 public:
-	explicit AccountsModel(QObject *parent = 0);
+	explicit AccountsModel(AccountManager *accountManager, QObject *parent = nullptr);
 	virtual ~AccountsModel();
 
 	virtual int columnCount(const QModelIndex &parent) const;
 	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
 
 	virtual QVariant data(const QModelIndex &index, int role) const;
-	virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
 
 	Account account(const QModelIndex &index) const;
 	int accountIndex(Account account) const;
-	virtual QModelIndex indexForValue(const QVariant &value) const;
+	virtual QModelIndexList indexListForValue(const QVariant &value) const;
 
 	void setIncludeIdInDisplay(bool includeIdInDisplay);
 
-};
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<IconsManager> m_iconsManager;
 
-#endif // ACCOUNTS_MODEL
+	bool m_includeIdInDisplay;
+
+private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+
+	void accountUpdated(Account account);
+	void accountAboutToBeRegistered(Account account);
+	void accountRegistered(Account account);
+	void accountAboutToBeUnregistered(Account account);
+	void accountUnregistered(Account account);
+
+};
