@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,25 +19,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QTimer>
-
-#include "avatars/avatar-job-runner.h"
-#include "contacts/contact.h"
-
 #include "avatar-job-manager.h"
 
-AvatarJobManager * AvatarJobManager::Instance = 0;
+#include "avatars/avatar-job-runner.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "contacts/contact.h"
+#include "core/injected-factory.h"
 
-AvatarJobManager * AvatarJobManager::instance()
-{
-	if (!Instance)
-		Instance = new AvatarJobManager();
+#include <QtCore/QTimer>
 
-	return Instance;
-}
-
-AvatarJobManager::AvatarJobManager() :
-		Mutex(QMutex::Recursive), IsJobRunning(false)
+AvatarJobManager::AvatarJobManager(QObject *parent) :
+		QObject{parent},
+		Mutex{QMutex::Recursive},
+		IsJobRunning{false}
 {
 }
 
@@ -49,6 +39,16 @@ AvatarJobManager::~AvatarJobManager()
 {
 }
 
+void AvatarJobManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void AvatarJobManager::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 void AvatarJobManager::scheduleJob()
 {
 	QMutexLocker locker(&mutex());
@@ -69,10 +69,13 @@ void AvatarJobManager::runJob()
 	if (!hasJob())
 		return;
 
+	if (!m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowAvatars", true))
+		return;
+
 	IsJobRunning = true;
 
-	Contact contact = nextJob();
-	AvatarJobRunner *runner = new AvatarJobRunner(contact, this);
+	auto contact = nextJob();
+	auto runner = m_injectedFactory->makeInjected<AvatarJobRunner>(contact, this);
 	connect(runner, SIGNAL(jobFinished(bool)), this, SLOT(jobFinished()));
 	runner->runJob();
 }
