@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QTimer>
+#include "avatar-job-runner.h"
 
 #include "avatars/avatar-manager.h"
 #include "avatars/avatar.h"
@@ -27,7 +27,7 @@
 #include "protocols/services/avatar-downloader.h"
 #include "protocols/services/avatar-service.h"
 
-#include "avatar-job-runner.h"
+#include <QtCore/QTimer>
 
 AvatarJobRunner::AvatarJobRunner(const Contact &contact, QObject *parent) :
 		QObject(parent), MyContact(contact), Timer(0)
@@ -38,6 +38,11 @@ AvatarJobRunner::~AvatarJobRunner()
 {
 }
 
+void AvatarJobRunner::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
 void AvatarJobRunner::runJob()
 {
 	AvatarService *service = AvatarService::fromAccount(MyContact.contactAccount());
@@ -71,7 +76,7 @@ void AvatarJobRunner::avatarDownloaded(bool ok, QImage avatar)
 	if (Timer)
 		Timer->stop();
 
-	Avatar contactAvatar = AvatarManager::instance()->byContact(MyContact, ActionCreateAndAdd);
+	Avatar contactAvatar = m_avatarManager->byContact(MyContact, ActionCreateAndAdd);
 	contactAvatar.setLastUpdated(QDateTime::currentDateTime());
 	contactAvatar.setNextUpdate(QDateTime::fromTime_t(QDateTime::currentDateTime().toTime_t() + 7200));
 	contactAvatar.setPixmap(QPixmap::fromImage(avatar));
