@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,8 +22,10 @@
 #include <QtCore/QFile>
 #include <QtCore/QTimer>
 
+#include "accounts/account-manager.h"
 #include "accounts/account.h"
 #include "avatars/avatar-job-manager.h"
+#include "avatars/avatar-storage.h"
 #include "avatars/avatar.h"
 #include "configuration/configuration-manager.h"
 #include "contacts/contact-manager.h"
@@ -37,42 +37,53 @@
 
 #include "avatar-manager.h"
 
-AvatarManager * AvatarManager::Instance = 0;
-
-AvatarManager * AvatarManager::instance()
-{
-	if (!Instance)
-	{
-		Instance = new AvatarManager();
-		Instance->init();
-	}
-
-	return Instance;
-}
-
-AvatarManager::AvatarManager() :
+AvatarManager::AvatarManager(QObject *parent) :
+		SimpleManager<Avatar>{parent},
 		UpdateTimer{nullptr}
 {
 }
 
 AvatarManager::~AvatarManager()
 {
-	triggerAllAccountsUnregistered();
-	disconnect(ContactManager::instance(), 0, this, 0);
+}
+
+void AvatarManager::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void AvatarManager::setAvatarJobManager(AvatarJobManager *avatarJobManager)
+{
+	m_avatarJobManager = avatarJobManager;
+}
+
+void AvatarManager::setAvatarStorage(AvatarStorage *avatarStorage)
+{
+	m_avatarStorage = avatarStorage;
+}
+
+void AvatarManager::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
 }
 
 void AvatarManager::init()
 {
-	triggerAllAccountsRegistered();
+	triggerAllAccountsRegistered(m_accountManager);
 
 	UpdateTimer = new QTimer(this);
-	UpdateTimer->setInterval(5 * 60 * 1000); // 5 minutes
+	UpdateTimer->setInterval(30 * 60 * 1000); // half an hour
 	connect(UpdateTimer, SIGNAL(timeout()), this, SLOT(updateAvatars()));
-	connect(ContactManager::instance(), SIGNAL(contactAdded(Contact)), this, SLOT(contactAdded(Contact)));
+	connect(m_contactManager, SIGNAL(contactAdded(Contact)), this, SLOT(contactAdded(Contact)));
 
 	UpdateTimer->start();
 }
 
+void AvatarManager::done()
+{
+	triggerAllAccountsUnregistered(m_accountManager);
+}
+
 void AvatarManager::itemAboutToBeAdded(Avatar item)
 {
 	emit avatarAboutToBeAdded(item);
@@ -96,6 +107,11 @@ void AvatarManager::itemRemoved(Avatar item)
 	emit avatarRemoved(item);
 }
 
+Avatar AvatarManager::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+{
+	return m_avatarStorage->loadStubFromStorage(storagePoint);
+}
+
 void AvatarManager::accountRegistered(Account account)
 {
 	QMutexLocker locker(&mutex());
@@ -114,9 +130,14 @@ void AvatarManager::contactAdded(Contact contact)
 {
 	QMutexLocker locker(&mutex());
 
-	Protocol *protocol = contact.contactAccount().protocolHandler();
-	if (protocol && protocol->isConnected())
-		updateAvatar(contact, true);
+	auto protocol = contact.contactAccount().protocolHandler();
+	if (!protocol || !protocol->isConnected() || !protocol->avatarService())
+		return;
+
+	if (protocol->avatarService()->eventBasedUpdates())
+		return;
+
+	updateAvatar(contact, true);
 }
 
 bool AvatarManager::needUpdate(const Contact &contact)
@@ -150,16 +171,36 @@ void AvatarManager::updateAvatar(const Contact &contact, bool force)
 	if (!force && !needUpdate(contact))
 		return;
 
-	AvatarJobManager::instance()->addJob(contact);
+	m_avatarJobManager->addJob(contact);
+}
+
+void AvatarManager::removeAvatar(const Contact &contact)
+{
+	auto avatar = byContact(contact, ActionReturnNull);
+	if (!avatar)
+		return;
+
+	avatar.setLastUpdated(QDateTime::currentDateTime());
+	avatar.setNextUpdate(QDateTime::fromTime_t(QDateTime::currentDateTime().toTime_t() + 7200));
+	avatar.setPixmap(QPixmap{});
 }
 
 void AvatarManager::updateAvatars()
 {
 	QMutexLocker locker(&mutex());
 
-	foreach (const Contact &contact, ContactManager::instance()->items())
+	foreach (const Contact &contact, m_contactManager->items())
 		if (!contact.isAnonymous())
+		{
+			auto account = contact.contactAccount();
+			if (!account || !account.protocolHandler() || !account.protocolHandler()->avatarService())
+				continue;
+
+			if (account.protocolHandler()->avatarService()->eventBasedUpdates())
+				continue;
+
 			updateAvatar(contact);
+		}
 }
 
 void AvatarManager::updateAccountAvatars()
@@ -167,10 +208,13 @@ void AvatarManager::updateAccountAvatars()
 	QMutexLocker locker(&mutex());
 
 	Account account(sender());
-	if (!account)
+	if (!account || !account.protocolHandler() || !account.protocolHandler()->avatarService())
 		return;
 
-	foreach (const Contact &contact, ContactManager::instance()->contacts(account))
+	if (account.protocolHandler()->avatarService()->eventBasedUpdates())
+		return;
+
+	foreach (const Contact &contact, m_contactManager->contacts(account))
 		if (!contact.isAnonymous())
 			updateAvatar(contact, true);
 }
@@ -201,7 +245,7 @@ Avatar AvatarManager::byBuddy(Buddy buddy, NotFoundAction action)
 	if (ActionReturnNull == action)
 		return Avatar::null;
 
-	Avatar avatar = Avatar::create();
+	auto avatar = m_avatarStorage->create();
 	buddy.setBuddyAvatar(avatar);
 
 	if (ActionCreateAndAdd == action)
@@ -218,7 +262,7 @@ Avatar AvatarManager::byContact(Contact contact, NotFoundAction action)
 	if (ActionReturnNull == action)
 		return Avatar::null;
 
-	Avatar avatar = Avatar::create();
+	auto avatar = m_avatarStorage->create();
 	contact.setContactAvatar(avatar);
 
 	if (ActionCreateAndAdd == action)
