@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,40 +19,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtGui/QImageReader>
+#include "avatar-shared.h"
 
 #include "avatars/avatar-manager.h"
 #include "buddies/buddy.h"
 #include "contacts/contact.h"
 #include "misc/change-notifier.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 
-#include "avatar-shared.h"
-
-AvatarShared * AvatarShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	AvatarShared *result = loadFromStorage(storagePoint);
-	result->loadStub();
-
-	return result;
-}
-
-AvatarShared * AvatarShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	AvatarShared *result = new AvatarShared();
-	result->setStorage(storagePoint);
-
-	return result;
-}
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtGui/QImageReader>
 
 AvatarShared::AvatarShared(const QUuid &uuid) :
 		Shared(uuid)
 {
-	AvatarsDir = KaduPaths::instance()->profilePath() + QLatin1String("avatars/");
-
-	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
 }
 
 AvatarShared::~AvatarShared()
@@ -61,14 +41,31 @@ AvatarShared::~AvatarShared()
 	ref.ref();
 }
 
+void AvatarShared::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void AvatarShared::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void AvatarShared::init()
+{
+	AvatarsDir = m_pathsProvider->profilePath() + QStringLiteral("avatars/");
+
+	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
+}
+
 StorableObject * AvatarShared::storageParent()
 {
-	return AvatarManager::instance();
+	return m_avatarManager;
 }
 
 QString AvatarShared::storageNodeName()
 {
-	return QLatin1String("Avatar");
+	return QStringLiteral("Avatar");
 }
 
 QString AvatarShared::filePath()
@@ -142,9 +139,9 @@ void AvatarShared::storeAvatar()
 	storeValue("LastUpdated", LastUpdated);
 	storeValue("NextUpdate", NextUpdate);
 
-	QDir avatarsDir(KaduPaths::instance()->profilePath() + QLatin1String("avatars"));
+	QDir avatarsDir(m_pathsProvider->profilePath() + QStringLiteral("avatars"));
 	if (!avatarsDir.exists())
-		avatarsDir.mkpath(QLatin1String("."));
+		avatarsDir.mkpath(QStringLiteral("."));
 
 	if (Pixmap.isNull())
 		QFile::remove(filePath());
@@ -172,9 +169,9 @@ void AvatarShared::storeSmallPixmap()
 	if (!isValidStorage())
 		return;
 
-	QDir avatarsDir(KaduPaths::instance()->profilePath() + QLatin1String("avatars"));
+	QDir avatarsDir(m_pathsProvider->profilePath() + QStringLiteral("avatars"));
 	if (!avatarsDir.exists())
-		avatarsDir.mkpath(QLatin1String("."));
+		avatarsDir.mkpath(QStringLiteral("."));
 
 	SmallFilePath = filePathToSmallFilePath(filePath());
 
