@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +20,7 @@
  */
 
 #include "contacts/contact.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 
 #include "avatar.h"
 
@@ -30,21 +28,6 @@ KaduSharedBaseClassImpl(Avatar)
 
 Avatar Avatar::null;
 
-Avatar Avatar::create()
-{
-	return new AvatarShared();
-}
-
-Avatar Avatar::loadStubFromStorage(const std::shared_ptr<StoragePoint> &avatarStoragePoint)
-{
-	return AvatarShared::loadStubFromStorage(avatarStoragePoint);
-}
-
-Avatar Avatar::loadFromStorage(const std::shared_ptr<StoragePoint> &avatarStoragePoint)
-{
-	return AvatarShared::loadFromStorage(avatarStoragePoint);
-}
-
 Avatar::Avatar()
 {
 }
