@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -39,14 +37,11 @@ class KADUAPI Avatar : public SharedBase<AvatarShared>
 	KaduSharedBaseClass(Avatar)
 
 public:
-	static Avatar create();
-	static Avatar loadStubFromStorage(const QSharedPointer<StoragePoint> &storage);
-	static Avatar loadFromStorage(const QSharedPointer<StoragePoint> &storage);
 	static Avatar null;
 
 	Avatar();
 	Avatar(AvatarShared *data);
-	Avatar(QObject *data);
+	explicit Avatar(QObject *data);
 	Avatar(const Avatar &copy);
 	virtual ~Avatar();
 
