@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2008, 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,35 +20,23 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "accounts/account.h"
+#include "buddy-manager.h"
 
+#include "accounts/account.h"
 #include "buddies/buddy-list.h"
+#include "buddies/buddy-storage.h"
+#include "configuration/configuration-api.h"
 #include "configuration/configuration-manager.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
 #include "core/core.h"
-#include "protocols/roster.h"
+#include "roster/roster.h"
 #include "storage/storage-point.h"
-
 #include "debug.h"
 
-#include "buddy-manager.h"
-
-BuddyManager * BuddyManager::Instance = 0;
-
-BuddyManager * BuddyManager::instance()
-{
-	if (0 == Instance)
-	{
-		Instance = new BuddyManager();
-		Instance->init();
-	}
-
-	return Instance;
-}
-
-BuddyManager::BuddyManager()
+BuddyManager::BuddyManager(QObject *parent) :
+		SimpleManager<Buddy>{parent}
 {
 }
 
@@ -57,43 +44,34 @@ BuddyManager::~BuddyManager()
 {
 }
 
-void BuddyManager::init()
+void BuddyManager::setBuddyStorage(BuddyStorage *buddyStorage)
 {
-	QMutexLocker locker(&mutex());
-
-	int itemsSize = items().size();
-	QDomElement buddiesNode = xml_config_file->getNode("Buddies", XmlConfigFile::ModeFind);
-	QDomElement oldContactsNode = xml_config_file->getNode("OldContacts", XmlConfigFile::ModeFind);
-	if (oldContactsNode.isNull() && (buddiesNode.isNull() || (itemsSize == 0 && !buddiesNode.hasAttribute("imported"))))
-	{
-		importConfiguration(xml_config_file);
-		buddiesNode.setAttribute("imported", "true");
-	}
+	m_buddyStorage = buddyStorage;
 }
 
-void BuddyManager::importConfiguration(XmlConfigFile *configurationStorage)
+void BuddyManager::setConfigurationManager(ConfigurationManager *configurationManager)
 {
-	QMutexLocker locker(&mutex());
+	m_configurationManager = configurationManager;
+}
 
-	QDomElement contactsNode = configurationStorage->getNode("Contacts", XmlConfigFile::ModeFind);
-	if (contactsNode.isNull())
-		return;
+void BuddyManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
 
-	contactsNode.setTagName("OldContacts");
-	QVector<QDomElement> contactElements = configurationStorage->getNodes(contactsNode, "Contact");
-	foreach (const QDomElement &contactElement, contactElements)
-	{
-		Buddy buddy = Buddy::create();
-		buddy.importConfiguration(contactElement);
+void BuddyManager::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
 
-		addItem(buddy);
-	}
+void BuddyManager::init()
+{
+	m_configurationManager->registerStorableObject(this);
+}
 
-	// OldContacts is no longer needed
-	contactsNode.parentNode().removeChild(contactsNode);
-
-	// flush configuration to save all changes
-	ConfigurationManager::instance()->flush();
+void BuddyManager::done()
+{
+	m_configurationManager->unregisterStorableObject(this);
 }
 
 void BuddyManager::load()
@@ -103,6 +81,11 @@ void BuddyManager::load()
 	SimpleManager<Buddy>::load();
 }
 
+Buddy BuddyManager::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+{
+	return m_buddyStorage->loadStubFromStorage(storagePoint);
+}
+
 void BuddyManager::itemAboutToBeAdded(Buddy buddy)
 {
 	QMutexLocker locker(&mutex());
@@ -180,7 +163,7 @@ void BuddyManager::mergeBuddies(Buddy destination, Buddy source)
 	// each item that stores pointer to "source" will now use the same uuid as "destination"
 	source.data()->setUuid(destination.uuid());
 
-	ConfigurationManager::instance()->flush();
+	m_configurationManager->flush();
 }
 
 Buddy BuddyManager::byDisplay(const QString &display, NotFoundAction action)
@@ -201,7 +184,7 @@ Buddy BuddyManager::byDisplay(const QString &display, NotFoundAction action)
 	if (ActionReturnNull == action)
 		return Buddy::null;
 
-	Buddy buddy = Buddy::create();
+	auto buddy = m_buddyStorage->create();
 	buddy.setDisplay(display);
 
 	if (ActionCreateAndAdd == action)
@@ -216,7 +199,7 @@ Buddy BuddyManager::byId(Account account, const QString &id, NotFoundAction acti
 
 	ensureLoaded();
 
-	Contact contact = ContactManager::instance()->byId(account, id, action);
+	auto contact = m_contactManager->byId(account, id, action);
 	if (contact.isNull())
 		return Buddy::null;
 
@@ -236,7 +219,7 @@ Buddy BuddyManager::byContact(Contact contact, NotFoundAction action)
 		return contact.ownerBuddy();
 
 	if (!contact.ownerBuddy())
-		contact.setOwnerBuddy(Buddy::create());
+		contact.setOwnerBuddy(m_buddyStorage->create());
 
 	if (ActionCreateAndAdd == action)
 		addItem(contact.ownerBuddy());
@@ -251,13 +234,13 @@ Buddy BuddyManager::byUuid(const QUuid &uuid)
 	ensureLoaded();
 
 	if (uuid.isNull())
-		return Buddy::create();
+		return m_buddyStorage->create();
 
 	foreach (const Buddy &buddy, items())
 		if (buddy.uuid() == uuid)
 			return buddy;
 
-	return Buddy::create();
+	return m_buddyStorage->create();
 }
 
 void BuddyManager::removeBuddyIfEmpty(Buddy buddy, bool checkOnlyForContacts)
