@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,28 +26,15 @@
 #include "chat/chat-manager.h"
 #include "chat/chat.h"
 #include "contacts/contact-set.h"
-#include "core/core.h"
-#include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/chat-widget/chat-widget-repository.h"
+#include "gui/widgets/chat-widget/chat-widget.h"
 #include "status/status-container.h"
 #include "buddy.h"
 
 #include "buddies/buddy-preferred-manager.h"
 
-BuddyPreferredManager *BuddyPreferredManager::m_instance = 0;
-
-BuddyPreferredManager *BuddyPreferredManager::instance()
-{
-	if (0 == m_instance)
-	{
-		m_instance = new BuddyPreferredManager();
-		m_instance->setChatWidgetRepository(Core::instance()->chatWidgetRepository());
-	}
-
-	return m_instance;
-}
-
-BuddyPreferredManager::BuddyPreferredManager()
+BuddyPreferredManager::BuddyPreferredManager(QObject *parent) :
+		QObject{parent}
 {
 }
 
@@ -55,6 +42,11 @@ BuddyPreferredManager::~BuddyPreferredManager()
 {
 }
 
+void BuddyPreferredManager::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
 void BuddyPreferredManager::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
 {
 	m_chatWidgetRepository = chatWidgetRepository;
@@ -75,9 +67,9 @@ Contact BuddyPreferredManager::preferredContact(const Buddy &buddy, const Accoun
 
 Contact BuddyPreferredManager::preferredContact2(const Buddy &buddy)
 {
-	Contact contact = BuddyPreferredManager::instance()->preferredContactByUnreadMessages(buddy);
+	auto contact = preferredContactByUnreadMessages(buddy);
 	if (!contact)
-		contact = BuddyPreferredManager::instance()->preferredContact(buddy);
+		contact = preferredContact(buddy);
 
 	return contact;
 }
@@ -193,7 +185,7 @@ bool BuddyPreferredManager::isAccountCommon(const Account &account, const BuddyS
 
 Account BuddyPreferredManager::getCommonAccount(const BuddySet &buddies)
 {
-	foreach (const Account &account, AccountManager::instance()->items())
+	foreach (const Account &account, m_accountManager->items())
 		if (isAccountCommon(account, buddies))
 			return account;
 
