@@ -1,13 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,37 +21,31 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_PREFERRED_MANAGER_H
-#define BUDDY_PREFERRED_MANAGER_H
-
-#include <QtCore/QMap>
-#include <QtCore/QObject>
+#pragma once
 
 #include "accounts/account.h"
 #include "buddies/buddy.h"
 #include "contacts/contact.h"
 #include "message/message.h"
 
-class Account;
+#include <QtCore/QMap>
+#include <QtCore/QObject>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
 class Buddy;
 class BuddySet;
+class ChatWidgetRepository;
 class Contact;
 class ContactSet;
 
 class KADUAPI BuddyPreferredManager : public QObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(BuddyPreferredManager)
-
-	static BuddyPreferredManager *Instance;
-
-	//QMap<Buddy, Contact> Preferreds;
-
-	BuddyPreferredManager();
-	~BuddyPreferredManager();
 
 public:
-	static BuddyPreferredManager *instance();
+	Q_INVOKABLE explicit BuddyPreferredManager(QObject *parent = nullptr);
+	virtual ~BuddyPreferredManager();
 
 	Contact preferredContact(const Buddy &buddy, const Account &account, bool includechats = true);
 	Contact preferredContact(const Buddy &buddy, bool includechats = true);
@@ -75,6 +66,15 @@ public:
 signals:
 	void buddyUpdated(const Buddy &buddy);
 
-};
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<ChatWidgetRepository> m_chatWidgetRepository;
 
-#endif // BUDDY_PREFERRED_MANAGER_H
+	bool isAccountCommon(const Account &account, const BuddySet &buddies);
+	Account getCommonAccount(const BuddySet &buddies);
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+
+};
