@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,11 +21,14 @@
  */
 
 #include "accounts/account.h"
+#include "buddies/buddy-storage.h"
+#include "contacts/contact-storage.h"
 
 #include "buddy-search-criteria.h"
 
-BuddySearchCriteria::BuddySearchCriteria() :
-		SearchBuddy(Buddy::create()), BirthYearTo(), Active(false), IgnoreResults(false)
+BuddySearchCriteria::BuddySearchCriteria(QObject *parent) :
+		QObject{parent},
+		BirthYearTo(), Active(false), IgnoreResults(false)
 {
 }
 
@@ -34,6 +36,21 @@ BuddySearchCriteria::~BuddySearchCriteria()
 {
 }
 
+void BuddySearchCriteria::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void BuddySearchCriteria::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
+void BuddySearchCriteria::init()
+{
+	SearchBuddy = m_buddyStorage->create();
+}
+
 void BuddySearchCriteria::reqUin(Account account, const QString &uin)
 {
 	// TODO ???
@@ -41,7 +58,7 @@ void BuddySearchCriteria::reqUin(Account account, const QString &uin)
 	Contact contact = contactslist.isEmpty() ? Contact::null : contactslist.at(0);
 	if (!contact)
 	{
-		contact = Contact::create();
+		contact = m_contactStorage->create();
 		contact.setContactAccount(account);
 		contact.setOwnerBuddy(SearchBuddy);
 	}
@@ -86,7 +103,7 @@ void BuddySearchCriteria::reqActive()
 
 void BuddySearchCriteria::clearData()
 {
-	SearchBuddy = Buddy::create();
+	SearchBuddy = m_buddyStorage->create();
 	BirthYearFrom.clear();
 	BirthYearTo.clear();
 	Active = false;
