@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,23 +18,32 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_SEARCH_CRITERIA_H
-#define BUDDY_SEARCH_CRITERIA_H
+#pragma once
 
 #include "buddies/buddy.h"
 #include "contacts/contact.h"
 
-struct KADUAPI BuddySearchCriteria
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class BuddyStorage;
+class ContactStorage;
+
+class KADUAPI BuddySearchCriteria : public QObject
 {
+	Q_OBJECT
+
+public:
+	explicit BuddySearchCriteria(QObject *parent = nullptr);
+	virtual ~BuddySearchCriteria();
+
 	Buddy SearchBuddy;
 	QString BirthYearFrom;
 	QString BirthYearTo;
 	bool Active;
 	bool IgnoreResults;
 
-	BuddySearchCriteria();
-	virtual ~BuddySearchCriteria();
-
 	void reqUin(Account account, const QString& uin);
 	void reqFirstName(const QString& firstName);
 	void reqLastName(const QString& lastName);
@@ -47,6 +55,13 @@ struct KADUAPI BuddySearchCriteria
 
 	void clearData();
 
-};
+private:
+	QPointer<BuddyStorage> m_buddyStorage;
+	QPointer<ContactStorage> m_contactStorage;
 
-#endif // BUDDY_SEARCH_CRITERIA_H
+private slots:
+	INJEQT_SET void setBuddyStorage(BuddyStorage *buddyStorage);
+	INJEQT_SET void setContactStorage(ContactStorage *contactStorage);
+	INJEQT_INIT void init();
+
+};
