@@ -1,12 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2008, 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,8 +21,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QVariant>
-#include <QtXml/QDomNamedNodeMap>
+#include "buddy-shared.h"
 
 #include "accounts/account.h"
 #include "avatars/avatar-manager.h"
@@ -32,38 +29,25 @@
 #include "buddies/buddy-manager.h"
 #include "buddies/group-manager.h"
 #include "buddies/group.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "misc/change-notifier.h"
-#include "protocols/services/roster/roster-entry.h"
+#include "roster/roster-entry-state.h"
+#include "roster/roster-entry.h"
 #include "storage/storage-point.h"
 
-#include "buddy-shared.h"
-
-BuddyShared * BuddyShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &buddyStoragePoint)
-{
-	BuddyShared *result = loadFromStorage(buddyStoragePoint);
-	result->loadStub();
-	return result;
-}
-
-BuddyShared * BuddyShared::loadFromStorage(const std::shared_ptr<StoragePoint> &buddyStoragePoint)
-{
-	BuddyShared *result = new BuddyShared();
-	result->setStorage(buddyStoragePoint);
-	return result;
-}
+#include <QtCore/QVariant>
+#include <QtXml/QDomNamedNodeMap>
 
 BuddyShared::BuddyShared(const QUuid &uuid) :
 		Shared(uuid), CollectingGarbage(false),
 		BirthYear(0), Gender(GenderUnknown), PreferHigherStatuses(true),
 		Anonymous(true), Temporary(false), Blocked(false), OfflineTo(false)
 {
-	BuddyAvatar = new Avatar();
-
-	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
 }
 
 BuddyShared::~BuddyShared()
@@ -73,6 +57,33 @@ BuddyShared::~BuddyShared()
 	BuddyAvatar = 0;
 }
 
+void BuddyShared::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void BuddyShared::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyShared::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
+}
+
+void BuddyShared::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void BuddyShared::init()
+{
+	BuddyAvatar = new Avatar();
+
+	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
+}
+
 void BuddyShared::collectGarbage()
 {
 	if (CollectingGarbage)
@@ -82,34 +93,26 @@ void BuddyShared::collectGarbage()
 
 	// 1 is for current Buddy
 	const int numberOfReferences = 1 + Contacts.length();
-#if QT_VERSION >= 0x050000
 	if (numberOfReferences != ref.load())
-#else
-	if (numberOfReferences != (int)ref)
-#endif
 	{
 		CollectingGarbage = false;
 		return;
 	}
 
-	foreach (const Contact &contact, Contacts)
+	for (auto &&contact : Contacts)
 	{
 		Q_ASSERT(!contact.isNull());
 
 		// 1 is for current BuddyShared
 		const int contactNumberOfReferences = 1;
-#if QT_VERSION >= 0x050000
 		if (contactNumberOfReferences != contact.data()->ref.load())
-#else
-		if (contactNumberOfReferences != (int)(contact.data()->ref))
-#endif
 		{
 			CollectingGarbage = false;
 			return;
 		}
 	}
 
-	foreach (const Contact &contact, Contacts)
+	for (auto &&contact : Contacts)
 		contact.setOwnerBuddy(Buddy::null);
 
 	CollectingGarbage = false;
@@ -117,12 +120,12 @@ void BuddyShared::collectGarbage()
 
 StorableObject * BuddyShared::storageParent()
 {
-	return BuddyManager::instance();
+	return m_buddyManager;
 }
 
 QString BuddyShared::storageNodeName()
 {
-	return QLatin1String("Buddy");
+	return QStringLiteral("Buddy");
 }
 
 #define ImportProperty(name, old_name) \
@@ -148,8 +151,8 @@ void BuddyShared::importConfiguration(const QDomElement &parent)
 void BuddyShared::importConfiguration()
 {
 	QStringList groups = CustomData["groups"].split(',', QString::SkipEmptyParts);
-	foreach (const QString &group, groups)
-		doAddToGroup(GroupManager::instance()->byName(group));
+	for (auto &&group : groups)
+		doAddToGroup(m_groupManager->byName(group));
 
 	CustomData.remove("groups");
 
@@ -169,10 +172,10 @@ void BuddyShared::load()
 
 	Shared::load();
 
-	XmlConfigFile *configurationStorage = storage()->storage();
+	ConfigurationApi *configurationStorage = storage()->storage();
 	QDomElement parent = storage()->point();
 
-	QDomElement customDataValues = configurationStorage->getNode(parent, "CustomDataValues", XmlConfigFile::ModeFind);
+	QDomElement customDataValues = configurationStorage->getNode(parent, "CustomDataValues", ConfigurationApi::ModeFind);
 	QDomNodeList customDataValuesList = customDataValues.elementsByTagName("CustomDataValue");
 
 	int count = customDataValuesList.count();
@@ -189,7 +192,7 @@ void BuddyShared::load()
 	}
 
 	Groups.clear();
-	QDomElement groupsNode = configurationStorage->getNode(parent, "ContactGroups", XmlConfigFile::ModeFind);
+	QDomElement groupsNode = configurationStorage->getNode(parent, "ContactGroups", ConfigurationApi::ModeFind);
 	if (!groupsNode.isNull())
 	{
 		QDomNodeList groupsList = groupsNode.elementsByTagName("Group");
@@ -200,11 +203,11 @@ void BuddyShared::load()
 			QDomElement groupElement = groupsList.at(i).toElement();
 			if (groupElement.isNull())
 				continue;
-			doAddToGroup(GroupManager::instance()->byUuid(groupElement.text()));
+			doAddToGroup(m_groupManager->byUuid(groupElement.text()));
 		}
 	}
 
-	setBuddyAvatar(AvatarManager::instance()->byUuid(loadValue<QString>("Avatar")));
+	setBuddyAvatar(m_avatarManager->byUuid(loadValue<QString>("Avatar")));
 	Display = loadValue<QString>("Display");
 	FirstName = loadValue<QString>("FirstName");
 	LastName = loadValue<QString>("LastName");
@@ -231,10 +234,10 @@ void BuddyShared::store()
 
 	Shared::store();
 
-	XmlConfigFile *configurationStorage = storage()->storage();
+	ConfigurationApi *configurationStorage = storage()->storage();
 	QDomElement parent = storage()->point();
 
-	QDomElement customDataValues = configurationStorage->getNode(parent, "CustomDataValues", XmlConfigFile::ModeCreate);
+	QDomElement customDataValues = configurationStorage->getNode(parent, "CustomDataValues", ConfigurationApi::ModeCreate);
 
 	for (QMap<QString, QString>::const_iterator it = CustomData.constBegin(), end = CustomData.constEnd(); it != end; ++it)
 		configurationStorage->createNamedTextNode(customDataValues, "CustomDataValue", it.key(), it.value());
@@ -268,8 +271,8 @@ void BuddyShared::store()
 
 	if (!Groups.isEmpty())
 	{
-		QDomElement groupsNode = configurationStorage->getNode(parent, "ContactGroups", XmlConfigFile::ModeCreate);
-		foreach (const Group &group, Groups)
+		QDomElement groupsNode = configurationStorage->getNode(parent, "ContactGroups", ConfigurationApi::ModeCreate);
+		for (auto &&group : Groups)
 			configurationStorage->appendTextNode(groupsNode, "Group", group.uuid().toString());
 	}
 	else
@@ -290,7 +293,7 @@ void BuddyShared::aboutToBeRemoved()
 	Contacts.clear();
 	Groups.clear();
 
-	AvatarManager::instance()->removeItem(*BuddyAvatar);
+	m_avatarManager->removeItem(*BuddyAvatar);
 	setBuddyAvatar(Avatar::null);
 }
 
@@ -322,6 +325,7 @@ void BuddyShared::addContact(const Contact &contact)
 
 	emit contactAdded(contact);
 
+	connect(contact, SIGNAL(priorityUpdated()), &changeNotifier(), SLOT(notify()));
 	changeNotifier().notify();
 }
 
@@ -332,6 +336,8 @@ void BuddyShared::removeContact(const Contact &contact)
 	if (!contact || !Contacts.contains(contact))
 		return;
 
+	disconnect(contact, SIGNAL(priorityUpdated()), &changeNotifier(), SLOT(notify()));
+
 	emit contactAboutToBeRemoved(contact);
 	Contacts.removeAll(contact);
 	emit contactRemoved(contact);
@@ -346,7 +352,7 @@ QVector<Contact> BuddyShared::contacts(const Account &account)
 	ensureLoaded();
 
 	QVector<Contact> contacts;
-	foreach (const Contact &contact, Contacts)
+	for (auto &&contact :  Contacts)
 		if (contact.contactAccount() == account)
 			contacts.append(contact);
 
@@ -385,7 +391,7 @@ void BuddyShared::sortContacts()
 void BuddyShared::normalizePriorities()
 {
 	int priority = 0;
-	foreach (const Contact &contact, Contacts)
+	for (auto &&contact : Contacts)
 		contact.setPriority(priority++);
 }
 
@@ -432,11 +438,11 @@ void BuddyShared::setGroups(const QSet<Group> &groups)
 
 	QSet<Group> groupsToRemove = Groups;
 
-	foreach (const Group &group, groups)
+	for (auto &&group : groups)
 		if (!groupsToRemove.remove(group))
 			doAddToGroup(group);
 
-	foreach (const Group &group, groupsToRemove)
+	for (auto &&group : groupsToRemove)
 		doRemoveFromGroup(group);
 
 	changeNotifier().notify();
@@ -454,7 +460,7 @@ bool BuddyShared::showInAllGroup()
 {
 	ensureLoaded();
 
-	foreach (const Group &group, Groups)
+	for (auto &&group : Groups)
 		if (group && !group.showInAllGroup())
 			return false;
 
@@ -526,9 +532,9 @@ void BuddyShared::markContactsDirty()
 {
 	ensureLoaded();
 
-	foreach (const Contact &contact, Contacts)
+	for (auto &&contact : Contacts)
 		if (contact.rosterEntry())
-			contact.rosterEntry()->setState(RosterEntryDesynchronized);
+			contact.rosterEntry()->setHasLocalChanges();
 }
 
 quint16 BuddyShared::unreadMessagesCount()
@@ -536,7 +542,7 @@ quint16 BuddyShared::unreadMessagesCount()
 	ensureLoaded();
 
 	quint16 result = 0;
-	foreach (const Contact &contact, Contacts)
+	for (auto &&contact : Contacts)
 		result += contact.unreadMessagesCount();
 
 	return result;
@@ -545,7 +551,7 @@ quint16 BuddyShared::unreadMessagesCount()
 std::shared_ptr<StoragePoint> BuddyShared::createStoragePoint()
 {
 	// TODO: fix this, it is only a workaround for an empty buddy on list
-	if (Core::instance()->myself() == Buddy(this))
+	if (m_myself->buddy() == Buddy(this))
 		return {};
 	else
 		return Shared::createStoragePoint();
