@@ -1,11 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,41 +21,30 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "accounts/account-storage.h"
 #include "accounts/account.h"
 #include "avatars/avatar-manager.h"
 #include "avatars/avatar.h"
 #include "buddies/buddy-manager.h"
 #include "buddies/group.h"
+#include "configuration/configuration-api.h"
 #include "configuration/configuration-manager.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration.h"
 #include "contacts/contact.h"
 #include "core/core.h"
+#include "core/injected-factory.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
 
 #include "buddy.h"
+#include <QtWidgets/qapplication.h>
 
 KaduSharedBaseClassImpl(Buddy)
 
 Buddy Buddy::null;
 
-Buddy Buddy::create()
-{
-	return new BuddyShared();
-}
-
-Buddy Buddy::loadStubFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint)
-{
-	return BuddyShared::loadStubFromStorage(contactStoragePoint);
-}
-
-Buddy Buddy::loadFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint)
-{
-	return BuddyShared::loadFromStorage(contactStoragePoint);
-}
-
 Buddy::Buddy()
 {
 }
@@ -218,44 +206,6 @@ QString Buddy::display() const
 	return result;
 }
 
-Buddy Buddy::dummy()
-{
-	Buddy example = Buddy::create();
-
-	example.setFirstName("Mark");
-	example.setLastName("Smith");
-	example.setNickName("Jimbo");
-	example.setDisplay("Jimbo");
-	example.setMobile("+48123456789");
-	example.setEmail("jimbo@mail.server.net");
-	example.setHomePhone("+481234567890");
-
-	Identity identity = Identity::create();
-	identity.setName(identity.data()->tr("Example identity"));
-
-	Account account = Account::create("");
-	account.setAccountIdentity(identity);
-
-	Contact contact = Contact::create();
-	contact.setContactAccount(account);
-	contact.setOwnerBuddy(example);
-	contact.setId("999999");
-	contact.setCurrentStatus(Status(StatusTypeAway, example.data()->tr("Example description")));
-	contact.setAddress(QHostAddress(2130706433));
-	contact.setPort(80);
-
-	// this is just an example contact, do not add avatar to list
-	Avatar avatar = AvatarManager::instance()->byContact(contact, ActionCreate);
-
-	avatar.setLastUpdated(QDateTime::currentDateTime());
-	avatar.setFilePath(KaduIcon("kadu_icons/buddy0", "96x96").fullPath());
-
-	example.addContact(contact);
-	example.setAnonymous(false);
-
-	return example;
-}
-
 KaduSharedBase_PropertyDefCRW(Buddy, Avatar, buddyAvatar, BuddyAvatar, Avatar::null)
 KaduSharedBase_PropertyWriteDef(Buddy, const QString &, display, Display)
 KaduSharedBase_PropertyDefCRW(Buddy, QString, firstName, FirstName, QString())
