@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,31 +20,16 @@
  */
 
 #include "buddies/group-manager.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "misc/change-notifier.h"
 
 #include "group-shared.h"
 
-GroupShared * GroupShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	GroupShared *result = loadFromStorage(storagePoint);
-	result->loadStub();
-
-	return result;
-}
-
-GroupShared * GroupShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	GroupShared *result = new GroupShared();
-	result->setStorage(storagePoint);
-
-	return result;
-}
-
 GroupShared::GroupShared(const QUuid &uuid) :
 		Shared(uuid),
-		NotifyAboutStatusChanges(false), ShowInAllGroup(false),
-		OfflineToGroup(false), ShowIcon(false), ShowName(false),
+		NotifyAboutStatusChanges(true), ShowInAllGroup(true),
+		OfflineToGroup(false), ShowIcon(false), ShowName(true),
 		TabPosition(-1)
 {
 	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
@@ -55,20 +40,30 @@ GroupShared::~GroupShared()
 	ref.ref();
 }
 
+void GroupShared::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void GroupShared::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
+}
+
 StorableObject * GroupShared::storageParent()
 {
-	return GroupManager::instance();
+	return m_groupManager;
 }
 
 QString GroupShared::storageNodeName()
 {
-	return QLatin1String("Group");
+	return QStringLiteral("Group");
 }
 
 void GroupShared::importConfiguration(const QString &name)
 {
 	Name = name;
-	Icon = config_file.readEntry("GroupIcon", name);
+	Icon = m_configuration->deprecatedApi()->readEntry("GroupIcon", name);
 	NotifyAboutStatusChanges = true;
 	ShowInAllGroup= true;
 	OfflineToGroup= false;
