@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "storage/storage-point.h"
 
 #include "group-manager.h"
@@ -31,21 +32,6 @@ KaduSharedBaseClassImpl(Group)
 
 Group Group::null;
 
-Group Group::create()
-{
-	return new GroupShared();
-}
-
-Group Group::loadStubFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint)
-{
-	return GroupShared::loadStubFromStorage(contactStoragePoint);
-}
-
-Group Group::loadFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint)
-{
-	return GroupShared::loadFromStorage(contactStoragePoint);
-}
-
 Group::Group()
 {
 }
