@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,26 +19,46 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QVariant>
-#include <QtGui/QIcon>
+#include "buddy-data-extractor.h"
 
 #include "avatars/avatar.h"
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "model/roles.h"
 #include "talkable/talkable.h"
 
-#include "buddy-data-extractor.h"
+#include <QtCore/QVariant>
+#include <QtGui/QIcon>
+
+BuddyDataExtractor::BuddyDataExtractor(QObject *parent) :
+		QObject{parent}
+{
+}
+
+BuddyDataExtractor::~BuddyDataExtractor()
+{
+}
+
+void BuddyDataExtractor::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void BuddyDataExtractor::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
 
 QVariant BuddyDataExtractor::decoration(const Buddy &buddy)
 {
 	if (!buddy.homePhone().isEmpty() || !buddy.mobile().isEmpty())
-		return KaduIcon("phone").icon();
+		return m_iconsManager->iconByPath(KaduIcon("phone"));
 	else if (!buddy.email().isEmpty())
-		return KaduIcon("mail-message-new").icon();
+		return m_iconsManager->iconByPath(KaduIcon("mail-message-new"));
 	else
-		return KaduIcon("system-users").icon();
+		return m_iconsManager->iconByPath(KaduIcon("system-users"));
 }
 
 QVariant BuddyDataExtractor::data(const Buddy &buddy, int role)
@@ -54,7 +74,7 @@ QVariant BuddyDataExtractor::data(const Buddy &buddy, int role)
 		case AvatarRole:
 			return buddy.buddyAvatar().pixmap();
 		case StatusRole:
-			return QVariant::fromValue(BuddyPreferredManager::instance()->preferredContact(buddy, false).currentStatus());
+			return QVariant::fromValue(m_buddyPreferredManager->preferredContact(buddy, false).currentStatus());
 		case ItemTypeRole:
 			return BuddyRole;
 		case TalkableRole:
