@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
 
-#include "buddies/buddy-list-mime-data-helper.h"
+#include "buddies/buddy-list-mime-data-service.h"
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy.h"
 #include "contacts/contact-manager.h"
@@ -30,13 +30,62 @@
 #include "contacts/model/contact-data-extractor.h"
 #include "model/roles.h"
 #include "protocols/protocol.h"
+#include "talkable/talkable-converter.h"
 #include "talkable/talkable.h"
 
 #include "buddy-data-extractor.h"
 #include "buddy-list-model.h"
 
+#include <QtCore/QMimeData>
+
 BuddyListModel::BuddyListModel(QObject *parent) :
 		QAbstractItemModel(parent), Checkable(false)
+{
+}
+
+BuddyListModel::~BuddyListModel()
+{
+	setBuddyList(BuddyList());
+
+	triggerAllAccountsUnregistered(m_accountManager);
+}
+
+void BuddyListModel::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void BuddyListModel::setBuddyDataExtractor(BuddyDataExtractor *buddyDataExtractor)
+{
+	m_buddyDataExtractor = buddyDataExtractor;
+}
+
+void BuddyListModel::setBuddyListMimeDataService(BuddyListMimeDataService *buddyListMimeDataService)
+{
+	m_buddyListMimeDataService = buddyListMimeDataService;
+}
+
+void BuddyListModel::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void BuddyListModel::setContactDataExtractor(ContactDataExtractor *contactDataExtractor)
+{
+	m_contactDataExtractor = contactDataExtractor;
+}
+
+void BuddyListModel::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void BuddyListModel::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void BuddyListModel::init()
 {
 	QHash<int, QByteArray> roles;
 	roles[Qt::DisplayRole] = "display";
@@ -44,21 +93,12 @@ BuddyListModel::BuddyListModel(QObject *parent) :
 	roles[StatusIconPath] = "statusIcon";
 	setRoleNames(roles);
 
-	triggerAllAccountsRegistered();
+	triggerAllAccountsRegistered(m_accountManager);
 
-	connect(ContactManager::instance(), SIGNAL(contactUpdated(Contact)),
+	connect(m_contactManager, SIGNAL(contactUpdated(Contact)),
 	        this, SLOT(contactUpdated(Contact)), Qt::DirectConnection);
 }
 
-BuddyListModel::~BuddyListModel()
-{
-	setBuddyList(BuddyList());
-
-	triggerAllAccountsUnregistered();
-
-	disconnect(ContactManager::instance(), 0, this, 0);
-}
-
 Buddy BuddyListModel::buddyFromVariant(const QVariant &variant) const
 {
 	Buddy buddy = variant.value<Buddy>();
@@ -66,7 +106,7 @@ Buddy BuddyListModel::buddyFromVariant(const QVariant &variant) const
 		return buddy;
 	Talkable talkable = variant.value<Talkable>();
 	if (talkable.isValidBuddy())
-		return talkable.toBuddy();
+		return m_talkableConverter->toBuddy(talkable);
 	else
 		return Buddy::null;
 }
@@ -78,7 +118,7 @@ Contact BuddyListModel::contactFromVariant(const QVariant &variant) const
 		return contact;
 	Talkable talkable = variant.value<Talkable>();
 	if (talkable.isValidContact())
-		return talkable.toContact();
+		return m_talkableConverter->toContact(talkable);
 	else
 		return Contact::null;
 }
@@ -413,17 +453,17 @@ QVariant BuddyListModel::data(const QModelIndex &index, int role) const
 				return QVariant();
 		}
 
-		const Contact &contact = BuddyPreferredManager::instance()->preferredContact(buddy);
+		const Contact &contact = m_buddyPreferredManager->preferredContact(buddy);
 
 		return TalkableRole != role && !contact.isNull()
-				? ContactDataExtractor::data(contact, role, true)
-				: BuddyDataExtractor::data(buddy, role);
+				? m_contactDataExtractor->data(contact, role, true)
+				: m_buddyDataExtractor->data(buddy, role);
 	}
 
-	ContactShared *contactShared = qobject_cast<ContactShared *>(sharedData);
+	auto contactShared = qobject_cast<ContactShared *>(sharedData);
 	Q_ASSERT(contactShared);
 
-	return ContactDataExtractor::data(Contact(contactShared), role, false);
+	return m_contactDataExtractor->data(Contact(contactShared), role, false);
 }
 
 bool BuddyListModel::setData(const QModelIndex &index, const QVariant &value, int role)
@@ -503,7 +543,7 @@ QModelIndexList BuddyListModel::indexListForValue(const QVariant &value) const
 
 QStringList BuddyListModel::mimeTypes() const
 {
-	return BuddyListMimeDataHelper::mimeTypes();
+	return m_buddyListMimeDataService->mimeTypes();
 }
 
 QMimeData * BuddyListModel::mimeData(const QModelIndexList &indexes) const
@@ -517,7 +557,7 @@ QMimeData * BuddyListModel::mimeData(const QModelIndexList &indexes) const
 		list << con;
 	}
 
-	return BuddyListMimeDataHelper::toMimeData(list);
+	return m_buddyListMimeDataService->toMimeData(list).release();
 }
 
 void BuddyListModel::accountRegistered(Account account)
