@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,23 +19,28 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_LIST_MODEL_H
-#define BUDDY_LIST_MODEL_H
-
-#include <QtCore/QModelIndex>
+#pragma once
 
 #include "accounts/accounts-aware-object.h"
-
 #include "buddies/buddy-list.h"
-#include "buddies/buddy.h"
 #include "buddies/buddy-set.h"
+#include "buddies/buddy.h"
+#include "model/kadu-abstract-model.h"
 #include "status/status.h"
 #include "exports.h"
 
-#include "accounts/accounts-aware-object.h"
-#include "model/kadu-abstract-model.h"
+#include <QtCore/QModelIndex>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
+class AccountManager;
+class BuddyDataExtractor;
+class BuddyListMimeDataService;
+class BuddyPreferredManager;
 class Buddy;
+class ContactDataExtractor;
+class ContactManager;
+class TalkableConverter;
 
 /**
  * @addtogroup Buddy
@@ -54,155 +59,6 @@ class KADUAPI BuddyListModel : public QAbstractItemModel, public KaduAbstractMod
 {
 	Q_OBJECT
 
-	bool Checkable;
-	BuddyList List;
-	BuddySet CheckedBuddies;
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Converts variant to Buddy.
-	 * @param variant variant to convert
-	 * @return Buddy from given variant.
-	 *
-	 * This class can convert variants that holds a Buddy instance or a Talkable instance that is a valid Buddy.
-	 */
-	Buddy buddyFromVariant(const QVariant &variant) const;
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Converts variant to Contact.
-	 * @param variant variant to convert
-	 * @return Contact from given variant.
-	 *
-	 * This class can convert variants that holds a Contact instance or a Talkable instance that is a valid Contact.
-	 */
-	Contact contactFromVariant(const QVariant &variant) const;
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @todo Remove after Qt 4.8 is required
-	 * @short Return true if given index is checkable.
-	 * @param index index to check
-	 * @return true if given index is checkable
-	 *
-	 * Index is checkable when whole model is checkable and given index holds a valid Buddy.
-	 */
-	bool isCheckableIndex(const QModelIndex &index) const;
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Return contact with given contactIndex from buddy holded at given index.
-	 * @param index model index of buddy
-	 * @param contactIndex index of contact in given buddy
-	 * @return contact with given contactIndex from buddy holded at given index
-	 *
-	 * If index does not hold a valid buddy or contactIndex is out of range then null Contact is returned.
-	 */
-	Contact buddyContact(const QModelIndex &index, int contactIndex) const;
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Connect given buddy to this object's slots.
-	 * @param buddy buddy to connect
-	 *
-	 * Calling this method on each new buddy ensures that model is automatically updated.
-	 */
-	void connectBuddy(const Buddy &buddy);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Disonnect given buddy from this object's slots.
-	 * @param buddy buddy to disconnect
-	 *
-	 * Calling this method on each removed buddy ensures that this model does not unneccessary updates.
-	 */
-	void disconnectBuddy(const Buddy &buddy);
-
-private slots:
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a buddy's data changes.
-	 *
-	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
-	 */
-	void buddyUpdated();
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a contact's data changes.
-	 * @param contact updated Contact
-	 *
-	 * This slot is connected to @link ContactManager @endlink singleton. When updated contact belongs to one of
-	 * buddy on the list then an update is performed.
-	 */
-	void contactUpdated(const Contact &contact);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a contact's status changes.
-	 * @param contact updated Contact
-	 * @param oldStatus old status of updated Contact
-	 *
-	 * This slot is connected to every registered @link Addoun @endlink. When updated contact belongs to one of
-	 * buddy on the list then an update is performed.
-	 */
-	void contactStatusChanged(const Contact &contact, const Status &oldStatus);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a contact is about to be added to known buddy.
-	 * @param contact about-to-be-added contact
-	 *
-	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
-	 */
-	void contactAboutToBeAdded(const Contact &contact);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a contact is added to known buddy.
-	 * @param contact newly added contact
-	 *
-	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
-	 */
-	void contactAdded(const Contact &contact);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a contact is about to be removed from known buddy.
-	 * @param contact about-to-be-removed contact
-	 *
-	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
-	 */
-	void contactAboutToBeRemoved(const Contact &contact);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Slot called every time a contact is removed from known buddy.
-	 * @param contact just removed contact
-	 *
-	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
-	 */
-	void contactRemoved(const Contact &contact);
-
-protected:
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Method called every time a new account is registerd.
-	 * @param account just registered account
-	 *
-	 * In this method a connection is made to ensure that this model is informed about status changes of contacts.
-	 */
-	virtual void accountRegistered(Account account);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Method called every time an account is unregisterd.
-	 * @param account just unregistered account
-	 *
-	 * In this method connection connection made in @link accountRegistered @endlink is disconnected.
-	 */
-	virtual void accountUnregistered(Account account);
-
 public:
 	/**
 	 * @author Rafał 'Vogel' Malinowski
@@ -212,7 +68,7 @@ public:
 	 * In this contructor connection to @link ContactManager @endlink is made to ensure that this model
 	 * is informed about changes in contacts' data.
 	 */
-	explicit BuddyListModel(QObject *parent = 0);
+	explicit BuddyListModel(QObject *parent = nullptr);
 	virtual ~BuddyListModel();
 
 	/**
@@ -381,7 +237,6 @@ public:
 	 */
 	virtual QModelIndexList indexListForValue(const QVariant &value) const;
 
-
 signals:
 	/**
 	 * @author Rafał 'Vogel' Malinowski
@@ -391,10 +246,175 @@ signals:
 	 */
 	void checkedBuddiesChanged(const BuddySet &checkedBuddies);
 
+protected:
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Method called every time a new account is registerd.
+	 * @param account just registered account
+	 *
+	 * In this method a connection is made to ensure that this model is informed about status changes of contacts.
+	 */
+	virtual void accountRegistered(Account account);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Method called every time an account is unregisterd.
+	 * @param account just unregistered account
+	 *
+	 * In this method connection connection made in @link accountRegistered @endlink is disconnected.
+	 */
+	virtual void accountUnregistered(Account account);
+
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<BuddyDataExtractor> m_buddyDataExtractor;
+	QPointer<BuddyListMimeDataService> m_buddyListMimeDataService;
+	QPointer<BuddyPreferredManager> m_buddyPreferredManager;
+	QPointer<ContactDataExtractor> m_contactDataExtractor;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<TalkableConverter> m_talkableConverter;
+
+	bool Checkable;
+	BuddyList List;
+	BuddySet CheckedBuddies;
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Converts variant to Buddy.
+	 * @param variant variant to convert
+	 * @return Buddy from given variant.
+	 *
+	 * This class can convert variants that holds a Buddy instance or a Talkable instance that is a valid Buddy.
+	 */
+	Buddy buddyFromVariant(const QVariant &variant) const;
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Converts variant to Contact.
+	 * @param variant variant to convert
+	 * @return Contact from given variant.
+	 *
+	 * This class can convert variants that holds a Contact instance or a Talkable instance that is a valid Contact.
+	 */
+	Contact contactFromVariant(const QVariant &variant) const;
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @todo Remove after Qt 4.8 is required
+	 * @short Return true if given index is checkable.
+	 * @param index index to check
+	 * @return true if given index is checkable
+	 *
+	 * Index is checkable when whole model is checkable and given index holds a valid Buddy.
+	 */
+	bool isCheckableIndex(const QModelIndex &index) const;
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Return contact with given contactIndex from buddy holded at given index.
+	 * @param index model index of buddy
+	 * @param contactIndex index of contact in given buddy
+	 * @return contact with given contactIndex from buddy holded at given index
+	 *
+	 * If index does not hold a valid buddy or contactIndex is out of range then null Contact is returned.
+	 */
+	Contact buddyContact(const QModelIndex &index, int contactIndex) const;
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Connect given buddy to this object's slots.
+	 * @param buddy buddy to connect
+	 *
+	 * Calling this method on each new buddy ensures that model is automatically updated.
+	 */
+	void connectBuddy(const Buddy &buddy);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Disonnect given buddy from this object's slots.
+	 * @param buddy buddy to disconnect
+	 *
+	 * Calling this method on each removed buddy ensures that this model does not unneccessary updates.
+	 */
+	void disconnectBuddy(const Buddy &buddy);
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setBuddyDataExtractor(BuddyDataExtractor *buddyDataExtractor);
+	INJEQT_SET void setBuddyListMimeDataService(BuddyListMimeDataService *buddyListMimeDataService);
+	INJEQT_SET void setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager);
+	INJEQT_SET void setContactDataExtractor(ContactDataExtractor *contactDataExtractor);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setTalkableConverter(TalkableConverter *talkableConverter);
+	INJEQT_INIT void init();
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a buddy's data changes.
+	 *
+	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
+	 */
+	void buddyUpdated();
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a contact's data changes.
+	 * @param contact updated Contact
+	 *
+	 * This slot is connected to @link ContactManager @endlink singleton. When updated contact belongs to one of
+	 * buddy on the list then an update is performed.
+	 */
+	void contactUpdated(const Contact &contact);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a contact's status changes.
+	 * @param contact updated Contact
+	 * @param oldStatus old status of updated Contact
+	 *
+	 * This slot is connected to every registered @link Addoun @endlink. When updated contact belongs to one of
+	 * buddy on the list then an update is performed.
+	 */
+	void contactStatusChanged(const Contact &contact, const Status &oldStatus);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a contact is about to be added to known buddy.
+	 * @param contact about-to-be-added contact
+	 *
+	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
+	 */
+	void contactAboutToBeAdded(const Contact &contact);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a contact is added to known buddy.
+	 * @param contact newly added contact
+	 *
+	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
+	 */
+	void contactAdded(const Contact &contact);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a contact is about to be removed from known buddy.
+	 * @param contact about-to-be-removed contact
+	 *
+	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
+	 */
+	void contactAboutToBeRemoved(const Contact &contact);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Slot called every time a contact is removed from known buddy.
+	 * @param contact just removed contact
+	 *
+	 * This slot is connected to every buddy in list. Updated buddy is read from QObject::sender() method.
+	 */
+	void contactRemoved(const Contact &contact);
+
 };
 
 /**
  * @}
  */
-
-#endif // BUDDY_LIST_MODEL_H
