@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,21 +26,29 @@
 BuddyManagerAdapter::BuddyManagerAdapter(BuddyListModel *model) :
 		QObject(model), Model(model)
 {
-	Model->setBuddyList(BuddyManager::instance()->items().toList());
-
-	BuddyManager *manager = BuddyManager::instance();
-	connect(manager, SIGNAL(buddyAdded(Buddy)),
-			this, SLOT(buddyAdded(Buddy)), Qt::DirectConnection);
-	connect(manager, SIGNAL(buddyRemoved(Buddy)),
-			this, SLOT(buddyRemoved(Buddy)), Qt::DirectConnection);
 }
 
 BuddyManagerAdapter::~BuddyManagerAdapter()
 {
-	BuddyManager *manager = BuddyManager::instance();
+	BuddyManager *manager = m_buddyManager;
 	disconnect(manager, 0, this, 0);
 }
 
+void BuddyManagerAdapter::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyManagerAdapter::init()
+{
+	Model->setBuddyList(m_buddyManager->items().toList());
+
+	connect(m_buddyManager, SIGNAL(buddyAdded(Buddy)),
+			this, SLOT(buddyAdded(Buddy)), Qt::DirectConnection);
+	connect(m_buddyManager, SIGNAL(buddyRemoved(Buddy)),
+			this, SLOT(buddyRemoved(Buddy)), Qt::DirectConnection);
+}
+
 void BuddyManagerAdapter::buddyAdded(const Buddy &buddy)
 {
 	Model->addBuddy(buddy);
