@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,21 +21,23 @@
 
 #include "chat-style/chat-style.h"
 #include "configuration/configuration-aware-object.h"
-#include "os/generic/compositing-aware-object.h"
 
-#include <map>
-#include <memory>
 #include <QtCore/QMap>
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
 #include <QtCore/QStringList>
 #include <QtGui/QColor>
+#include <map>
+#include <memory>
+#include <injeqt/injeqt.h>
 
+class AdiumStyleEngine;
+class ChatConfigurationHolder;
 class ChatStyleEngine;
-class ChatStylePreview;
+class Configuration;
 class ConfiguredChatStyleRendererFactoryProvider;
-class FormattedStringFactory;
-class MainConfigurationWindow;
+class KaduStyleEngine;
+class PathsProvider;
 
 class QCheckBox;
 class QComboBox;
@@ -52,27 +51,23 @@ struct StyleInfo
 	StyleInfo() : global(false), engine(0) {}
 };
 
-class KADUAPI ChatStyleManager : public QObject, ConfigurationAwareObject, CompositingAwareObject
+class KADUAPI ChatStyleManager : public QObject, ConfigurationAwareObject
 {
 	Q_OBJECT
 
-	static ChatStyleManager *Instance;
+	QPointer<AdiumStyleEngine> m_adiumStyleEngine;
+	QPointer<ChatConfigurationHolder> m_chatConfigurationHolder;
+	QPointer<Configuration> m_configuration;
+	QPointer<ConfiguredChatStyleRendererFactoryProvider> m_configuredChatStyleRendererFactoryProvider;
+	QPointer<KaduStyleEngine> m_kaduStyleEngine;
+	QPointer<PathsProvider> m_pathsProvider;
 
-	QPointer<FormattedStringFactory> CurrentFormattedStringFactory;
-	QPointer<ConfiguredChatStyleRendererFactoryProvider> CurrentConfiguredChatStyleRendererFactoryProvider;
-
-	ChatStyleManager();
-
-	void init();
-
-	std::map<QString, std::unique_ptr<ChatStyleEngine>> RegisteredEngines;
+	std::map<QString, ChatStyleEngine *> m_engines;
 	ChatStyle m_currentChatStyle;
 	QMap<QString, StyleInfo> AvailableStyles;
 
 	ChatStyleEngine *CurrentEngine;
 
-	bool CompositingEnabled;
-
 	bool CfgNoHeaderRepeat; /*!< Remove repeated message headers. */
 	int CfgHeaderSeparatorHeight; /*!< Header separator height. */
 	int CfgNoHeaderInterval; /*!< Time Interval, in which headers will not be repeated*/
@@ -85,41 +80,35 @@ class KADUAPI ChatStyleManager : public QObject, ConfigurationAwareObject, Compo
 
 	QString MainStyle;
 
-	//configuration
-	QComboBox *SyntaxListCombo;
-	QComboBox *VariantListCombo;
-	QCheckBox *TurnOnTransparency;
-
-	ChatStylePreview *EnginePreview;
-
-	void compositingEnabled();
-	void compositingDisabled();
-
 	QString fixedStyleName(QString styleName);
 	QString fixedVariantName(const QString &styleName, QString variantName);
 
 private slots:
-	void styleChangedSlot(const QString &styleName);
-	void variantChangedSlot(const QString &variantName);
-	void configurationWindowDestroyed();
-	void configurationApplied();
+	INJEQT_SET void setAdiumStyleEngine(AdiumStyleEngine *adiumStyleEngine);
+	INJEQT_SET void setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setConfiguredChatStyleRendererFactoryProvider(ConfiguredChatStyleRendererFactoryProvider *configuredChatStyleRendererFactoryProvider);
+	INJEQT_SET void setKaduStyleEngine(KaduStyleEngine *kaduStyleEngine);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+	INJEQT_INIT void init();
 
 protected:
 	virtual void configurationUpdated();
 
 public:
-	static ChatStyleManager * instance();
-
+	Q_INVOKABLE explicit ChatStyleManager(QObject *parent = nullptr);
 	virtual ~ChatStyleManager();
 
-	void setConfiguredChatStyleRendererFactoryProvider(ConfiguredChatStyleRendererFactoryProvider *configuredChatStyleRendererFactoryProvider);
-	void setFormattedStringFactory(FormattedStringFactory *formattedStringFactory);
-
-	void registerChatStyleEngine(const QString &name, std::unique_ptr<ChatStyleEngine>);
+	void registerChatStyleEngine(const QString &name, ChatStyleEngine *engine);
 	void unregisterChatStyleEngine(const QString &name);
 
-	bool hasChatStyle(const QString &name) { return  AvailableStyles.contains(name); }
-	StyleInfo chatStyleInfo(const QString &name);
+	ChatStyle currentChatStyle() const { return m_currentChatStyle; }
+	ChatStyleEngine * currentEngine() const { return CurrentEngine; }
+
+	QMap<QString, StyleInfo> availableStyles() const { return AvailableStyles; }
+	bool hasChatStyle(const QString &name) const { return  AvailableStyles.contains(name); }
+	bool isChatStyleValid(const QString &name) const;
+	StyleInfo chatStyleInfo(const QString &name) const;
 
 	void loadStyles();
 
@@ -135,11 +124,6 @@ public:
 
 	const QString & mainStyle() { return MainStyle; }
 
-	void mainConfigurationWindowCreated(MainConfigurationWindow *window);
-	QComboBox * syntaxListCombo() { return SyntaxListCombo; }
-
-	void addStyle(const QString &syntaxName, ChatStyleEngine *engine);
-
 signals:
 	void chatStyleConfigurationUpdated();
 
