@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Marcel Zięba (marseel@gmail.com)
- * Copyright 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,15 +20,16 @@
 #include "adium-style-engine.h"
 
 #include "chat-style/chat-style.h"
-#include "chat-style/engine/adium/adium-style.h"
 #include "chat-style/engine/adium/adium-style-renderer-factory.h"
-#include "message/message-html-renderer-service.h"
-#include "misc/kadu-paths.h"
+#include "chat-style/engine/adium/adium-style.h"
+#include "core/injected-factory.h"
 #include "misc/memory.h"
+#include "misc/paths-provider.h"
 
 #include <QtCore/QDir>
 
-AdiumStyleEngine::AdiumStyleEngine()
+AdiumStyleEngine::AdiumStyleEngine(QObject *parent) :
+		QObject{parent}
 {
 }
 
@@ -41,9 +37,14 @@ AdiumStyleEngine::~AdiumStyleEngine()
 {
 }
 
-void AdiumStyleEngine::setMessageHtmlRendererService(MessageHtmlRendererService *messageHtmlRendererService)
+void AdiumStyleEngine::setInjectedFactory(InjectedFactory *injectedFactory)
 {
-	CurrentMessageHtmlRendererService = messageHtmlRendererService;
+	m_injectedFactory = injectedFactory;
+}
+
+void AdiumStyleEngine::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
 }
 
 QString AdiumStyleEngine::isStyleValid(QString stylePath)
@@ -53,22 +54,22 @@ QString AdiumStyleEngine::isStyleValid(QString stylePath)
 
 bool AdiumStyleEngine::styleUsesTransparencyByDefault(QString styleName)
 {
-	auto style = AdiumStyle{styleName};
+	auto style = AdiumStyle{m_pathsProvider, styleName};
 	return style.defaultBackgroundIsTransparent();
 }
 
 QString AdiumStyleEngine::defaultVariant(const QString &styleName)
 {
-	auto style = AdiumStyle{styleName};
+	auto style = AdiumStyle{m_pathsProvider, styleName};
 	return style.defaultVariant();
 }
 
 QStringList AdiumStyleEngine::styleVariants(QString styleName)
 {
 	QDir dir;
-	QString styleBaseHref = KaduPaths::instance()->profilePath() + QLatin1String("syntax/chat/") + styleName + QLatin1String("/Contents/Resources/Variants/");
+	QString styleBaseHref = m_pathsProvider->profilePath() + QStringLiteral("syntax/chat/") + styleName + QStringLiteral("/Contents/Resources/Variants/");
 	if (!dir.exists(styleBaseHref))
-		styleBaseHref = KaduPaths::instance()->dataPath() + QLatin1String("syntax/chat/") + styleName + QLatin1String("/Contents/Resources/Variants/");
+		styleBaseHref = m_pathsProvider->dataPath() + QStringLiteral("syntax/chat/") + styleName + QStringLiteral("/Contents/Resources/Variants/");
 	dir.setPath(styleBaseHref);
 	dir.setNameFilters(QStringList("*.css"));
 	return dir.entryList();
@@ -76,12 +77,10 @@ QStringList AdiumStyleEngine::styleVariants(QString styleName)
 
 std::unique_ptr<ChatStyleRendererFactory> AdiumStyleEngine::createRendererFactory(const ChatStyle &chatStyle)
 {
-	auto style = std::make_shared<AdiumStyle>(chatStyle.name());
+	auto style = std::make_shared<AdiumStyle>(m_pathsProvider, chatStyle.name());
 	style->setCurrentVariant(chatStyle.variant());
 
-	auto result = make_unique<AdiumStyleRendererFactory>(style);
-	result.get()->setMessageHtmlRendererService(CurrentMessageHtmlRendererService);
-	return std::move(result);
+	return m_injectedFactory->makeUnique<AdiumStyleRendererFactory>(style);
 }
 
 #include "moc_adium-style-engine.cpp"
