@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,20 +21,21 @@
 
 #include "chat-style/engine/chat-style-engine.h"
 
+#include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
-class MessageHtmlRendererService;
+class InjectedFactory;
+class PathsProvider;
 
-class AdiumStyleEngine : public ChatStyleEngine
+class AdiumStyleEngine : public QObject, public ChatStyleEngine
 {
-	QPointer<MessageHtmlRendererService> CurrentMessageHtmlRendererService;
+	Q_OBJECT
 
 public:
-	explicit AdiumStyleEngine();
+	Q_INVOKABLE explicit AdiumStyleEngine(QObject *parent = nullptr);
 	virtual ~AdiumStyleEngine();
 
-	void setMessageHtmlRendererService(MessageHtmlRendererService *messageHtmlRendererService);
-
 	virtual std::unique_ptr<ChatStyleRendererFactory> createRendererFactory(const ChatStyle &chatStyle);
 
 	virtual bool supportVariants() { return true; }
@@ -47,4 +45,12 @@ public:
 	virtual QStringList styleVariants(QString styleName);
 	virtual bool styleUsesTransparencyByDefault(QString styleName);
 
+private:
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<PathsProvider> m_pathsProvider;
+
+private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+
 };
