@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,9 +20,12 @@
 #include "adium-style-renderer-factory.h"
 
 #include "chat-style/engine/adium/adium-style-renderer.h"
+#include "core/core.h"
+#include "core/injected-factory.h"
 #include "message/message-html-renderer-service.h"
 
-AdiumStyleRendererFactory::AdiumStyleRendererFactory(std::shared_ptr<AdiumStyle> style) :
+AdiumStyleRendererFactory::AdiumStyleRendererFactory(std::shared_ptr<AdiumStyle> style, QObject *parent) :
+		QObject{parent},
 		m_style{std::move(style)}
 {
 }
@@ -31,14 +34,15 @@ AdiumStyleRendererFactory::~AdiumStyleRendererFactory()
 {
 }
 
-void AdiumStyleRendererFactory::setMessageHtmlRendererService(MessageHtmlRendererService *messageHtmlRendererService)
+void AdiumStyleRendererFactory::setInjectedFactory(InjectedFactory *injectedFactory)
 {
-	m_messageHtmlRendererService = messageHtmlRendererService;
+	m_injectedFactory = injectedFactory;
 }
 
-qobject_ptr<ChatStyleRenderer> AdiumStyleRendererFactory::createChatStyleRenderer(ChatStyleRendererConfiguration configuration)
+not_owned_qptr<ChatStyleRenderer> AdiumStyleRendererFactory::createChatStyleRenderer(ChatStyleRendererConfiguration configuration)
 {
-	auto renderer = make_qobject<AdiumStyleRenderer>(std::move(configuration), m_style);
-	renderer->setMessageHtmlRendererService(m_messageHtmlRendererService);
-	return qobject_ptr<ChatStyleRenderer>{renderer.release()};
+	auto result = m_injectedFactory->makeNotOwned<AdiumStyleRenderer>(std::move(configuration), m_style);
+	return not_owned_qptr<ChatStyleRenderer>(result.release());
 }
+
+#include "moc_adium-style-renderer-factory.cpp"
