@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,9 +22,13 @@
 #include "chat-style/engine/chat-style-renderer.h"
 
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class AdiumStyle;
+class ChatConfigurationHolder;
+class IconsManager;
 class MessageHtmlRendererService;
+class SystemInfo;
 
 class AdiumStyleRenderer : public ChatStyleRenderer
 {
@@ -34,17 +38,18 @@ public:
 	explicit AdiumStyleRenderer(ChatStyleRendererConfiguration configuration, std::shared_ptr<AdiumStyle> style, QObject *parent = nullptr);
 	virtual ~AdiumStyleRenderer();
 
-	void setMessageHtmlRendererService(MessageHtmlRendererService *messageHtmlRendererService);
-
 	virtual void clearMessages() override;
 	virtual void appendChatMessage(const Message &message, const MessageRenderInfo &messageRenderInfo) override;
 	virtual void removeFirstMessage() override;
 	virtual void displayMessageStatus(const QString &id, MessageStatus) override;
-	virtual void displayChatState(ChatStateService::State, const QString &, const QString &) override;
+	virtual void displayChatState(ChatState, const QString &, const QString &) override;
 	virtual void displayChatImage(const ChatImage &chatImage, const QString &fileName) override;
 
 private:
+	QPointer<ChatConfigurationHolder> m_chatConfigurationHolder;
+	QPointer<IconsManager> m_iconsManager;
 	QPointer<MessageHtmlRendererService> m_messageHtmlRendererService;
+	QPointer<SystemInfo> m_systemInfo;
 
 	std::shared_ptr<AdiumStyle> m_style;
 
@@ -53,6 +58,12 @@ private:
 	QString preprocessStyleBaseHtml(bool useTransparency);
 
 private slots:
+	INJEQT_SET void setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setMessageHtmlRendererService(MessageHtmlRendererService *messageHtmlRendererService);
+	INJEQT_SET void setSystemInfo(SystemInfo *systemInfo);
+	INJEQT_INIT void init();
+
 	void pageLoaded();
 
 };
