@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +19,8 @@
 
 #include "adium-style.h"
 
-#include "misc/kadu-paths.h"
+#include "core/core.h"
+#include "misc/paths-provider.h"
 
 #include <QtCore/QDir>
 #include <QtCore/QTextCodec>
@@ -96,20 +95,20 @@ AdiumStyle::AdiumStyle() :
 {
 }
 
-AdiumStyle::AdiumStyle(const QString &styleName) :
-		Name{styleName}, StyleViewVersion{0}, DefaultBackgroundIsTransparent{false}, UsesCustomTemplateHtml{false}
+AdiumStyle::AdiumStyle(PathsProvider *pathsProvider, const QString &styleName) :
+		m_pathsProvider{pathsProvider}, Name{styleName}, StyleViewVersion{0}, DefaultBackgroundIsTransparent{false}, UsesCustomTemplateHtml{false}
 {
 	QDir dir;
-	BaseHref = KaduPaths::instance()->profilePath() + QLatin1String("syntax/chat/") + styleName + QLatin1String("/Contents/Resources/");
+	BaseHref = m_pathsProvider->profilePath() + QStringLiteral("syntax/chat/") + styleName + QStringLiteral("/Contents/Resources/");
 	if (!dir.exists(BaseHref))
-		BaseHref = KaduPaths::instance()->dataPath() + QLatin1String("syntax/chat/") + styleName + QLatin1String("/Contents/Resources/");
+		BaseHref = m_pathsProvider->dataPath() + QStringLiteral("syntax/chat/") + styleName + QStringLiteral("/Contents/Resources/");
 
-	readConfiugrationFile();
+	readConfigurationFile();
 	loadHtmlFiles();
 	loadVariants();
 }
 
-void AdiumStyle::readConfiugrationFile()
+void AdiumStyle::readConfigurationFile()
 {
 	QSettings styleSettings(BaseHref + "../Info.plist", plistFormat);
 
@@ -138,7 +137,7 @@ void AdiumStyle::loadHtmlFiles()
 		TemplateHref = BaseHref + "template.html";
 	else
 	{
-		TemplateHref = KaduPaths::instance()->dataPath() + QLatin1String("syntax/chat/Default/Template.html");
+		TemplateHref = m_pathsProvider->dataPath() + QStringLiteral("syntax/chat/Default/Template.html");
 		UsesCustomTemplateHtml = false;
 	}
 
