@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,21 +21,38 @@
 
 #include "chat-style/chat-style.h"
 #include "chat-style/engine/chat-style-renderer-factory.h"
-#include "chat-style/engine/kadu/kadu-style-renderer-factory.h"
 #include "chat-style/engine/kadu/kadu-chat-syntax.h"
+#include "chat-style/engine/kadu/kadu-style-renderer-factory.h"
+#include "core/injected-factory.h"
+#include "misc/paths-provider.h"
 #include "misc/syntax-list.h"
 
 #include <QtCore/QFileInfo>
 
-KaduStyleEngine::KaduStyleEngine()
+KaduStyleEngine::KaduStyleEngine(QObject *parent) :
+		QObject{parent}
 {
-	syntaxList = QSharedPointer<SyntaxList>(new SyntaxList("chat"));
 }
 
 KaduStyleEngine::~KaduStyleEngine()
 {
 }
 
+void KaduStyleEngine::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void KaduStyleEngine::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void KaduStyleEngine::init()
+{
+	syntaxList = QSharedPointer<SyntaxList>(m_injectedFactory->makeInjected<SyntaxList>("chat"));
+}
+
 QString KaduStyleEngine::isStyleValid(QString stylePath)
 {
 	QFileInfo fi;
@@ -48,12 +62,12 @@ QString KaduStyleEngine::isStyleValid(QString stylePath)
 
 std::unique_ptr<ChatStyleRendererFactory> KaduStyleEngine::createRendererFactory(const ChatStyle &chatStyle)
 {
-	QString chatSyntax = SyntaxList::readSyntax("chat", chatStyle.name(),
+	QString chatSyntax = SyntaxList::readSyntax(m_pathsProvider, "chat", chatStyle.name(),
 		"<p style=\"background-color: #{backgroundColor};\">#{separator}"
 		  "<font color=\"#{fontColor}\"><kadu:header><b><font color=\"#{nickColor}\">%a</font> :: "
 			"#{receivedDate}[ / S #{sentDate}]</b><br /></kadu:header>"
 		"#{message}</font></p>"
 	);
 
-	return make_unique<KaduStyleRendererFactory>(std::make_shared<KaduChatSyntax>(chatSyntax));
+	return m_injectedFactory->makeUnique<KaduStyleRendererFactory>(std::make_shared<KaduChatSyntax>(chatSyntax));
 }
