@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,8 +19,8 @@
 
 #include "kadu-style-renderer.h"
 
-#include "chat-style/engine/kadu/kadu-chat-syntax.h"
 #include "chat-style/chat-style-manager.h"
+#include "chat-style/engine/kadu/kadu-chat-syntax.h"
 #include "contacts/contact-set.h"
 #include "message/message-render-info.h"
 #include "misc/misc.h"
@@ -31,13 +28,31 @@
 #include "protocols/services/chat-image.h"
 
 #include <QtGui/QTextDocument>
-#include <QtWebKit/QWebFrame>
+#include <QtWebKitWidgets/QWebFrame>
 
 KaduStyleRenderer::KaduStyleRenderer(ChatStyleRendererConfiguration configuration, std::shared_ptr<KaduChatSyntax> style, QObject *parent) :
 		ChatStyleRenderer{std::move(configuration), parent},
 		m_style{std::move(style)}
 {
-	auto top = Parser::parse(m_style->top(), Talkable(this->configuration().chat().contacts().toContact()), ParserEscape::HtmlEscape);
+}
+
+KaduStyleRenderer::~KaduStyleRenderer()
+{
+}
+
+void KaduStyleRenderer::setChatStyleManager(ChatStyleManager *chatStyleManager)
+{
+	m_chatStyleManager = chatStyleManager;
+}
+
+void KaduStyleRenderer::setParser(Parser *parser)
+{
+	m_parser = parser;
+}
+
+void KaduStyleRenderer::init()
+{
+	auto top = m_parser->parse(m_style->top(), Talkable(configuration().chat().contacts().toContact()), ParserEscape::HtmlEscape);
 	auto html = QString{
 		"<html>"
 		"	<head>"
@@ -54,17 +69,13 @@ KaduStyleRenderer::KaduStyleRenderer(ChatStyleRendererConfiguration configuratio
 		"</html>"
 	};
 
-	this->configuration().webFrame().setHtml(html
-		.arg(Qt::escape(ChatStyleManager::instance()->mainStyle()))
-		.arg(this->configuration().javaScript())
+	configuration().webFrame().setHtml(html
+		.arg(Qt::escape(m_chatStyleManager->mainStyle()))
+		.arg(configuration().javaScript())
 		.arg(top)
 	);
 
-	connect(&this->configuration().webFrame(), SIGNAL(loadFinished(bool)), this, SLOT(setReady()));
-}
-
-KaduStyleRenderer::~KaduStyleRenderer()
-{
+	setReady();
 }
 
 void KaduStyleRenderer::clearMessages()
@@ -79,9 +90,9 @@ void KaduStyleRenderer::removeFirstMessage()
 
 void KaduStyleRenderer::appendChatMessage(const Message &message, const MessageRenderInfo &messageRenderInfo)
 {
-	QString html(replacedNewLine(formatMessage(message, messageRenderInfo), QLatin1String(" ")));
-	html.replace('\\', QLatin1String("\\\\"));
-	html.replace('\'', QLatin1String("\\'"));
+	QString html(replacedNewLine(formatMessage(message, messageRenderInfo), QStringLiteral(" ")));
+	html.replace('\\', QStringLiteral("\\\\"));
+	html.replace('\'', QStringLiteral("\\'"));
 	if (!message.id().isEmpty())
 		html.prepend(QString("<span class=\"kadu_message\" id=\"message_%1\">").arg(Qt::escape(message.id())));
 	else
@@ -96,7 +107,7 @@ void KaduStyleRenderer::displayMessageStatus(const QString &id, MessageStatus st
 	configuration().webFrame().evaluateJavaScript(QString("kadu_messageStatusChanged(\"%1\", %2);").arg(Qt::escape(id)).arg(static_cast<int>(status)));
 }
 
-void KaduStyleRenderer::displayChatState(ChatStateService::State state, const QString &message, const QString &name)
+void KaduStyleRenderer::displayChatState(ChatState state, const QString &message, const QString &name)
 {
 	configuration().webFrame().evaluateJavaScript(QString("kadu_contactActivityChanged(%1, \"%2\", \"%3\");").arg(static_cast<int>(state)).arg(Qt::escape(message)).arg(Qt::escape(name)));
 }
@@ -113,7 +124,7 @@ QString KaduStyleRenderer::formatMessage(const Message &message, const MessageRe
 			? m_style->withHeader()
 			: m_style->withoutHeader();
 
-	return Parser::parse(format, Talkable{sender}, &messageRenderInfo, ParserEscape::HtmlEscape);
+	return m_parser->parse(format, Talkable{sender}, &messageRenderInfo, ParserEscape::HtmlEscape);
 }
 
 #include "moc_kadu-style-renderer.cpp"
