@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +21,12 @@
 
 #include "chat-style/engine/chat-style-renderer.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class ChatStyleManager;
 class KaduChatSyntax;
+class Parser;
 
 class KaduStyleRenderer : public ChatStyleRenderer
 {
@@ -35,12 +40,20 @@ public:
 	virtual void appendChatMessage(const Message &message, const MessageRenderInfo &messageRenderInfo) override;
 	virtual void removeFirstMessage() override;
 	virtual void displayMessageStatus(const QString &id, MessageStatus) override;
-	virtual void displayChatState(ChatStateService::State, const QString &, const QString &) override;
+	virtual void displayChatState(ChatState, const QString &, const QString &) override;
 	virtual void displayChatImage(const ChatImage &chatImage, const QString &fileName) override;
 
 private:
+	QPointer<ChatStyleManager> m_chatStyleManager;
+	QPointer<Parser> m_parser;
+
 	std::shared_ptr<KaduChatSyntax> m_style;
 
 	QString formatMessage(const Message &message, const MessageRenderInfo &messageRenderInfo);
 
+private slots:
+	INJEQT_SET void setChatStyleManager(ChatStyleManager *chatStyleManager);
+	INJEQT_SET void setParser(Parser *parser);
+	INJEQT_INIT void init();
+
 };
