@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,61 +18,66 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "accounts/account-manager.h"
-#include "protocols/protocol.h"
 
+#include "buddy-chat-manager.h"
+
+#include "accounts/account-manager.h"
 #include "buddies/buddy-manager.h"
 #include "chat/chat-details-buddy.h"
 #include "chat/chat-details-contact.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact.h"
 #include "contacts/contact-set.h"
+#include "protocols/protocol.h"
 
-#include "buddy-chat-manager.h"
-
-BuddyChatManager * BuddyChatManager::Instance = 0;
-
-BuddyChatManager * BuddyChatManager::instance()
-{
-	if (!Instance)
-	{
-		Instance = new BuddyChatManager();
-		Instance->init();
-	}
-
-	return Instance;
-}
-
-BuddyChatManager::BuddyChatManager()
+BuddyChatManager::BuddyChatManager(QObject *parent) :
+		QObject{parent}
 {
 }
 
 BuddyChatManager::~BuddyChatManager()
 {
-	disconnect(BuddyManager::instance(), 0, this, 0);
-	disconnect(ChatManager::instance(), 0, this, 0);
+}
 
-	foreach (const Chat &chat, ChatManager::instance()->items())
-		chatRemoved(chat);
+void BuddyChatManager::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyChatManager::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void BuddyChatManager::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
 }
 
 void BuddyChatManager::init()
 {
-	connect(BuddyManager::instance(), SIGNAL(buddyContactAdded(Buddy,Contact)),
+	connect(m_buddyManager, SIGNAL(buddyContactAdded(Buddy,Contact)),
 	        this, SLOT(buddyContactAdded(Buddy,Contact)));
-	connect(BuddyManager::instance(), SIGNAL(buddyContactRemoved(Buddy,Contact)),
+	connect(m_buddyManager, SIGNAL(buddyContactRemoved(Buddy,Contact)),
 	        this, SLOT(buddyContactRemoved(Buddy,Contact)));
 
-	connect(ChatManager::instance(), SIGNAL(chatAdded(Chat)), this, SLOT(chatAdded(Chat)));
-	connect(ChatManager::instance(), SIGNAL(chatRemoved(Chat)), this, SLOT(chatRemoved(Chat)));
+	connect(m_chatManager, SIGNAL(chatAdded(Chat)), this, SLOT(chatAdded(Chat)));
+	connect(m_chatManager, SIGNAL(chatRemoved(Chat)), this, SLOT(chatRemoved(Chat)));
 
-	foreach (const Chat &chat, ChatManager::instance()->items())
+	foreach (const Chat &chat, m_chatManager->items())
 		chatAdded(chat);
 }
 
+void BuddyChatManager::done()
+{
+	foreach (const Chat &chat, m_chatManager->items())
+		chatRemoved(chat);
+}
+
 Chat BuddyChatManager::createAndInsertBuddyChat(const Buddy &buddy)
 {
-	Chat result = Chat::create();
+	auto result = m_chatStorage->create();
 	result.setType("Buddy");
 
 	ChatDetailsBuddy *buddyDetails = qobject_cast<ChatDetailsBuddy *>(result.details());
@@ -83,7 +86,7 @@ Chat BuddyChatManager::createAndInsertBuddyChat(const Buddy &buddy)
 	QVector<Chat> chats;
 	foreach (const Contact &contact, buddy.contacts())
 	{
-		const Chat &contactChat = ChatTypeContact::findChat(contact, ActionReturnNull);
+		auto contactChat = ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd);
 		if (contactChat)
 			chats.append(contactChat);
 	}
@@ -102,7 +105,7 @@ void BuddyChatManager::buddyContactAdded(const Buddy &buddy, const Contact &cont
 	ChatDetailsBuddy *buddyDetails = qobject_cast<ChatDetailsBuddy *>(chat.details());
 	Q_ASSERT(buddyDetails);
 
-	buddyDetails->addChat(ChatTypeContact::findChat(contact, ActionReturnNull));
+	buddyDetails->addChat(ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionReturnNull));
 }
 
 void BuddyChatManager::buddyContactRemoved(const Buddy &buddy, const Contact &contact)
@@ -114,7 +117,7 @@ void BuddyChatManager::buddyContactRemoved(const Buddy &buddy, const Contact &co
 	ChatDetailsBuddy *buddyDetails = qobject_cast<ChatDetailsBuddy *>(chat.details());
 	Q_ASSERT(buddyDetails);
 
-	buddyDetails->removeChat(ChatTypeContact::findChat(contact, ActionReturnNull));
+	buddyDetails->removeChat(ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionReturnNull));
 }
 
 void BuddyChatManager::chatAdded(const Chat &addedChat)
