@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -40,6 +39,11 @@ ChatDetailsBuddy::~ChatDetailsBuddy()
 {
 }
 
+void ChatDetailsBuddy::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Return false, this class should never be stored.
@@ -60,7 +64,7 @@ bool ChatDetailsBuddy::shouldStore()
  */
 ChatType * ChatDetailsBuddy::type() const
 {
-	return ChatTypeManager::instance()->chatType("Buddy");
+	return m_chatTypeManager->chatType("Buddy");
 }
 
 /**
@@ -72,7 +76,7 @@ ChatType * ChatDetailsBuddy::type() const
  */
 ContactSet ChatDetailsBuddy::contacts() const
 {
-	return Chats.isEmpty() ? ContactSet() : Chats.at(0).contacts();
+	return m_chats.isEmpty() ? ContactSet() : m_chats.at(0).contacts();
 }
 
 /**
@@ -84,7 +88,7 @@ ContactSet ChatDetailsBuddy::contacts() const
  */
 QString ChatDetailsBuddy::name() const
 {
-	return Chats.isEmpty() ? MyBuddy.isEmpty() ? QString() : MyBuddy.display() : Chats.at(0).name();
+	return m_chats.isEmpty() ? m_buddy.isEmpty() ? QString() : m_buddy.display() : m_chats.at(0).name();
 }
 
 bool ChatDetailsBuddy::isConnected() const
@@ -94,12 +98,12 @@ bool ChatDetailsBuddy::isConnected() const
 
 void ChatDetailsBuddy::setBuddy(const Buddy &buddy)
 {
-	MyBuddy = buddy;
+	m_buddy = buddy;
 }
 
 Buddy ChatDetailsBuddy::buddy() const
 {
-	return MyBuddy;
+	return m_buddy;
 }
 
 /**
@@ -110,7 +114,7 @@ Buddy ChatDetailsBuddy::buddy() const
  */
 void ChatDetailsBuddy::setChats(const QVector<Chat> &chats)
 {
-	Chats.clear();
+	m_chats.clear();
 	for (auto &&chat : chats)
 		addChat(chat);
 }
@@ -123,20 +127,20 @@ void ChatDetailsBuddy::setChats(const QVector<Chat> &chats)
  */
 const QVector<Chat> & ChatDetailsBuddy::chats() const
 {
-	return Chats;
+	return m_chats;
 }
 
 void ChatDetailsBuddy::addChat(const Chat &chat)
 {
-	if (chat && !Chats.contains(chat))
-		Chats.append(chat);
+	if (chat && !m_chats.contains(chat))
+		m_chats.append(chat);
 }
 
 void ChatDetailsBuddy::removeChat(const Chat &chat)
 {
-	int indexOf = Chats.indexOf(chat);
+	int indexOf = m_chats.indexOf(chat);
 	if (indexOf >= 0)
-		Chats.remove(indexOf);
+		m_chats.remove(indexOf);
 }
 
 #include "moc_chat-details-buddy.cpp"
