@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,13 +17,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHAT_DETAILS_BUDDY_H
-#define CHAT_DETAILS_BUDDY_H
+#pragma once
 
 #include "chat/chat-details.h"
 #include "contacts/contact.h"
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class ChatTypeManager;
+
 /**
  * @addtogroup Chat
  * @{
@@ -44,9 +44,6 @@ class KADUAPI ChatDetailsBuddy : public ChatDetails
 {
 	Q_OBJECT
 
-	Buddy MyBuddy;
-	QVector<Chat> Chats;
-
 public:
 	explicit ChatDetailsBuddy(ChatShared *chatData);
 	virtual ~ChatDetailsBuddy();
@@ -68,10 +65,17 @@ public:
 	void addChat(const Chat &chat);
 	void removeChat(const Chat &chat);
 
+private:
+	QPointer<ChatTypeManager> m_chatTypeManager;
+
+	Buddy m_buddy;
+	QVector<Chat> m_chats;
+
+private slots:
+	INJEQT_SET void setChatTypeManager(ChatTypeManager *chatTypeManager);
+
 };
 
 /**
  * @}
  */
-
-#endif // CHAT_DETAILS_BUDDY_H
