@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,14 +18,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "chat-details-contact-set.h"
+
 #include "buddies/buddy-manager.h"
 #include "chat/chat.h"
 #include "chat/type/chat-type-manager.h"
+#include "contacts/contact-manager.h"
 #include "contacts/contact-set-configuration-helper.h"
 #include "protocols/protocol.h"
 
-#include "chat-details-contact-set.h"
-
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Creates empty ChatDetailsContactSet object.
@@ -52,6 +50,16 @@ ChatDetailsContactSet::~ChatDetailsContactSet()
 {
 }
 
+void ChatDetailsContactSet::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
+void ChatDetailsContactSet::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Loads ChatDetailsContactSet object from storage.
@@ -66,7 +74,7 @@ void ChatDetailsContactSet::load()
 
 	ChatDetails::load();
 
-	Contacts = ContactSetConfigurationHelper::loadFromConfiguration(this, "Contacts");
+	m_contacts = ContactSetConfigurationHelper::loadFromConfiguration(m_contactManager, this, "Contacts");
 }
 
 /**
@@ -74,7 +82,7 @@ void ChatDetailsContactSet::load()
  * @short Stores ChatDetailsContactSet object to storage.
  *
  * Stores ChatDetailsContactSet object to the same storage assigned Chat object is
- * using. This stores set of contacts into 'Contacts' subnode.
+ * using. This stores set of contacts into 'm_contacts' subnode.
  */
 void ChatDetailsContactSet::store()
 {
@@ -83,7 +91,7 @@ void ChatDetailsContactSet::store()
 
 	ensureLoaded();
 
-	ContactSetConfigurationHelper::saveToConfiguration(this, "Contacts", Contacts);
+	ContactSetConfigurationHelper::saveToConfiguration(this, "Contacts", m_contacts);
 }
 
 /**
@@ -98,7 +106,7 @@ bool ChatDetailsContactSet::shouldStore()
 {
 	ensureLoaded();
 
-	return StorableObject::shouldStore() && !Contacts.isEmpty();
+	return StorableObject::shouldStore() && !m_contacts.isEmpty();
 }
 
 /**
@@ -110,7 +118,7 @@ bool ChatDetailsContactSet::shouldStore()
  */
 ChatType * ChatDetailsContactSet::type() const
 {
-	return ChatTypeManager::instance()->chatType("ContactSet");
+	return m_chatTypeManager->chatType("ContactSet");
 }
 
 /**
@@ -124,7 +132,7 @@ ChatType * ChatDetailsContactSet::type() const
 QString ChatDetailsContactSet::name() const
 {
 	QStringList displays;
-	foreach (const Contact &contact, Contacts)
+	foreach (const Contact &contact, m_contacts)
 		displays.append(contact.display(true));
 
 	displays.sort();
@@ -147,7 +155,7 @@ void ChatDetailsContactSet::setContacts(const ContactSet &contacts)
 {
 	ensureLoaded();
 
-	Contacts = contacts;
+	m_contacts = contacts;
 }
 
 #include "moc_chat-details-contact-set.cpp"
