@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,14 +17,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHAT_DETAILS_CONTACT_SET_H
-#define CHAT_DETAILS_CONTACT_SET_H
+#pragma once
 
 #include "buddies/buddy-set.h"
+#include "chat/chat-details.h"
 #include "contacts/contact-set.h"
 #include "contacts/contact.h"
 
-#include "chat/chat-details.h"
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class ChatTypeManager;
+class ContactManager;
 
 /**
  * @addtogroup Chat
@@ -48,29 +48,35 @@ class ChatDetailsContactSet : public ChatDetails
 {
 	Q_OBJECT
 
-	ContactSet Contacts;
-
-protected:
-	virtual void load();
-	virtual void store();
-	virtual bool shouldStore();
-
 public:
 	explicit ChatDetailsContactSet(ChatShared *chatData);
 	virtual ~ChatDetailsContactSet();
 
 	virtual ChatType * type() const;
-	virtual ContactSet contacts() const { return Contacts; }
+	virtual ContactSet contacts() const { return m_contacts; }
 	virtual QString name() const;
 
 	virtual bool isConnected() const;
 
 	void setContacts(const ContactSet &contacts);
 
+protected:
+	virtual void load();
+	virtual void store();
+	virtual bool shouldStore();
+
+private:
+	QPointer<ChatTypeManager> m_chatTypeManager;
+	QPointer<ContactManager> m_contactManager;
+
+	ContactSet m_contacts;
+
+private slots:
+	INJEQT_SET void setChatTypeManager(ChatTypeManager *chatTypeManager);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+
 };
 
 /**
  * @}
  */
-
-#endif // CHAT_DETAILS_CONTACT_SET_H
