@@ -1,11 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,38 +31,16 @@
 #include "chat/chat-manager.h"
 #include "chat/type/chat-type-manager.h"
 #include "chat/type/chat-type.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-set.h"
+#include "core/injected-factory.h"
 #include "misc/change-notifier.h"
 #include "parser/parser.h"
 #include "debug.h"
 
 #include "chat-shared.h"
 
-ChatShared * ChatShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	ChatShared *result = loadFromStorage(storagePoint);
-	result->loadStub();
-
-	return result;
-}
-
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Loads chat data from given storage point.
- * @param storagePoint storagePoint from which chat data will be loaded
- *
- * Creates new object of ChatShared type and assigns storagePoint to it.
- * Object is lazy-loaded (it will be loaded when used first time).
- */
-ChatShared * ChatShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	ChatShared *result = new ChatShared();
-	result->setStorage(storagePoint);
-
-	return result;
-}
-
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Creates new ChatShared object.
@@ -74,11 +52,8 @@ ChatShared * ChatShared::loadFromStorage(const std::shared_ptr<StoragePoint> &st
  * created.
  */
 ChatShared::ChatShared(const QUuid &uuid) :
-		Shared(uuid), Details(0), IgnoreAllMessages(false), UnreadMessagesCount(0), Open(false)
+		Shared(uuid), ChatAccount{nullptr}, Details(0), IgnoreAllMessages(false), UnreadMessagesCount(0), Open(false)
 {
-	ChatAccount = new Account();
-
-	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
 }
 
 /**
@@ -92,11 +67,41 @@ ChatShared::~ChatShared()
 {
 	ref.ref();
 
-	triggerAllChatTypesUnregistered();
-
 	delete ChatAccount;
 }
 
+void ChatShared::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void ChatShared::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void ChatShared::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
+void ChatShared::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ChatShared::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
+}
+
+void ChatShared::init()
+{
+	ChatAccount = new Account();
+
+	connect(&changeNotifier(), SIGNAL(changed()), this, SIGNAL(updated()));
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Returns parent storage node for this object - ChatManager node.
@@ -106,7 +111,7 @@ ChatShared::~ChatShared()
  */
 StorableObject * ChatShared::storageParent()
 {
-	return ChatManager::instance();
+	return m_chatManager;
 }
 
 /**
@@ -118,7 +123,7 @@ StorableObject * ChatShared::storageParent()
  */
 QString ChatShared::storageNodeName()
 {
-	return QLatin1String("Chat");
+	return QStringLiteral("Chat");
 }
 
 /**
@@ -139,12 +144,12 @@ void ChatShared::load()
 
 	Shared::load();
 
-	XmlConfigFile *configurationStorage = storage()->storage();
+	ConfigurationApi *configurationStorage = storage()->storage();
 	QDomElement parent = storage()->point();
 
 	Groups.clear();
 
-	QDomElement groupsNode = configurationStorage->getNode(parent, "ChatGroups", XmlConfigFile::ModeFind);
+	QDomElement groupsNode = configurationStorage->getNode(parent, "ChatGroups", ConfigurationApi::ModeFind);
 	if (!groupsNode.isNull())
 	{
 		QDomNodeList groupsList = groupsNode.elementsByTagName("Group");
@@ -155,24 +160,24 @@ void ChatShared::load()
 			QDomElement groupElement = groupsList.at(i).toElement();
 			if (groupElement.isNull())
 				continue;
-			doAddToGroup(GroupManager::instance()->byUuid(groupElement.text()));
+			doAddToGroup(m_groupManager->byUuid(groupElement.text()));
 		}
 	}
 
-	*ChatAccount = AccountManager::instance()->byUuid(QUuid(loadValue<QString>("Account")));
+	*ChatAccount = m_accountManager->byUuid(QUuid(loadValue<QString>("Account")));
 	Display = loadValue<QString>("Display");
-	Type = loadValue<QString>("Type");
+	auto type = loadValue<QString>("Type");
 
 	// import from alias to new name of chat type
-	ChatType *chatType = ChatTypeManager::instance()->chatType(Type);
+	ChatType *chatType = m_chatTypeManager->chatType(type);
 	if (chatType)
-		Type = chatType->name();
+		type = chatType->name();
 
 	// we should not have display names for Contact chats
-	if (Type == "Contact")
+	if (type == "Contact")
 		Display.clear();
 
-	triggerAllChatTypesRegistered();
+	setType(type);
 }
 
 /**
@@ -190,14 +195,14 @@ void ChatShared::store()
 
 	Shared::store();
 
-	XmlConfigFile *configurationStorage = storage()->storage();
+	ConfigurationApi *configurationStorage = storage()->storage();
 	QDomElement parent = storage()->point();
 
 	storeValue("Account", ChatAccount->uuid().toString());
 	storeValue("Display", Display);
 
 	// import from alias to new name of chat type
-	ChatType *chatType = ChatTypeManager::instance()->chatType(Type);
+	ChatType *chatType = m_chatTypeManager->chatType(Type);
 	if (chatType)
 		Type = chatType->name();
 
@@ -205,7 +210,7 @@ void ChatShared::store()
 
 	if (!Groups.isEmpty())
 	{
-		QDomElement groupsNode = configurationStorage->getNode(parent, "ChatGroups", XmlConfigFile::ModeCreate);
+		QDomElement groupsNode = configurationStorage->getNode(parent, "ChatGroups", ConfigurationApi::ModeCreate);
 		foreach (const Group &group, Groups)
 			configurationStorage->appendTextNode(groupsNode, "Group", group.uuid().toString());
 	}
@@ -231,7 +236,7 @@ bool ChatShared::shouldStore()
 		return false;
 
 	// we dont need data for non-roster contacts only from 4 version of sql schema
-	if (config_file.readNumEntry("History", "Schema", 0) < 4)
+	if (m_configuration->deprecatedApi()->readNumEntry("History", "Schema", 0) < 4)
 		return true;
 
 	if (customProperties()->shouldStore())
@@ -252,7 +257,8 @@ bool ChatShared::shouldStore()
  */
 void ChatShared::aboutToBeRemoved()
 {
-	*ChatAccount = Account::null;
+	if (ChatAccount)
+		*ChatAccount = Account::null;
 	Groups.clear();
 
 	if (Details)
@@ -263,16 +269,10 @@ void ChatShared::aboutToBeRemoved()
 	}
 }
 
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Called after new chat type was registered.
- *
- * If no details class is loaded and registered chat type is valid for this chat
- * new details class is created, assigned and loaded for this object.
- */
-void ChatShared::chatTypeRegistered(ChatType *chatType)
+void ChatShared::loadDetails()
 {
-	if (chatType->name() != Type)
+	auto chatType = m_chatTypeManager->chatType(type());
+	if (!chatType)
 		return;
 
 	if (!Details)
@@ -291,29 +291,7 @@ void ChatShared::chatTypeRegistered(ChatType *chatType)
 		Details->ensureLoaded();
 	}
 
-	ChatManager::instance()->registerItem(this);
-}
-
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Called after chat type was unregistered.
- *
- * If details class is loaded and unregistered chat type is valid for this chat
- * details class is stored and removed from this object.
- */
-void ChatShared::chatTypeUnregistered(ChatType *chatType)
-{
-	if (chatType->name() != Type)
-		return;
-
-	if (Details)
-	{
-		Details->ensureStored();
-		delete Details;
-		Details = 0;
-	}
-
-	ChatManager::instance()->unregisterItem(this);
+	m_chatManager->registerItem(this);
 }
 
 /**
@@ -359,14 +337,11 @@ void ChatShared::setType(const QString &type)
 		delete Details;
 		Details = 0;
 
-		ChatManager::instance()->unregisterItem(this);
+		m_chatManager->unregisterItem(this);
 	}
 
 	Type = type;
-
-	ChatType *chatType = ChatTypeManager::instance()->chatType(type);
-	if (chatType)
-		chatTypeRegistered(chatType); // this will add details
+	loadDetails();
 }
 
 void ChatShared::setGroups(const QSet<Group> &groups)
