@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +26,7 @@
 #include "chat/chat-details.h"
 #include "chat/chat-manager.h"
 #include "contacts/contact-set.h"
+#include "core/injected-factory.h"
 
 #include "chat.h"
 
@@ -39,37 +40,6 @@ KaduSharedBaseClassImpl(Chat)
  */
 Chat Chat::null;
 
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Creates new empty Chat object.
- * @return new empty Chat object, with @link ChatShared @endlink attached.
- *
- * Creates new empty Chat object, with @link ChatShared @endlink attached.
- */
-Chat Chat::create()
-{
-	return new ChatShared();
-}
-
-Chat Chat::loadStubFromStorage(const std::shared_ptr<StoragePoint> &chatStoragePoint)
-{
-	return ChatShared::loadStubFromStorage(chatStoragePoint);
-}
-
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Loads Chat object from storage.
- * @param chatStoragePoint storage point from which chat data will be loaded
- * @return Chat object loaded from given storage poin.
- *
- * Loads Chat object from storage point and returns it. Real data will be loaded
- * at first usage of Chat object.
- */
-Chat Chat::loadFromStorage(const std::shared_ptr<StoragePoint> &chatStoragePoint)
-{
-	return ChatShared::loadFromStorage(chatStoragePoint);
-}
-
 Chat::Chat()
 {
 }
@@ -172,3 +142,11 @@ void Chat::setOpen(bool open)
 	if (!isNull())
 		data()->setOpen(open);
 }
+
+QString title(const Chat& chat)
+{
+	if (!chat.display().isEmpty())
+		return chat.display();
+	else
+		return chat.name();
+}
