@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,14 +18,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "chat/chat-list-mime-data-helper.h"
+#include "chat-list-model.h"
+
+#include "chat/chat-list-mime-data-service.h"
 #include "chat/model/chat-data-extractor.h"
 #include "contacts/contact-set.h"
 #include "contacts/model/contact-data-extractor.h"
 #include "model/roles.h"
+#include "talkable/talkable-converter.h"
 #include "talkable/talkable.h"
 
-#include "chat-list-model.h"
+#include <QtCore/QMimeData>
+
+#define NO_PARENT_ID 0xffffff
 
 ChatListModel::ChatListModel(QObject *parent) :
 		QAbstractItemModel(parent)
@@ -36,6 +41,26 @@ ChatListModel::~ChatListModel()
 {
 }
 
+void ChatListModel::setChatDataExtractor(ChatDataExtractor *chatDataExtractor)
+{
+	m_chatDataExtractor = chatDataExtractor;
+}
+
+void ChatListModel::setChatListMimeDataService(ChatListMimeDataService *chatListMimeDataService)
+{
+	m_chatListMimeDataService = chatListMimeDataService;
+}
+
+void ChatListModel::setContactDataExtractor(ContactDataExtractor *contactDataExtractor)
+{
+	m_contactDataExtractor = contactDataExtractor;
+}
+
+void ChatListModel::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
 void ChatListModel::connectChat(const Chat &chat)
 {
 	connect(chat, SIGNAL(contactAboutToBeAdded(Contact)), this, SLOT(contactAboutToBeAdded(Contact)));
@@ -98,7 +123,7 @@ void ChatListModel::removeChat(const Chat &chat)
 
 QModelIndex ChatListModel::index(int row, int column, const QModelIndex &parent) const
 {
-	return hasIndex(row, column, parent) ? createIndex(row, column, parent.isValid() ? parent.row() : -1) : QModelIndex();
+	return hasIndex(row, column, parent) ? createIndex(row, column, parent.isValid() ? parent.row() : NO_PARENT_ID) : QModelIndex();
 }
 
 int ChatListModel::columnCount(const QModelIndex &parent) const
@@ -132,7 +157,7 @@ QFlags<Qt::ItemFlag> ChatListModel::flags(const QModelIndex& index) const
 
 QModelIndex ChatListModel::parent(const QModelIndex &child) const
 {
-	if (-1 == child.internalId())
+	if (NO_PARENT_ID == child.internalId())
 		return QModelIndex();
 	else
 		return index(static_cast<int>(child.internalId()), 0, QModelIndex());
@@ -149,7 +174,7 @@ QVariant ChatListModel::data(const QModelIndex &index, int role) const
 		if (ItemTypeRole == role)
 			return ChatRole;
 
-		return ChatDataExtractor::data(chatAt(index), role);
+		return m_chatDataExtractor->data(chatAt(index), role);
 	}
 
 	if (!parentIndex.parent().isValid())
@@ -161,7 +186,7 @@ QVariant ChatListModel::data(const QModelIndex &index, int role) const
 		if (index.row() >= contacts.size())
 			return QVariant();
 
-		return ContactDataExtractor::data(contacts.at(index.row()), role, true);
+		return m_contactDataExtractor->data(contacts.at(index.row()), role, true);
 	}
 
 	return QVariant();
@@ -286,7 +311,7 @@ Chat ChatListModel::chatFromVariant(const QVariant &variant) const
 
 	const Talkable &talkable = variant.value<Talkable>();
 	if (talkable.isValidChat())
-		return talkable.toChat();
+		return m_talkableConverter->toChat(talkable);
 
 	return Chat::null;
 }
@@ -330,7 +355,7 @@ QModelIndexList ChatListModel::indexListForValue(const QVariant &value) const
 
 QStringList ChatListModel::mimeTypes() const
 {
-	return ChatListMimeDataHelper::mimeTypes();
+	return m_chatListMimeDataService->mimeTypes();
 }
 
 QMimeData * ChatListModel::mimeData(const QModelIndexList &indexes) const
@@ -343,7 +368,7 @@ QMimeData * ChatListModel::mimeData(const QModelIndexList &indexes) const
 			list << chat;
 	}
 
-	return ChatListMimeDataHelper::toMimeData(list);
+	return m_chatListMimeDataService->toMimeData(list).release();
 }
 
 #include "moc_chat-list-model.cpp"
