@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,23 +18,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "chat-type-buddy.h"
+
 #include "chat/chat-details-buddy.h"
 #include "chat/chat.h"
+#include "core/injected-factory.h"
 #include "icons/kadu-icon.h"
 
-#include "chat-type-buddy.h"
-
 ChatTypeBuddy::ChatTypeBuddy(QObject *parent) :
 		ChatType(parent)
 {
-	Aliases.append("Buddy");
-	Aliases.append("Aggregate");
+	m_aliases.append(QStringLiteral("Buddy"));
+	m_aliases.append(QStringLiteral("Aggregate"));
 }
 
 ChatTypeBuddy::~ChatTypeBuddy()
 {
 }
 
+void ChatTypeBuddy::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Internal name of chat type.
@@ -67,7 +67,7 @@ QString ChatTypeBuddy::name() const
  */
 QStringList ChatTypeBuddy::aliases() const
 {
-	return Aliases;
+	return m_aliases;
 }
 
 /**
@@ -81,7 +81,7 @@ QStringList ChatTypeBuddy::aliases() const
  */
 KaduIcon ChatTypeBuddy::icon() const
 {
-	return KaduIcon("kadu_icons/conference");
+	return KaduIcon(QStringLiteral("kadu_icons/conference"));
 }
 
 /**
@@ -94,7 +94,7 @@ KaduIcon ChatTypeBuddy::icon() const
  */
 QString ChatTypeBuddy::windowRole() const
 {
-	return "kadu-chat-aggregate";
+	return QStringLiteral("kadu-chat-aggregate");
 }
 
 /**
@@ -107,7 +107,7 @@ QString ChatTypeBuddy::windowRole() const
  */
 ChatDetails * ChatTypeBuddy::createChatDetails(ChatShared *chatData) const
 {
-	return new ChatDetailsBuddy(chatData);
+	return m_injectedFactory->makeInjected<ChatDetailsBuddy>(chatData);
 }
 
 ChatEditWidget * ChatTypeBuddy::createEditWidget(const Chat &chat, QWidget *parent) const
