@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,13 +18,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "chat/chat-details-contact-set.h"
-#include "chat/chat-manager.h"
-#include "icons/kadu-icon.h"
-
 #include "chat-type-contact-set.h"
 
-Chat ChatTypeContactSet::findChat(const ContactSet &contacts, NotFoundAction notFoundAction)
+#include "chat/chat-details-contact-set.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
+#include "core/injected-factory.h"
+#include "icons/kadu-icon.h"
+
+Chat ChatTypeContactSet::findChat(ChatManager *chatManager, ChatStorage *chatStorage, const ContactSet &contacts, NotFoundAction notFoundAction)
 {
 	if (contacts.count() < 2)
 		return Chat::null;
@@ -50,8 +46,8 @@ Chat ChatTypeContactSet::findChat(const ContactSet &contacts, NotFoundAction not
 		if (contact.id() == account.id())
 			return Chat::null;
 
-	foreach (const Chat &chat, ChatManager::instance()->allItems()) // search allItems, chats can be not loaded yet
-		if (chat.type() == QLatin1String("ContactSet") || chat.type() == QLatin1String("Conference"))
+	foreach (const Chat &chat, chatManager->allItems()) // search allItems, chats can be not loaded yet
+		if (chat.type() == QStringLiteral("ContactSet") || chat.type() == QStringLiteral("Conference"))
 			if (chat.contacts() == contacts)
 			{
 				// when contacts changed their accounts we need to change account of chat too
@@ -62,7 +58,7 @@ Chat ChatTypeContactSet::findChat(const ContactSet &contacts, NotFoundAction not
 	if (ActionReturnNull == notFoundAction)
 		return Chat::null;
 
-	Chat chat = Chat::create();
+	auto chat = chatStorage->create();
 	chat.setChatAccount(account);
 
 	Contact contact = contacts.toContact();
@@ -82,7 +78,7 @@ Chat ChatTypeContactSet::findChat(const ContactSet &contacts, NotFoundAction not
 	}
 
 	if (ActionCreateAndAdd == notFoundAction)
-		ChatManager::instance()->addItem(chat);
+		chatManager->addItem(chat);
 
 	return chat;
 }
@@ -90,14 +86,19 @@ Chat ChatTypeContactSet::findChat(const ContactSet &contacts, NotFoundAction not
 ChatTypeContactSet::ChatTypeContactSet(QObject *parent) :
 		ChatType(parent)
 {
-	Aliases.append("ContactSet");
-	Aliases.append("Conference");
+	m_aliases.append("ContactSet");
+	m_aliases.append("Conference");
 }
 
 ChatTypeContactSet::~ChatTypeContactSet()
 {
 }
 
+void ChatTypeContactSet::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Internal name of chat type.
@@ -124,7 +125,7 @@ QString ChatTypeContactSet::name() const
  */
 QStringList ChatTypeContactSet::aliases() const
 {
-	return Aliases;
+	return m_aliases;
 }
 
 /**
@@ -164,7 +165,7 @@ QString ChatTypeContactSet::windowRole() const
  */
 ChatDetails * ChatTypeContactSet::createChatDetails(ChatShared *chatData) const
 {
-	return new ChatDetailsContactSet(chatData);
+	return m_injectedFactory->makeInjected<ChatDetailsContactSet>(chatData);
 }
 
 ChatEditWidget * ChatTypeContactSet::createEditWidget(const Chat &chat, QWidget *parent) const
