@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,13 +20,15 @@
 
 #include "chat/chat-details-contact.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/chat.h"
 #include "contacts/contact-set.h"
+#include "core/injected-factory.h"
 #include "icons/kadu-icon.h"
 
 #include "chat-type-contact.h"
 
-Chat ChatTypeContact::findChat(const Contact &contact, NotFoundAction notFoundAction)
+Chat ChatTypeContact::findChat(ChatManager *chatManager, ChatStorage *chatStorage, const Contact &contact, NotFoundAction notFoundAction)
 {
 	Account account = contact.contactAccount();
 	if (!account)
@@ -41,8 +37,8 @@ Chat ChatTypeContact::findChat(const Contact &contact, NotFoundAction notFoundAc
 	if (contact.id() == account.id())
 		return Chat::null;
 
-	foreach (const Chat &chat, ChatManager::instance()->allItems())
-		if (chat.type() == QLatin1String("Contact") || chat.type() == QLatin1String("Simple"))
+	foreach (const Chat &chat, chatManager->allItems())
+		if (chat.type() == QStringLiteral("Contact") || chat.type() == QStringLiteral("Simple"))
 			if (chat.contacts().toContact() == contact)
 			{
 				// when contacts changed their accounts we need to change account of chat too
@@ -53,7 +49,7 @@ Chat ChatTypeContact::findChat(const Contact &contact, NotFoundAction notFoundAc
 	if (ActionReturnNull == notFoundAction)
 		return Chat::null;
 
-	Chat chat = Chat::create();
+	auto chat = chatStorage->create();
 	chat.setChatAccount(account);
 	chat.setType("Contact");
 
@@ -65,7 +61,7 @@ Chat ChatTypeContact::findChat(const Contact &contact, NotFoundAction notFoundAc
 	}
 
 	if (ActionCreateAndAdd == notFoundAction)
-		ChatManager::instance()->addItem(chat);
+		chatManager->addItem(chat);
 
 	return chat;
 }
@@ -81,6 +77,11 @@ ChatTypeContact::~ChatTypeContact()
 {
 }
 
+void ChatTypeContact::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Internal name of chat type.
@@ -134,7 +135,7 @@ KaduIcon ChatTypeContact::icon() const
  */
 QString ChatTypeContact::windowRole() const
 {
-	return "kadu-chat-contact";
+	return QStringLiteral("kadu-chat-contact");
 }
 
 /**
@@ -147,7 +148,7 @@ QString ChatTypeContact::windowRole() const
  */
 ChatDetails * ChatTypeContact::createChatDetails(ChatShared *chatData) const
 {
-	return new ChatDetailsContact(chatData);
+	return m_injectedFactory->makeInjected<ChatDetailsContact>(chatData);
 }
 
 ChatEditWidget * ChatTypeContact::createEditWidget(const Chat &chat, QWidget *parent) const
