@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,18 +20,19 @@
 
 #include "chat/chat-details-room.h"
 #include "chat/chat-manager.h"
-#include "chat/chat.h"
+#include "chat/chat-storage.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/chat-room-edit-widget.h"
 #include "icons/kadu-icon.h"
 
 #include "chat-type-room.h"
 
-Chat ChatTypeRoom::findChat(const Account &account, const QString &room, NotFoundAction notFoundAction)
+Chat ChatTypeRoom::findChat(ChatManager *chatManager, ChatStorage *chatStorage, const Account &account, const QString &room, NotFoundAction notFoundAction)
 {
 	if (!account)
 		return Chat::null;
 
-	foreach (const Chat &chat, ChatManager::instance()->allItems())
+	foreach (const Chat &chat, chatManager->allItems())
 	{
 		if (chat.type() != "Room")
 			continue;
@@ -55,7 +50,7 @@ Chat ChatTypeRoom::findChat(const Account &account, const QString &room, NotFoun
 	if (ActionReturnNull == notFoundAction)
 		return Chat::null;
 
-	Chat chat = Chat::create();
+	auto chat = chatStorage->create();
 	chat.setChatAccount(account);
 	chat.setType("Room");
 
@@ -65,7 +60,7 @@ Chat ChatTypeRoom::findChat(const Account &account, const QString &room, NotFoun
 	details->setRoom(room);
 
 	if (ActionCreateAndAdd == notFoundAction)
-		ChatManager::instance()->addItem(chat);
+		chatManager->addItem(chat);
 
 	return chat;
 }
@@ -79,6 +74,11 @@ ChatTypeRoom::~ChatTypeRoom()
 {
 }
 
+void ChatTypeRoom::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 /**
  * @author Rafal 'Vogel' Malinowski
  * @short Internal name of chat type.
@@ -145,12 +145,12 @@ QString ChatTypeRoom::windowRole() const
  */
 ChatDetails * ChatTypeRoom::createChatDetails(ChatShared *chatData) const
 {
-	return new ChatDetailsRoom(chatData);
+	return m_injectedFactory->makeInjected<ChatDetailsRoom>(chatData);
 }
 
 ChatEditWidget * ChatTypeRoom::createEditWidget(const Chat &chat, QWidget *parent) const
 {
-	return new ChatRoomEditWidget(chat, parent);
+	return m_injectedFactory->makeInjected<ChatRoomEditWidget>(chat, parent);
 }
 
 #include "moc_chat-type-room.cpp"
