@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,16 +19,23 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/core.h"
 
 #include "config-file-data-manager.h"
 
+void ConfigFileDataManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
 void ConfigFileDataManager::writeEntry(const QString &section, const QString &name, const QVariant &value)
 {
 	if (section.isEmpty() || name.isEmpty())
 		return;
 
-	config_file.writeEntry(section, name, value.toString());
+	m_configuration->deprecatedApi()->writeEntry(section, name, value.toString());
 }
 
 QVariant ConfigFileDataManager::readEntry(const QString &section, const QString &name)
@@ -38,7 +43,7 @@ QVariant ConfigFileDataManager::readEntry(const QString &section, const QString
 	if (section.isEmpty() || name.isEmpty())
 		return QVariant(QString());
 
-	return QVariant(config_file.readEntry(section, name));
+	return QVariant(m_configuration->deprecatedApi()->readEntry(section, name));
 }
 
 
