@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,12 +20,14 @@
 
 #include <QtCore/QVariant>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/core.h"
 
 #include "config-file-variant-wrapper.h"
 
-ConfigFileVariantWrapper::ConfigFileVariantWrapper(const QString &group, const QString &name) :
-		Group(group), Name(name)
+ConfigFileVariantWrapper::ConfigFileVariantWrapper(Configuration *configuration, const QString &group, const QString &name) :
+		m_configuration{configuration}, Group(group), Name(name)
 {
 }
 
@@ -36,10 +37,10 @@ ConfigFileVariantWrapper::~ConfigFileVariantWrapper()
 
 QVariant ConfigFileVariantWrapper::get(const QVariant &defaultValue) const
 {
-	return config_file.readEntry(Group, Name, defaultValue.toString());
+	return m_configuration->deprecatedApi()->readEntry(Group, Name, defaultValue.toString());
 }
 
 void ConfigFileVariantWrapper::set(const QVariant &value)
 {
-	config_file.writeEntry(Group, Name, value.toString());
+	m_configuration->deprecatedApi()->writeEntry(Group, Name, value.toString());
 }
