@@ -1,12 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,31 +21,20 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-
-#include "configuration/toolbar-configuration-manager.h"
-#include "configuration/xml-configuration-file.h"
-#include "storage/storable-object.h"
-
 #include "configuration-manager.h"
 
-ConfigurationManager * ConfigurationManager::Instance = 0;
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "core/application.h"
+#include "gui/configuration/toolbar-configuration-manager.h"
+#include "storage/storable-object.h"
 
-ConfigurationManager * ConfigurationManager::instance()
-{
-	if (!Instance)
-	{
-		Instance = new ConfigurationManager(qApp);
-		Instance->load();
-	}
-
-	return Instance;
-}
+#include <QtWidgets/QApplication>
 
 ConfigurationManager::ConfigurationManager(QObject *parent) :
-		QObject(parent)
+		QObject{parent}
 {
-	ToolbarConfiguration = new ToolbarConfigurationManager();
+	m_toolbarConfiguration = new ToolbarConfigurationManager();
 
 	connect(qApp, SIGNAL(commitDataRequest(QSessionManager&)),
 			this, SLOT(flush()));
@@ -55,33 +42,43 @@ ConfigurationManager::ConfigurationManager(QObject *parent) :
 
 ConfigurationManager::~ConfigurationManager()
 {
-	delete ToolbarConfiguration;
-	ToolbarConfiguration = 0;
+	delete m_toolbarConfiguration;
+	m_toolbarConfiguration = 0;
 }
 
-void ConfigurationManager::load()
+void ConfigurationManager::setApplication(Application *application)
 {
-	xml_config_file->makeBackup();
+	m_application = application;
+}
+
+void ConfigurationManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ConfigurationManager::init()
+{
+	m_application->backupConfiguration();
 
 	importConfiguration();
 
-	Uuid = xml_config_file->rootElement().attribute("uuid");
-	if (Uuid.isNull())
-		Uuid = QUuid::createUuid();
+	m_uuid = m_configuration->api()->rootElement().attribute("uuid");
+	if (m_uuid.isNull())
+		m_uuid = QUuid::createUuid();
 }
 
 void ConfigurationManager::flush()
 {
-	foreach (StorableObject *object, RegisteredStorableObjects)
+	foreach (StorableObject *object, m_registeredStorableObjects)
 		object->ensureStored();
 
-	xml_config_file->rootElement().setAttribute("uuid", Uuid.toString());
-	xml_config_file->sync();
+	m_configuration->api()->rootElement().setAttribute("uuid", m_uuid.toString());
+	m_application->flushConfiguration();
 }
 
 void ConfigurationManager::registerStorableObject(StorableObject *object)
 {
-	if (RegisteredStorableObjects.contains(object))
+	if (m_registeredStorableObjects.contains(object))
 	{
 		qWarning("Someone tried to register already registered storable object.");
 		return;
@@ -91,23 +88,25 @@ void ConfigurationManager::registerStorableObject(StorableObject *object)
 	// This way if object A is registered and then object B which depends on A and can
 	// change A's properties is registered, we first call ensureStored() on B, which can
 	// safely change A's properties and they will be stored.
-	RegisteredStorableObjects.prepend(object);
+	m_registeredStorableObjects.prepend(object);
 }
 
 void ConfigurationManager::unregisterStorableObject(StorableObject *object)
 {
 	object->ensureStored();
 
-	if (RegisteredStorableObjects.removeAll(object) <= 0)
+	if (m_registeredStorableObjects.removeAll(object) <= 0)
 		qWarning("Someone tried to unregister unregistered storable object.");
 }
 
 void ConfigurationManager::importConfiguration()
 {
-	QDomElement root = xml_config_file->rootElement();
-	QDomElement general = xml_config_file->findElementByProperty(root.firstChild().firstChild().toElement(), "Group", "name", "General");
-	QDomElement mainConfiguration = xml_config_file->findElementByProperty(general, "Entry", "name", "ConfigGeometry");
+	QDomElement root = m_configuration->api()->rootElement();
+	QDomElement general = m_configuration->api()->findElementByProperty(root.firstChild().firstChild().toElement(), "Group", "name", "General");
+	QDomElement mainConfiguration = m_configuration->api()->findElementByProperty(general, "Entry", "name", "ConfigGeometry");
 
 	if (!mainConfiguration.isNull())
 		  mainConfiguration.setAttribute("name", "MainConfiguration_Geometry");
 }
+
+#include "moc_configuration-manager.cpp"
