@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -34,7 +30,8 @@ class KADUAPI ConfigurationWindowDataManager : public QObject
 	Q_OBJECT
 
 public:
-	explicit ConfigurationWindowDataManager(QObject *parent = 0) : QObject(parent) {}
+	explicit ConfigurationWindowDataManager(QObject *parent = nullptr);
+	virtual ~ConfigurationWindowDataManager();
 
 	virtual void writeEntry(const QString &section, const QString &name, const QVariant &value) = 0;
 	virtual QVariant readEntry(const QString &section, const QString &name) = 0;
