@@ -1,9 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,57 +21,70 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "contact-manager.h"
+
+#include "buddies/buddy-manager.h"
+#include "buddies/buddy-storage.h"
+#include "buddies/buddy.h"
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "contacts/contact-storage.h"
+#include "core/myself.h"
+#include "message/unread-message-repository.h"
+#include "misc/change-notifier-lock.h"
+#include "parser/parser.h"
+#include "protocols/protocol-factory.h"
+#include "protocols/protocol.h"
+#include "roster/roster-entry-state.h"
+#include "roster/roster-entry.h"
+#include "debug.h"
+
 #include <QtCore/QPair>
 #include <QtCore/QTimer>
 
-#include "buddies/buddy-manager.h"
-#include "buddies/buddy.h"
-#include "configuration/configuration-file.h"
-#include "configuration/configuration-manager.h"
-#include "contacts/contact-parser-tags.h"
-#include "core/core.h"
-#include "message/unread-message-repository.h"
-#include "misc/change-notifier-lock.h"
-#include "protocols/protocol-factory.h"
-#include "protocols/protocol.h"
-#include "protocols/services/roster/roster-entry.h"
-#include "debug.h"
-
-#include "contact-manager.h"
-
-ContactManager * ContactManager::Instance = 0;
-
-ContactManager * ContactManager::instance()
-{
-	if (0 == Instance)
-	{
-		// this must be called before ContactManager has its own pretty storage point
-		// if ContactManager is called first and import from 0.6.5 is done
-		// when ContactManager's storage() point will be modified from Contacts to OldContacts
-		// and everything will be fucked up
-		BuddyManager::instance();
-
-		Instance = new ContactManager();
-
-		// moved from here because of #2758
-		// Instance->init();
-	}
-
-	return Instance;
-}
-
-ContactManager::ContactManager()
+ContactManager::ContactManager(QObject *parent) :
+		SimpleManager<Contact>{parent}
 {
 }
 
 ContactManager::~ContactManager()
 {
-	disconnect(Core::instance()->unreadMessageRepository(), 0, this, 0);
+}
 
-	foreach (const Message &message, Core::instance()->unreadMessageRepository()->allUnreadMessages())
-		unreadMessageRemoved(message);
+void ContactManager::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
 
-	ContactParserTags::unregisterParserTags();
+void ContactManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void ContactManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ContactManager::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
+void ContactManager::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void ContactManager::setParser(Parser *parser)
+{
+	m_parser = parser;
+}
+
+void ContactManager::setUnreadMessageRepository(UnreadMessageRepository *unreadMessageRepository)
+{
+	m_unreadMessageRepository = unreadMessageRepository;
 }
 
 void ContactManager::init()
@@ -78,32 +92,25 @@ void ContactManager::init()
 	// needed for QueuedConnection
 	qRegisterMetaType<Contact>("Contact");
 
-	ContactParserTags::registerParserTags();
-
-	foreach (const Message &message, Core::instance()->unreadMessageRepository()->allUnreadMessages())
+	foreach (const Message &message, m_unreadMessageRepository->allUnreadMessages())
 		unreadMessageAdded(message);
 
-	connect(Core::instance()->unreadMessageRepository(), SIGNAL(unreadMessageAdded(Message)),
-	        this, SLOT(unreadMessageAdded(Message)));
-	connect(Core::instance()->unreadMessageRepository(), SIGNAL(unreadMessageRemoved(Message)),
-	        this, SLOT(unreadMessageRemoved(Message)));
+	connect(m_unreadMessageRepository, SIGNAL(unreadMessageAdded(Message)), this, SLOT(unreadMessageAdded(Message)));
+	connect(m_unreadMessageRepository, SIGNAL(unreadMessageRemoved(Message)), this, SLOT(unreadMessageRemoved(Message)));
+
+	m_configurationManager->registerStorableObject(this);
+
+	ensureLoaded();
 }
 
-void ContactManager::dirtinessChanged()
+void ContactManager::done()
 {
-	QMutexLocker locker(&mutex());
+	disconnect(m_unreadMessageRepository, 0, this, 0);
 
-	Contact contact(sender());
-	if (!contact.isNull() && contact.ownerBuddy() != Core::instance()->myself())
-	{
-		if (contact.rosterEntry()->requiresSynchronization())
-		{
-			DirtyContacts.append(contact);
-			emit dirtyContactAdded(contact);
-		}
-		else
-			DirtyContacts.removeAll(contact);
-	}
+	foreach (const Message &message, m_unreadMessageRepository->allUnreadMessages())
+		unreadMessageRemoved(message);
+
+	m_configurationManager->unregisterStorableObject(this);
 }
 
 void ContactManager::unreadMessageAdded(const Message &message)
@@ -120,7 +127,7 @@ void ContactManager::unreadMessageRemoved(const Message &message)
 		contact.setUnreadMessagesCount(unreadMessagesCount - 1);
 }
 
-void ContactManager::itemAboutToBeRegistered(Contact item)
+void ContactManager::itemAboutToBeAdded(Contact item)
 {
 	QMutexLocker locker(&mutex());
 
@@ -128,7 +135,7 @@ void ContactManager::itemAboutToBeRegistered(Contact item)
 	emit contactAboutToBeAdded(item);
 }
 
-void ContactManager::itemRegistered(Contact item)
+void ContactManager::itemAdded(Contact item)
 {
 	if (!item)
 		return;
@@ -137,18 +144,11 @@ void ContactManager::itemRegistered(Contact item)
 
 	emit contactAdded(item);
 
-	if (Core::instance()->myself() == item.ownerBuddy())
-		item.rosterEntry()->setState(RosterEntrySynchronized);
-	else if (item.rosterEntry()->requiresSynchronization())
-	{
-		DirtyContacts.append(item);
-		emit dirtyContactAdded(item);
-	}
-
-	connect(item, SIGNAL(dirtinessChanged()), this, SLOT(dirtinessChanged()));
+	if (m_myself->buddy() == item.ownerBuddy())
+		item.rosterEntry()->setSynchronized();
 }
 
-void ContactManager::itemAboutToBeUnregisterd(Contact item)
+void ContactManager::itemAboutToBeRemoved(Contact item)
 {
 	QMutexLocker locker(&mutex());
 
@@ -156,13 +156,8 @@ void ContactManager::itemAboutToBeUnregisterd(Contact item)
 	emit contactAboutToBeRemoved(item);
 }
 
-void ContactManager::itemUnregistered(Contact item)
+void ContactManager::itemRemoved(Contact item)
 {
-	disconnect(item, SIGNAL(dirtinessChanged()), this, SLOT(dirtinessChanged()));
-
-	if (item && item.rosterEntry()->requiresSynchronization())
-		DirtyContacts.removeAll(item);
-
 	emit contactRemoved(item);
 }
 
@@ -175,30 +170,24 @@ Contact ContactManager::byId(Account account, const QString &id, NotFoundAction
 	if (id.isEmpty() || account.isNull())
 		return Contact::null;
 
-	foreach (const Contact &contact, allItems())
+	foreach (const Contact &contact, items())
 		if (account == contact.contactAccount() && id == contact.id())
 			return contact;
 
 	if (action == ActionReturnNull)
 		return Contact::null;
 
-	Contact contact = Contact::create();
+	Contact contact = m_contactStorage->create();
 
-	ChangeNotifierLock lock(contact.rosterEntry()->changeNotifier(), ChangeNotifierLock::ModeForget); // don't emit dirty signals
+	ChangeNotifierLock lock(contact.rosterEntry()->hasLocalChangesNotifier(), ChangeNotifierLock::ModeForget); // don't emit dirty signals
 	contact.setId(id);
 	contact.setContactAccount(account);
-	contact.rosterEntry()->setState(RosterEntrySynchronized); // TODO: setId desynchronized it, make a factory
 
 	if (action == ActionCreateAndAdd)
 		addItem(contact);
 
-	ContactDetails *details = contact.details();
-	if (details)
-		details->setState(StateNew);
-
-	Buddy buddy = Buddy::create();
+	auto buddy = m_buddyStorage->create();
 	contact.setOwnerBuddy(buddy);
-	contact.rosterEntry()->setState(RosterEntrySynchronized);
 
 	return contact;
 }
@@ -214,31 +203,13 @@ QVector<Contact> ContactManager::contacts(Account account, AnonymousInclusion in
 	if (account.isNull())
 		return contacts;
 
-	foreach (const Contact &contact, allItems())
+	foreach (const Contact &contact, items())
 		if (account == contact.contactAccount() && ((IncludeAnonymous == inclusion) || !contact.isAnonymous()))
 			contacts.append(contact);
 
 	return contacts;
 }
 
-QVector<Contact> ContactManager::dirtyContacts(Account account)
-{
-	QMutexLocker locker(&mutex());
-
-	ensureLoaded();
-
-	QVector<Contact> contacts;
-
-	if (account.isNull())
-		return contacts;
-
-	foreach (const Contact &contact, DirtyContacts)
-		if (account == contact.contactAccount())
-			contacts.append(contact);
-
-	return contacts;
-}
-
 void ContactManager::contactDataUpdated()
 {
 	QMutexLocker locker(&mutex());
@@ -254,7 +225,7 @@ void ContactManager::removeDuplicateContacts()
 {
 	QMap<QPair<Account, QString>, Contact> uniqueContacts;
 
-	foreach (const Contact &contact, allItems())
+	foreach (const Contact &contact, items())
 	{
 		QMap<QPair<Account, QString>, Contact>::iterator it = uniqueContacts.find(qMakePair(contact.contactAccount(), contact.id()));
 		if (it != uniqueContacts.end())
@@ -275,16 +246,21 @@ void ContactManager::removeDuplicateContacts()
 			uniqueContacts.insert(qMakePair(contact.contactAccount(), contact.id()), contact);
 	}
 
-	config_file.writeEntry("General", "ContactsImportedFrom0_9", true);
+	m_configuration->deprecatedApi()->writeEntry("General", "ContactsImportedFrom0_9", true);
 }
 
 void ContactManager::loaded()
 {
-	Manager<Contact>::loaded();
+	SimpleManager<Contact>::loaded();
 
-	if (!config_file.readBoolEntry("General", "ContactsImportedFrom0_9", false))
+	if (!m_configuration->deprecatedApi()->readBoolEntry("General", "ContactsImportedFrom0_9", false))
 		// delay it so that everything needed will be loaded when we call this method
 		QTimer::singleShot(0, this, SLOT(removeDuplicateContacts()));
 }
 
+Contact ContactManager::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+{
+	return m_contactStorage->loadStubFromStorage(storagePoint);
+}
+
 #include "moc_contact-manager.cpp"
