@@ -3,8 +3,8 @@
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,29 +21,31 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtXml/QDomElement>
+#include "contact-set-configuration-helper.h"
 
 #include "buddies/buddy-manager.h"
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
+#include "core/core.h"
 
-#include "contact-set-configuration-helper.h"
+#include <QtXml/QDomElement>
 
-ContactSet ContactSetConfigurationHelper::loadFromConfiguration(StorableObject *parent, const QString &nodeName)
+ContactSet ContactSetConfigurationHelper::loadFromConfiguration(ContactManager *contactManager, StorableObject *parent, const QString &nodeName)
 {
 	if (!parent->isValidStorage())
 		return ContactSet();
 
-	XmlConfigFile *configurationStorage = parent->storage()->storage();
+	ConfigurationApi *configurationStorage = parent->storage()->storage();
 	QDomElement contactSetNode = configurationStorage->getNode(parent->storage()->point(), nodeName);
 
-	return loadFromConfiguration(configurationStorage, contactSetNode);
+	return loadFromConfiguration(contactManager, configurationStorage, contactSetNode);
 }
 
-ContactSet ContactSetConfigurationHelper::loadFromConfiguration(XmlConfigFile *configurationStorage, QDomElement contactSetNode)
+ContactSet ContactSetConfigurationHelper::loadFromConfiguration(ContactManager *contactManager, ConfigurationApi *configurationStorage, QDomElement contactSetNode)
 {
 	ContactSet result;
 
@@ -51,7 +53,7 @@ ContactSet ContactSetConfigurationHelper::loadFromConfiguration(XmlConfigFile *c
 	result.reserve(contactElements.count());
 	foreach (const QDomElement &contactElement, contactElements)
 	{
-		Contact contact = ContactManager::instance()->byUuid(contactElement.text());
+		Contact contact = contactManager->byUuid(contactElement.text());
 		if (!contact.isNull())
 			result.insert(contact);
 	}
@@ -64,13 +66,13 @@ void ContactSetConfigurationHelper::saveToConfiguration(StorableObject *parent,
 	if (!parent->isValidStorage())
 		return;
 
-	XmlConfigFile *configurationStorage = parent->storage()->storage();
+	ConfigurationApi *configurationStorage = parent->storage()->storage();
 	QDomElement contactSetNode = configurationStorage->getNode(parent->storage()->point(), nodeName);
 
 	saveToConfiguration(configurationStorage, contactSetNode, contactSet);
 }
 
-void ContactSetConfigurationHelper::saveToConfiguration(XmlConfigFile *configurationStorage, QDomElement contactSetNode, const ContactSet &contactSet)
+void ContactSetConfigurationHelper::saveToConfiguration(ConfigurationApi *configurationStorage, QDomElement contactSetNode, const ContactSet &contactSet)
 {
 	while (!contactSetNode.childNodes().isEmpty())
 		contactSetNode.removeChild(contactSetNode.childNodes().at(0));
