@@ -1,13 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,17 +20,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONTACT_SET_CONFIGURATION_HELPER_H
-#define CONTACT_SET_CONFIGURATION_HELPER_H
+#pragma once
 
 #include "contacts/contact-set.h"
 
+class ContactManager;
+
 namespace ContactSetConfigurationHelper
 {
-	ContactSet loadFromConfiguration(StorableObject *parent, const QString &nodeName);
-	ContactSet loadFromConfiguration(XmlConfigFile *configurationStorage, QDomElement contactSetNode);
+	ContactSet loadFromConfiguration(ContactManager *contactManager, StorableObject *parent, const QString &nodeName);
+	ContactSet loadFromConfiguration(ContactManager *contactManager, ConfigurationApi *configurationStorage, QDomElement contactSetNode);
 	void saveToConfiguration(StorableObject *parent, const QString &nodeName, const ContactSet &contactSet);
-	void saveToConfiguration(XmlConfigFile *configurationStorage, QDomElement contactSetNode, const ContactSet &contactSet);
+	void saveToConfiguration(ConfigurationApi *configurationStorage, QDomElement contactSetNode, const ContactSet &contactSet);
 }
-
-#endif // CONTACT_SET_CONFIGURATION_HELPER_H
