@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,76 +25,94 @@
 #include "avatars/avatar-manager.h"
 #include "avatars/avatar.h"
 #include "buddies/buddy-manager.h"
-#include "configuration/configuration-file.h"
-#include "contacts/contact-details.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "misc/change-notifier.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
-#include "protocols/services/roster/roster-entry.h"
+#include "roster/roster-entry-state.h"
+#include "roster/roster-entry.h"
 
 #include "contact-shared.h"
 
-ContactShared * ContactShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	ContactShared *result = loadFromStorage(storagePoint);
-	result->loadStub();
-
-	return result;
-}
-
-ContactShared * ContactShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	ContactShared *result = new ContactShared();
-	result->setStorage(storagePoint);
-
-	return result;
-}
-
 ContactShared::ContactShared(const QUuid &uuid) :
-		Shared(uuid), Details(0),
+		Shared(uuid),
 		Priority(-1), MaximumImageSize(0), UnreadMessagesCount(0),
-		Blocking(false), IgnoreNextStatusChange(false), Port(0)
+		Blocking(false), IgnoreNextStatusChange(false)
 {
-	Entry = new RosterEntry(this);
-	connect(&Entry->changeNotifier(), SIGNAL(changed()), this, SIGNAL(dirtinessChanged()));
-
-	ContactAccount = new Account();
-	ContactAvatar = new Avatar();
-	OwnerBuddy = new Buddy();
-
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
-	        this, SLOT(protocolFactoryRegistered(ProtocolFactory*)));
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
-	        this, SLOT(protocolFactoryUnregistered(ProtocolFactory*)));
-
-	connect(&Entry->changeNotifier(), SIGNAL(changed()), this, SLOT(changeNotifierChanged()));
-	connect(&changeNotifier(), SIGNAL(changed()), this, SLOT(changeNotifierChanged()));
 }
 
 ContactShared::~ContactShared()
 {
 	ref.ref();
 
-	disconnect(ProtocolsManager::instance(), 0, this, 0);
+	disconnect(m_protocolsManager, 0, this, 0);
 
-	protocolFactoryUnregistered(ProtocolsManager::instance()->byName(ContactAccount->protocolName()));
+	protocolFactoryUnregistered(m_protocolsManager->byName(ContactAccount->protocolName()));
 
 	delete OwnerBuddy;
 	delete ContactAvatar;
 	delete ContactAccount;
 }
 
+void ContactShared::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void ContactShared::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void ContactShared::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void ContactShared::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ContactShared::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void ContactShared::setProtocolsManager(ProtocolsManager *protocolsManager)
+{
+	m_protocolsManager = protocolsManager;
+}
+
+void ContactShared::init()
+{
+	Entry = new RosterEntry(this);
+	connect(&Entry->hasLocalChangesNotifier(), SIGNAL(changed()), this, SIGNAL(updatedLocally()));
+
+	ContactAccount = new Account();
+	ContactAvatar = new Avatar();
+	OwnerBuddy = new Buddy();
+
+	connect(m_protocolsManager, SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
+	        this, SLOT(protocolFactoryRegistered(ProtocolFactory*)));
+	connect(m_protocolsManager, SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
+	        this, SLOT(protocolFactoryUnregistered(ProtocolFactory*)));
+
+	connect(&changeNotifier(), SIGNAL(changed()), this, SLOT(changeNotifierChanged()));
+}
+
 StorableObject * ContactShared::storageParent()
 {
-	return ContactManager::instance();
+	return m_contactManager;
 }
 
 QString ContactShared::storageNodeName()
 {
-	return QLatin1String("Contact");
+	return QStringLiteral("Contact");
 }
 
 void ContactShared::load()
@@ -107,11 +125,7 @@ void ContactShared::load()
 	Id = loadValue<QString>("Id");
 	Priority = loadValue<int>("Priority", -1);
 
-	if (loadValue<bool>("Dirty", true))
-		Entry->setState(RosterEntryDesynchronized);
-	else
-		Entry->setState(RosterEntrySynchronized);
-
+	// TODO: remove after 01.05.2015
 	// It's an explicit hack for update path from 0.10.1-0.11.x to 0.12+. 0.10/0.11 didn't
 	// have Detached property. But they did have an explicit hack for totally ignoring
 	// what Facebook says about groups, thus allowing users to place their Facebook contacts
@@ -119,16 +133,23 @@ void ContactShared::load()
 	// by useless a Facebook-provided group until we try to upload something to roster
 	// for the first time, we fail and only then we set Detached to true, when group
 	// information is already lost.
-	if (!hasValue("Detached"))
-		Entry->setDetached(Id.endsWith(QLatin1String("@chat.facebook.com")));
+	bool detached = hasValue("Detached")
+		? loadValue<bool>("Detached", false)
+		: Id.endsWith(QStringLiteral("@chat.facebook.com"));
+	bool dirty = loadValue<bool>("Dirty", true);
+	if (detached)
+		Entry->setDetached();
+	else if (dirty)
+		Entry->setHasLocalChanges();
 	else
-		Entry->setDetached(loadValue<bool>("Detached", false));
+		Entry->setSynchronized();
 
-	*ContactAccount = AccountManager::instance()->byUuid(loadValue<QString>("Account"));
-	doSetOwnerBuddy(BuddyManager::instance()->byUuid(loadValue<QString>("Buddy")));
-	doSetContactAvatar(AvatarManager::instance()->byUuid(loadValue<QString>("Avatar")));
+	*ContactAccount = m_accountManager->byUuid(loadValue<QString>("Account"));
+	doSetOwnerBuddy(m_buddyManager->byUuid(loadValue<QString>("Buddy")));
+	doSetContactAvatar(m_avatarManager->byUuid(loadValue<QString>("Avatar")));
 
-	protocolFactoryRegistered(ProtocolsManager::instance()->byName(ContactAccount->protocolName()));
+	protocolFactoryRegistered(m_protocolsManager->byName(ContactAccount->protocolName()));
+	addToBuddy();
 }
 
 void ContactShared::aboutToBeRemoved()
@@ -138,11 +159,9 @@ void ContactShared::aboutToBeRemoved()
 	removeFromBuddy();
 	doSetOwnerBuddy(Buddy::null);
 
-	AvatarManager::instance()->removeItem(*ContactAvatar);
+	m_avatarManager->removeItem(*ContactAvatar);
 	doSetContactAvatar(Avatar::null);
 
-	deleteDetails();
-
 	changeNotifier().notify();
 }
 
@@ -158,9 +177,9 @@ void ContactShared::store()
 	storeValue("Id", Id);
 	storeValue("Priority", Priority);
 
-	storeValue("Dirty", RosterEntrySynchronized != Entry->state());
+	storeValue("Dirty", RosterEntryState::Synchronized != Entry->state());
 	// Detached property needs to be always stored, see the load() method.
-	storeValue("Detached", Entry->detached());
+	storeValue("Detached", RosterEntryState::Detached == Entry->state());
 
 	storeValue("Account", ContactAccount->uuid().toString());
 	storeValue("Buddy", !isAnonymous()
@@ -184,7 +203,7 @@ bool ContactShared::shouldStore()
 		return false;
 
 	// we dont need data for non-roster contacts only from 4 version of sql schema
-	if (config_file.readNumEntry("History", "Schema", 0) < 4)
+	if (m_configuration->deprecatedApi()->readNumEntry("History", "Schema", 0) < 4)
 		return true;
 
 	return !isAnonymous() || rosterEntry()->requiresSynchronization() || customProperties()->shouldStore();
@@ -193,7 +212,7 @@ bool ContactShared::shouldStore()
 void ContactShared::addToBuddy()
 {
 	// dont add to buddy if details are not available
-	if (Details && *OwnerBuddy)
+	if (*OwnerBuddy)
 		OwnerBuddy->addContact(this);
 }
 
@@ -220,8 +239,9 @@ void ContactShared::setOwnerBuddy(const Buddy &buddy)
 	doSetOwnerBuddy(buddy);
 	addToBuddy();
 
-	Entry->setState(RosterEntryDesynchronized);
+	Entry->setHasLocalChanges();
 	changeNotifier().notify();
+
 	emit buddyUpdated();
 }
 
@@ -250,17 +270,7 @@ void ContactShared::protocolFactoryRegistered(ProtocolFactory *protocolFactory)
 	if (!protocolFactory || !*ContactAccount || ContactAccount->protocolName() != protocolFactory->name())
 		return;
 
-	if (Details)
-		return;
-
-	Details = protocolFactory->createContactDetails(this);
-	if (Details)
-		Details->ensureLoaded();
-
 	changeNotifier().notify();
-
-	ContactManager::instance()->registerItem(this);
-	addToBuddy();
 }
 
 void ContactShared::protocolFactoryUnregistered(ProtocolFactory *protocolFactory)
@@ -275,29 +285,9 @@ void ContactShared::protocolFactoryUnregistered(ProtocolFactory *protocolFactory
 	 * delete it. But we don't want this to happen.
 	 */
 	Contact guard(this);
-
-	deleteDetails();
-
 	changeNotifier().notify();
 }
 
-void ContactShared::deleteDetails()
-{
-	if (Details)
-	{
-		// do not store contacts that are not in contact manager
-		if (ContactManager::instance()->allItems().contains(uuid()))
-			Details->ensureStored();
-
-		removeFromBuddy();
-
-		delete Details;
-		Details = 0;
-	}
-
-	ContactManager::instance()->unregisterItem(this);
-}
-
 void ContactShared::setId(const QString &id)
 {
 	ensureLoaded();
@@ -308,7 +298,6 @@ void ContactShared::setId(const QString &id)
 	QString oldId = Id;
 	Id = id;
 
-	Entry->setState(RosterEntryDesynchronized);
 	changeNotifier().notify();
 }
 
@@ -375,9 +364,21 @@ void ContactShared::setContactAvatar(const Avatar &contactAvatar)
 		return;
 
 	doSetContactAvatar(contactAvatar);
+
 	changeNotifier().notify();
 }
 
+void ContactShared::setPriority(int priority)
+{
+	ensureLoaded();
+	if (Priority != priority)
+	{
+		Priority = priority;
+		changeNotifier().notify();
+		emit priorityUpdated();
+	}
+}
+
 bool ContactShared::isAnonymous()
 {
 	ensureLoaded();
