@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,28 +19,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONTACT_SHARED_H
-#define CONTACT_SHARED_H
+#pragma once
 
-#include <QtCore/QObject>
-#include <QtNetwork/QHostAddress>
-
-#include "contacts/contact-details.h"
 #include "status/status.h"
 #include "storage/shared.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtNetwork/QHostAddress>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
 class Account;
+class AvatarManager;
 class Avatar;
+class BuddyManager;
 class Buddy;
+class Configuration;
+class ContactManager;
 class ProtocolFactory;
+class ProtocolsManager;
 class RosterEntry;
 
-class KADUAPI ContactShared : public QObject, public Shared
+class KADUAPI ContactShared : public Shared
 {
 	Q_OBJECT
 	Q_DISABLE_COPY(ContactShared)
 
-	ContactDetails *Details;
+	QPointer<AccountManager> m_accountManager;
+	QPointer<AvatarManager> m_avatarManager;
+	QPointer<BuddyManager> m_buddyManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<ProtocolsManager> m_protocolsManager;
+
 	RosterEntry *Entry;
 
 	Account *ContactAccount;
@@ -55,14 +67,6 @@ class KADUAPI ContactShared : public QObject, public Shared
 	bool Blocking;
 	bool IgnoreNextStatusChange;
 
-	QString ProtocolVersion;
-
-	QHostAddress Address;
-	unsigned int Port;
-	QString DnsName;
-
-	void deleteDetails();
-
 	void addToBuddy();
 	void removeFromBuddy();
 
@@ -70,6 +74,14 @@ class KADUAPI ContactShared : public QObject, public Shared
 	void doSetContactAvatar(const Avatar &contactAvatar);
 
 private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setAvatarManager(AvatarManager *avatarManager);
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setProtocolsManager(ProtocolsManager *protocolsManager);
+	INJEQT_INIT void init();
+
 	void protocolFactoryRegistered(ProtocolFactory *protocolFactory);
 	void protocolFactoryUnregistered(ProtocolFactory *protocolFactory);
 
@@ -82,9 +94,6 @@ protected:
 	virtual bool shouldStore();
 
 public:
-	static ContactShared * loadStubFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint);
-	static ContactShared * loadFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint);
-
 	explicit ContactShared(const QUuid &uuid = QUuid());
 	virtual ~ContactShared();
 
@@ -93,8 +102,6 @@ public:
 
 	virtual void aboutToBeRemoved();
 
-	ContactDetails * details() const { return Details; }
-
 	KaduShared_PropertyRead(const QString &, id, Id)
 	void setId(const QString &id);
 
@@ -114,14 +121,12 @@ public:
 
 	KaduShared_PropertyDeclCRW(Buddy, ownerBuddy, OwnerBuddy)
 
-	KaduShared_Property(int, priority, Priority)
+	KaduShared_PropertyRead(int, priority, Priority)
+	void setPriority(int priority);
+
 	KaduShared_Property(const Status &, currentStatus, CurrentStatus)
 	KaduShared_PropertyBool(Blocking)
 	KaduShared_Property(bool, ignoreNextStatusChange, IgnoreNextStatusChange)
-	KaduShared_Property(const QString &, protocolVersion, ProtocolVersion)
-	KaduShared_Property(const QHostAddress &, address, Address)
-	KaduShared_Property(unsigned int, port, Port)
-	KaduShared_Property(const QString &, dnsName, DnsName)
 	KaduShared_Property(short int, maximumImageSize, MaximumImageSize)
 	KaduShared_Property(quint16, unreadMessagesCount, UnreadMessagesCount)
 
@@ -132,9 +137,7 @@ public:
 signals:
 	void updated();
 	void buddyUpdated();
-	void dirtinessChanged();
+	void priorityUpdated();
+	void updatedLocally();
 
 };
-
-#endif // CONTACT_SHARED_H
-
