@@ -1,12 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,9 +26,10 @@
 #include "accounts/account.h"
 #include "avatars/avatar.h"
 #include "buddies/buddy-manager.h"
-#include "configuration/xml-configuration-file.h"
-#include "contacts/contact-details.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "contacts/contact-manager.h"
+#include "core/injected-factory.h"
 #include "storage/storage-point.h"
 
 #include "contact.h"
@@ -38,21 +38,6 @@ KaduSharedBaseClassImpl(Contact)
 
 Contact Contact::null;
 
-Contact Contact::create()
-{
-	return new ContactShared();
-}
-
-Contact Contact::loadStubFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint)
-{
-	return ContactShared::loadStubFromStorage(contactStoragePoint);
-}
-
-Contact Contact::loadFromStorage(const std::shared_ptr<StoragePoint> &contactStoragePoint)
-{
-	return ContactShared::loadFromStorage(contactStoragePoint);
-}
-
 Contact::Contact()
 {
 }
@@ -103,7 +88,6 @@ Contact Contact::contactWithHigherStatus(const Contact &c1, const Contact &c2)
 	return c2.currentStatus() < c1.currentStatus() ? c2 : c1;
 }
 
-KaduSharedBase_PropertyReadDef(Contact, ContactDetails *, details, Details, 0)
 KaduSharedBase_PropertyReadDef(Contact, QUuid, uuid, Uuid, QUuid())
 KaduSharedBase_PropertyReadDef(Contact, std::shared_ptr<StoragePoint>, storage, Storage, std::shared_ptr<StoragePoint>())
 KaduSharedBase_PropertyDefCRW(Contact, Account, contactAccount, ContactAccount, Account::null)
@@ -123,10 +107,6 @@ RosterEntry * Contact::rosterEntry() const
 		return data()->rosterEntry();
 }
 
-KaduSharedBase_PropertyDefCRW(Contact, QString, protocolVersion, ProtocolVersion, QString())
-KaduSharedBase_PropertyDefCRW(Contact, QHostAddress, address, Address, QHostAddress())
-KaduSharedBase_PropertyDef(Contact, unsigned int, port, Port, 0)
-KaduSharedBase_PropertyDefCRW(Contact, QString, dnsName, DnsName, QString())
 KaduSharedBase_PropertyDef(Contact, short int, maximumImageSize, MaximumImageSize, 0)
 KaduSharedBase_PropertyDef(Contact, quint16, unreadMessagesCount, UnreadMessagesCount, 0)
 KaduSharedBase_PropertyBoolReadDef(Contact, Anonymous, true)
