@@ -3,11 +3,10 @@
  * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010, 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -40,16 +39,13 @@
 class Avatar;
 class ContactDetails;
 class ContactShared;
-class XmlConfigFile;
+class ConfigurationApi;
 
 class KADUAPI Contact : public SharedBase<ContactShared>
 {
 	KaduSharedBaseClass(Contact)
 
 public:
-	static Contact create();
-	static Contact loadStubFromStorage(const std::shared_ptr<StoragePoint> &storage);
-	static Contact loadFromStorage(const std::shared_ptr<StoragePoint> &storage);
 	static Contact null;
 
 	static Contact contactWithHigherStatus(const Contact &c1, const Contact &c2);
@@ -63,7 +59,6 @@ public:
 	QString display(bool useBuddyData) const;
 	Avatar avatar(bool useBuddyData) const;
 
-	KaduSharedBase_PropertyRead(ContactDetails *, details, Details)
 	KaduSharedBase_PropertyRead(QUuid, uuid, Uuid)
 	KaduSharedBase_PropertyRead(std::shared_ptr<StoragePoint>, storage, Storage)
 	KaduSharedBase_PropertyCRW(Account, contactAccount, ContactAccount)
@@ -84,10 +79,6 @@ public:
 	 */
 	RosterEntry * rosterEntry() const;
 
-	KaduSharedBase_PropertyCRW(QString, protocolVersion, ProtocolVersion)
-	KaduSharedBase_PropertyCRW(QHostAddress, address, Address)
-	KaduSharedBase_Property(unsigned int, port, Port)
-	KaduSharedBase_PropertyCRW(QString, dnsName, DnsName)
 	KaduSharedBase_Property(short int, maximumImageSize, MaximumImageSize)
 	KaduSharedBase_Property(quint16, unreadMessagesCount, UnreadMessagesCount)
 	KaduSharedBase_PropertyBoolRead(Anonymous)
