@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,6 +25,7 @@
 #include "accounts/account.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity.h"
 #include "model/roles.h"
@@ -50,6 +51,11 @@ BuddyContactModel::~BuddyContactModel()
 	disconnect(SourceBuddy, 0, this, 0);
 }
 
+void BuddyContactModel::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
 int BuddyContactModel::columnCount(const QModelIndex &parent) const
 {
 	return parent.isValid() ? 0 : 1;
@@ -76,7 +82,7 @@ QVariant BuddyContactModel::data(const QModelIndex &index, int role) const
 
 		case Qt::DecorationRole:
 			return data.contactAccount().protocolHandler()
-					? data.contactAccount().protocolHandler()->icon().icon()
+					? m_iconsManager->iconByPath(data.contactAccount().protocolHandler()->icon())
 					: QIcon();
 
 		case ContactRole:
