@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,32 +19,25 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_CONTACT_MODEL_H
-#define BUDDY_CONTACT_MODEL_H
-
-#include <QtCore/QAbstractListModel>
-#include <QtCore/QModelIndex>
+#pragma once
 
 #include "buddies/buddy.h"
 
+#include <QtCore/QAbstractListModel>
+#include <QtCore/QModelIndex>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class Account;
 class Contact;
+class IconsManager;
 
 class BuddyContactModel : public QAbstractListModel
 {
 	Q_OBJECT
 
-	Buddy SourceBuddy;
-	bool IncludeIdentityInDisplay;
-
-private slots:
-	void contactAboutToBeAdded(Contact data);
-	void contactAdded(Contact data);
-	void contactAboutToBeRemoved(Contact data);
-	void contactRemoved(Contact data);
-
 public:
-	explicit BuddyContactModel(Buddy contact, QObject *parent = 0);
+	explicit BuddyContactModel(Buddy contact, QObject *parent = nullptr);
 	virtual ~BuddyContactModel();
 
 	virtual int columnCount(const QModelIndex &parent) const;
@@ -57,9 +51,18 @@ public:
 
 	void setIncludeIdentityInDisplay(bool includeIdentityInDisplay);
 
+private:
+	QPointer<IconsManager> m_iconsManager;
+
+	Buddy SourceBuddy;
+	bool IncludeIdentityInDisplay;
+
+private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+
+	void contactAboutToBeAdded(Contact data);
+	void contactAdded(Contact data);
+	void contactAboutToBeRemoved(Contact data);
+	void contactRemoved(Contact data);
+
 };
-
-// for MOC
-#include "contacts/contact.h"
-
-#endif // BUDDY_CONTACT_MODEL_H
