@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,19 +20,34 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QVariant>
-#include <QtGui/QIcon>
+#include "contact-data-extractor.h"
 
 #include "accounts/account.h"
 #include "avatars/avatar.h"
 #include "contacts/contact.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "model/roles.h"
 #include "status/status-container.h"
 #include "talkable/talkable.h"
 
-#include "contact-data-extractor.h"
+#include <QtCore/QFileInfo>
+#include <QtCore/QVariant>
+#include <QtGui/QIcon>
+
+ContactDataExtractor::ContactDataExtractor(QObject *parent) :
+		QObject{parent}
+{
+}
+
+ContactDataExtractor::~ContactDataExtractor()
+{
+}
+
+void ContactDataExtractor::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
 
 QVariant ContactDataExtractor::data(const Contact &contact, int role, bool useBuddyData)
 {
@@ -46,27 +61,27 @@ QVariant ContactDataExtractor::data(const Contact &contact, int role, bool useBu
 		case Qt::DecorationRole:
 		{
 			if (contact.ownerBuddy().isBlocked())
-				return KaduIcon("kadu_icons/blocked").icon();
+				return m_iconsManager->iconByPath(KaduIcon("kadu_icons/blocked"));
 
 			if (contact.isBlocking())
-				return KaduIcon("kadu_icons/blocking").icon();
+				return m_iconsManager->iconByPath(KaduIcon("kadu_icons/blocking"));
 
 			// TODO generic icon
 			return contact.contactAccount().statusContainer()
-					? contact.contactAccount().statusContainer()->statusIcon(contact.currentStatus()).icon()
+					? m_iconsManager->iconByPath(contact.contactAccount().statusContainer()->statusIcon(contact.currentStatus()))
 					: QIcon();
 		}
 		case StatusIconPath:
 		{
 			if (contact.ownerBuddy().isBlocked())
-				return KaduIcon("kadu_icons/blocked").fullPath();
+				return m_iconsManager->iconPath(KaduIcon("kadu_icons/blocked"));
 
 			if (contact.isBlocking())
-				return KaduIcon("kadu_icons/blocking").fullPath();
+				return m_iconsManager->iconPath(KaduIcon("kadu_icons/blocking"));
 
 			// TODO generic icon
 			return contact.contactAccount().statusContainer()
-					? contact.contactAccount().statusContainer()->statusIcon(contact.currentStatus()).fullPath()
+					? m_iconsManager->iconPath(contact.contactAccount().statusContainer()->statusIcon(contact.currentStatus()))
 					: QString();
 		}
 		case BuddyRole:
@@ -101,3 +116,5 @@ QVariant ContactDataExtractor::data(const Contact &contact, int role, bool useBu
 			return QVariant();
 	}
 }
+
+#include "moc_contact-data-extractor.cpp"
