@@ -1,13 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2014 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,18 +20,33 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONTACT_DATA_EXTRACTOR_H
-#define CONTACT_DATA_EXTRACTOR_H
+#pragma once
 
 #include "exports.h"
 
-class QVariant;
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class Contact;
+class IconsManager;
 
-namespace ContactDataExtractor
+class QVariant;
+
+class KADUAPI ContactDataExtractor : public QObject
 {
-	KADUAPI QVariant data(const Contact &contact, int role, bool useBuddyData);
-}
+	Q_OBJECT
 
-#endif // CONTACT_DATA_EXTRACTOR_H
+public:
+	Q_INVOKABLE explicit ContactDataExtractor(QObject *parent = nullptr);
+	virtual ~ContactDataExtractor();
+
+	QVariant data(const Contact &contact, int role, bool useBuddyData);
+
+private:
+	QPointer<IconsManager> m_iconsManager;
+
+private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+
+};
