@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,12 +22,38 @@
 #ifndef ADAPTER_H
 #define ADAPTER_H
 
+/**
+ * @addtogroup Core
+ * @{
+ */
+
+/**
+ * @class Adapter
+ * @short Interface for adapting one type to another.
+ * @author Rafał 'Vogel' Malinowski
+ * @author Piotr Dąbrowski
+ * @param T_dest type of result class
+ * @param T_src type of class to adapt
+ */
 template <typename T_dest, typename T_src>
 class Adapter
 {
 public:
-	virtual T_dest adapt(const T_src &) = 0;
+	virtual ~Adapter<T_dest, T_src>() {}
+
+	/**
+	 * @short Adapt instance of class from one type to another.
+	 * @author Rafał 'Vogel' Malinowski
+	 * @author Piotr Dąbrowski
+	 * @param object object to adapt
+	 * @return object adapted to type T_dest
+	 */
+	virtual T_dest adapt(const T_src &object) = 0;
 
 };
 
+/**
+ * @}
+ */
+
 #endif // ADAPTER_H
