@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DOM_PROCESSOR_H
-#define DOM_PROCESSOR_H
+#pragma once
 
 #include "exports.h"
 
@@ -43,10 +42,7 @@ class DomVisitor;
  */
 class KADUAPI DomProcessor
 {
-	QDomDocument &DomDocument;
-
-	QDomNode acceptNode(DomVisitor *visitor, QDomNode node);
-
+	
 public:
 	/**
 	 * @short Create new instance of DomProcessor.
@@ -62,12 +58,34 @@ public:
 	 *
 	 * Processing is not read-only, so domDocument can be changed after calling this method.
 	 */
-	void accept(DomVisitor *visitor);
+	void accept(const DomVisitor *visitor);
+
+	/**
+	 * @short Accept set of visitors.
+	 * @author Rafał 'Vogel' Malinowski
+	 * @param visitor to accept
+	 *
+	 * Processing is not read-only, so domDocument can be changed after calling this method.
+	 */
+	template<class Iterator>
+	void accept(Iterator begin, Iterator end)
+	{
+		std::for_each(begin, end, [this](const DomVisitor *visitor){ accept(visitor); });
+	}
+
+private:
+	QDomDocument &m_domDocument;
+
+	QDomNode acceptNode(const DomVisitor *visitor, QDomNode node);
 
 };
 
+class invalid_xml : public std::exception {};
+
+KADUAPI QDomDocument toDomDocument(const QString &xml);
+KADUAPI QString toString(const QDomDocument &domDocument);
+KADUAPI QString processDom(const QString &xml, const DomVisitor &domVisitor);
+
 /**
  * @}
  */
-
-#endif // DOM_PROCESSOR_H
