@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,28 +31,28 @@ DomTextRegexpVisitor::~DomTextRegexpVisitor()
 {
 }
 
-QDomText DomTextRegexpVisitor::expandFirstMatch(QDomText textNode)
+QDomText DomTextRegexpVisitor::expandFirstMatch(QDomText textNode) const
 {
-	QString text = textNode.nodeValue();
-	int index = RegExp.indexIn(text);
+	auto text = textNode.nodeValue();
+	auto index = RegExp.indexIn(text);
 	if (index < 0)
 		return QDomText();
 
-	int length = RegExp.matchedLength();
+	auto length = RegExp.matchedLength();
 
-	QDomText afterMatch = textNode.splitText(index + length);
+	auto afterMatch = textNode.splitText(index + length);
 	textNode.setNodeValue(textNode.nodeValue().mid(0, index));
 
-	QList<QDomNode> newNodes = matchToDomNodes(textNode.ownerDocument(), RegExp);
-	foreach (QDomNode newNode, newNodes)
+	auto newNodes = matchToDomNodes(textNode.ownerDocument(), RegExp);
+	for (auto newNode : newNodes)
 		textNode.parentNode().insertBefore(newNode, afterMatch);
 
 	return afterMatch;
 }
 
-QDomNode DomTextRegexpVisitor::visit(QDomText textNode)
+QDomNode DomTextRegexpVisitor::visit(QDomText textNode) const
 {
-	QDomText result = textNode;
+	auto result = textNode;
 	while (!textNode.isNull())
 	{
 		result = textNode;
@@ -62,12 +62,12 @@ QDomNode DomTextRegexpVisitor::visit(QDomText textNode)
 	return result;
 }
 
-QDomNode DomTextRegexpVisitor::beginVisit(QDomElement elementNode)
+QDomNode DomTextRegexpVisitor::beginVisit(QDomElement elementNode) const
 {
 	return elementNode;
 }
 
-QDomNode DomTextRegexpVisitor::endVisit(QDomElement elementNode)
+QDomNode DomTextRegexpVisitor::endVisit(QDomElement elementNode) const
 {
-	return elementNode;
+	return elementNode.nextSibling();
 }
