@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2008, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,20 +25,8 @@
 
 #ifdef libkadu_EXPORTS
 #	define KADUAPI Q_DECL_EXPORT
-
-#	ifdef KADU_EXPORT_TESTS
-#		define KADUAPI_TESTS Q_DECL_EXPORT
-#	else
-#		define KADUAPI_TESTS
-#	endif
 #else
 #	define KADUAPI Q_DECL_IMPORT
-
-#	ifdef KADU_EXPORT_TESTS
-#		define KADUAPI_TESTS Q_DECL_IMPORT
-#	else
-#		define KADUAPI_TESTS
-#	endif
 #endif
 
 #endif // EXPORTS_H
