@@ -3,8 +3,8 @@
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,12 +21,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FILE_TRANSFER_H
-#define FILE_TRANSFER_H
+#pragma once
 
 #include "file-transfer/file-transfer-shared.h"
 #include "storage/shared-base.h"
-
 #include "exports.h"
 
 class QFile;
@@ -38,14 +36,11 @@ class KADUAPI FileTransfer : public SharedBase<FileTransferShared>
 	KaduSharedBaseClass(FileTransfer)
 
 public:
-	static FileTransfer create();
-	static FileTransfer loadStubFromStorage(const QSharedPointer<StoragePoint> &fileTransferStoragePoint);
-	static FileTransfer loadFromStorage(const QSharedPointer<StoragePoint> &fileTransferStoragePoint);
 	static FileTransfer null;
 
 	FileTransfer();
 	FileTransfer(FileTransferShared *data);
-	FileTransfer(QObject *data);
+	explicit FileTransfer(QObject *data);
 	FileTransfer(const FileTransfer &copy);
 	virtual ~FileTransfer();
 
@@ -54,18 +49,14 @@ public:
 	KaduSharedBase_PropertyCRW(QString, remoteFileName, RemoteFileName)
 	KaduSharedBase_Property(unsigned long, fileSize, FileSize)
 	KaduSharedBase_Property(unsigned long, transferredSize, TransferredSize)
-	KaduSharedBase_Property(FileTransferType, transferType, TransferType)
+	KaduSharedBase_Property(QString, error, Error)
+	KaduSharedBase_Property(FileTransferDirection, transferDirection, TransferDirection)
 	KaduSharedBase_Property(FileTransferStatus, transferStatus, TransferStatus)
-	KaduSharedBase_Property(FileTransferError, transferError, TransferError)
+	KaduSharedBase_Property(FileTransferType, transferType, TransferType)
 	KaduSharedBase_Property(FileTransferHandler *, handler, Handler)
 
-	virtual bool accept(const QString &file);
-
-	void createHandler();
 	unsigned int percent();
 
 };
 
 Q_DECLARE_METATYPE(FileTransfer)
-
-#endif // FILE_TRANSFER_H
