@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,45 +22,62 @@
 #include <QtGui/QTextBlock>
 #include <QtGui/QTextDocument>
 
+#include "dom/dom-processor.h"
 #include "formatted-string/composite-formatted-string.h"
+#include "formatted-string/force-space-dom-visitor.h"
 #include "formatted-string/formatted-string-image-block.h"
 #include "formatted-string/formatted-string-text-block.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "html/normalized-html-string.h"
 #include "misc/memory.h"
 #include "services/image-storage-service.h"
 
 #include "formatted-string-factory.h"
 
+#include <QtXml/QDomDocument>
+#include <memory>
+
+FormattedStringFactory::FormattedStringFactory()
+{
+}
+
+FormattedStringFactory::~FormattedStringFactory()
+{
+}
+
 void FormattedStringFactory::setImageStorageService(ImageStorageService *imageStorageService)
 {
-	CurrentImageStorageService = imageStorageService;
+	m_imageStorageService = imageStorageService;
 }
 
 std::unique_ptr<FormattedString> FormattedStringFactory::fromPlainText(const QString& plainText)
 {
-	return make_unique<FormattedStringTextBlock>(plainText, false, false, false, QColor{});
+	return std::make_unique<FormattedStringTextBlock>(plainText, false, false, false, QColor{});
 }
 
 std::unique_ptr<FormattedString> FormattedStringFactory::partFromQTextCharFormat(const QTextCharFormat &textCharFormat, const QString &text)
 {
-	QString replacedNewLine = text;
+	auto replacedNewLine = text;
+	replacedNewLine.replace("\u00A0", " ");
 	replacedNewLine.replace(QChar::LineSeparator, '\n');
-	return make_unique<FormattedStringTextBlock>(replacedNewLine, textCharFormat.font().bold(), textCharFormat.font().italic(), textCharFormat.font().underline(), textCharFormat.foreground().color());
+	return std::make_unique<FormattedStringTextBlock>(replacedNewLine, textCharFormat.font().bold(), textCharFormat.font().italic(), textCharFormat.font().underline(), textCharFormat.foreground().color());
 }
 
 std::unique_ptr<FormattedString> FormattedStringFactory::partFromQTextImageFormat(const QTextImageFormat& textImageFormat)
 {
-	QString filePath = textImageFormat.name();
-	QFileInfo fileInfo(filePath);
+	auto filePath = textImageFormat.name();
+	QFileInfo fileInfo{filePath};
 
-	if (CurrentImageStorageService)
-		filePath = CurrentImageStorageService.data()->storeImage(filePath);
+	if (m_imageStorageService)
+		filePath = m_imageStorageService.data()->storeImage(filePath);
 
-	return make_unique<FormattedStringImageBlock>(filePath);
+	return std::make_unique<FormattedStringImageBlock>(filePath);
 }
 
 std::unique_ptr<FormattedString> FormattedStringFactory::partFromQTextFragment(const QTextFragment &textFragment, bool prependNewLine)
 {
-	QTextCharFormat format = textFragment.charFormat();
+	auto format = textFragment.charFormat();
 	if (!format.isImageFormat())
 		return partFromQTextCharFormat(format, prependNewLine ? '\n' + textFragment.text() : textFragment.text());
 	else
@@ -73,9 +87,8 @@ std::unique_ptr<FormattedString> FormattedStringFactory::partFromQTextFragment(c
 std::vector<std::unique_ptr<FormattedString>> FormattedStringFactory::partsFromQTextBlock(const QTextBlock &textBlock, bool firstBlock)
 {
 	auto result = std::vector<std::unique_ptr<FormattedString>>{};
-
-	bool firstFragment = true;
-	for (QTextBlock::iterator it = textBlock.begin(); !it.atEnd(); ++it)
+	auto firstFragment = true;
+	for (auto it = textBlock.begin(); !it.atEnd(); ++it)
 	{
 		if (!it.fragment().isValid())
 			continue;
@@ -93,18 +106,37 @@ std::vector<std::unique_ptr<FormattedString>> FormattedStringFactory::partsFromQ
 
 std::unique_ptr<FormattedString> FormattedStringFactory::fromHtml(const QString &html)
 {
-	QTextDocument document;
-	document.setHtml(html);
+	QTextDocument document{};
+	try
+	{
+		document.setHtml(processDom(html, ForceSpaceDomVisitor{}));
+	}
+	catch (invalid_xml &)
+	{
+		// secure it by applying another html escape
+		// at least it won't break anything in webview
+		document.setHtml(plainToHtml(html).string());
+	}
 
-	return fromTextDocument(&document);
+	return fromTextDocument(document);
 }
 
-std::unique_ptr<FormattedString> FormattedStringFactory::fromTextDocument(QTextDocument *textDocument)
+std::unique_ptr<FormattedString> FormattedStringFactory::fromHtml(const HtmlString &html)
+{
+	return fromHtml(html.string());
+}
+
+std::unique_ptr<FormattedString> FormattedStringFactory::fromHtml(const NormalizedHtmlString &html)
+{
+	return fromHtml(html.string());
+}
+
+std::unique_ptr<FormattedString> FormattedStringFactory::fromTextDocument(const QTextDocument &textDocument)
 {
 	auto firstBlock = true;
 	auto items = std::vector<std::unique_ptr<FormattedString>>{};
 
-	QTextBlock block = textDocument->firstBlock();
+	auto block = textDocument.firstBlock();
 	while (block.isValid())
 	{
 		auto parts = partsFromQTextBlock(block, firstBlock);
@@ -115,18 +147,18 @@ std::unique_ptr<FormattedString> FormattedStringFactory::fromTextDocument(QTextD
 		firstBlock = false;
 	}
 
-	return make_unique<CompositeFormattedString>(std::move(items));
+	return std::make_unique<CompositeFormattedString>(std::move(items));
 }
 
 std::unique_ptr<FormattedString> FormattedStringFactory::fromText(const QString &text)
 {
-	QScopedPointer<QTextDocument> document(new QTextDocument());
+	QTextDocument document;
 	if (isHtml(text))
-		document->setHtml(text);
+		document.setHtml(text);
 	else
-		document->setPlainText(text);
+		document.setPlainText(text);
 
-	return fromTextDocument(document.data());
+	return fromTextDocument(document);
 }
 
 bool FormattedStringFactory::isHtml(const QString &text) const
