@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,24 +18,26 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FORMATTED_STRING_FACTORY_H
-#define FORMATTED_STRING_FACTORY_H
-
-#include <memory>
-#include <vector>
-#include <QtCore/QPointer>
+#pragma once
 
 #include "formatted-string/formatted-string.h"
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <memory>
+#include <vector>
+#include <injeqt/injeqt.h>
+
+class HtmlString;
+class ImageStorageService;
+class NormalizedHtmlString;
+
 class QTextBlock;
 class QTextCharFormat;
 class QTextDocument;
 class QTextFragment;
 class QTextImageFormat;
 
-class ImageStorageService;
-
 /**
  * @addtogroup FormattedString
  * @{
@@ -50,7 +52,7 @@ class KADUAPI FormattedStringFactory : public QObject
 {
 	Q_OBJECT
 
-	QPointer<ImageStorageService> CurrentImageStorageService;
+	QPointer<ImageStorageService> m_imageStorageService;
 
 	std::unique_ptr<FormattedString> partFromQTextCharFormat(const QTextCharFormat &textCharFormat, const QString &text);
 	std::unique_ptr<FormattedString> partFromQTextImageFormat(const QTextImageFormat &textImageFormat);
@@ -58,15 +60,8 @@ class KADUAPI FormattedStringFactory : public QObject
 	std::vector<std::unique_ptr<FormattedString>> partsFromQTextBlock(const QTextBlock &textBlock, bool firstBlock);
 
 public:
-	/**
-	 * @short Set ImageStorageService to use by this factory.
-	 * @author Rafał 'Vogel' Malinowski
-	 * @param imageStorageService ImageStorageService to use by this factory
-	 *
-	 * ImageStorageService will be used to store images and change path to them to make FormattedString working even when Kadu instance
-	 * is moved to new location.
-	 */
-	void setImageStorageService(ImageStorageService *imageStorageService);
+	Q_INVOKABLE FormattedStringFactory();
+	virtual ~FormattedStringFactory();
 
 	/**
 	 * @short Create FormattedString instance from plain text.
@@ -90,7 +85,8 @@ public:
 	 *
 	 * This method never returns null.
 	 */
-	std::unique_ptr<FormattedString> fromHtml(const QString &html);
+	std::unique_ptr<FormattedString> fromHtml(const HtmlString &html);
+	std::unique_ptr<FormattedString> fromHtml(const NormalizedHtmlString &html);
 
 	/**
 	 * @short Create FormattedString instance from text document.
@@ -101,7 +97,7 @@ public:
 	 *
 	 * This method never returns null.
 	 */
-	std::unique_ptr<FormattedString> fromTextDocument(QTextDocument *textDocument);
+	std::unique_ptr<FormattedString> fromTextDocument(const QTextDocument &textDocument);
 
 	/**
 	 * @short Create FormattedString instance from HTML or plain text.
@@ -122,10 +118,22 @@ public:
 	 */
 	bool isHtml(const QString &text) const;
 
+private:
+	std::unique_ptr<FormattedString> fromHtml(const QString &html);
+
+private slots:
+	/**
+	 * @short Set ImageStorageService to use by this factory.
+	 * @author Rafał 'Vogel' Malinowski
+	 * @param imageStorageService ImageStorageService to use by this factory
+	 *
+	 * ImageStorageService will be used to store images and change path to them to make FormattedString working even when Kadu instance
+	 * is moved to new location.
+	 */
+	INJEQT_SET void setImageStorageService(ImageStorageService *imageStorageService);
+
 };
 
 /**
  * @}
  */
-
-#endif // FORMATTED_STRING_FACTORY_H
