@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 
 #include "formatted-string/formatted-string-image-block.h"
 #include "formatted-string/formatted-string-text-block.h"
+#include "html/html-string.h"
 #include "misc/misc.h"
 
 #include "formatted-string-html-visitor.h"
@@ -60,9 +61,9 @@ void FormattedStringHtmlVisitor::visit(const FormattedStringImageBlock * const f
 
 void FormattedStringHtmlVisitor::visit(const FormattedStringTextBlock * const formattedStringTextBlock)
 {
-	QString content(replacedNewLine(Qt::escape(formattedStringTextBlock->content()), QLatin1String("<br/>")));
+	QString content(replacedNewLine(Qt::escape(formattedStringTextBlock->content()), QStringLiteral("<br/>")));
 
-	if (!formattedStringTextBlock->bold() && !formattedStringTextBlock->italic() && !formattedStringTextBlock->underline() && !formattedStringTextBlock->color().isValid())
+	if (!formattedStringTextBlock->bold() && !formattedStringTextBlock->italic() && !formattedStringTextBlock->underline())
 	{
 		append(content);
 		return;
@@ -91,7 +92,7 @@ void FormattedStringHtmlVisitor::append(QString content)
 	m_result.append(std::move(content));
 }
 
-QString FormattedStringHtmlVisitor::result() const
+HtmlString FormattedStringHtmlVisitor::result() const
 {
-	return m_result;
+	return HtmlString{m_result};
 }
