@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +26,8 @@
 #include "formatted-string/formatted-string-visitor.h"
 #include "exports.h"
 
+class HtmlString;
+
 /**
  * @addtogroup FormattedString
  * @{
@@ -56,7 +58,7 @@ public:
 	* @author Rafał 'Vogel' Malinowski
 	* @return HTML view of visited FormattedString
 	*/
-	QString result() const;
+	HtmlString result() const;
 
 protected:
 	void append(QString content);
