@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,31 +19,35 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QLatin1String>
-#include <QtCore/QMetaMethod>
+#include "action-description.h"
 
+#include "core/injected-factory.h"
+#include "configuration/configuration.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
 #include "gui/hot-key.h"
 #include "gui/windows/main-window.h"
 
-#include "action-description.h"
+#include <QtCore/QLatin1String>
+#include <QtCore/QMetaMethod>
 
 ActionDescription::ActionDescription(QObject *parent, ActionType type, const QString &name, QObject *object, const char *slot,
 		const KaduIcon &icon, const QString &text, bool checkable, ActionBoolCallback enableCallback) :
-		QObject(parent), Type(type), Name(name), Object(object), Slot(slot), Icon(icon), Text(text),
+		QObject(parent),
+		Type(type), Name(name), Object(object), Slot(slot), Icon(icon), Text(text),
 		Checkable(checkable), EnableCallback(enableCallback), ShortcutContext(Qt::WidgetShortcut)
 {
 	Deleting = false;
-
-	registerAction();
+	m_selfRegister = true;
 }
 
-ActionDescription::ActionDescription(QObject *parent) :
-		QObject(parent), Type(TypeAll), Object(0), Slot(0),
+ActionDescription::ActionDescription( QObject *parent) :
+		QObject(parent),
+		Type(TypeAll), Object(0), Slot(0),
 		Checkable(false), EnableCallback(0), ShortcutContext(Qt::WidgetShortcut)
 {
 	Deleting = false;
+	m_selfRegister = false;
 }
 
 ActionDescription::~ActionDescription()
@@ -53,17 +57,53 @@ ActionDescription::~ActionDescription()
 	qDeleteAll(MappedActions);
 	MappedActions.clear();
 
-	unregisterAction();
+	unregisterAction(m_actions);
 }
 
-void ActionDescription::registerAction()
+void ActionDescription::setActions(Actions *actions)
 {
-	Actions::instance()->insert(this);
+	m_actions = actions;
 }
 
-void ActionDescription::unregisterAction()
+void ActionDescription::setConfiguration(Configuration *configuration)
 {
-	Actions::instance()->remove(this);
+	m_configuration = configuration;
+}
+
+void ActionDescription::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ActionDescription::init()
+{
+	if (m_selfRegister)
+		registerAction(m_actions);
+}
+
+Configuration * ActionDescription::configuration() const
+{
+	return m_configuration;
+}
+
+InjectedFactory * ActionDescription::injectedFactory() const
+{
+	return m_injectedFactory;
+}
+
+Actions * ActionDescription::actionsRegistry() const
+{
+	return m_actions;
+}
+
+void ActionDescription::registerAction(Actions *actions)
+{
+	actions->insert(this);
+}
+
+void ActionDescription::unregisterAction(Actions *actions)
+{
+	actions->remove(this);
 }
 
 void ActionDescription::actionAboutToBeDestroyed(Action *action)
@@ -145,7 +185,13 @@ void ActionDescription::actionInstanceCreated(Action *action)
 void ActionDescription::updateActionState(Action *action)
 {
 	if (EnableCallback)
-		(*EnableCallback)(action);
+		EnableCallback(action);
+}
+
+void ActionDescription::updateActionStates()
+{
+	for (auto &&action : actions())
+		updateActionState(action);
 }
 
 Action * ActionDescription::createAction(ActionContext *context, QObject *parent)
@@ -159,7 +205,7 @@ Action * ActionDescription::createAction(ActionContext *context, QObject *parent
 		return result;
 	}
 
-	result = new Action(this, context, parent);
+	result = m_injectedFactory->makeInjected<Action>(this, context, parent);
 	MappedActions.insert(context, result);
 
 	actionInstanceCreated(result);
@@ -167,12 +213,12 @@ Action * ActionDescription::createAction(ActionContext *context, QObject *parent
 
 	if (ShortcutContext != Qt::ApplicationShortcut)
 	{
-		result->setShortcut(HotKey::shortCutFromFile("ShortCuts", ShortcutItem));
+		result->setShortcut(HotKey::shortCutFromFile(m_configuration, "ShortCuts", ShortcutItem));
 		result->setShortcutContext(ShortcutContext);
 	}
 	else if (MappedActions.count() == 1)
 	{
-		result->setShortcut(HotKey::shortCutFromFile("ShortCuts", ShortcutItem));
+		result->setShortcut(HotKey::shortCutFromFile(m_configuration, "ShortCuts", ShortcutItem));
 		result->setShortcutContext(ShortcutContext);
 	}
 
@@ -206,31 +252,22 @@ void ActionDescription::configurationUpdated()
 	{
 		foreach (Action *action, MappedActions)
 		{
-			action->setShortcut(HotKey::shortCutFromFile("ShortCuts", ShortcutItem));
+			action->setShortcut(HotKey::shortCutFromFile(m_configuration, "ShortCuts", ShortcutItem));
 			action->setShortcutContext(ShortcutContext);
 		}
 	}
 	else if (!MappedActions.isEmpty())
 	{
-		MappedActions.values().at(0)->setShortcut(HotKey::shortCutFromFile("ShortCuts", ShortcutItem));
+		MappedActions.values().at(0)->setShortcut(HotKey::shortCutFromFile(m_configuration, "ShortCuts", ShortcutItem));
 		MappedActions.values().at(0)->setShortcutContext(ShortcutContext);
 	}
 }
 
-// TODO: a hack
-#if QT_VERSION >= 0x050000
 void ActionDescription::connectNotify(const QMetaMethod &signal)
-#else
-void ActionDescription::connectNotify(const char *signal)
-#endif
 {
 	QObject::connectNotify(signal);
 
-#if QT_VERSION >= 0x050000
 	if (signal == QMetaMethod::fromSignal(&ActionDescription::actionCreated))
-#else
-	if (QLatin1String(signal) == SIGNAL(actionCreated(Action*))) // do not insert space here
-#endif
 		foreach (Action *action, MappedActions)
 			emit actionCreated(action);
 }
