@@ -3,8 +3,8 @@
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QMenu>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account-manager.h"
 #include "buddies/buddy-set.h"
@@ -38,13 +38,6 @@ Action::Action(ActionDescription *description, ActionContext *context, QObject *
 		QAction(parent), Description(description), Context(context)
 {
 	setText(Description->Text);
-
-	if (!Description->icon().isNull())
-	{
-		connect(IconsManager::instance(), SIGNAL(themeChanged()), this, SLOT(updateIcon()));
-		setIcon(Description->icon());
-	}
-
 	setCheckable(Description->Checkable);
 
 	connect(this, SIGNAL(changed()), this, SLOT(changedSlot()));
@@ -52,7 +45,6 @@ Action::Action(ActionDescription *description, ActionContext *context, QObject *
 	connect(this, SIGNAL(triggered(bool)), this, SLOT(triggeredSlot(bool)));
 
 	connect(context, SIGNAL(changed()), this, SLOT(checkState()));
-	checkState();
 }
 
 Action::~Action()
@@ -67,6 +59,22 @@ Action::~Action()
 	}
 }
 
+void Action::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void Action::init()
+{
+	if (!Description->icon().isNull())
+	{
+		connect(m_iconsManager, SIGNAL(themeChanged()), this, SLOT(updateIcon()));
+		setIcon(Description->icon());
+	}
+
+	checkState();
+}
+
 ActionContext * Action::context()
 {
 	return Context;
@@ -102,7 +110,7 @@ void Action::updateIcon()
 
 void Action::setIcon(const KaduIcon &icon)
 {
-	QAction::setIcon(icon.icon());
+	QAction::setIcon(m_iconsManager->iconByPath(icon));
 }
 
 void disableEmptyContacts(Action *action)
@@ -112,7 +120,7 @@ void disableEmptyContacts(Action *action)
 
 void disableNoChat(Action *action)
 {
-	action->setEnabled(action->context()->chat());
+	action->setEnabled(action->context()->chat() && !action->context()->buddies().isAnyTemporary());
 }
 
 #include "moc_action.cpp"
