@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,28 +19,28 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "core/core.h"
+#include "core/session-service.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/windows/main-window.h"
 
 #include "actions.h"
 
-Actions * Actions::Instance = 0;
-
-Actions * Actions::instance()
+Actions::Actions(QObject *parent) :
+		QObject{parent},
+		BlockSignals{false}
 {
-	if (!Instance)
-		Instance = new Actions();
-
-	return Instance;
 }
 
-Actions::Actions() :
-	BlockSignals(false)
+Actions::~Actions()
 {
 }
 
+void Actions::setSessionService(SessionService *sessionService)
+{
+	m_sessionService = sessionService;
+}
+
 void Actions::insert(ActionDescription *action)
 {
 	QMap<QString, ActionDescription *>::insert(action->name(), action);
@@ -53,16 +53,20 @@ void Actions::remove(ActionDescription *action)
 {
 	QMap<QString, ActionDescription *>::remove(action->name());
 
-	if (!Core::instance()->isClosing())
+	if (!m_sessionService->isClosing())
 		emit actionUnloaded(action);
 }
 
 QAction * Actions::createAction(const QString &name, ActionContext *context, QObject *parent)
 {
 	if (!contains(name))
-		return 0;
+		return nullptr;
 
-	Action *result = value(name)->createAction(context, parent);
+	auto v = value(name);
+	if (!v)
+		return nullptr;
+
+	auto result = v->createAction(context, parent);
 
 	emit actionCreated(result);
 
