@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,21 +18,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHANGE_STATUS_ACTION_H
-#define CHANGE_STATUS_ACTION_H
-
-#include <QtGui/QAction>
+#pragma once
 
 #include "gui/actions/action-description.h"
 
+#include <QtWidgets/QAction>
+
 class ChangeStatusAction : public ActionDescription
 {
 	Q_OBJECT
 
-protected:
-	virtual QMenu * menuForAction(Action *action);
-	virtual void actionInstanceCreated(Action *action);
-
 public:
 	explicit ChangeStatusAction(QObject *parent);
 	virtual ~ChangeStatusAction();
@@ -43,6 +37,8 @@ public:
 		return QToolButton::InstantPopup;
 	}
 
-};
+protected:
+	virtual QMenu * menuForAction(Action *action);
+	virtual void actionInstanceCreated(Action *action);
 
-#endif // CHANGE_STATUS_ACTION_H
+};
