@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,6 +21,8 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
+#include "core/injected-factory.h"
+#include "gui/actions/actions.h"
 #include "gui/actions/action.h"
 #include "gui/windows/add-conference-window.h"
 
@@ -31,37 +31,44 @@
 AddConferenceAction::AddConferenceAction(QObject *parent) :
 		ActionDescription(parent)
 {
-	setType(ActionDescription::TypeGlobal);
-	setName("addConferenceAction");
-	setText(tr("Add Conference..."));
-
-	registerAction();
-
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)),
-	        this, SLOT(updateAddChatMenuItem()));
-	connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)),
-	        this, SLOT(updateAddChatMenuItem()));
-
-	updateAddChatMenuItem();
 }
 
 AddConferenceAction::~AddConferenceAction()
 {
 }
 
+void AddConferenceAction::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void AddConferenceAction::init()
+{
+	setType(ActionDescription::TypeGlobal);
+	setName("addConferenceAction");
+	setText(tr("Add Conference..."));
+
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)),
+	        this, SLOT(updateAddChatMenuItem()));
+	connect(m_accountManager, SIGNAL(accountUnregistered(Account)),
+	        this, SLOT(updateAddChatMenuItem()));
+
+	updateAddChatMenuItem();
+}
+
 void AddConferenceAction::triggered(QWidget *widget, ActionContext *context, bool toggled)
 {
 	Q_UNUSED(context)
 	Q_UNUSED(toggled)
 
-	(new AddConferenceWindow(widget))->show();
+	(injectedFactory()->makeInjected<AddConferenceWindow>(widget))->show();
 }
 
 void AddConferenceAction::updateAddChatMenuItem()
 {
 	bool isConferenceSupported = false;
 
-	foreach (const Account &account, AccountManager::instance()->items())
+	foreach (const Account &account, m_accountManager->items())
 	{
 		if (account.protocolName() == "gadu")
 			isConferenceSupported = true;
