@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,6 +21,7 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
+#include "core/injected-factory.h"
 #include "gui/actions/action.h"
 
 #include "gui/windows/add-room-chat-window.h"
@@ -35,34 +34,38 @@ AddRoomChatAction::AddRoomChatAction(QObject *parent) :
 	setType(ActionDescription::TypeGlobal);
 	setName("addRoomChatAction");
 	setText(tr("Join Room..."));
-
-	registerAction();
-
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)),
-	        this, SLOT(updateAddChatMenuItem()));
-	connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)),
-	        this, SLOT(updateAddChatMenuItem()));
-
-	updateAddChatMenuItem();
 }
 
 AddRoomChatAction::~AddRoomChatAction()
 {
 }
 
+void AddRoomChatAction::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void AddRoomChatAction::init()
+{
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)), this, SLOT(updateAddChatMenuItem()));
+	connect(m_accountManager, SIGNAL(accountUnregistered(Account)), this, SLOT(updateAddChatMenuItem()));
+
+	updateAddChatMenuItem();
+}
+
 void AddRoomChatAction::triggered(QWidget *widget, ActionContext *context, bool toggled)
 {
 	Q_UNUSED(context)
 	Q_UNUSED(toggled)
 
-	(new AddRoomChatWindow(widget))->show();
+	(injectedFactory()->makeInjected<AddRoomChatWindow>(widget))->show();
 }
 
 void AddRoomChatAction::updateAddChatMenuItem()
 {
 	bool isRoomChatSupported = false;
 
-	foreach (const Account &account, AccountManager::instance()->items())
+	foreach (const Account &account, m_accountManager->items())
 	{
 		if (account.protocolName() == "jabber")
 			isRoomChatSupported = true;
