@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,27 +19,34 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ADD_ROOM_CHAT_ACTION_H
-#define ADD_ROOM_CHAT_ACTION_H
-
-#include <QtGui/QAction>
+#pragma once
 
 #include "gui/actions/action-description.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QAction>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
+
 class AddRoomChatAction : public ActionDescription
 {
 	Q_OBJECT
 
-private slots:
-	void updateAddChatMenuItem();
-
-protected:
-	virtual void triggered(QWidget *widget, ActionContext *context, bool toggled);
-
 public:
 	explicit AddRoomChatAction(QObject *parent);
 	virtual ~AddRoomChatAction();
 
-};
+protected:
+	virtual void triggered(QWidget *widget, ActionContext *context, bool toggled);
 
-#endif // ADD_ROOM_CHAT_ACTION_H
+private:
+	QPointer<AccountManager> m_accountManager;
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_INIT void init();
+
+	void updateAddChatMenuItem();
+
+};
