@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "leave-chat-action.h"
+
 #include "chat/chat.h"
-#include "core/core.h"
 #include "gui/actions/action-context.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/chat-widget/chat-widget-repository.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/windows/message-dialog.h"
-
-#include "leave-chat-action.h"
+#include "icons/icons-manager.h"
+#include "protocols/protocol.h"
+#include "protocols/services/chat-service.h"
 
 LeaveChatAction::LeaveChatAction(QObject *parent) :
 		ActionDescription(parent)
@@ -36,14 +38,22 @@ LeaveChatAction::LeaveChatAction(QObject *parent) :
 	setName("leaveChatAction");
 	setIcon(KaduIcon("kadu_icons/block-buddy"));
 	setText(tr("Leave"));
-
-	registerAction();
 }
 
 LeaveChatAction::~LeaveChatAction()
 {
 }
 
+void LeaveChatAction::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
+{
+	m_chatWidgetRepository = chatWidgetRepository;
+}
+
+void LeaveChatAction::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
 void LeaveChatAction::triggered(QWidget *widget, ActionContext *context, bool toggled)
 {
 	Q_UNUSED(toggled)
@@ -52,19 +62,28 @@ void LeaveChatAction::triggered(QWidget *widget, ActionContext *context, bool to
 	if (!chat)
 		return;
 
-	auto chatWidget = Core::instance()->chatWidgetRepository()->widgetForChat(chat);
+	auto account = chat.chatAccount();
+	auto protocol = account.protocolHandler();
+	if (!protocol)
+		return;
+
+	auto chatService = protocol->chatService();
+	if (!chatService)
+		return;
+
+	auto chatWidget = m_chatWidgetRepository->widgetForChat(chat);
 	if (!chatWidget)
 		return;
 
-	auto dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Kadu"),
-						      tr("All messages received in this conference will be ignored\nfrom now on. Are you sure you want to leave this conference?"),
-						      widget);
+	auto dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"),
+		tr("All messages received in this conference will be ignored\nfrom now on. Are you sure you want to leave this conference?"),
+		widget);
 	dialog->addButton(QMessageBox::Yes, tr("Leave conference"));
 	dialog->addButton(QMessageBox::No, tr("Cancel"));
 	if (!dialog->ask())
 		return;
 
-	chat.setIgnoreAllMessages(true);
+	chatService->leaveChat(chat);
 	chatWidget->requestClose();
 }
 
