@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,17 +18,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QMenu>
+#include "default-proxy-action.h"
 
+#include "core/injected-factory.h"
+#include "gui/actions/actions.h"
 #include "gui/actions/action.h"
-#include "gui/windows/proxy-edit-window.h"
+#include "gui/windows/proxy-edit-window-service.h"
 #include "model/roles.h"
 #include "network/proxy/model/network-proxy-model.h"
 #include "network/proxy/model/network-proxy-proxy-model.h"
 #include "network/proxy/network-proxy-manager.h"
 
-#include "default-proxy-action.h"
+#include <QtWidgets/QAction>
+#include <QtWidgets/QMenu>
 
 DefaultProxyAction::DefaultProxyAction(QObject *parent) :
 		ActionDescription(parent)
@@ -36,14 +38,22 @@ DefaultProxyAction::DefaultProxyAction(QObject *parent) :
 	setType(ActionDescription::TypeGlobal);
 	setName("defaultProxyAction");
 	setText(tr("Select Default Proxy"));
-
-	registerAction();
 }
 
 DefaultProxyAction::~DefaultProxyAction()
 {
 }
 
+void DefaultProxyAction::setNetworkProxyManager(NetworkProxyManager *networkProxyManager)
+{
+	m_networkProxyManager = networkProxyManager;
+}
+
+void DefaultProxyAction::setProxyEditWindowService(ProxyEditWindowService *proxyEditWindowService)
+{
+	m_proxyEditWindowService = proxyEditWindowService;
+}
+
 QMenu * DefaultProxyAction::menuForAction(Action *action)
 {
 	Q_UNUSED(action)
@@ -57,8 +67,8 @@ QMenu * DefaultProxyAction::menuForAction(Action *action)
 
 void DefaultProxyAction::populateMenu(QMenu *menu, QActionGroup *actionGroup, NetworkProxy defaultProxy)
 {
-	NetworkProxyModel *proxyModel = new NetworkProxyModel();
-	NetworkProxyProxyModel *proxyProxyModel = new NetworkProxyProxyModel();
+	auto proxyModel = injectedFactory()->makeInjected<NetworkProxyModel>();
+	auto proxyProxyModel = new NetworkProxyProxyModel();
 	proxyProxyModel->setSourceModel(proxyModel);
 
 	int proxCount = proxyProxyModel->rowCount();
@@ -89,7 +99,7 @@ void DefaultProxyAction::prepareMenu()
 
 	menu->clear();
 
-	NetworkProxy defaultProxy = NetworkProxyManager::instance()->defaultProxy();
+	NetworkProxy defaultProxy = m_networkProxyManager->defaultProxy();
 
 	QAction *proxyAction = menu->addAction(tr(" - No proxy - "));
 
@@ -110,12 +120,12 @@ void DefaultProxyAction::prepareMenu()
 void DefaultProxyAction::selectProxyActionTriggered(QAction *action)
 {
 	NetworkProxy defaultProxy = qvariant_cast<NetworkProxy>(action->data());
-	NetworkProxyManager::instance()->setDefaultProxy(defaultProxy);
+	m_networkProxyManager->setDefaultProxy(defaultProxy);
 }
 
 void DefaultProxyAction::editProxyConfiguration()
 {
-	ProxyEditWindow::show();
+	m_proxyEditWindowService->show();
 }
 
 #include "moc_default-proxy-action.cpp"
