@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,31 +18,25 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DEFAULT_PROXY_ACTION_H
-#define DEFAULT_PROXY_ACTION_H
-
-#include <QtGui/QAction>
+#pragma once
 
 #include "gui/actions/action-description.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QAction>
+#include <injeqt/injeqt.h>
+
+class Actions;
+class NetworkProxyManager;
 class NetworkProxy;
+class ProxyEditWindowService;
 
 class DefaultProxyAction : public ActionDescription
 {
 	Q_OBJECT
 
-	void populateMenu(QMenu *menu, QActionGroup *actionGroup, NetworkProxy defaultProxy);
-
-private slots:
-	void prepareMenu();
-	void selectProxyActionTriggered(QAction *action);
-	void editProxyConfiguration();
-
-protected:
-	virtual QMenu * menuForAction(Action *action);
-
 public:
-	explicit DefaultProxyAction(QObject *parent);
+	explicit DefaultProxyAction(QObject *parent = nullptr);
 	virtual ~DefaultProxyAction();
 
 	virtual QToolButton::ToolButtonPopupMode buttonPopupMode() const
@@ -51,6 +44,21 @@ public:
 		return QToolButton::InstantPopup;
 	}
 
-};
+protected:
+	virtual QMenu * menuForAction(Action *action);
 
-#endif // DEFAULT_PROXY_ACTION_H
+private:
+	QPointer<NetworkProxyManager> m_networkProxyManager;
+	QPointer<ProxyEditWindowService> m_proxyEditWindowService;
+
+	void populateMenu(QMenu *menu, QActionGroup *actionGroup, NetworkProxy defaultProxy);
+
+private slots:
+	INJEQT_SET void setNetworkProxyManager(NetworkProxyManager *networkProxyManager);
+	INJEQT_SET void setProxyEditWindowService(ProxyEditWindowService *proxyEditWindowService);
+
+	void prepareMenu();
+	void selectProxyActionTriggered(QAction *action);
+	void editProxyConfiguration();
+
+};
