@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,17 +19,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 #include "buddies/buddy-set.h"
 #include "chat/chat.h"
 #include "chat/type/chat-type-manager.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/actions/action-context.h"
 #include "gui/actions/action.h"
 #include "gui/windows/buddy-delete-window.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 
 #include "delete-talkable-action.h"
 
@@ -42,14 +44,32 @@ DeleteTalkableAction::DeleteTalkableAction(QObject *parent) :
 	setIcon(KaduIcon("edit-delete"));
 	setShortcut("kadu_deleteuser");
 	setText(tr("Delete Buddy"));
-
-	registerAction();
 }
 
 DeleteTalkableAction::~DeleteTalkableAction()
 {
 }
 
+void DeleteTalkableAction::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
+void DeleteTalkableAction::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void DeleteTalkableAction::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void DeleteTalkableAction::init()
+{
+	registerAction(actionsRegistry());
+}
+
 int DeleteTalkableAction::actionRole(ActionContext *context) const
 {
 	if (context->roles().contains(ContactRole)) // we wont allow deleting contacts
@@ -88,8 +108,8 @@ void DeleteTalkableAction::updateChatActionState(Action *action)
 {
 	setChatActionTitleAndIcon(action);
 
-	const Chat &chat = actionChat(action->context());
-	ChatType *chatType = ChatTypeManager::instance()->chatType(chat.type());
+	auto const &chat = actionChat(action->context());
+	auto chatType = m_chatTypeManager->chatType(chat.type());
 	action->setEnabled(chat && (!chatType || (chatType->name() != "Contact" && !chat.display().isEmpty())));
 }
 
@@ -98,7 +118,7 @@ void DeleteTalkableAction::updateBuddyActionState(Action *action)
 	setBuddyActionTitleAndIcon(action);
 
 	const BuddySet &buddies = action->context()->buddies();
-	if (buddies.isEmpty() || buddies.contains(Core::instance()->myself()))
+	if (buddies.isEmpty() || buddies.contains(m_myself->buddy()))
 		return;
 
 	action->setEnabled(true);
@@ -123,6 +143,9 @@ void DeleteTalkableAction::updateActionState(Action *action)
 {
 	action->setEnabled(false);
 
+	if (action->context()->buddies().isAnyTemporary())
+		return;
+
 	switch (actionRole(action->context()))
 	{
 		case ChatRole:
@@ -140,7 +163,7 @@ void DeleteTalkableAction::chatActionTriggered(ActionContext *context)
 	if (!chat)
 		return;
 
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Delete Chat"),
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Delete Chat"),
 	                        tr("<b>%1</b> chat will be deleted.<br/>Are you sure?").arg(chat.display()));
 	dialog->addButton(QMessageBox::Yes, tr("Delete chat"));
 	dialog->addButton(QMessageBox::No, tr("Cancel"));
@@ -151,11 +174,11 @@ void DeleteTalkableAction::chatActionTriggered(ActionContext *context)
 
 void DeleteTalkableAction::buddyActionTriggered(ActionContext *context)
 {
-	BuddySet buddySet = context->buddies();
+	auto buddySet = context->buddies();
 	if (buddySet.empty())
 		return;
 
-	BuddyDeleteWindow *deleteWindow = new BuddyDeleteWindow(buddySet);
+	auto deleteWindow = injectedFactory()->makeInjected<BuddyDeleteWindow>(buddySet);
 	deleteWindow->show();
 }
 
