@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,12 +18,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 #include "buddies/buddy-set.h"
 #include "chat/chat.h"
 #include "chat/type/chat-type-manager.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/actions/action-context.h"
 #include "gui/actions/action.h"
 #include "gui/windows/add-buddy-window.h"
@@ -31,6 +32,7 @@
 #include "gui/windows/buddy-data-window.h"
 #include "gui/windows/chat-data-window-repository.h"
 #include "gui/windows/chat-data-window.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 
 #include "edit-talkable-action.h"
@@ -43,14 +45,37 @@ EditTalkableAction::EditTalkableAction(QObject *parent) :
 	setName("editUserAction");
 	setIcon(KaduIcon("x-office-address-book"));
 	setText(tr("View Buddy Properties"));
-
-	registerAction();
 }
 
 EditTalkableAction::~EditTalkableAction()
 {
 }
 
+void EditTalkableAction::setBuddyDataWindowRepository(BuddyDataWindowRepository *buddyDataWindowRepository)
+{
+	m_buddyDataWindowRepository = buddyDataWindowRepository;
+}
+
+void EditTalkableAction::setChatDataWindowRepository(ChatDataWindowRepository *chatDataWindowRepository)
+{
+	m_chatDataWindowRepository = chatDataWindowRepository;
+}
+
+void EditTalkableAction::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
+void EditTalkableAction::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void EditTalkableAction::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
 int EditTalkableAction::actionRole(ActionContext *context) const
 {
 	if (context->roles().contains(ChatRole))
@@ -99,7 +124,7 @@ void EditTalkableAction::updateChatActionState(Action *action)
 	setChatActionTitleAndIcon(action);
 
 	const Chat &chat = actionChat(action->context());
-	ChatType *chatType = ChatTypeManager::instance()->chatType(chat.type());
+	ChatType *chatType = m_chatTypeManager->chatType(chat.type());
 	action->setEnabled(chat && (!chatType || (chatType->name() != "Contact" && !chat.display().isEmpty())));
 }
 
@@ -111,7 +136,7 @@ void EditTalkableAction::updateBuddyActionState(Action *action)
 	if (!buddy)
 		return;
 
-	if (buddy == Core::instance()->myself())
+	if (buddy == m_myself->buddy())
 		return;
 
 	action->setEnabled(true);
@@ -136,6 +161,9 @@ void EditTalkableAction::updateActionState(Action *action)
 {
 	action->setEnabled(false);
 
+	if (action->context()->buddies().isAnyTemporary())
+		return;
+
 	switch (actionRole(action->context()))
 	{
 		case ChatRole:
@@ -153,7 +181,7 @@ void EditTalkableAction::chatActionTriggered(ActionContext *context)
 	if (!chat)
 		return;
 
-	Core::instance()->chatDataWindowRepository()->showChatWindow(chat);
+	m_chatDataWindowRepository->showChatWindow(chat);
 }
 
 void EditTalkableAction::buddyActionTriggered(ActionContext *context)
@@ -162,9 +190,9 @@ void EditTalkableAction::buddyActionTriggered(ActionContext *context)
 	if (!buddy)
 		return;
 	if (buddy.isAnonymous())
-		(new AddBuddyWindow(Core::instance()->kaduWindow(), buddy, true))->show();
+		(injectedFactory()->makeInjected<AddBuddyWindow>(m_kaduWindowService->kaduWindow(), buddy, true))->show();
 	else
-		Core::instance()->buddyDataWindowRepository()->showBuddyWindow(buddy);
+		m_buddyDataWindowRepository->showBuddyWindow(buddy);
 }
 
 void EditTalkableAction::triggered(QWidget *widget, ActionContext *context, bool toggled)
