@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,16 +19,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QMenu>
+#include "recent-chats-action.h"
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/actions/action.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/recent-chats-menu.h"
 
-#include "recent-chats-action.h"
+#include <QtWidgets/QMenu>
 
 RecentChatsAction::RecentChatsAction(QObject *parent) :
 		ActionDescription(parent)
@@ -37,29 +37,34 @@ RecentChatsAction::RecentChatsAction(QObject *parent) :
 	setName("openRecentChatsAction");
 	setIcon(KaduIcon("internet-group-chat"));
 	setText(tr("Recent Chats"));
-
-	RecentChatsMenuInstance = new RecentChatsMenu();
-	connect(RecentChatsMenuInstance, SIGNAL(triggered(QAction *)),
-		this, SLOT(openRecentChats(QAction *)));
 }
 
 RecentChatsAction::~RecentChatsAction()
 {
-	delete RecentChatsMenuInstance;
-	RecentChatsMenuInstance = 0;
+}
+
+void RecentChatsAction::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void RecentChatsAction::init()
+{
+	m_recentChatsMenu = injectedFactory()->makeNotOwned<RecentChatsMenu>();
+	connect(m_recentChatsMenu, SIGNAL(triggered(QAction *)), this, SLOT(openRecentChats(QAction *)));
 }
 
 void RecentChatsAction::actionInstanceCreated(Action *action)
 {
 	action->setEnabled(false);
-	action->setMenu(RecentChatsMenuInstance);
-	connect(RecentChatsMenuInstance, SIGNAL(chatsListAvailable(bool)),
-		action, SLOT(setEnabled(bool)));
+	action->setMenu(m_recentChatsMenu);
+	connect(m_recentChatsMenu, SIGNAL(chatsListAvailable(bool)), action, SLOT(setEnabled(bool)));
+	m_recentChatsMenu->invalidate();
 }
 
 void RecentChatsAction::openRecentChats(QAction *action)
 {
-	Core::instance()->chatWidgetManager()->openChat(action->data().value<Chat>(), OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(action->data().value<Chat>(), OpenChatActivation::Activate);
 }
 
 #include "moc_recent-chats-action.cpp"
