@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,22 +22,22 @@
 
 #include <QtGui/QKeyEvent>
 
-#include "configuration/configuration-file.h"
-
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "hot-key.h"
 
-QKeySequence HotKey::shortCutFromFile(const QString &groupname, const QString &name)
+QKeySequence HotKey::shortCutFromFile(Configuration *configuration, const QString &groupname, const QString &name)
 {
-	return QKeySequence(config_file.readEntry(groupname, name));
+	return QKeySequence::fromString(configuration->deprecatedApi()->readEntry(groupname, name), QKeySequence::PortableText);
 }
 
-bool HotKey::shortCut(QKeyEvent *e, const QString &groupname, const QString &name)
+bool HotKey::shortCut(Configuration *configuration, QKeyEvent *e, const QString &groupname, const QString &name)
 {
-	QString config = config_file.readEntry(groupname, name);
-	return !config.isEmpty() && config == keyEventToString(e);
+	QString config = configuration->deprecatedApi()->readEntry(groupname, name);
+	return !config.isEmpty() && config == keyEventToString(e, QKeySequence::PortableText);
 }
 
-QString HotKey::keyEventToString(QKeyEvent *e)
+QString HotKey::keyEventToString(QKeyEvent *e, QKeySequence::SequenceFormat format)
 {
 	QString result;
 	if ((e->modifiers() & Qt::ControlModifier) || (e->key() == Qt::Key_Control))
@@ -57,7 +57,7 @@ QString HotKey::keyEventToString(QKeyEvent *e)
 		(e->key() == Qt::Key_Shift) ||
 		(e->key() == Qt::Key_Alt) ||
 		(e->key() == Qt::Key_Meta)))
-		result += QKeySequence(e->key()).toString();
+		result += QKeySequence(e->key()).toString(format);
 
 	return result;
 }
@@ -69,18 +69,17 @@ HotKeyEdit::HotKeyEdit(QWidget *parent)
 
 QString HotKeyEdit::shortCutString() const
 {
-	return text();
+	return shortCut().toString(QKeySequence::PortableText);
 }
 
 QKeySequence HotKeyEdit::shortCut() const
 {
-	return QKeySequence(text());
+	return QKeySequence::fromString(text(), QKeySequence::NativeText);
 }
 
 void HotKeyEdit::setShortCut(const QString &shortcut)
 {
-	QKeySequence str(shortcut);
-	if (str.isEmpty())
+	if (QKeySequence::fromString(shortcut, QKeySequence::PortableText).isEmpty())
 		clear();
 	else
 		setText(shortcut);
@@ -88,12 +87,12 @@ void HotKeyEdit::setShortCut(const QString &shortcut)
 
 void HotKeyEdit::setShortCut(const QKeySequence &shortcut)
 {
-	setText(shortcut);
+	setText(shortcut.toString(QKeySequence::NativeText));
 }
 
 void HotKeyEdit::keyPressEvent(QKeyEvent *e)
 {
-	setText(HotKey::keyEventToString(e));
+	setText(HotKey::keyEventToString(e, QKeySequence::NativeText));
 }
 
 void HotKeyEdit::keyReleaseEvent(QKeyEvent *)
