@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +26,7 @@
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/menu/menu-inventory.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "protocols/protocol-menu-manager.h"
 #include "menu-item.h"
@@ -33,7 +34,9 @@
 #include "kadu-menu.h"
 
 KaduMenu::KaduMenu(const QString &category, KaduMenu *parent) :
-		QObject(parent), Category(category), IsSorted(true)
+		QObject{parent},
+		Category{category},
+		IsSorted{true}
 {
 }
 
@@ -41,6 +44,16 @@ KaduMenu::~KaduMenu()
 {
 }
 
+void KaduMenu::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void KaduMenu::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
 void KaduMenu::menuDestroyed(QObject *object)
 {
 	Menus.removeAll(static_cast<QMenu *>(object));
@@ -119,7 +132,8 @@ void KaduMenu::appendTo(QMenu *menu, ActionContext *context)
 		? context
 		: getActionContext();
 
-	bool firstItem = true;
+	auto firstItem = true;
+	auto actionsFirstItem = true;
 	MenuSection latestSection = KaduMenu::SectionAbout; // prevent 4.9 from complaining
 
 	QMenu *actions = new QMenu(tr("More Actions..."), menu);
@@ -129,27 +143,34 @@ void KaduMenu::appendTo(QMenu *menu, ActionContext *context)
 		if (!menuItem->actionDescription())
 			continue;
 
-		QMenu *currentMenu = menuItem->section() == KaduMenu::SectionActions
+		auto isActions = menuItem->section() == KaduMenu::SectionActions || menuItem->section() == KaduMenu::KaduMenu::SectionActionsGui;
+		auto currentMenu = isActions
 			? actions
 			: menu;
+		auto menuFirstItem = isActions
+			? &actionsFirstItem
+			: &firstItem;
 
-		if (!firstItem && latestSection != menuItem->section())
+		if (!*menuFirstItem && latestSection != menuItem->section())
 			currentMenu->addSeparator();
 
-		Action *action = menuItem->actionDescription()->createAction(actionContext, currentMenu->parent());
+		auto parent = currentMenu->parent() ? currentMenu->parent() : currentMenu;
+		Action *action = menuItem->actionDescription()->createAction(actionContext, parent);
 		currentMenu->addAction(action);
 		action->checkState();
 
 		latestSection = menuItem->section();
-		firstItem = false;
+		*menuFirstItem = false;
 	}
 
 	if ("buddy-list" != Category)
 		return;
 
-	if (actionContext->roles().contains(ContactRole) && 1 == actionContext->contacts().size())
+	auto isContact = actionContext->roles().contains(ContactRole) && 1 == actionContext->contacts().size();
+	auto isOneContactbuddy = actionContext->roles().contains(BuddyRole) && 1 == actionContext->buddies().size() && 1 == actionContext->buddies().begin()->contacts().size();
+	if (isContact || isOneContactbuddy)
 	{
-		foreach (ProtocolMenuManager *manager, MenuInventory::instance()->protocolMenuManagers())
+		foreach (ProtocolMenuManager *manager, m_menuInventory->protocolMenuManagers())
 		{
 			Contact contact = *actionContext->contacts().constBegin();
 			if (contact.contactAccount().protocolName() != manager->protocolName())
@@ -197,7 +218,7 @@ void KaduMenu::updateGuiMenuSlot()
 
 ActionContext * KaduMenu::getActionContext()
 {
-	return Core::instance()->kaduWindow()->actionContext();
+	return m_kaduWindowService->kaduWindow()->actionContext();
 }
 
 void KaduMenu::update()
