@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,14 +28,18 @@
 StatusIcon::StatusIcon(StatusContainer *statusContainer, QObject *parent) :
 		QObject(parent), MyStatusContainer(statusContainer), BlinkTimer(0), BlinkOffline(true)
 {
-	statusUpdated();
-	connect(MyStatusContainer, SIGNAL(statusUpdated(StatusContainer *)), this, SLOT(statusUpdated(StatusContainer *)));
 }
 
 StatusIcon::~StatusIcon()
 {
 }
 
+void StatusIcon::init()
+{
+	statusUpdated();
+	connect(MyStatusContainer, SIGNAL(statusUpdated(StatusContainer *)), this, SLOT(statusUpdated(StatusContainer *)));
+}
+
 void StatusIcon::enableBlink()
 {
 	if (BlinkTimer)
@@ -72,7 +72,7 @@ void StatusIcon::blink()
 	BlinkOffline = !BlinkOffline;
 
 	if (BlinkOffline)
-		setIcon(MyStatusContainer->statusIcon(StatusTypeOffline));
+		setIcon(MyStatusContainer->statusIcon(Status{StatusType::Offline}));
 	else
 		setIcon(MyStatusContainer->statusIcon());
 }
