@@ -2,10 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +23,7 @@
 #ifndef ACCOUNT_ADD_WIDGET_H
 #define ACCOUNT_ADD_WIDGET_H
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 #include "accounts/account.h"
 #include "gui/widgets/modal-configuration-widget.h"
@@ -44,7 +42,7 @@ protected:
 	SimpleConfigurationValueStateNotifier * simpleStateNotifier() const;
 
 public:
-	explicit AccountAddWidget(QWidget *parent = 0);
+	explicit AccountAddWidget(QWidget *parent = nullptr);
 	virtual ~AccountAddWidget();
 
 	virtual const ConfigurationValueStateNotifier * stateNotifier() const;
