@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +19,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QFileDialog>
-#include <QtGui/QLabel>
-#include <QtGui/QMovie>
-#include <QtGui/QPushButton>
-#include <QtGui/QVBoxLayout>
+#include "account-avatar-widget.h"
 
 #include "avatars/avatar-manager.h"
 #include "avatars/avatar.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
@@ -34,28 +31,51 @@
 #include "protocols/services/avatar-service.h"
 #include "protocols/services/avatar-uploader.h"
 
-#include "account-avatar-widget.h"
+#include <QtGui/QMovie>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QVBoxLayout>
 
 AccountAvatarWidget::AccountAvatarWidget(Account account, QWidget *parent) :
 		QWidget(parent), MyAccount(account), Service(0), WaitMovie(0)
 {
-	WaitMovie = new QMovie(KaduIcon("kadu_icons/please-wait", "16x16").fullPath(), QByteArray(), this);
-
-	createGui();
-
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
-	        this, SLOT(protocolRegistered(ProtocolFactory*)));
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
-	        this, SLOT(protocolUnregistered(ProtocolFactory*)));
-
-	foreach (ProtocolFactory *factory, ProtocolsManager::instance()->protocolFactories())
-		protocolRegistered(factory);
 }
 
 AccountAvatarWidget::~AccountAvatarWidget()
 {
 }
 
+void AccountAvatarWidget::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void AccountAvatarWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void AccountAvatarWidget::setProtocolsManager(ProtocolsManager *protocolsManager)
+{
+	m_protocolsManager = protocolsManager;
+}
+
+void AccountAvatarWidget::init()
+{
+	WaitMovie = new QMovie(m_iconsManager->iconPath(KaduIcon("kadu_icons/please-wait", "16x16")), QByteArray(), this);
+
+	createGui();
+
+	connect(m_protocolsManager, SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
+	        this, SLOT(protocolRegistered(ProtocolFactory*)));
+	connect(m_protocolsManager, SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
+	        this, SLOT(protocolUnregistered(ProtocolFactory*)));
+
+	for (auto factory : m_protocolsManager->protocolFactories())
+		protocolRegistered(factory);
+}
+
 void AccountAvatarWidget::serviceDestroyed()
 {
 	Service = 0;
@@ -78,14 +98,14 @@ void AccountAvatarWidget::createGui()
 
 	layout->addWidget(ChangePhotoButton, 0, Qt::AlignHCenter);
 
-	auto avatar = AvatarManager::instance()->byContact(MyAccount.accountContact(), ActionCreateAndAdd);
+	auto avatar = m_avatarManager->byContact(MyAccount.accountContact(), ActionCreateAndAdd);
 	connect(avatar, SIGNAL(updated()), this, SLOT(avatarUpdated()));
 	avatarUpdated();
 }
 
 void AccountAvatarWidget::setupMode()
 {
-	auto avatar = AvatarManager::instance()->byContact(MyAccount.accountContact(), ActionCreateAndAdd);
+	auto avatar = m_avatarManager->byContact(MyAccount.accountContact(), ActionCreateAndAdd);
 	if (MyAccount.protocolHandler()->protocolFactory()->canRemoveAvatar() && !avatar.isEmpty())
 		Mode = ModeRemove;
 	else
@@ -181,7 +201,7 @@ void AccountAvatarWidget::removeAvatar()
 void AccountAvatarWidget::avatarUploaded(bool ok, QImage image)
 {
 	if (ok)
-		AvatarManager::instance()->byContact(MyAccount.accountContact(), ActionCreateAndAdd).setPixmap(QPixmap::fromImage(image));
+		m_avatarManager->byContact(MyAccount.accountContact(), ActionCreateAndAdd).setPixmap(QPixmap::fromImage(image));
 
 	avatarUpdated();
 	ChangePhotoButton->setEnabled(true);
