@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,32 +27,37 @@
 #include "account-configuration-widget-factory.h"
 #include "account-edit-widget.h"
 
-AccountEditWidget::AccountEditWidget(AccountConfigurationWidgetFactoryRepository *accountConfigurationWidgetFactoryRepository, Account account, QWidget *parent) :
-		AccountConfigurationWidget(account, parent), MyAccountConfigurationWidgetFactoryRepository(accountConfigurationWidgetFactoryRepository),
+AccountEditWidget::AccountEditWidget(Account account, QWidget *parent) :
+		AccountConfigurationWidget(account, parent),
 		StateNotifier(new SimpleConfigurationValueStateNotifier(this)),
 		CompositeStateNotifier(new CompositeConfigurationValueStateNotifier(this))
 {
 	CompositeStateNotifier->addConfigurationValueStateNotifier(StateNotifier);
-
-	if (MyAccountConfigurationWidgetFactoryRepository)
-	{
-		connect(MyAccountConfigurationWidgetFactoryRepository, SIGNAL(factoryRegistered(AccountConfigurationWidgetFactory*)),
-				this, SLOT(factoryRegistered(AccountConfigurationWidgetFactory*)));
-		connect(MyAccountConfigurationWidgetFactoryRepository, SIGNAL(factoryUnregistered(AccountConfigurationWidgetFactory*)),
-				this, SLOT(factoryUnregistered(AccountConfigurationWidgetFactory*)));
-
-		foreach (AccountConfigurationWidgetFactory *factory, MyAccountConfigurationWidgetFactoryRepository->factories())
-			factoryRegistered(factory);
-	}
 }
 
 AccountEditWidget::~AccountEditWidget()
 {
 }
 
+void AccountEditWidget::setAccountConfigurationWidgetFactoryRepository(AccountConfigurationWidgetFactoryRepository *accountConfigurationWidgetFactoryRepository)
+{
+	m_accountConfigurationWidgetFactoryRepository = accountConfigurationWidgetFactoryRepository;
+}
+
+void AccountEditWidget::init()
+{
+	connect(m_accountConfigurationWidgetFactoryRepository, SIGNAL(factoryRegistered(AccountConfigurationWidgetFactory*)),
+			this, SLOT(factoryRegistered(AccountConfigurationWidgetFactory*)));
+	connect(m_accountConfigurationWidgetFactoryRepository, SIGNAL(factoryUnregistered(AccountConfigurationWidgetFactory*)),
+			this, SLOT(factoryUnregistered(AccountConfigurationWidgetFactory*)));
+
+	for (auto factory : m_accountConfigurationWidgetFactoryRepository->factories())
+		factoryRegistered(factory);
+}
+
 AccountConfigurationWidgetFactoryRepository * AccountEditWidget::accountConfigurationWidgetFactoryRepository() const
 {
-	return MyAccountConfigurationWidgetFactoryRepository;
+	return m_accountConfigurationWidgetFactoryRepository;
 }
 
 void AccountEditWidget::factoryRegistered(AccountConfigurationWidgetFactory *factory)
@@ -74,11 +77,13 @@ void AccountEditWidget::factoryUnregistered(AccountConfigurationWidgetFactory *f
 	if (AccountConfigurationWidgets.contains(factory))
 	{
 		AccountConfigurationWidget *widget = AccountConfigurationWidgets.value(factory);
+		if (!widget)
+			return;
 		if (widget->stateNotifier())
 			CompositeStateNotifier->removeConfigurationValueStateNotifier(widget->stateNotifier());
+		AccountConfigurationWidgets.remove(factory);
 		emit widgetRemoved(widget);
 		widget->deleteLater();
-		AccountConfigurationWidgets.remove(factory);
 	}
 }
 
