@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,11 +19,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
+#include <QtWidgets/QAction>
 
+#include "accounts/account-manager.h"
 #include "accounts/filter/abstract-account-filter.h"
 #include "accounts/model/accounts-model.h"
 #include "accounts/model/accounts-proxy-model.h"
+#include "core/injected-factory.h"
 #include "model/model-chain.h"
 #include "model/roles.h"
 
@@ -34,19 +36,32 @@ AccountsComboBox::AccountsComboBox(bool includeSelectAccount, ActionVisibility v
 {
 	if (includeSelectAccount)
 		addBeforeAction(new QAction(tr(" - Select account - "), this), visibility);
-
-	ModelChain *chain = new ModelChain(this);
-	Model = new AccountsModel(chain);
-	ProxyModel = new AccountsProxyModel(chain);
-	chain->setBaseModel(Model);
-	chain->addProxyModel(ProxyModel);
-	setUpModel(AccountRole, chain);
 }
 
 AccountsComboBox::~AccountsComboBox()
 {
 }
 
+void AccountsComboBox::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void AccountsComboBox::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void AccountsComboBox::init()
+{
+	ModelChain *chain = new ModelChain(this);
+	Model = m_injectedFactory->makeInjected<AccountsModel>(m_accountManager, chain);
+	ProxyModel = new AccountsProxyModel(chain);
+	chain->setBaseModel(Model);
+	chain->addProxyModel(ProxyModel);
+	setUpModel(AccountRole, chain);
+}
+
 void AccountsComboBox::setCurrentAccount(Account account)
 {
 	setCurrentValue(account);
