@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,25 +19,25 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ACCOUNTS_COMBO_BOX_H
-#define ACCOUNTS_COMBO_BOX_H
+#pragma once
 
 #include "accounts/account.h"
 #include "gui/widgets/actions-combo-box.h"
 
+#include <injeqt/injeqt.h>
+
 class AbstractAccountFilter;
+class AccountManager;
 class AccountsModel;
 class AccountsProxyModel;
+class InjectedFactory;
 
 class AccountsComboBox : public ActionsComboBox
 {
 	Q_OBJECT
 
-	AccountsModel *Model;
-	AccountsProxyModel *ProxyModel;
-
 public:
-	explicit AccountsComboBox(bool includeSelectAccount, ActionVisibility visibility, QWidget *parent = 0);
+	explicit AccountsComboBox(bool includeSelectAccount, ActionVisibility visibility, QWidget *parent = nullptr);
 	virtual ~AccountsComboBox();
 
 	void setCurrentAccount(Account account);
@@ -50,6 +48,16 @@ public:
 	void addFilter(AbstractAccountFilter *filter);
 	void removeFilter(AbstractAccountFilter *filter);
 
-};
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<InjectedFactory> m_injectedFactory;
 
-#endif // ACCOUNTS_COMBO_BOX_H
+	AccountsModel *Model;
+	AccountsProxyModel *ProxyModel;
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
+};
