@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,13 +19,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_AVATAR_WIDGET_H
-#define BUDDY_AVATAR_WIDGET_H
-
-#include <QtGui/QWidget>
+#pragma once
 
 #include "buddies/buddy.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
+class AvatarManager;
+class BuddyPreferredManager;
+
 class QLabel;
 class QPushButton;
 
@@ -36,6 +37,16 @@ class BuddyAvatarWidget : public QWidget
 {
 	Q_OBJECT
 
+public:
+	explicit BuddyAvatarWidget(Buddy buddy, QWidget *parent = nullptr);
+
+	const QPixmap avatarPixmap();
+	bool buddyAvatar() const { return BuddyAvatar; }
+
+private:
+	QPointer<AvatarManager> m_avatarManager;
+	QPointer<BuddyPreferredManager> m_buddyPreferredManager;
+
 	Buddy MyBuddy;
 
 	bool BuddyAvatar;
@@ -57,14 +68,10 @@ class BuddyAvatarWidget : public QWidget
 	void removeAvatar();
 
 private slots:
+	INJEQT_SET void setAvatarManager(AvatarManager *avatarManager);
+	INJEQT_SET void setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager);
+	INJEQT_INIT void init();
+
 	void buttonClicked();
 
-public:
-	explicit BuddyAvatarWidget(Buddy buddy, QWidget *parent = 0);
-
-	const QPixmap avatarPixmap();
-	bool buddyAvatar() const { return BuddyAvatar; }
-
 };
-
-#endif // BUDDY_AVATAR_WIDGET_H
