@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,14 +20,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QEvent>
-#include <QtGui/QComboBox>
+#include "buddy-contacts-table-delegate.h"
 
 #include "accounts/account.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/accounts-combo-box.h"
 #include "model/roles.h"
 
-#include "buddy-contacts-table-delegate.h"
+#include <QtCore/QEvent>
+#include <QtWidgets/QComboBox>
 
 BuddyContactsTableDelegate::BuddyContactsTableDelegate(QObject *parent) :
 		QStyledItemDelegate(parent)
@@ -40,14 +39,18 @@ BuddyContactsTableDelegate::~BuddyContactsTableDelegate()
 {
 }
 
+void BuddyContactsTableDelegate::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 QWidget * BuddyContactsTableDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
 	if (1 != index.column()) // not account
 		return QStyledItemDelegate::createEditor(parent, option, index);
 
-	AccountsComboBox *accountsComboBox = new AccountsComboBox(index.data(AccountRole).value<Account>().isNull(),
-	                                                          AccountsComboBox::NotVisibleWithOneRowSourceModel,
-	                                                          parent);
+	AccountsComboBox *accountsComboBox = m_injectedFactory->makeInjected<AccountsComboBox>(
+		index.data(AccountRole).value<Account>().isNull(), AccountsComboBox::NotVisibleWithOneRowSourceModel, parent);
 	// this connect does not work withour Account
 	connect(accountsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 
