@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +21,7 @@
 #ifndef BUDDY_CONTACTS_TABLE_MODEL_PROXY_H
 #define BUDDY_CONTACTS_TABLE_MODEL_PROXY_H
 
-#include <QtGui/QSortFilterProxyModel>
+#include <QtCore/QSortFilterProxyModel>
 
 class BuddyContactsTableModelProxy : public QSortFilterProxyModel
 {
@@ -36,7 +32,7 @@ protected:
 	virtual bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
 
 public:
-	explicit BuddyContactsTableModelProxy(QObject *parent = 0);
+	explicit BuddyContactsTableModelProxy(QObject *parent = nullptr);
 	virtual ~BuddyContactsTableModelProxy();
 
 };
