@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,35 +20,61 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QColor>
-#include <QtGui/QIcon>
+#include "buddy-contacts-table-model.h"
 
 #include "buddies/buddy-manager.h"
 #include "contacts/contact-manager.h"
 #include "gui/widgets/buddy-contacts-table-item.h"
 #include "gui/widgets/simple-configuration-value-state-notifier.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity.h"
 #include "model/roles.h"
 #include "protocols/protocol.h"
-#include "protocols/roster.h"
-#include "protocols/services/roster/roster-entry.h"
 #include "protocols/services/subscription-service.h"
+#include "roster/roster-entry-state.h"
+#include "roster/roster-entry.h"
+#include "roster/roster.h"
 
-#include "buddy-contacts-table-model.h"
+#include <QtGui/QColor>
+#include <QtGui/QIcon>
 
 BuddyContactsTableModel::BuddyContactsTableModel(Buddy buddy, QObject *parent) :
 		QAbstractTableModel(parent), ModelBuddy(buddy),
 		StateNotifier(new SimpleConfigurationValueStateNotifier(this)), CurrentMaxPriority(-1)
 {
-	contactsFromBuddy();
-	updateStateNotifier();
 }
 
 BuddyContactsTableModel::~BuddyContactsTableModel()
 {
 }
 
+void BuddyContactsTableModel::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyContactsTableModel::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void BuddyContactsTableModel::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void BuddyContactsTableModel::setRoster(Roster *roster)
+{
+	m_roster = roster;
+}
+
+void BuddyContactsTableModel::init()
+{
+	contactsFromBuddy();
+	updateStateNotifier();
+}
+
 const ConfigurationValueStateNotifier * BuddyContactsTableModel::valueStateNotifier() const
 {
 	return StateNotifier;
@@ -104,7 +130,7 @@ void BuddyContactsTableModel::contactsFromBuddy()
 
 	if (!ModelBuddy.contacts().isEmpty())
 		foreach (const Contact &contact, ModelBuddy.contacts())
-			addItem(new BuddyContactsTableItem(contact, this), false);
+			addItem(new BuddyContactsTableItem(m_contactManager, contact, this), false);
 
 	endResetModel();
 }
@@ -150,38 +176,40 @@ void BuddyContactsTableModel::performItemActionEdit(BuddyContactsTableItem *item
 
 	if (contact.contactAccount() == item->itemAccount() && contact.id() == item->id())
 	{
-		// TODO fix this issue
-		// when user marks detached contact as non-detached we set it as Synchronized
-		// so next data from roster overrides our changes
-		// this is not perfect solution but i'm unable to figure out a perfect one now
-		if (!item->rosterDetached() && contact.rosterEntry()->detached())
-			contact.rosterEntry()->setState(RosterEntrySynchronized);
-
-		contact.rosterEntry()->setDetached(item->rosterDetached());
+		if (item->rosterDetached())
+			contact.rosterEntry()->setDetached();
+		else
+			contact.rosterEntry()->setSynchronized(); // set as synchronized so next remote update fixes our data
 		return;
 	}
 
 	// First we need to remove existing contact from the manager to avoid duplicates.
-	Contact existingContact = ContactManager::instance()->byId(item->itemAccount(), item->id(), ActionReturnNull);
+	Contact existingContact = m_contactManager->byId(item->itemAccount(), item->id(), ActionReturnNull);
 	if (existingContact)
-		ContactManager::instance()->removeItem(existingContact);
+		m_contactManager->removeItem(existingContact);
 
-	Roster::instance()->removeContact(contact);
+	m_roster->removeContact(contact);
 	contact.setContactAccount(item->itemAccount());
 	contact.setId(item->id());
-	contact.rosterEntry()->setDetached(item->rosterDetached());
-	Roster::instance()->addContact(contact);
+	if (item->rosterDetached())
+		contact.rosterEntry()->setDetached();
+	else
+		contact.rosterEntry()->setSynchronized();
+	m_roster->addContact(contact);
 	sendAuthorization(contact);
 }
 
 void BuddyContactsTableModel::performItemActionAdd(BuddyContactsTableItem *item)
 {
-	Contact contact = ContactManager::instance()->byId(item->itemAccount(), item->id(), ActionCreateAndAdd);
+	Contact contact = m_contactManager->byId(item->itemAccount(), item->id(), ActionCreateAndAdd);
 	contact.setOwnerBuddy(ModelBuddy);
 	contact.setPriority(item->itemContactPriority());
-	contact.rosterEntry()->setDetached(item->rosterDetached());
+	if (item->rosterDetached())
+		contact.rosterEntry()->setDetached();
+	else
+		contact.rosterEntry()->setSynchronized();
 
-	Roster::instance()->addContact(contact);
+	m_roster->addContact(contact);
 	sendAuthorization(contact);
 }
 
@@ -195,7 +223,7 @@ void BuddyContactsTableModel::performItemActionDetach(BuddyContactsTableItem *it
 	if (display.isEmpty())
 		return;
 
-	Buddy newBuddy = BuddyManager::instance()->byDisplay(display, ActionCreateAndAdd);
+	Buddy newBuddy = m_buddyManager->byDisplay(display, ActionCreateAndAdd);
 	newBuddy.setAnonymous(false);
 	contact.setOwnerBuddy(newBuddy);
 }
@@ -219,7 +247,7 @@ void BuddyContactsTableModel::performItemActionRemove(BuddyContactsTableItem *it
 	Contact contact = item->itemContact();
 	contact.setOwnerBuddy(Buddy::null);
 
-	Roster::instance()->removeContact(contact);
+	m_roster->removeContact(contact);
 }
 
 void BuddyContactsTableModel::addItem(BuddyContactsTableItem *item, bool emitRowsInserted)
@@ -272,7 +300,7 @@ bool BuddyContactsTableModel::insertRows(int row, int count, const QModelIndex &
 	{
 		CurrentMaxPriority++;
 
-		BuddyContactsTableItem *item = new BuddyContactsTableItem(Contact::null, this);
+		BuddyContactsTableItem *item = new BuddyContactsTableItem(m_contactManager, Contact::null, this);
 		item->setAction(BuddyContactsTableItem::ItemAdd);
 		item->setItemContactPriority(CurrentMaxPriority);
 		item->setRosterDetached(false);
@@ -310,7 +338,7 @@ Qt::ItemFlags BuddyContactsTableModel::flags(const QModelIndex &index) const
 		if ("gadu" == item->itemAccount().protocolName())
 			return QAbstractItemModel::flags(index);
 		else
-			return QAbstractItemModel::flags(index) | Qt::ItemIsEditable;
+			return (QAbstractItemModel::flags(index) | Qt::ItemIsSelectable | Qt::ItemIsUserCheckable) & ~Qt::ItemIsEditable;
 	}
 
 	return QAbstractItemModel::flags(index) | Qt::ItemIsEditable;
@@ -369,7 +397,7 @@ QVariant BuddyContactsTableModel::data(const QModelIndex &index, int role) const
 					return item->itemAccount().accountIdentity().name();
 				case Qt::DecorationRole:
 					return item->itemAccount().protocolHandler()
-							? item->itemAccount().protocolHandler()->icon().icon()
+							? m_iconsManager->iconByPath(item->itemAccount().protocolHandler()->icon())
 							: QIcon();
 				case AccountRole:
 					return QVariant::fromValue<Account>(item->itemAccount());
@@ -382,12 +410,11 @@ QVariant BuddyContactsTableModel::data(const QModelIndex &index, int role) const
 		{
 			switch (role)
 			{
-				case Qt::DisplayRole:
-				case Qt::EditRole:
+				case Qt::CheckStateRole:
 					if ("gadu" == item->itemAccount().protocolName())
-						return true;
+						return QVariant(Qt::Checked);
 					else
-						return !item->rosterDetached();
+						return item->rosterDetached() ? QVariant(Qt::Unchecked) : QVariant(Qt::Checked);
 			}
 
 			return QVariant();
@@ -416,8 +443,8 @@ bool BuddyContactsTableModel::setData(const QModelIndex &index, const QVariant &
 			break;
 
 		case 2:
-			if (Qt::EditRole == role && "gadu" != item->itemAccount().protocolName())
-				item->setRosterDetached(!value.toBool());
+			if (Qt::CheckStateRole == role && "gadu" != item->itemAccount().protocolName())
+				item->setRosterDetached(value.toInt() != Qt::Checked);
 			break;
 	}
 
