@@ -1,12 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,18 +21,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QHeaderView>
-#include <QtGui/QInputDialog>
-#include <QtGui/QPushButton>
-#include <QtGui/QTableView>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QHeaderView>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTableView>
 
-#include "gui/model/checkbox-styled-item-delegate.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/buddy-contacts-table-delegate.h"
 #include "gui/widgets/buddy-contacts-table-item.h"
 #include "gui/widgets/buddy-contacts-table-model-proxy.h"
 #include "gui/widgets/buddy-contacts-table-model.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "identities/identity.h"
 #include "model/roles.h"
 
@@ -43,18 +42,32 @@
 BuddyContactsTable::BuddyContactsTable(Buddy buddy, QWidget *parent) :
 		QWidget(parent), MyBuddy(buddy)
 {
-	Delegate = new BuddyContactsTableDelegate(this);
-	Model = new BuddyContactsTableModel(buddy, this);
-	Proxy = new BuddyContactsTableModelProxy(Model);
-	Proxy->setSourceModel(Model);
-
-	createGui();
 }
 
 BuddyContactsTable::~BuddyContactsTable()
 {
 }
 
+void BuddyContactsTable::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void BuddyContactsTable::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void BuddyContactsTable::init()
+{
+	Delegate = new BuddyContactsTableDelegate(this);
+	Model = m_injectedFactory->makeInjected<BuddyContactsTableModel>(MyBuddy, this);
+	Proxy = new BuddyContactsTableModelProxy(Model);
+	Proxy->setSourceModel(Model);
+
+	createGui();
+}
+
 void BuddyContactsTable::createGui()
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
@@ -72,8 +85,6 @@ void BuddyContactsTable::createGui()
 	View->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
 	View->horizontalHeader()->setStretchLastSection(true);
 
-	View->setItemDelegateForColumn(2, new CheckboxStyledItemDelegate(View));
-
 	connect(View->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
 			this, SLOT(viewSelectionChanged(QModelIndex,QModelIndex)));
 
@@ -213,7 +224,7 @@ void BuddyContactsTable::removeClicked()
 		return;
 	}
 
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Kadu"),
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"),
 			tr("Are you sure do you want to delete this contact from buddy <b>%1</b>?").arg(MyBuddy.display()));
 	dialog->addButton(QMessageBox::Yes, tr("Delete contact"));
 	dialog->addButton(QMessageBox::No, tr("Cancel"));
