@@ -1,15 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,16 +21,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QCheckBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QGridLayout>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QTreeView>
-#include <QtGui/QVBoxLayout>
+#include "buddy-general-configuration-widget.h"
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
@@ -44,6 +30,7 @@
 #include "buddies/buddy-manager.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/buddy-avatar-widget.h"
 #include "gui/widgets/buddy-contacts-table.h"
 #include "gui/widgets/composite-configuration-value-state-notifier.h"
@@ -56,7 +43,16 @@
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
 
-#include "buddy-general-configuration-widget.h"
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTreeView>
+#include <QtWidgets/QVBoxLayout>
 
 BuddyGeneralConfigurationWidget::BuddyGeneralConfigurationWidget(const Buddy &buddy, QWidget *parent) :
 		QWidget(parent),
@@ -64,19 +60,35 @@ BuddyGeneralConfigurationWidget::BuddyGeneralConfigurationWidget(const Buddy &bu
 		SimpleValueStateNotifier(new SimpleConfigurationValueStateNotifier(this)),
 		MyBuddy(buddy)
 {
-	setAttribute(Qt::WA_DeleteOnClose);
-
-	createGui();
-
-	ValueStateNotifier->addConfigurationValueStateNotifier(SimpleValueStateNotifier);
-
-	updateStateNotifier();
 }
 
 BuddyGeneralConfigurationWidget::~BuddyGeneralConfigurationWidget()
 {
 }
 
+void BuddyGeneralConfigurationWidget::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void BuddyGeneralConfigurationWidget::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyGeneralConfigurationWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void BuddyGeneralConfigurationWidget::init()
+{
+	setAttribute(Qt::WA_DeleteOnClose);
+	createGui();
+	ValueStateNotifier->addConfigurationValueStateNotifier(SimpleValueStateNotifier);
+	updateStateNotifier();
+}
+
 void BuddyGeneralConfigurationWidget::createGui()
 {
 	QVBoxLayout *layout = new QVBoxLayout(this);
@@ -103,12 +115,12 @@ void BuddyGeneralConfigurationWidget::createGui()
 		}
 	}
 
-	AvatarWidget = new BuddyAvatarWidget(MyBuddy, nameWidget);
+	AvatarWidget = m_injectedFactory->makeInjected<BuddyAvatarWidget>(MyBuddy, nameWidget);
 	nameLayout->addWidget(AvatarWidget);
 
 	QGroupBox *contactsBox = new QGroupBox(tr("Buddy contacts"), this);
 	QVBoxLayout *contactsLayout = new QVBoxLayout(contactsBox);
-	ContactsTable = new BuddyContactsTable(MyBuddy, contactsBox);
+	ContactsTable = m_injectedFactory->makeInjected<BuddyContactsTable>(MyBuddy, contactsBox);
 	ValueStateNotifier->addConfigurationValueStateNotifier(ContactsTable->valueStateNotifier());
 	contactsLayout->addWidget(ContactsTable);
 
@@ -155,7 +167,7 @@ bool BuddyGeneralConfigurationWidget::isValid() const
 	if (display.isEmpty())
 		return false;
 
-	Buddy buddy = BuddyManager::instance()->byDisplay(display, ActionReturnNull);
+	Buddy buddy = m_buddyManager->byDisplay(display, ActionReturnNull);
 	if (buddy && buddy != MyBuddy)
 		return false;
 
@@ -169,6 +181,8 @@ void BuddyGeneralConfigurationWidget::updateStateNotifier()
 
 void BuddyGeneralConfigurationWidget::save()
 {
+	ContactsTable->save(); // first update contacts
+
 	MyBuddy.setDisplay(DisplayEdit->text());
 	MyBuddy.setHomePhone(PhoneEdit->text());
 	MyBuddy.setMobile(MobileEdit->text());
@@ -181,24 +195,22 @@ void BuddyGeneralConfigurationWidget::save()
 		removeBuddyAvatar();
 	else
 		setBuddyAvatar(avatar);
-
-	ContactsTable->save();
 }
 
 void BuddyGeneralConfigurationWidget::removeBuddyAvatar()
 {
-	Avatar buddyAvatar = MyBuddy.buddyAvatar();
+	auto buddyAvatar = MyBuddy.buddyAvatar();
 	if (buddyAvatar.isNull())
 		return;
 
 	buddyAvatar.setPixmap(QPixmap());
-	AvatarManager::instance()->removeItem(buddyAvatar);
+	m_avatarManager->removeItem(buddyAvatar);
 	MyBuddy.setBuddyAvatar(Avatar::null);
 }
 
 void BuddyGeneralConfigurationWidget::setBuddyAvatar(const QPixmap& avatar)
 {
-	Avatar buddyAvatar = AvatarManager::instance()->byBuddy(MyBuddy, ActionCreateAndAdd);
+	auto buddyAvatar = m_avatarManager->byBuddy(MyBuddy, ActionCreateAndAdd);
 	buddyAvatar.setPixmap(avatar);
 }
 
