@@ -1,15 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,32 +21,48 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_GENERAL_CONFIGURATION_WIDGET_H
-#define BUDDY_GENERAL_CONFIGURATION_WIDGET_H
-
-#include <QtGui/QWidget>
+#pragma once
 
 #include "buddies/buddy.h"
 #include "contacts/contact.h"
 #include "contacts/model/buddy-contact-model.h"
-
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
 class QCheckBox;
 class QLineEdit;
 
+class AvatarManager;
 class BuddyAvatarWidget;
 class BuddyContactsTable;
+class BuddyManager;
 class CompositeConfigurationValueStateNotifier;
 class ConfigurationValueStateNotifier;
 class Contact;
 class ContactManager;
+class InjectedFactory;
 class SimpleConfigurationValueStateNotifier;
 
 class KADUAPI BuddyGeneralConfigurationWidget : public QWidget
 {
 	Q_OBJECT
 
+public:
+	explicit BuddyGeneralConfigurationWidget(const Buddy &buddy, QWidget *parent = nullptr);
+	virtual ~BuddyGeneralConfigurationWidget();
+
+	const ConfigurationValueStateNotifier * valueStateNotifier() const;
+
+	void save();
+
+private:
+	QPointer<AvatarManager> m_avatarManager;
+	QPointer<BuddyManager> m_buddyManager;
+	QPointer<InjectedFactory> m_injectedFactory;
+
 	QLineEdit *DisplayEdit;
 	QLineEdit *PhoneEdit;
 	QLineEdit *MobileEdit;
@@ -75,16 +86,11 @@ class KADUAPI BuddyGeneralConfigurationWidget : public QWidget
 	bool isValid() const;
 
 private slots:
+	INJEQT_SET void setAvatarManager(AvatarManager *avatarManager);
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
 	void updateStateNotifier();
 
-public:
-	explicit BuddyGeneralConfigurationWidget(const Buddy &buddy, QWidget *parent = 0);
-	virtual ~BuddyGeneralConfigurationWidget();
-
-	const ConfigurationValueStateNotifier * valueStateNotifier() const;
-
-	void save();
-
 };
-
-#endif // BUDDY_GENERAL_CONFIGURATION_WIDGET_H
