@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,29 +21,67 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtWebKit/QWebFrame>
+#include <QtWebKitWidgets/QWebFrame>
 
 #include "accounts/account.h"
-#include "avatars/avatar.h"
 #include "avatars/avatar-manager.h"
+#include "avatars/avatar.h"
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
-#include "core/core.h"
 #include "dom/dom-processor-service.h"
+#include "misc/paths-provider.h"
 #include "misc/syntax-list.h"
 #include "parser/parser.h"
+#include "talkable/talkable-converter.h"
 #include "url-handlers/url-handler-manager.h"
-
 #include "debug.h"
 
 #include "buddy-info-panel.h"
 
 BuddyInfoPanel::BuddyInfoPanel(QWidget *parent) : KaduWebView(parent)
 {
-	configurationUpdated();
+}
 
+BuddyInfoPanel::~BuddyInfoPanel()
+{
+	disconnect(m_buddyPreferredManager, 0, this, 0);
+}
+
+void BuddyInfoPanel::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void BuddyInfoPanel::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void BuddyInfoPanel::setDomProcessorService(DomProcessorService *domProcessorService)
+{
+	m_domProcessorService = domProcessorService;
+}
+
+void BuddyInfoPanel::setParser(Parser *parser)
+{
+	m_parser = parser;
+}
+
+void BuddyInfoPanel::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void BuddyInfoPanel::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void BuddyInfoPanel::init()
+{
 	QPalette p = palette();
 	p.setBrush(QPalette::Base, Qt::transparent);
 	page()->setPalette(p);
@@ -54,33 +92,30 @@ BuddyInfoPanel::BuddyInfoPanel(QWidget *parent) : KaduWebView(parent)
 		"XMLHttpRequest.prototype.send = function() { return false; };"
 	);
 
-	connect(BuddyPreferredManager::instance(), SIGNAL(buddyUpdated(Buddy)), this, SLOT(buddyUpdated(Buddy)));
-}
+	connect(m_buddyPreferredManager, SIGNAL(buddyUpdated(Buddy)), this, SLOT(buddyUpdated(Buddy)));
 
-BuddyInfoPanel::~BuddyInfoPanel()
-{
-	disconnect(BuddyPreferredManager::instance(), 0, this, 0);
+	configurationUpdated();
 }
 
 void BuddyInfoPanel::configurationUpdated()
 {
-	setUserFont(config_file.readFontEntry("Look", "PanelFont").toString(), true);
+	setUserFont(configuration()->deprecatedApi()->readFontEntry("Look", "PanelFont").toString(), true);
 
 	update();
 }
 
 void BuddyInfoPanel::buddyUpdated(const Buddy &buddy)
 {
-	if (buddy == Item.toBuddy())
+	if (buddy == m_talkableConverter->toBuddy(Item))
 		update();
 }
 
 void BuddyInfoPanel::update()
 {
-	if (Core::instance()->isClosing())
+	if (!configuration())
 		return;
 
-	QFont font = config_file.readFontEntry("Look", "PanelFont");
+	QFont font = configuration()->deprecatedApi()->readFontEntry("Look", "PanelFont");
 	QString fontFamily = font.family();
 	QString fontSize;
 	if (font.pointSize() > 0)
@@ -91,10 +126,10 @@ void BuddyInfoPanel::update()
 	QString fontStyle = font.italic() ? "italic" : "normal";
 	QString fontWeight = font.bold() ? "bold" : "normal";
 	QString textDecoration = font.underline() ? "underline" : "none";
-	QString fontColor = config_file.readColorEntry("Look", "InfoPanelFgColor").name();
-	bool backgroundFilled = config_file.readBoolEntry("Look", "InfoPanelBgFilled");
+	QString fontColor = configuration()->deprecatedApi()->readColorEntry("Look", "InfoPanelFgColor").name();
+	bool backgroundFilled = configuration()->deprecatedApi()->readBoolEntry("Look", "InfoPanelBgFilled");
 	if (backgroundFilled)
-		BackgroundColor = config_file.readColorEntry("Look", "InfoPanelBgColor").name();
+		BackgroundColor = configuration()->deprecatedApi()->readColorEntry("Look", "InfoPanelBgColor").name();
 	else
 		BackgroundColor = "transparent";
 
@@ -131,19 +166,20 @@ void BuddyInfoPanel::update()
 		"</html>"
 		).arg(fontColor, fontStyle, fontWeight, fontSize, fontFamily, textDecoration, BackgroundColor, "%1");
 
-	QString syntaxFile = config_file.readEntry("Look", "InfoPanelSyntaxFile", "ultr");
+	QString syntaxFile = configuration()->deprecatedApi()->readEntry("Look", "InfoPanelSyntaxFile", "ultr");
 	if (syntaxFile == "default")
 	{
 		syntaxFile = "Old Default";
-		config_file.writeEntry("Look", "InfoPanelSyntaxFile", syntaxFile);
+		configuration()->deprecatedApi()->writeEntry("Look", "InfoPanelSyntaxFile", syntaxFile);
 	}
 
-	Syntax = SyntaxList::readSyntax("infopanel", syntaxFile,
-		"<table><tr><td><img width=\"32\" height=\"32\" align=\"left\" valign=\"top\" src=\"file:///@{x-office-address-book:32x32}\"></td><td> "
+	Syntax = SyntaxList::readSyntax(m_pathsProvider, "infopanel", syntaxFile,
+		"<table><tr><td><img width=\"32\" height=\"32\" align=\"left\" valign=\"top\" src=\"@{x-office-address-book:32x32}\"></td><td> "
 		"<div align=\"left\"> [<b>%a</b>][ (%u)] [<br>tel.: %m][<br>IP: %i]</div></td></tr></table> <hr> <b>%s</b> [<br>%d]");
+	Syntax = Syntax.remove("file:///");
 	displayItem(Item);
 
-	if (config_file.readBoolEntry("Look", "PanelVerticalScrollbar"))
+	if (configuration()->deprecatedApi()->readBoolEntry("Look", "PanelVerticalScrollbar"))
 		page()->mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAsNeeded);
 	else
 		page()->mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
@@ -151,7 +187,7 @@ void BuddyInfoPanel::update()
 
 void BuddyInfoPanel::connectItem()
 {
-	Buddy buddy = Item.toBuddy();
+	Buddy buddy = m_talkableConverter->toBuddy(Item);
 	if (buddy)
 	{
 		connect(buddy, SIGNAL(updated()), this, SLOT(update()));
@@ -159,11 +195,11 @@ void BuddyInfoPanel::connectItem()
 			connect(buddy.buddyAvatar(), SIGNAL(updated()), this, SLOT(update()));
 	}
 
-	Contact contact = Item.toContact();
+	Contact contact = m_talkableConverter->toContact(Item);
 	if (contact)
 	{
 		connect(contact, SIGNAL(updated()), this, SLOT(update()));
-		auto avatar = AvatarManager::instance()->byContact(contact, ActionReturnNull);
+		auto avatar = m_avatarManager->byContact(contact, ActionReturnNull);
 		if (avatar)
 			connect(avatar, SIGNAL(updated()), this, SLOT(update()));
 	}
@@ -171,7 +207,7 @@ void BuddyInfoPanel::connectItem()
 
 void BuddyInfoPanel::disconnectItem()
 {
-	Buddy buddy = Item.toBuddy();
+	Buddy buddy = m_talkableConverter->toBuddy(Item);
 	if (buddy)
 	{
 		disconnect(buddy, 0, this, 0);
@@ -179,11 +215,11 @@ void BuddyInfoPanel::disconnectItem()
 			disconnect(buddy.buddyAvatar(), 0, this, 0);
 	}
 
-	Contact contact = Item.toContact();
+	Contact contact = m_talkableConverter->toContact(Item);
 	if (contact)
 	{
 		disconnect(contact, 0, this, 0);
-		auto avatar = AvatarManager::instance()->byContact(contact, ActionReturnNull);
+		auto avatar = m_avatarManager->byContact(contact, ActionReturnNull);
 		if (avatar)
 			disconnect(avatar, 0, this, 0);
 	}
@@ -204,12 +240,7 @@ void BuddyInfoPanel::displayItem(Talkable item)
 		return;
 	}
 
-	QDomDocument domDocument;
-	domDocument.setContent(Template.arg(Parser::parse(Syntax, item, ParserEscape::HtmlEscape)));
-
-	Core::instance()->domProcessorService()->process(domDocument);
-
-	setHtml(domDocument.toString(0));
+	setHtml(m_domProcessorService->process(Template.arg(m_parser->parse(Syntax, item, ParserEscape::HtmlEscape))));
 }
 
 void BuddyInfoPanel::setVisible(bool visible)
