@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,19 +19,34 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_INFO_PANEL_H
-#define BUDDY_INFO_PANEL_H
+#pragma once
+
+#include "kadu-web-view.h"
 
 #include "configuration/configuration-aware-object.h"
 #include "contacts/contact.h"
 #include "talkable/talkable.h"
 
-#include "kadu-web-view.h"
+#include <injeqt/injeqt.h>
+
+class AvatarManager;
+class BuddyPreferredManager;
+class DomProcessorService;
+class Parser;
+class PathsProvider;
+class TalkableConverter;
 
 class BuddyInfoPanel : public KaduWebView, private ConfigurationAwareObject
 {
 	Q_OBJECT
 
+	QPointer<AvatarManager> m_avatarManager;
+	QPointer<BuddyPreferredManager> m_buddyPreferredManager;
+	QPointer<DomProcessorService> m_domProcessorService;
+	QPointer<Parser> m_parser;
+	QPointer<PathsProvider> m_pathsProvider;
+	QPointer<TalkableConverter> m_talkableConverter;
+
 	Talkable Item;
 	QString Template;
 	QString Syntax;
@@ -41,13 +56,21 @@ class BuddyInfoPanel : public KaduWebView, private ConfigurationAwareObject
 	void disconnectItem();
 
 private slots:
+	INJEQT_SET void setAvatarManager(AvatarManager *avatarManager);
+	INJEQT_SET void setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager);
+	INJEQT_SET void setDomProcessorService(DomProcessorService *domProcessorService);
+	INJEQT_SET void setParser(Parser *parser);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+	INJEQT_SET void setTalkableConverter(TalkableConverter *talkableConverter);
+	INJEQT_INIT void init();
+
 	void buddyUpdated(const Buddy &buddy);
 
 protected:
 	virtual void configurationUpdated();
 
 public:
-	explicit BuddyInfoPanel(QWidget *parent = 0);
+	explicit BuddyInfoPanel(QWidget *parent = nullptr);
 	virtual ~BuddyInfoPanel();
 
 	virtual void setVisible(bool visible);
@@ -58,5 +81,3 @@ public slots:
 	void styleFixup(QString &syntax);
 
 };
-
-#endif // BUDDY_INFO_PANEL_H
