@@ -21,7 +21,7 @@
 #ifndef KCATEGORIZEDVIEW_H
 #define KCATEGORIZEDVIEW_H
 
-#include <QtGui/QListView>
+#include <QtWidgets/QListView>
 
 class CategorizedListViewPrivate;
 
@@ -91,7 +91,7 @@ class CategorizedListView
         Q_PROPERTY(bool collapsibleBlocks READ collapsibleBlocks WRITE setCollapsibleBlocks)
 
 public:
-        CategorizedListView(QWidget *parent = 0);
+        CategorizedListView(QWidget *parent = nullptr);
 
         ~CategorizedListView();
 
@@ -304,10 +304,8 @@ protected:
           * Reimplemented from QAbstractItemView.
           */
         virtual void dataChanged(const QModelIndex &topLeft,
-                                 const QModelIndex &bottomRight
-#if QT_VERSION >= 0x050000
-                                 , const QVector<int> &
-#endif
+                                 const QModelIndex &bottomRight,
+                                 const QVector<int> &
                                  );
 
         /**
