@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,33 +18,35 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/configuration-file.h"
-
 #include "chat-edit-box-size-manager.h"
 
-ChatEditBoxSizeManager * ChatEditBoxSizeManager::Instance = 0;
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/core.h"
 
-ChatEditBoxSizeManager * ChatEditBoxSizeManager::instance()
+ChatEditBoxSizeManager::ChatEditBoxSizeManager(QObject *parent) :
+		QObject{parent},
+		CommonHeight{}
 {
-	if (!Instance)
-		Instance = new ChatEditBoxSizeManager();
-
-	return Instance;
-}
-
-ChatEditBoxSizeManager::ChatEditBoxSizeManager() :
-		CommonHeight(0)
-{
-	configurationUpdated();
 }
 
 ChatEditBoxSizeManager::~ChatEditBoxSizeManager()
 {
 }
 
+void ChatEditBoxSizeManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ChatEditBoxSizeManager::init()
+{
+	configurationUpdated();
+}
+
 void ChatEditBoxSizeManager::configurationUpdated()
 {
-	setCommonHeight(config_file.readNumEntry("Chat", "ChatEditBoxHeight", 0));
+	setCommonHeight(m_configuration->deprecatedApi()->readNumEntry("Chat", "ChatEditBoxHeight", 0));
 }
 
 void ChatEditBoxSizeManager::setCommonHeight(int height)
@@ -54,7 +54,7 @@ void ChatEditBoxSizeManager::setCommonHeight(int height)
 	if (height != CommonHeight)
 	{
 		CommonHeight = height;
-		config_file.writeEntry("Chat", "ChatEditBoxHeight", CommonHeight);
+		m_configuration->deprecatedApi()->writeEntry("Chat", "ChatEditBoxHeight", CommonHeight);
 		emit commonHeightChanged(CommonHeight);
 	}
 }
