@@ -1,12 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,31 +17,24 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHAT_EDIT_BOX_SIZE_MANAGER_H
-#define CHAT_EDIT_BOX_SIZE_MANAGER_H
-
-#include <QtCore/QObject>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 #include "exports.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+
 class KADUAPI ChatEditBoxSizeManager : public QObject, ConfigurationAwareObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(ChatEditBoxSizeManager)
-
-	static ChatEditBoxSizeManager *Instance;
-
-	int CommonHeight;
-
-	ChatEditBoxSizeManager();
-	virtual ~ChatEditBoxSizeManager();
-
-protected:
-	virtual void configurationUpdated();
 
 public:
-	static ChatEditBoxSizeManager * instance();
+	Q_INVOKABLE explicit ChatEditBoxSizeManager(QObject *parent = nullptr);
+	virtual ~ChatEditBoxSizeManager();
 
 	void setCommonHeight(int height);
 	int commonHeight() { return CommonHeight; }
@@ -57,6 +44,16 @@ public:
 signals:
 	void commonHeightChanged(int height);
 
-};
+protected:
+	virtual void configurationUpdated();
 
-#endif // CHAT_EDIT_BOX_SIZE_MANAGER_H
+private:
+	QPointer<Configuration> m_configuration;
+
+	int CommonHeight;
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_INIT void init();
+
+};
