@@ -1,13 +1,13 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2008, 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,36 +24,39 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QFileDialog>
 #include <QtGui/QResizeEvent>
+#include <QtWidgets/QFileDialog>
 #include <QtXml/QDomElement>
 
 
 #include "accounts/account-details.h"
 #include "buddies/buddy-set.h"
 #include "chat/chat.h"
-#include "configuration/chat-configuration-holder.h"
-#include "configuration/configuration-file.h"
-#include "configuration/main-configuration-holder.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-set.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/actions/action.h"
 #include "gui/actions/base-action-context.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "gui/widgets/chat-edit-box-size-manager.h"
-#include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/chat-widget/chat-widget-actions.h"
+#include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/color-selector.h"
 #include "gui/widgets/custom-input.h"
 #include "gui/widgets/talkable-tree-view.h"
 #include "gui/widgets/toolbar.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "identities/identity.h"
 #include "misc/change-notifier-lock.h"
 #include "misc/error.h"
 #include "protocols/protocol.h"
 #include "protocols/services/chat-image-service.h"
+#include "status/status-configuration-holder.h"
 #include "status/status-container-manager.h"
 #include "debug.h"
 
@@ -62,7 +65,44 @@
 QList<ChatEditBox *> chatEditBoxes;
 
 ChatEditBox::ChatEditBox(const Chat &chat, QWidget *parent) :
-		MainWindow(new BaseActionContext(), "chat", parent), CurrentChat(chat)
+		MainWindow(new BaseActionContext(this), "chat", parent), CurrentChat(chat)
+{
+}
+
+ChatEditBox::~ChatEditBox()
+{
+// 	disconnect(m_chatWidgetActions->colorSelector(), 0, this, 0);
+	disconnect(InputBox, 0, this, 0);
+
+	chatEditBoxes.removeAll(this);
+}
+
+void ChatEditBox::setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder)
+{
+	m_chatConfigurationHolder = chatConfigurationHolder;
+}
+
+void ChatEditBox::setChatWidgetActions(ChatWidgetActions *chatWidgetActions)
+{
+	m_chatWidgetActions = chatWidgetActions;
+}
+
+void ChatEditBox::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void ChatEditBox::setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder)
+{
+	m_statusConfigurationHolder = statusConfigurationHolder;
+}
+
+void ChatEditBox::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void ChatEditBox::init()
 {
 	chatEditBoxes.append(this);
 
@@ -82,12 +122,9 @@ ChatEditBox::ChatEditBox(const Chat &chat, QWidget *parent) :
 	Context->setBuddies(CurrentChat.contacts().toBuddySet());
 	updateContext();
 
-	connect(MainConfigurationHolder::instance(), SIGNAL(setStatusModeChanged()), this, SLOT(updateContext()));
-
-	InputBox = new CustomInput(CurrentChat, this);
-	InputBox->setImageStorageService(Core::instance()->imageStorageService());
-	InputBox->setFormattedStringFactory(Core::instance()->formattedStringFactory());
+	connect(m_statusConfigurationHolder, SIGNAL(setStatusModeChanged()), this, SLOT(updateContext()));
 
+	InputBox = injectedFactory()->makeInjected<CustomInput>(CurrentChat, this);
 	InputBox->setWordWrapMode(QTextOption::WordWrap);
 
 	setCentralWidget(InputBox);
@@ -103,34 +140,26 @@ ChatEditBox::ChatEditBox(const Chat &chat, QWidget *parent) :
 	else
 		loadToolBarsFromConfig(); // load new config
 
-// 	connect(Core::instance()->chatWidgetActions()->colorSelector(), SIGNAL(actionCreated(Action *)),
+// 	connect(m_chatWidgetActions->colorSelector(), SIGNAL(actionCreated(Action *)),
 // 			this, SLOT(colorSelectorActionCreated(Action *)));
 	connect(InputBox, SIGNAL(keyPressed(QKeyEvent *,CustomInput *, bool &)),
 			this, SIGNAL(keyPressed(QKeyEvent *,CustomInput *,bool &)));
 	connect(InputBox, SIGNAL(fontChanged(QFont)), this, SLOT(fontChanged(QFont)));
 	connect(InputBox, SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
 
-	connect(ChatConfigurationHolder::instance(), SIGNAL(chatConfigurationUpdated()), this, SLOT(configurationUpdated()));
+	connect(m_chatConfigurationHolder, SIGNAL(chatConfigurationUpdated()), this, SLOT(configurationUpdated()));
 
 	configurationUpdated();
 }
 
-ChatEditBox::~ChatEditBox()
-{
-// 	disconnect(Core::instance()->chatWidgetActions()->colorSelector(), 0, this, 0);
-	disconnect(InputBox, 0, this, 0);
-
-	chatEditBoxes.removeAll(this);
-}
-
 void ChatEditBox::fontChanged(QFont font)
 {
-	if (Core::instance()->chatWidgetActions()->bold()->action(actionContext()))
-		Core::instance()->chatWidgetActions()->bold()->action(actionContext())->setChecked(font.bold());
-	if (Core::instance()->chatWidgetActions()->italic()->action(actionContext()))
-		Core::instance()->chatWidgetActions()->italic()->action(actionContext())->setChecked(font.italic());
-	if (Core::instance()->chatWidgetActions()->underline()->action(actionContext()))
-		Core::instance()->chatWidgetActions()->underline()->action(actionContext())->setChecked(font.underline());
+	if (m_chatWidgetActions->bold()->action(actionContext()))
+		m_chatWidgetActions->bold()->action(actionContext())->setChecked(font.bold());
+	if (m_chatWidgetActions->italic()->action(actionContext()))
+		m_chatWidgetActions->italic()->action(actionContext())->setChecked(font.italic());
+	if (m_chatWidgetActions->underline()->action(actionContext()))
+		m_chatWidgetActions->underline()->action(actionContext())->setChecked(font.underline());
 }
 
 void ChatEditBox::colorSelectorActionCreated(Action *action)
@@ -148,7 +177,7 @@ void ChatEditBox::configurationUpdated()
 {
 	setColorFromCurrentText(true);
 
-	InputBox->setAutoSend(ChatConfigurationHolder::instance()->autoSend());
+	InputBox->setAutoSend(m_chatConfigurationHolder->autoSend());
 }
 
 void ChatEditBox::setAutoSend(bool autoSend)
@@ -177,12 +206,12 @@ TalkableProxyModel * ChatEditBox::talkableProxyModel()
 
 void ChatEditBox::updateContext()
 {
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
-		Context->setStatusContainer(CurrentChat.chatAccount().accountIdentity().data());
-	else if (MainConfigurationHolder::instance()->isSetStatusPerAccount())
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity())
+		Context->setStatusContainer(CurrentChat.chatAccount().accountIdentity().statusContainer());
+	else if (m_statusConfigurationHolder->isSetStatusPerAccount())
 		Context->setStatusContainer(CurrentChat.chatAccount().statusContainer());
 	else
-		Context->setStatusContainer(StatusContainerManager::instance());
+		Context->setStatusContainer(m_statusContainerManager);
 }
 
 ChatWidget * ChatEditBox::chatWidget()
@@ -198,20 +227,20 @@ ChatWidget * ChatEditBox::chatWidget()
 	return 0;
 }
 
-void ChatEditBox::createDefaultToolbars(QDomElement toolbarsConfig)
+void ChatEditBox::createDefaultToolbars(Configuration *configuration, QDomElement toolbarsConfig)
 {
-	QDomElement dockAreaConfig = getDockAreaConfigElement(toolbarsConfig, "chat_topDockArea");
-	QDomElement toolbarConfig = xml_config_file->createElement(dockAreaConfig, "ToolBar");
+	QDomElement dockAreaConfig = getDockAreaConfigElement(configuration, toolbarsConfig, "chat_topDockArea");
+	QDomElement toolbarConfig = configuration->api()->createElement(dockAreaConfig, "ToolBar");
 
-	addToolButton(toolbarConfig, "autoSendAction");
-	addToolButton(toolbarConfig, "clearChatAction");
-	addToolButton(toolbarConfig, "insertEmoticonAction", Qt::ToolButtonTextBesideIcon);
-	addToolButton(toolbarConfig, "insertImageAction");
-	addToolButton(toolbarConfig, "showHistoryAction");
-	addToolButton(toolbarConfig, "encryptionAction");
-	addToolButton(toolbarConfig, "editUserAction");
-	addToolButton(toolbarConfig, "__spacer1", Qt::ToolButtonTextBesideIcon);
-	addToolButton(toolbarConfig, "sendAction", Qt::ToolButtonTextBesideIcon);
+	addToolButton(configuration, toolbarConfig, "autoSendAction");
+	addToolButton(configuration, toolbarConfig, "clearChatAction");
+	addToolButton(configuration, toolbarConfig, "insertEmoticonAction", Qt::ToolButtonTextBesideIcon);
+	addToolButton(configuration, toolbarConfig, "insertImageAction");
+	addToolButton(configuration, toolbarConfig, "showHistoryAction");
+	addToolButton(configuration, toolbarConfig, "encryptionAction");
+	addToolButton(configuration, toolbarConfig, "editUserAction");
+	addToolButton(configuration, toolbarConfig, "__spacer1", Qt::ToolButtonTextBesideIcon);
+	addToolButton(configuration, toolbarConfig, "sendAction", Qt::ToolButtonTextBesideIcon);
 }
 
 void ChatEditBox::openColorSelector(const QWidget *activatingWidget)
@@ -229,24 +258,24 @@ void ChatEditBox::openInsertImageDialog()
 		return;
 
 	// QTBUG-849
-	QString selectedFile = QFileDialog::getOpenFileName(this, tr("Insert image"), config_file.readEntry("Chat", "LastImagePath"),
+	QString selectedFile = QFileDialog::getOpenFileName(this, tr("Insert image"), configuration()->deprecatedApi()->readEntry("Chat", "LastImagePath"),
 							tr("Images (*.png *.PNG *.jpg *.JPG *.jpeg *.JPEG *.gif *.GIF *.bmp *.BMP);;All Files (*)"));
 	if (!selectedFile.isEmpty())
 	{
 		QFileInfo f(selectedFile);
 
-		config_file.writeEntry("Chat", "LastImagePath", f.absolutePath());
+		configuration()->deprecatedApi()->writeEntry("Chat", "LastImagePath", f.absolutePath());
 
 		if (!f.isReadable())
 		{
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("This file is not readable"), QMessageBox::Ok, this);
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("This file is not readable"), QMessageBox::Ok, this);
 			return;
 		}
 
 		Error imageSizeError = chatImageService->checkImageSize(f.size());
 		if (!imageSizeError.message().isEmpty())
 		{
-			MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Kadu"), imageSizeError.message(), this);
+			MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), imageSizeError.message(), this);
 			dialog->addButton(QMessageBox::Yes, tr("Send anyway"));
 			dialog->addButton(QMessageBox::No, tr("Cancel"));
 
@@ -259,7 +288,7 @@ void ChatEditBox::openInsertImageDialog()
 						return;
 					break;
 				case ErrorHigh:
-					MessageDialog::show(KaduIcon("dialog-error"), tr("Kadu"), imageSizeError.message(), QMessageBox::Ok, this);
+					MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-error")), tr("Kadu"), imageSizeError.message(), QMessageBox::Ok, this);
 					return;
 				default:
 					break;
@@ -298,7 +327,7 @@ void ChatEditBox::openInsertImageDialog()
 		if (tooBigCounter > 0 || disconnectedCounter > 0)
 			message += tr("Do you really want to send this image?");
 
-		MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-question"), tr("Kadu"), message, this);
+		MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-question")), tr("Kadu"), message, this);
 		dialog->addButton(QMessageBox::Yes, tr("Send anyway"));
 		dialog->addButton(QMessageBox::No, tr("Cancel"));
 
@@ -316,7 +345,7 @@ void ChatEditBox::changeColor(const QColor &newColor)
 	QPixmap p(12, 12);
 	p.fill(CurrentColor);
 
-// 	Action *action = Core::instance()->chatWidgetActions()->colorSelector()->action(this);
+// 	Action *action = m_chatWidgetActions->colorSelector()->action(this);
 // 	if (action)
 // 		action->setIcon(p);
 
@@ -328,7 +357,7 @@ void ChatEditBox::setColorFromCurrentText(bool force)
 	Q_UNUSED(force);
 
 /*
-	Action *action = Core::instance()->chatWidgetActions()->colorSelector()->action(this);
+	Action *action = m_chatWidgetActions->colorSelector()->action(this);
 	if (!action || (!force && (InputBox->textColor() == CurrentColor)))
 		return;
 
