@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +22,9 @@
 #include "chat-edit-widget.h"
 
 ChatEditWidget::ChatEditWidget(Chat chat, QWidget *parent) :
-		ModalConfigurationWidget(parent), StateNotifier{new SimpleConfigurationValueStateNotifier{this}}, MyChat(chat)
+		ModalConfigurationWidget{parent},
+		m_stateNotifier{make_owned<SimpleConfigurationValueStateNotifier>(this)},
+		m_chat{chat}
 {
 }
 
@@ -33,17 +32,17 @@ ChatEditWidget::~ChatEditWidget()
 {
 }
 
-Chat ChatEditWidget::chat()
+Chat ChatEditWidget::chat() const
 {
-	return MyChat;
+	return m_chat;
 }
 
 SimpleConfigurationValueStateNotifier * ChatEditWidget::simpleStateNotifier() const
 {
-	return StateNotifier;
+	return m_stateNotifier.get();
 }
 
 const ConfigurationValueStateNotifier * ChatEditWidget::stateNotifier() const
 {
-	return StateNotifier;
+	return m_stateNotifier.get();
 }
