@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,35 +18,58 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QFormLayout>
-#include <QtGui/QLineEdit>
+#include "chat-room-edit-widget.h"
 
 #include "accounts/filter/protocol-filter.h"
 #include "chat/chat-details-room.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-room.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/accounts-combo-box.h"
 #include "gui/widgets/simple-configuration-value-state-notifier.h"
 
-#include "chat-room-edit-widget.h"
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLineEdit>
 
 ChatRoomEditWidget::ChatRoomEditWidget(const Chat &chat, QWidget *parent) :
 		ChatEditWidget(chat, parent)
 {
-	RoomDetails = qobject_cast<ChatDetailsRoom *>(chat.details());
-
-	createGui();
-	loadChatData();
 }
 
 ChatRoomEditWidget::~ChatRoomEditWidget()
 {
 }
 
+void ChatRoomEditWidget::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void ChatRoomEditWidget::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void ChatRoomEditWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ChatRoomEditWidget::init()
+{
+	RoomDetails = qobject_cast<ChatDetailsRoom *>(chat().details());
+
+	createGui();
+	loadChatData();
+}
+
 void ChatRoomEditWidget::createGui()
 {
 	QFormLayout *layout = new QFormLayout(this);
 
-	AccountCombo = new AccountsComboBox(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
+	AccountCombo = m_injectedFactory->makeInjected<AccountsComboBox>(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
 	AccountCombo->setIncludeIdInDisplay(true);
 
 	// only xmpp rooms for now
@@ -76,6 +96,11 @@ void ChatRoomEditWidget::createGui()
 	connect(PasswordEdit, SIGNAL(textChanged(QString)), this, SLOT(dataChanged()));
 
 	layout->addRow(tr("Password:"), PasswordEdit);
+
+	StayInRoomAfterClosingWindowCheckBox = new QCheckBox{tr("Stay in chat room after closing chat window"), this};
+	connect(StayInRoomAfterClosingWindowCheckBox, SIGNAL(toggled(bool)), this, SLOT(dataChanged()));
+
+	layout->addRow(StayInRoomAfterClosingWindowCheckBox);
 }
 
 void ChatRoomEditWidget::dataChanged()
@@ -86,7 +111,8 @@ void ChatRoomEditWidget::dataChanged()
 	if (AccountCombo->currentAccount() == chat().chatAccount()
 			&& RoomEdit->text() == RoomDetails->room()
 			&& NickEdit->text() == RoomDetails->nick()
-			&& PasswordEdit->text() == RoomDetails->password())
+			&& PasswordEdit->text() == RoomDetails->password()
+			&& StayInRoomAfterClosingWindowCheckBox->isChecked() == RoomDetails->stayInRoomAfterClosingWindow())
 	{
 		simpleStateNotifier()->setState(StateNotChanged);
 		return;
@@ -98,7 +124,7 @@ void ChatRoomEditWidget::dataChanged()
 		return;
 	}
 
-	Chat sameChat = ChatTypeRoom::findChat(AccountCombo->currentAccount(), RoomEdit->text(), ActionReturnNull);
+	Chat sameChat = ChatTypeRoom::findChat(m_chatManager, m_chatStorage, AccountCombo->currentAccount(), RoomEdit->text(), ActionReturnNull);
 	if (sameChat && (sameChat != chat()))
 	{
 		simpleStateNotifier()->setState(StateChangedDataInvalid);
@@ -117,6 +143,7 @@ void ChatRoomEditWidget::loadChatData()
 	RoomEdit->setText(RoomDetails->room());
 	NickEdit->setText(RoomDetails->nick());
 	PasswordEdit->setText(RoomDetails->password());
+	StayInRoomAfterClosingWindowCheckBox->setChecked(RoomDetails->stayInRoomAfterClosingWindow());
 }
 
 void ChatRoomEditWidget::apply()
@@ -128,6 +155,7 @@ void ChatRoomEditWidget::apply()
 	RoomDetails->setRoom(RoomEdit->text());
 	RoomDetails->setNick(NickEdit->text());
 	RoomDetails->setPassword(PasswordEdit->text());
+	RoomDetails->setStayInRoomAfterClosingWindow(StayInRoomAfterClosingWindowCheckBox->isChecked());
 
 	simpleStateNotifier()->setState(StateNotChanged);
 }
