@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,15 +20,21 @@
 #include "chat-style-preview.h"
 
 #include "buddies/buddy-preferred-manager.h"
-#include "chat/chat-details-contact.h"
+#include "buddies/buddy-storage.h"
 #include "chat-style/engine/chat-style-renderer-factory-provider.h"
-#include "configuration/chat-configuration-holder.h"
-#include "core/core.h"
-#include "formatted-string/formatted-string-factory.h"
-#include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
+#include "chat/chat-details-contact.h"
+#include "chat/chat-storage.h"
+#include "contacts/contact-storage.h"
+#include "core/myself.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "gui/widgets/webkit-messages-view/webkit-messages-view-factory.h"
+#include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "html/normalized-html-string.h"
+#include "message/message-storage.h"
 
-#include <QtGui/QHBoxLayout>
+#include <QtWidgets/QHBoxLayout>
 
 ChatStylePreview::ChatStylePreview(QWidget *parent) :
 		QFrame{parent}
@@ -36,68 +42,109 @@ ChatStylePreview::ChatStylePreview(QWidget *parent) :
 	setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
 	setFixedHeight(250);
 	setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
-
-	auto layout = make_qobject<QHBoxLayout>(this);
-	layout->setContentsMargins(0, 0, 0, 0);
-
-	m_view = preparePreview();
-
-	layout->addWidget(m_view.get());
-
-	configurationUpdated();
 }
 
 ChatStylePreview::~ChatStylePreview()
 {
 }
 
+void ChatStylePreview::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void ChatStylePreview::setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder)
+{
+	m_chatConfigurationHolder = chatConfigurationHolder;
+}
+
+void ChatStylePreview::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void ChatStylePreview::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
+void ChatStylePreview::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void ChatStylePreview::setMessageStorage(MessageStorage *messageStorage)
+{
+	m_messageStorage = messageStorage;
+}
+
+void ChatStylePreview::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void ChatStylePreview::setWebkitMessagesViewFactory(WebkitMessagesViewFactory *webkitMessagesViewFactory)
+{
+	m_webkitMessagesViewFactory = webkitMessagesViewFactory;
+}
+
+void ChatStylePreview::init()
+{
+	auto layout = make_owned<QHBoxLayout>(this);
+	layout->setContentsMargins(0, 0, 0, 0);
+	m_view = preparePreview();
+	layout->addWidget(m_view.get());
+
+	configurationUpdated();
+}
+
 void ChatStylePreview::setRendererFactory(std::unique_ptr<ChatStyleRendererFactory> rendererFactory)
 {
 	m_view.get()->setChatStyleRendererFactory(std::move(rendererFactory));
 }
 
-qobject_ptr<WebkitMessagesView> ChatStylePreview::preparePreview()
+owned_qptr<WebkitMessagesView> ChatStylePreview::preparePreview()
 {
-	auto example = Buddy::dummy();
+	auto example = m_buddyStorage->create();
 
-	auto chat = Chat::create();
+	auto chat = m_chatStorage->create();
 	chat.setType("Contact");
 
 	auto details = static_cast<ChatDetailsContact *>(chat.details());
 	details->setState(StorableObject::StateNew);
-	details->setContact(BuddyPreferredManager::instance()->preferredContact(example));
+	details->setContact(m_buddyPreferredManager->preferredContact(example));
 
-	auto buddy = Buddy::create();
-	buddy.setDisplay(Core::instance()->myself().display());
-	auto contact = Contact::create();
+	auto buddy = m_buddyStorage->create();
+	buddy.setDisplay(m_myself->buddy().display());
+	auto contact = m_contactStorage->create();
 	contact.setId("id@network");
 	contact.setOwnerBuddy(buddy);
 
-	auto sentMessage = Message::create();
+	auto sentMessage = m_messageStorage->create();
 	sentMessage.setMessageChat(chat);
 	sentMessage.setType(MessageTypeSent);
 	sentMessage.setMessageSender(contact);
-	sentMessage.setContent(Core::instance()->formattedStringFactory()->fromPlainText(tr("Your message")));
+	sentMessage.setContent(normalizeHtml(plainToHtml(tr("Your message"))));
 	sentMessage.setReceiveDate(QDateTime::currentDateTime());
 	sentMessage.setSendDate(QDateTime::currentDateTime());
 
-	auto receivedMessage = Message::create();
+	auto receivedMessage = m_messageStorage->create();
 	receivedMessage.setMessageChat(chat);
 	receivedMessage.setType(MessageTypeReceived);
-	receivedMessage.setMessageSender(BuddyPreferredManager::instance()->preferredContact(example));
-	receivedMessage.setContent(Core::instance()->formattedStringFactory()->fromPlainText(tr("Message from Your friend")));
+	receivedMessage.setMessageSender(m_buddyPreferredManager->preferredContact(example));
+	receivedMessage.setContent(normalizeHtml(plainToHtml(tr("Message from Your friend"))));
 	receivedMessage.setReceiveDate(QDateTime::currentDateTime());
 	receivedMessage.setSendDate(QDateTime::currentDateTime());
 
-	auto result = Core::instance()->webkitMessagesViewFactory()->createWebkitMessagesView(chat, false, this);
+	auto result = m_webkitMessagesViewFactory->createWebkitMessagesView(chat, false, this);
 	result->add(sentMessage);
 	result->add(receivedMessage);
-	return std::move(result);
+	return result;
 }
 
 void ChatStylePreview::configurationUpdated()
 {
-	m_view->setUserFont(ChatConfigurationHolder::instance()->chatFont().toString(), ChatConfigurationHolder::instance()->forceCustomChatFont());
+	m_view->setUserFont(m_chatConfigurationHolder->chatFont().toString(), m_chatConfigurationHolder->forceCustomChatFont());
 }
 
 #include "moc_chat-style-preview.cpp"
