@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,35 +18,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QVBoxLayout>
 
 #include "gui/widgets/chat-top-bar-widget-factory-repository.h"
 #include "gui/widgets/chat-top-bar-widget-factory.h"
 
 #include "chat-top-bar-container-widget.h"
 
-ChatTopBarContainerWidget::ChatTopBarContainerWidget(ChatTopBarWidgetFactoryRepository *chatTopBarWidgetFactoryRepository,
-													 const Chat &chat, QWidget *parent) :
-		QWidget(parent), MyChatTopBarWidgetFactoryRepository(chatTopBarWidgetFactoryRepository), MyChat(chat)
+ChatTopBarContainerWidget::ChatTopBarContainerWidget(const Chat &chat, QWidget *parent) :
+		QWidget(parent),MyChat(chat)
 {
-	createGui();
-
-	if (MyChatTopBarWidgetFactoryRepository)
-	{
-		connect(MyChatTopBarWidgetFactoryRepository, SIGNAL(factoryRegistered(ChatTopBarWidgetFactory*)),
-				this, SLOT(factoryRegistered(ChatTopBarWidgetFactory*)));
-		connect(MyChatTopBarWidgetFactoryRepository, SIGNAL(factoryUnregistered(ChatTopBarWidgetFactory*)),
-				this, SLOT(factoryUnregistered(ChatTopBarWidgetFactory*)));
-
-		foreach (ChatTopBarWidgetFactory *factory, MyChatTopBarWidgetFactoryRepository->factories())
-			factoryRegistered(factory);
-	}
 }
 
 ChatTopBarContainerWidget::~ChatTopBarContainerWidget()
 {
 }
 
+void ChatTopBarContainerWidget::setChatTopBarWidgetFactoryRepository(ChatTopBarWidgetFactoryRepository *chatTopBarWidgetFactoryRepository)
+{
+	m_chatTopBarWidgetFactoryRepository = chatTopBarWidgetFactoryRepository;
+}
+
+void ChatTopBarContainerWidget::init()
+{
+	createGui();
+
+	connect(m_chatTopBarWidgetFactoryRepository, SIGNAL(factoryRegistered(ChatTopBarWidgetFactory*)),
+			this, SLOT(factoryRegistered(ChatTopBarWidgetFactory*)));
+	connect(m_chatTopBarWidgetFactoryRepository, SIGNAL(factoryUnregistered(ChatTopBarWidgetFactory*)),
+			this, SLOT(factoryUnregistered(ChatTopBarWidgetFactory*)));
+
+	foreach (ChatTopBarWidgetFactory *factory, m_chatTopBarWidgetFactoryRepository->factories())
+		factoryRegistered(factory);
+}
+
 void ChatTopBarContainerWidget::createGui()
 {
 	Layout = new QVBoxLayout(this);
