@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +18,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHAT_TOP_BAR_CONTAINER_WIDGET_H
-#define CHAT_TOP_BAR_CONTAINER_WIDGET_H
-
-#include <QtGui/QWidget>
+#pragma once
 
 #include "chat/chat.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
 class QVBoxLayout;
 
 class ChatTopBarWidgetFactory;
@@ -35,7 +35,8 @@ class ChatTopBarContainerWidget : public QWidget
 {
 	Q_OBJECT
 
-	ChatTopBarWidgetFactoryRepository *MyChatTopBarWidgetFactoryRepository;
+	QPointer<ChatTopBarWidgetFactoryRepository> m_chatTopBarWidgetFactoryRepository;
+
 	Chat MyChat;
 	QVBoxLayout *Layout;
 	QMap<ChatTopBarWidgetFactory *, QWidget *> TopBarWidgets;
@@ -43,13 +44,14 @@ class ChatTopBarContainerWidget : public QWidget
 	void createGui();
 
 private slots:
+	INJEQT_SET void setChatTopBarWidgetFactoryRepository(ChatTopBarWidgetFactoryRepository *chatTopBarWidgetFactoryRepository);
+	INJEQT_INIT void init();
+
 	void factoryRegistered(ChatTopBarWidgetFactory *factory);
 	void factoryUnregistered(ChatTopBarWidgetFactory *factory);
 
 public:
-	explicit ChatTopBarContainerWidget(ChatTopBarWidgetFactoryRepository *chatTopBarWidgetFactoryRepository, const Chat &chat, QWidget *parent = 0);
+	explicit ChatTopBarContainerWidget(const Chat &chat, QWidget *parent = nullptr);
 	virtual ~ChatTopBarContainerWidget();
 
 };
-
-#endif // CHAT_TOP_BAR_CONTAINER_WIDGET_H
