@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -34,7 +32,7 @@ class KADUAPI ChatTopBarWidgetFactoryRepository : public QObject
 	QList<ChatTopBarWidgetFactory *> Factories;
 
 public:
-	explicit ChatTopBarWidgetFactoryRepository(QObject *parent = 0);
+	Q_INVOKABLE explicit ChatTopBarWidgetFactoryRepository(QObject *parent = nullptr);
 	virtual ~ChatTopBarWidgetFactoryRepository();
 
 	void registerFactory(ChatTopBarWidgetFactory *factory);
