@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009 Longer (longer89@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,20 +18,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QMenu>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
 #include "chat/chat-manager.h"
-#include "configuration/chat-configuration-holder.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-set.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/myself.h"
+#include "core/injected-factory.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
 #include "gui/actions/chat/leave-chat-action.h"
 #include "gui/actions/edit-talkable-action.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "gui/menu/menu-inventory.h"
 #include "gui/widgets/chat-edit-box.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
@@ -47,6 +43,7 @@
 #include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
 #include "gui/windows/kadu-window-actions.h"
 #include "gui/windows/message-dialog.h"
+#include "gui/windows/open-chat-with/open-chat-with-service.h"
 #include "gui/windows/open-chat-with/open-chat-with.h"
 #include "model/roles.h"
 #include "debug.h"
@@ -96,11 +93,17 @@ static void disableNoChatImageService(Action *action)
 	action->setEnabled(protocol->chatImageService());
 }
 
-static void checkBlocking(Action *action)
+static void checkBlocking(Myself *myself, Action *action)
 {
 	BuddySet buddies = action->context()->buddies();
 
-	if (!buddies.count() || buddies.contains(Core::instance()->myself()))
+	if (!buddies.count() || buddies.contains(myself->buddy()))
+	{
+		action->setEnabled(false);
+		return;
+	}
+
+	if (action->context()->buddies().isAnyTemporary())
 	{
 		action->setEnabled(false);
 		return;
@@ -139,22 +142,70 @@ static void disableNoGadu(Action *action)
 
 ChatWidgetActions::ChatWidgetActions(QObject *parent) : QObject(parent)
 {
-	Actions::instance()->blockSignals();
+}
 
-	MoreActions = new ActionDescription(0,
+ChatWidgetActions::~ChatWidgetActions()
+{
+}
+
+void ChatWidgetActions::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void ChatWidgetActions::setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder)
+{
+	m_chatConfigurationHolder = chatConfigurationHolder;
+}
+
+void ChatWidgetActions::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void ChatWidgetActions::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ChatWidgetActions::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ChatWidgetActions::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void ChatWidgetActions::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void ChatWidgetActions::setOpenChatWithService(OpenChatWithService *openChatWithService)
+{
+	m_openChatWithService = openChatWithService;
+}
+
+void ChatWidgetActions::init()
+{
+	m_actions->blockSignals();
+
+	MoreActions = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "moreActionsAction",
 		this, SLOT(moreActionsActionActivated(QAction *, bool)),
 		KaduIcon(), tr("More..."), false
 	);
 
-	AutoSend = new ActionDescription(0,
+	AutoSend = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "autoSendAction",
 		this, SLOT(autoSendActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/enter"), tr("Return Sends Message"), true
 	);
 	connect(AutoSend, SIGNAL(actionCreated(Action *)), this, SLOT(autoSendActionCreated(Action *)));
 
-	ClearChat = new ActionDescription(0,
+	ClearChat = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "clearChatAction",
 		this, SLOT(clearActionActivated(QAction *, bool)),
 		KaduIcon("edit-clear"), tr("Clear Messages in Chat Window"), false,
@@ -162,35 +213,35 @@ ChatWidgetActions::ChatWidgetActions(QObject *parent) : QObject(parent)
 	);
 	connect(ClearChat, SIGNAL(actionCreated(Action *)), this, SLOT(clearChatActionCreated(Action *)));
 
-	InsertImage = new ActionDescription(0,
+	InsertImage = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "insertImageAction",
 		this, SLOT(insertImageActionActivated(QAction *, bool)),
 		KaduIcon("insert-image"), tr("Insert Image"), false,
 		disableNoChatImageService
 	);
 
-	Bold = new ActionDescription(0,
+	Bold = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "boldAction",
 		this, SLOT(boldActionActivated(QAction *, bool)),
 		KaduIcon("format-text-bold"), tr("Bold"), true,
 		disableNoGadu
 	);
 
-	Italic = new ActionDescription(0,
+	Italic = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "italicAction",
 		this, SLOT(italicActionActivated(QAction *, bool)),
 		KaduIcon("format-text-italic"), tr("Italic"), true,
 		disableNoGadu
 	);
 
-	Underline = new ActionDescription(0,
+	Underline = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "underlineAction",
 		this, SLOT(underlineActionActivated(QAction *, bool)),
 		KaduIcon("format-text-underline"), tr("Underline"), true,
 		disableNoGadu
 	);
 
-	Send = new ActionDescription(0,
+	Send = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "sendAction",
 		this, SLOT(sendActionActivated(QAction *, bool)),
 		KaduIcon("go-next"), tr("&Send"), false,
@@ -198,46 +249,62 @@ ChatWidgetActions::ChatWidgetActions(QObject *parent) : QObject(parent)
 	);
 	connect(Send, SIGNAL(actionCreated(Action *)), this, SLOT(sendActionCreated(Action *)));
 
-	BlockUser = new ActionDescription(0,
+	BlockUser = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeUser, "blockUserAction",
 		this, SLOT(blockUserActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/block-buddy"), tr("Block Buddy"), true,
-		checkBlocking
+		[this](Action *action){ return checkBlocking(m_myself, action); }
 	);
 
 	// The last ActionDescription of each type will send actionLoaded() signal.
-	Actions::instance()->unblockSignals();
+	m_actions->unblockSignals();
 
-	OpenChat = new ActionDescription(0,
+	OpenChat = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeUser, "chatAction",
 		this, SLOT(openChatActionActivated(QAction *, bool)),
 		KaduIcon("internet-group-chat"), tr("&Chat"), false,
 		disableNoChat
 	);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(OpenChat, KaduMenu::SectionChat, 1000);
 
-	OpenWith = new ActionDescription(0,
+	OpenWith = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeGlobal, "openChatWithAction",
 		this, SLOT(openChatWithActionActivated(QAction *, bool)),
 		KaduIcon("internet-group-chat"), tr("Open Chat with...")
 	);
 	OpenWith->setShortcut("kadu_openchatwith", Qt::ApplicationShortcut);
 /*
-	ColorSelector = new ActionDescription(0,
+	ColorSelector = m_injectedFactory->makeInjected<ActionDescription>(nullptr,
 		ActionDescription::TypeChat, "colorAction",
 		this, SLOT(colorSelectorActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/change-color"), tr("Change Color")
 	);*/
 
-	EditTalkable = new EditTalkableAction(this);
-	LeaveChat = new LeaveChatAction(this);
+	EditTalkable = m_injectedFactory->makeInjected<EditTalkableAction>(this);
+	m_actions->insert(EditTalkable);
+
+	LeaveChat = m_injectedFactory->makeInjected<LeaveChatAction>(this);
+	m_actions->insert(LeaveChat);
 }
 
-ChatWidgetActions::~ChatWidgetActions()
+void ChatWidgetActions::done()
 {
+	delete MoreActions;
+	delete AutoSend;
+	delete ClearChat;
+	delete InsertImage;
+	delete Bold;
+	delete Italic;
+	delete Underline;
+	delete Send;
+	delete BlockUser;
+	delete OpenChat;
+	delete OpenWith;
+	delete EditTalkable;
+	delete LeaveChat;
 }
 
 void ChatWidgetActions::configurationUpdated()
@@ -247,7 +314,7 @@ void ChatWidgetActions::configurationUpdated()
 
 void ChatWidgetActions::autoSendActionCreated(Action *action)
 {
-	action->setChecked(config_file.readBoolEntry("Chat", "AutoSend"));
+	action->setChecked(m_configuration->deprecatedApi()->readBoolEntry("Chat", "AutoSend"));
 }
 
 void ChatWidgetActions::clearChatActionCreated(Action *action)
@@ -276,7 +343,7 @@ void ChatWidgetActions::sendActionCreated(Action *action)
 
 void ChatWidgetActions::autoSendActionCheck()
 {
- 	bool check = config_file.readBoolEntry("Chat", "AutoSend");
+ 	bool check = m_configuration->deprecatedApi()->readBoolEntry("Chat", "AutoSend");
  	foreach (Action *action, AutoSend->actions())
  		action->setChecked(check);
 }
@@ -289,10 +356,10 @@ void ChatWidgetActions::autoSendActionActivated(QAction *sender, bool toggled)
 	if (!chatEditBox)
 		return;
 
-	config_file.writeEntry("Chat", "AutoSend", toggled);
+	m_configuration->deprecatedApi()->writeEntry("Chat", "AutoSend", toggled);
 	autoSendActionCheck();
 
-	ChatConfigurationHolder::instance()->configurationUpdated();
+	m_chatConfigurationHolder->configurationUpdated();
 }
 
 void ChatWidgetActions::moreActionsActionActivated(QAction *sender, bool toggled)
@@ -324,16 +391,16 @@ void ChatWidgetActions::moreActionsActionActivated(QAction *sender, bool toggled
 	QMenu menu;
 	QMenu *subMenu = new QMenu(tr("More"), &menu);
 
-	foreach (const QString &actionName, Actions::instance()->keys())
+	foreach (const QString &actionName, m_actions->keys())
 	{
 		if (toolbar && toolbar->windowHasAction(actionName, false))
 			continue;
 
-		ActionDescription *actionDescription = Actions::instance()->value(actionName);
+		ActionDescription *actionDescription = m_actions->value(actionName);
 		if (ActionDescription::TypeChat == actionDescription->type())
-			menu.addAction(Actions::instance()->createAction(actionName, chatEditBox->actionContext(), chatEditBox));
+			menu.addAction(m_actions->createAction(actionName, chatEditBox->actionContext(), chatEditBox));
 		else if (ActionDescription::TypeUser == actionDescription->type())
-			subMenu->addAction(Actions::instance()->createAction(actionName, chatEditBox->actionContext(), chatEditBox));
+			subMenu->addAction(m_actions->createAction(actionName, chatEditBox->actionContext(), chatEditBox));
 	}
 
 	menu.addSeparator();
@@ -485,11 +552,11 @@ void ChatWidgetActions::openChatActionActivated(QAction *sender, bool toggled)
 
 	kdebugf();
 
-	Action *action = qobject_cast<Action *>(sender);
+	auto action = qobject_cast<Action *>(sender);
 	if (!action)
 		return;
 
-	Core::instance()->chatWidgetManager()->openChat(action->context()->chat(), OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(action->context()->chat(), OpenChatActivation::Activate);
 
 	kdebugf2();
 }
@@ -500,11 +567,11 @@ void ChatWidgetActions::openChatWithActionActivated(QAction *sender, bool toggle
 
 	kdebugf();
 
-	Action *action = qobject_cast<Action *>(sender);
+	auto action = qobject_cast<Action *>(sender);
 	if (!action)
 		return;
 
-	OpenChatWith::instance()->show();
+	m_openChatWithService->show();
 
 	kdebugf2();
 }
