@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,37 +19,55 @@
 
 #include "chat-widget-message-handler-configurator.h"
 
-#include "configuration/configuration-file.h"
-#include "gui/widgets/chat-widget/chat-widget-message-handler.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/widgets/chat-widget/chat-widget-message-handler-configuration.h"
+#include "gui/widgets/chat-widget/chat-widget-message-handler.h"
 
-ChatWidgetMessageHandlerConfigurator::ChatWidgetMessageHandlerConfigurator()
+ChatWidgetMessageHandlerConfigurator::ChatWidgetMessageHandlerConfigurator(QObject *parent) :
+		QObject{parent}
+{
+}
+
+ChatWidgetMessageHandlerConfigurator::~ChatWidgetMessageHandlerConfigurator()
 {
-	createDefaultConfiguration();
 }
 
 void ChatWidgetMessageHandlerConfigurator::setChatWidgetMessageHandler(ChatWidgetMessageHandler *chatWidgetMessageHandler)
 {
 	m_chatWidgetMessageHandler = chatWidgetMessageHandler;
-	configurationUpdated();
+}
+
+void ChatWidgetMessageHandlerConfigurator::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ChatWidgetMessageHandlerConfigurator::init()
+{
+	createDefaultConfiguration();
 }
 
 void ChatWidgetMessageHandlerConfigurator::configurationUpdated()
 {
 	if (m_chatWidgetMessageHandler)
-		m_chatWidgetMessageHandler.data()->setConfiguration(loadConfiguration());
+		m_chatWidgetMessageHandler.data()->setChatWidgetMessageHandlerConfiguration(loadConfiguration());
 }
 
 void ChatWidgetMessageHandlerConfigurator::createDefaultConfiguration() const
 {
-	config_file.addVariable("Chat", "OpenChatOnMessage", false);
-	config_file.addVariable("Chat", "OpenChatOnMessageWhenOnline", true);
+	m_configuration->deprecatedApi()->addVariable("Chat", "OpenChatOnMessage", false);
+	m_configuration->deprecatedApi()->addVariable("Chat", "OpenChatOnMessageWhenOnline", true);
+	m_configuration->deprecatedApi()->addVariable("Chat", "OpenChatOnMessageMinimized", false);
 }
 
 ChatWidgetMessageHandlerConfiguration ChatWidgetMessageHandlerConfigurator::loadConfiguration() const
 {
 	auto configuration = ChatWidgetMessageHandlerConfiguration();
-	configuration.setOpenChatOnMessage(config_file.readBoolEntry("Chat", "OpenChatOnMessage", false));
-	configuration.setOpenChatOnMessageOnlyWhenOnline(config_file.readBoolEntry("Chat", "OpenChatOnMessageWhenOnline", true));
+	configuration.setOpenChatOnMessage(m_configuration->deprecatedApi()->readBoolEntry("Chat", "OpenChatOnMessage", false));
+	configuration.setOpenChatOnMessageOnlyWhenOnline(m_configuration->deprecatedApi()->readBoolEntry("Chat", "OpenChatOnMessageWhenOnline", true));
+	configuration.setOpenChatOnMessageMinimized(m_configuration->deprecatedApi()->readBoolEntry("Chat", "OpenChatOnMessageMinimized", false));
 	return configuration;
 }
+
+#include "moc_chat-widget-message-handler-configurator.cpp"
