@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,20 +21,23 @@
 #include "chat-widget-message-handler.h"
 
 #include "chat/buddy-chat-manager.h"
-#include "configuration/configuration-file.h"
-#include "core/core.h"
-#include "gui/widgets/chat-widget/chat-widget.h"
+#include "configuration/configuration-api.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/widgets/chat-widget/chat-widget-activation-service.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/chat-widget/chat-widget-repository.h"
+#include "gui/widgets/chat-widget/chat-widget.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "message/message-manager.h"
 #include "message/sorted-messages.h"
 #include "message/unread-message-repository.h"
+#include "notification/silent-mode-service.h"
 #include "protocols/protocol.h"
-#include "services/notification-service.h"
+#include "status/status-type-data.h"
+#include "status/status-type-manager.h"
 
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 ChatWidgetMessageHandler::ChatWidgetMessageHandler(QObject *parent) :
 		QObject{parent}
@@ -44,15 +48,14 @@ ChatWidgetMessageHandler::~ChatWidgetMessageHandler()
 {
 }
 
+void ChatWidgetMessageHandler::setBuddyChatManager(BuddyChatManager *buddyChatManager)
+{
+	m_buddyChatManager = buddyChatManager;
+}
+
 void ChatWidgetMessageHandler::setChatWidgetActivationService(ChatWidgetActivationService *chatWidgetActivationService)
 {
 	m_chatWidgetActivationService = chatWidgetActivationService;
-
-	if (!m_chatWidgetActivationService)
-		return;
-
-	connect(m_chatWidgetActivationService.data(), SIGNAL(chatWidgetActivated(ChatWidget*)),
-			this, SLOT(chatWidgetActivated(ChatWidget*)));
 }
 
 void ChatWidgetMessageHandler::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
@@ -63,49 +66,57 @@ void ChatWidgetMessageHandler::setChatWidgetManager(ChatWidgetManager *chatWidge
 void ChatWidgetMessageHandler::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
 {
 	m_chatWidgetRepository = chatWidgetRepository;
+}
 
-	if (!m_chatWidgetRepository)
-		return;
+void ChatWidgetMessageHandler::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ChatWidgetMessageHandler::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void ChatWidgetMessageHandler::setMessageManager(MessageManager *messageManager)
+{
+	m_messageManager = messageManager;
+}
+
+void ChatWidgetMessageHandler::setSilentModeService(SilentModeService *silentModeService)
+{
+	m_silentModeService = silentModeService;
+}
+
+void ChatWidgetMessageHandler::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void ChatWidgetMessageHandler::setUnreadMessageRepository(UnreadMessageRepository *unreadMessageRepository)
+{
+	m_unreadMessageRepository = unreadMessageRepository;
+}
+
+void ChatWidgetMessageHandler::init()
+{
+	connect(m_chatWidgetActivationService, SIGNAL(chatWidgetActivated(ChatWidget*)), this, SLOT(chatWidgetActivated(ChatWidget*)));
 
 	connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetAdded(ChatWidget*)), this, SLOT(chatWidgetAdded(ChatWidget*)));
 	connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetRemoved(ChatWidget*)), this, SLOT(chatWidgetRemoved(ChatWidget*)));
 
 	for (auto chatWidget : m_chatWidgetRepository.data())
 		chatWidgetAdded(chatWidget);
+
+	// some other messageReceived slot may check if message chat is open and this
+	// slot can change this value, so let all other messageReceived be executed before this
+	connect(m_messageManager.data(), SIGNAL(messageReceived(Message)), this, SLOT(messageReceived(Message)), Qt::QueuedConnection);
+	connect(m_messageManager.data(), SIGNAL(messageSent(Message)), this, SLOT(messageSent(Message)), Qt::QueuedConnection);
 }
 
-void ChatWidgetMessageHandler::setMessageManager(MessageManager *messageManager)
+void ChatWidgetMessageHandler::setChatWidgetMessageHandlerConfiguration(ChatWidgetMessageHandlerConfiguration chatWidgetMessageHandlerConfiguration)
 {
-	m_messageManager = messageManager;
-
-	if (!m_messageManager)
-		return;
-
-	connect(m_messageManager.data(), SIGNAL(messageReceived(Message)), this, SLOT(messageReceived(Message)));
-	connect(m_messageManager.data(), SIGNAL(messageSent(Message)), this, SLOT(messageSent(Message)));
-}
-
-void ChatWidgetMessageHandler::setNotificationService(NotificationService *notificationService)
-{
-	m_notificationService = notificationService;
-}
-
-void ChatWidgetMessageHandler::setUnreadMessageRepository(UnreadMessageRepository *unreadMessageRepository)
-{
-	m_unreadMessageRepository = unreadMessageRepository;
-
-	if (!m_unreadMessageRepository)
-		return;
-
-	connect(m_unreadMessageRepository.data(), SIGNAL(unreadMessageAdded(Message)),
-			this, SLOT(handleUnreadMessageChange(Message)));
-	connect(m_unreadMessageRepository.data(), SIGNAL(unreadMessageRemoved(Message)),
-			this, SLOT(handleUnreadMessageChange(Message)));
-}
-
-void ChatWidgetMessageHandler::setConfiguration(ChatWidgetMessageHandlerConfiguration configuration)
-{
-	m_configuration = configuration;
+	m_chatWidgetMessageHandlerConfiguration = chatWidgetMessageHandlerConfiguration;
 }
 
 void ChatWidgetMessageHandler::chatWidgetAdded(ChatWidget *chatWidget)
@@ -133,11 +144,13 @@ void ChatWidgetMessageHandler::appendAllUnreadMessages(ChatWidget *chatWidget)
 	auto unreadMessagesAppended = chat.property("message:unreadMessagesAppended", false).toBool();
 
 	auto messages = unreadMessagesAppended ? m_unreadMessageRepository.data()->unreadMessagesForChat(chat) : loadAllUnreadMessages(chat);
-	m_unreadMessageRepository.data()->markMessagesAsRead(messages);
+	auto chatIsActive = m_chatWidgetActivationService ? m_chatWidgetActivationService.data()->isChatWidgetActive(chatWidget) : false;
+	if (chatIsActive)
+		m_unreadMessageRepository.data()->markMessagesAsRead(messages);
 
 	if (!unreadMessagesAppended)
 	{
-		chatWidget->appendMessages(messages);
+		chatWidget->addMessages(messages);
 		chat.addProperty("message:unreadMessagesAppended", true, CustomProperties::NonStorable);
 	}
 }
@@ -145,7 +158,7 @@ void ChatWidgetMessageHandler::appendAllUnreadMessages(ChatWidget *chatWidget)
 SortedMessages ChatWidgetMessageHandler::loadAllUnreadMessages(const Chat &chat) const
 {
 	// TODO: BuddyChatManager cannot be injected here, because it crashes, find out why
-	auto buddyChat = BuddyChatManager::instance()->buddyChat(chat);
+	auto buddyChat = m_buddyChatManager->buddyChat(chat);
 	auto unreadChat = buddyChat ? buddyChat : chat;
 	return m_unreadMessageRepository.data()->unreadMessagesForChat(unreadChat);
 }
@@ -164,29 +177,34 @@ void ChatWidgetMessageHandler::messageReceived(const Message &message)
 
 	if (chatWidget)
 	{
-		chatWidget->appendMessage(message);
+		chatWidget->addMessage(message);
 		return;
 	}
 
 	if (shouldOpenChatWidget(chat))
-		m_chatWidgetManager.data()->openChat(chat, OpenChatActivation::Activate);
+	{
+		auto activation = m_chatWidgetMessageHandlerConfiguration.openChatOnMessageMinimized()
+			? OpenChatActivation::Minimize
+			: OpenChatActivation::Activate;
+		m_chatWidgetManager.data()->openChat(chat, activation);
+	}
 	else
 	{
-#ifdef Q_OS_WIN32
-		if (!config_file.readBoolEntry("General", "HideMainWindowFromTaskbar"))
-			qApp->alert(Core::instance()->kaduWindow());
+#ifdef Q_OS_WIN
+		if (!m_configuration->deprecatedApi()->readBoolEntry("General", "HideMainWindowFromTaskbar"))
+			qApp->alert(m_kaduWindowService->kaduWindow());
 #else
-		qApp->alert(Core::instance()->kaduWindow());
+		qApp->alert(m_kaduWindowService->kaduWindow());
 #endif
 	}
 }
 
 bool ChatWidgetMessageHandler::shouldOpenChatWidget(const Chat &chat) const
 {
-	if (!m_configuration.openChatOnMessage())
+	if (!m_chatWidgetMessageHandlerConfiguration.openChatOnMessage())
 		return false;
 
-	auto silentMode = m_notificationService ? m_notificationService.data()->silentMode() : false;
+	auto silentMode = m_silentModeService->isSilentOrAutoSilent();
 	if (silentMode)
 		return false;
 
@@ -194,8 +212,8 @@ bool ChatWidgetMessageHandler::shouldOpenChatWidget(const Chat &chat) const
 	if (!handler)
 		return false;
 
-	if (m_configuration.openChatOnMessageOnlyWhenOnline())
-		return StatusTypeGroupOnline == handler->status().group();
+	if (m_chatWidgetMessageHandlerConfiguration.openChatOnMessageOnlyWhenOnline())
+		return StatusTypeGroup::Online == m_statusTypeManager->statusTypeData(handler->status().type()).typeGroup();
 	else
 		return true;
 }
@@ -208,18 +226,7 @@ void ChatWidgetMessageHandler::messageSent(const Message &message)
 	auto chat = message.messageChat();
 	auto chatWidget = m_chatWidgetRepository.data()->widgetForChat(chat);
 	if (chatWidget)
-		chatWidget->appendMessage(message);
-}
-
-void ChatWidgetMessageHandler::handleUnreadMessageChange(const Message &message)
-{
-	if (!m_unreadMessageRepository || !m_chatWidgetRepository)
-		return;
-
-	auto chat = message.messageChat();
-	auto chatWidget = m_chatWidgetRepository.data()->widgetForChat(chat);
-	if (chatWidget)
-		chatWidget->setUnreadMessagesCount(m_unreadMessageRepository.data()->unreadMessagesForChat(chat).size());
+		chatWidget->addMessage(message);
 }
 
 #include "moc_chat-widget-message-handler.cpp"
