@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2016 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,9 +23,9 @@
 #include "misc/iterator.h"
 #include "exports.h"
 
+#include <QtCore/QObject>
 #include <map>
 #include <memory>
-#include <QtCore/QObject>
 
 class ChatWidget;
 
@@ -37,17 +37,17 @@ class ChatWidget;
 /**
  * @class ChatWidgetRepository
  * @short Repository of ChatWidget instances.
- * @note This class is experimental in Kadu, watch for unique_ptr!
  *
- * This repository holds instances of ChatWidget. All instances are owned
- * by this class and can only be deleted by it.
+ * This repository holds instances of ChatWidget. Instances are not owned
+ * by repository and must be deleted elsewhere.
  *
- * Instances are added by addChatWidget(std::unique_ptr&lt;ChatWidget&gt;) which
- * transfers ownership of chat widget to repository. It also emits
+ * Instances are added by addChatWidget(ChatWidget*) It also emits
  * chatWidgetAdded(ChatWidget*) signals.
  *
  * Instances are removed by removeChatWidget(ChatWidget*) methods. Signal
- * chatWidgetRemoved(ChatWidget*) is removed and chat widget is destroyed.
+ * chatWidgetRemoved(ChatWidget*) is emitted. This method does not delete
+ * ChatWidget instance. It is also automatically called when ChatWidget
+ * is deleted elsewhere.
  *
  * Instances can be enumerated as ChatWidget* in standard for-range loop as
  * begin() and end() iterators are provided.
@@ -56,10 +56,9 @@ class KADUAPI ChatWidgetRepository : public QObject
 {
 	Q_OBJECT
 
-	using Storage = std::map<Chat, std::unique_ptr<ChatWidget>>;
-	using WrappedIterator = Storage::iterator;
-
 public:
+	using Storage = std::map<Chat, ChatWidget *>;
+	using WrappedIterator = Storage::iterator;
 	using Iterator = IteratorWrapper<WrappedIterator, ChatWidget *>;
 
 	explicit ChatWidgetRepository(QObject *parent = nullptr);
@@ -68,37 +67,27 @@ public:
 	/**
 	 * @short Begin iterator that returns ChatWidget *.
 	 */
-	Iterator begin();
+	virtual Iterator begin() = 0;
 
 	/**
-	 * @short Begin iterator that returns ChatWidget *.
+	 * @short End iterator that returns ChatWidget *.
 	 */
-	Iterator end();
+	virtual Iterator end() = 0;
 
 	/**
 	 * @short Add new chatWidget to repository.
 	 *
 	 * Add new chatWidget to repository only if it is valid and chat widget for given
-	 * chat is not already in repository. In other case argument is destroyed.
+	 * chat is not already in repository. In other case nothing happens.
 	 *
-	 * In case of successfull addition ownership of chatWidget is taken by repository
-	 * and chatWidgetAdded(ChatWidget*) signal is emitted.
+	 * In case of successfull addition ownership chatWidgetAdded(ChatWidget*) signal is emitted.
 	 */
-	void addChatWidget(std::unique_ptr<ChatWidget> chatWidget);
-
-	/**
-	 * @short Remove chatWidget from repository and destroy it.
-	 *
-	 * Remove chatWidget from repository only if it is  already in repository.
-	 * Signal chatWidgetRemoved(ChatWidget*) is emitted after successfull removal.
-	 * Then provided chat widget is destroyed.
-	 */
-	void removeChatWidget(ChatWidget *chatWidget);
+	virtual void addChatWidget(ChatWidget *chatWidget) = 0;
 
 	/**
 	 * @short Return true if repository has chat widget for given chat.
 	 */
-	bool hasWidgetForChat(const Chat &chat) const;
+	virtual bool hasWidgetForChat(const Chat &chat) const = 0;
 
 	/**
 	 * @short Return ChatWidget for given chat.
@@ -108,26 +97,40 @@ public:
 	 * If chat is null then nullptr is returned. If repository does contain ChatWidget then
 	 * it is returned. Else nullptr is returned.
 	 */
-	ChatWidget * widgetForChat(const Chat &chat);
+	virtual ChatWidget * widgetForChat(const Chat &chat) = 0;
+
+public slots:
+	/**
+	 * @short Remove chatWidget from repository
+	 *
+	 * Remove chatWidget from repository only if it is  already in repository.
+	 * Signal chatWidgetRemoved(ChatWidget*) is emitted after successfull removal.
+	 * ChatWidget instance is not destroyed after removal.
+	 */
+	virtual void removeChatWidget(ChatWidget *chatWidget) = 0;
+
+	/**
+	 * @short Remove ChatWidget for given chat from repository and destroy it.
+	 *
+	 * Remove chatWidget for given chat from repository only if it is  already in repository.
+	 * Signal chatWidgetRemoved(ChatWidget*) is emitted after successfull removal.
+	 * ChatWidget instance is not destroyed after removal.
+	 */
+	virtual void removeChatWidget(Chat chat) = 0;
 
 signals:
 	/**
-	 * @short Signal emitted when new ChatWidget was created for this repository.
-	 * @param chatWidget newly created ChatWidget instance
+	 * @short Signal emitted when new ChatWidget was added to this repository.
+	 * @param chatWidget newly added ChatWidget instance
 	 */
 	void chatWidgetAdded(ChatWidget *chatWidget);
 
 	/**
-	 * @short Signal emitted when new ChatWidget was destroyed in this repository.
-	 * @param chatWidget just destroyed ChatWidget instance
+	 * @short Signal emitted when new ChatWidget was removed from this repository.
+	 * @param chatWidget removed ChatWidget instance
 	 */
 	void chatWidgetRemoved(ChatWidget *chatWidget);
 
-private:
-	static ChatWidget * converter(WrappedIterator iterator);
-
-	Storage m_widgets;
-
 };
 
 inline ChatWidgetRepository::Iterator begin(ChatWidgetRepository *chatWidgetRepository)
