@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,9 +20,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QLabel>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
 
 #include "configuration/config-file-data-manager.h"
 #include "gui/widgets/color-button.h"
@@ -32,15 +32,16 @@
 
 #include "buddy-list-background-colors-widget.h"
 
-BuddyListBackgroundColorsWidget::BuddyListBackgroundColorsWidget(MainConfigurationWindow* mainWindow)
+BuddyListBackgroundColorsWidget::BuddyListBackgroundColorsWidget(MainConfigurationWindow* mainWindow) :
+		m_mainWindow{mainWindow}
 {
-	createGui(mainWindow);
+	createGui();
 	loadConfiguration();
 
-	connect(mainWindow, SIGNAL(configurationWindowApplied()), this, SLOT(configurationApplied()));
+	connect(m_mainWindow, SIGNAL(configurationWindowApplied()), this, SLOT(configurationApplied()));
 }
 
-void BuddyListBackgroundColorsWidget::createGui(MainConfigurationWindow* mainWindow)
+void BuddyListBackgroundColorsWidget::createGui()
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
 
@@ -50,27 +51,27 @@ void BuddyListBackgroundColorsWidget::createGui(MainConfigurationWindow* mainWin
 	layout->addWidget(colorButton);
 	layout->addWidget(alternateColorButton);
 
-	ConfigGroupBox *groupBox = mainWindow->widget()->configGroupBox("Look", "Buddies list", "Background");
+	ConfigGroupBox *groupBox = m_mainWindow->widget()->configGroupBox("Look", "Buddies list", "Background");
 
 	groupBox->addWidgets(new QLabel(QCoreApplication::translate("@default", "Background colors") + ':', this), this);
 }
 
 void BuddyListBackgroundColorsWidget::loadConfiguration()
 {
-	if (!MainConfigurationWindow::instanceDataManager())
+	if (!m_mainWindow || m_mainWindow->dataManager())
 		return;
 
-	colorButton->setColor(MainConfigurationWindow::instanceDataManager()->readEntry("Look", "UserboxBgColor").value<QColor>());
-	alternateColorButton->setColor(MainConfigurationWindow::instanceDataManager()->readEntry("Look", "UserboxAlternateBgColor").value<QColor>());
+	colorButton->setColor(m_mainWindow->dataManager()->readEntry("Look", "UserboxBgColor").value<QColor>());
+	alternateColorButton->setColor(m_mainWindow->dataManager()->readEntry("Look", "UserboxAlternateBgColor").value<QColor>());
 }
 
 void BuddyListBackgroundColorsWidget::configurationApplied()
 {
-	if (!MainConfigurationWindow::instanceDataManager())
+	if (!m_mainWindow || m_mainWindow->dataManager())
 		return;
 
-      	MainConfigurationWindow::instanceDataManager()->writeEntry("Look", "UserboxBgColor", QVariant(colorButton->color().name()));
-      	MainConfigurationWindow::instanceDataManager()->writeEntry("Look", "UserboxAlternateBgColor", QVariant(alternateColorButton->color().name()));
+	m_mainWindow->dataManager()->writeEntry("Look", "UserboxBgColor", QVariant(colorButton->color().name()));
+	m_mainWindow->dataManager()->writeEntry("Look", "UserboxAlternateBgColor", QVariant(alternateColorButton->color().name()));
 }
 
 #include "moc_buddy-list-background-colors-widget.cpp"
