@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,10 +19,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_LIST_BACKGROUND_COLORS_WIDGET_H
-#define BUDDY_LIST_BACKGROUND_COLORS_WIDGET_H
+#pragma once
 
-#include <QtGui/QWidget>
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
 
 class ColorButton;
 class MainConfigurationWindow;
@@ -34,10 +31,12 @@ class BuddyListBackgroundColorsWidget : public QWidget
 {
 	Q_OBJECT
 
+	QPointer<MainConfigurationWindow> m_mainWindow;
+
 	ColorButton *colorButton;
 	ColorButton *alternateColorButton;
 
-	void createGui(MainConfigurationWindow* mainWindow);
+	void createGui();
 	void loadConfiguration();
 
 private slots:
@@ -45,6 +44,5 @@ private slots:
 
 public:
 	explicit BuddyListBackgroundColorsWidget(MainConfigurationWindow *mainWindow);
-};
 
-#endif // BUDDY_LIST_BACKGROUND_COLORS_WIDGET_H
+};
