@@ -1,9 +1,10 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2008, 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,20 +21,23 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIG_SECTION_H
-#define CONFIG_SECTION_H
-
-#include <QtCore/QMap>
-#include <QtCore/QObject>
+#pragma once
 
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/widgets/configuration/kadu-tab-widget.h"
 #include "icons/kadu-icon.h"
 
+#include <QtCore/QMap>
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class ConfigGroupBox;
 class ConfigTab;
 class ConfigurationWidget;
+class Configuration;
 class ConfigWidget;
+class IconsManager;
 
 class QGridLayout;
 class QGroupBox;
@@ -43,6 +47,26 @@ class ConfigSection : public QObject
 {
 	Q_OBJECT
 
+public:
+	ConfigSection(const QString &name, ConfigurationWidget *configurationWidget, QListWidgetItem *listWidgetItem, QWidget *parentConfigGroupBoxWidget,
+		const KaduIcon &icon);
+	virtual ~ConfigSection();
+
+	const QString & name() const { return Name; }
+
+	void activate();
+
+	void show() { TabWidget->show(); }
+	void hide() { TabWidget->hide(); }
+
+	void addFullPageWidget(const QString &name, QWidget *widget);
+
+	ConfigGroupBox * configGroupBox(const QString &tab, const QString &groupBox, bool create);
+
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+
 	QString Name;
 	ConfigurationWidget *MyConfigurationWidget;
 	KaduIcon Icon;
@@ -57,24 +81,11 @@ class ConfigSection : public QObject
 	ConfigTab * configTab(const QString &name, bool create);
 
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_INIT void init();
+
 	void configTabDestroyed(QObject *obj);
 	void iconThemeChanged();
 
-public:
-	ConfigSection(const QString &name, ConfigurationWidget *configurationWidget, QListWidgetItem *listWidgetItem, QWidget *parentConfigGroupBoxWidget,
-		const KaduIcon &icon);
-	virtual ~ConfigSection();
-
-	const QString & name() const { return Name; }
-
-	void activate();
-
-	void show() { TabWidget->show(); }
-	void hide() { TabWidget->hide(); }
-
-	ConfigGroupBox * configGroupBox(const QString &tab, const QString &groupBox, bool create);
-
 };
-
-
-#endif
