@@ -1,14 +1,12 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,15 +24,17 @@
  */
 
 #include <QtCore/QFile>
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QListWidget>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QWidget>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QVBoxLayout>
+#include <QtWidgets/QWidget>
 #include <QtXml/QDomElement>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/configuration/config-action-button.h"
 #include "gui/widgets/configuration/config-check-box.h"
 #include "gui/widgets/configuration/config-color-button.h"
@@ -48,7 +48,6 @@
 #include "gui/widgets/configuration/config-list-widget.h"
 #include "gui/widgets/configuration/config-path-list-edit.h"
 #include "gui/widgets/configuration/config-preview.h"
-#include "gui/widgets/configuration/config-proxy-combo-box.h"
 #include "gui/widgets/configuration/config-radio-button.h"
 #include "gui/widgets/configuration/config-section.h"
 #include "gui/widgets/configuration/config-select-file.h"
@@ -60,12 +59,12 @@
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/windows/configuration-window.h"
 #include "icons/kadu-icon.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 
 #include "debug.h"
 
 ConfigurationWidget::ConfigurationWidget(ConfigurationWindowDataManager *dataManager, QWidget *parent) :
-		QWidget(parent), CurrentSection(0), DataManager(dataManager)
+		QWidget(parent), DataManager(dataManager), CurrentSection(0)
 {
 	QHBoxLayout *center_layout = new QHBoxLayout(this);
 	center_layout->setMargin(0);
@@ -95,7 +94,7 @@ ConfigurationWidget::ConfigurationWidget(ConfigurationWindowDataManager *dataMan
 ConfigurationWidget::~ConfigurationWidget()
 {
 	if (SectionsListWidget->currentItem())
-		config_file.writeEntry("General", "ConfigurationWindow_" + Name, SectionsListWidget->currentItem()->text());
+		m_configuration->deprecatedApi()->writeEntry("General", "ConfigurationWindow_" + Name, SectionsListWidget->currentItem()->text());
 
 	disconnect(SectionsListWidget, 0, this, 0);
 
@@ -107,13 +106,38 @@ ConfigurationWidget::~ConfigurationWidget()
 	}
 }
 
-void ConfigurationWidget::init()
+void ConfigurationWidget::setConfiguration(Configuration *configuration)
 {
-	QString lastSection = config_file.readEntry("General", "ConfigurationWindow_" + Name);
-	if (ConfigSections.contains(lastSection))
-		ConfigSections.value(lastSection)->activate();
+	m_configuration = configuration;
+}
+
+void ConfigurationWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void ConfigurationWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ConfigurationWidget::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void ConfigurationWidget::beforeShow()
+{
+	auto lastSection = m_configuration->deprecatedApi()->readEntry("General", "ConfigurationWindow_" + Name);
+	auto section = ConfigSections.value(lastSection);
+	if (section)
+		section->activate();
 	else if (SectionsListWidget->count() > 0)
-		ConfigSections.value(SectionsListWidget->item(0)->text())->activate();
+	{
+		auto firstSection = ConfigSections.value(SectionsListWidget->item(0)->text());
+		if (firstSection)
+			firstSection->activate();
+	}
 }
 
 QList<ConfigWidget *> ConfigurationWidget::appendUiFile(const QString &fileName, bool load)
@@ -213,7 +237,7 @@ QList<ConfigWidget *> ConfigurationWidget::processUiSectionFromDom(QDomNode sect
 	QString iconPath = sectionElement.attribute("icon");
 	// Additional slash is needed so that QUrl would treat the rest as _path_, which is desired here.
 	if (iconPath.startsWith("datapath:///"))
-		iconPath = KaduPaths::instance()->dataPath() + iconPath.midRef(static_cast<int>(qstrlen("datapath:///")));
+		iconPath = m_pathsProvider->dataPath() + iconPath.mid(static_cast<int>(qstrlen("datapath:///")));
 	configSection(KaduIcon(iconPath), QCoreApplication::translate("@default", sectionName.toUtf8().constData()), true);
 
 	const QDomNodeList children = sectionElement.childNodes();
@@ -332,43 +356,43 @@ ConfigWidget * ConfigurationWidget::appendUiElementFromDom(QDomNode uiElementNod
 	ConfigWidget *widget = 0;
 
 	if (tagName == "line-edit")
-		widget = new ConfigLineEdit(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigLineEdit>(configGroupBox, DataManager);
 	else if (tagName == "gg-password-edit")
-		widget = new ConfigGGPasswordEdit(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigGGPasswordEdit>(configGroupBox, DataManager);
 	else if (tagName == "check-box")
-		widget = new ConfigCheckBox(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigCheckBox>(configGroupBox, DataManager);
 	else if (tagName == "radio-button")
-		widget = new ConfigRadioButton(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigRadioButton>(configGroupBox, DataManager);
 	else if (tagName == "spin-box")
-		widget = new ConfigSpinBox(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigSpinBox>(configGroupBox, DataManager);
 	else if (tagName == "combo-box")
-		widget = new ConfigComboBox(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigComboBox>(configGroupBox, DataManager);
 	else if (tagName == "hot-key-edit")
-		widget = new ConfigHotKeyEdit(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigHotKeyEdit>(configGroupBox, DataManager);
 	else if (tagName == "path-list-edit")
-		widget = new ConfigPathListEdit(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigPathListEdit>(configGroupBox, DataManager);
 	else if (tagName == "color-button")
-		widget = new ConfigColorButton(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigColorButton>(configGroupBox, DataManager);
 	else if (tagName == "select-font")
-		widget = new ConfigSelectFont(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigSelectFont>(configGroupBox, DataManager);
 	else if (tagName == "syntax-editor")
-		widget = new ConfigSyntaxEditor(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigSyntaxEditor>(configGroupBox, DataManager);
 	else if (tagName == "action-button")
-		widget = new ConfigActionButton(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigActionButton>(configGroupBox, DataManager);
 	else if (tagName == "select-file")
-		widget = new ConfigSelectFile(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigSelectFile>(configGroupBox, DataManager);
 	else if (tagName == "preview")
-		widget = new ConfigPreview(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigPreview>(configGroupBox, DataManager);
 	else if (tagName == "proxy-combo-box")
-		widget = new ConfigProxyComboBox(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigPreview>(configGroupBox, DataManager);
 	else if (tagName == "slider")
-		widget = new ConfigSlider(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigSlider>(configGroupBox, DataManager);
 	else if (tagName == "label")
-		widget = new ConfigLabel(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigLabel>(configGroupBox, DataManager);
 	else if (tagName == "list-box")
-		widget = new ConfigListWidget(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigListWidget>(configGroupBox, DataManager);
 	else if (tagName == "line-separator")
-		widget = new ConfigLineSeparator(configGroupBox, DataManager);
+		widget = m_injectedFactory->makeInjected<ConfigLineSeparator>(configGroupBox, DataManager);
 	else
 	{
 		kdebugf2();
@@ -449,13 +473,13 @@ ConfigSection * ConfigurationWidget::configSection(const KaduIcon &icon, const Q
 	if (!create)
 		return 0;
 
-	QListWidgetItem *newConfigSectionListWidgetItem = new QListWidgetItem(icon.icon(), name, SectionsListWidget);
+	QListWidgetItem *newConfigSectionListWidgetItem = new QListWidgetItem(m_iconsManager->iconByPath(icon), name, SectionsListWidget);
 
 	QFontMetrics fontMetrics = SectionsListWidget->fontMetrics();
 	// TODO: 48 = margins + scrollbar - get real scrollbar width
 	int width = fontMetrics.width(name) + 80;
 
-	ConfigSection *newConfigSection = new ConfigSection(name, this, newConfigSectionListWidgetItem, ContainerWidget, icon);
+	auto newConfigSection = m_injectedFactory->makeInjected<ConfigSection>(name, this, newConfigSectionListWidgetItem, ContainerWidget, icon);
 	ConfigSections.insert(name, newConfigSection);
 	connect(newConfigSection, SIGNAL(destroyed(QObject *)), this, SLOT(configSectionDestroyed(QObject *)));
 
@@ -527,8 +551,12 @@ void ConfigurationWidget::changeSection(const QString &newSectionName)
 		CurrentSection->hide();
 
 	CurrentSection = newSection;
-	newSection->show();
-	newSection->activate();
+
+	if (CurrentSection)
+	{
+		CurrentSection->show();
+		CurrentSection->activate();
+	}
 }
 
 void ConfigurationWidget::configSectionDestroyed(QObject *obj)
