@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,45 +19,60 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QCheckBox>
-#include <QtGui/QHBoxLayout>
+#include "notify-group-box.h"
 
 #include "icons/icons-manager.h"
 
-#include "notify-group-box.h"
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QHBoxLayout>
 
 NotifyGroupBox::NotifyGroupBox(Notifier *notificator, const QString &caption, QWidget *parent) :
-		QWidget(parent), Notificator(notificator)
+		QWidget{parent},
+		m_notificator{notificator}
 {
-	new QHBoxLayout(this);
+	auto layout = new QHBoxLayout(this);
+	layout->setMargin(0);
+	layout->setSpacing(0);
 
-	NotifierCheckBox = new QCheckBox(caption);
-	NotifierCheckBox->setIcon(notificator->icon().icon());
-	layout()->addWidget(NotifierCheckBox);
-	connect(NotifierCheckBox, SIGNAL(clicked(bool)), this, SLOT(toggledSlot(bool)));
-	connect(IconsManager::instance(), SIGNAL(themeChanged()), this, SLOT(iconThemeChanged()));
+	m_notifierCheckBox = make_owned<QCheckBox>(caption, this);
+	layout->addWidget(m_notifierCheckBox);
+	connect(m_notifierCheckBox, SIGNAL(clicked(bool)), this, SLOT(toggledSlot(bool)));
+}
+
+NotifyGroupBox::~NotifyGroupBox()
+{
+}
+
+void NotifyGroupBox::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void NotifyGroupBox::init()
+{
+	connect(m_iconsManager, SIGNAL(themeChanged()), this, SLOT(iconThemeChanged()));
 }
 
 void NotifyGroupBox::setChecked(bool checked)
 {
-	NotifierCheckBox->setChecked(checked);
+	m_notifierCheckBox->setChecked(checked);
 }
 
 void NotifyGroupBox::addWidget(QWidget *widget)
 {
 	layout()->addWidget(widget);
-	widget->setEnabled(NotifierCheckBox->isChecked());
-	connect(NotifierCheckBox, SIGNAL(toggled(bool)), widget, SLOT(setEnabled(bool)));
+	widget->setEnabled(m_notifierCheckBox->isChecked());
+	connect(m_notifierCheckBox, SIGNAL(toggled(bool)), widget, SLOT(setEnabled(bool)));
 }
 
 void NotifyGroupBox::toggledSlot(bool toggle)
 {
-	emit toggled(Notificator, toggle);
+	emit toggled(m_notificator, toggle);
 }
 
 void NotifyGroupBox::iconThemeChanged()
 {
-	NotifierCheckBox->setIcon(Notificator->icon().icon());
+	m_notifierCheckBox->setIcon(m_iconsManager->iconByPath(m_notificator->icon()));
 }
 
 #include "moc_notify-group-box.cpp"
