@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,12 +20,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef NOTIFY_GROUP_BOX
-#define NOTIFY_GROUP_BOX
+#pragma once
 
-#include <QtGui/QWidget>
+#include "misc/memory.h"
+#include "notification/notifier.h"
 
-#include "notify/notifier.h"
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
+class IconsManager;
 
 class QCheckBox;
 
@@ -33,19 +37,11 @@ class KADUAPI NotifyGroupBox : public QWidget
 {
 	Q_OBJECT
 
-	QCheckBox *NotifierCheckBox;
-
-	Notifier *Notificator;
-
-private slots:
-	void toggledSlot(bool toggled);
-	void iconThemeChanged();
-
 public:
-	NotifyGroupBox(Notifier *Notificator, const QString &caption, QWidget *parent = 0);
-	virtual ~NotifyGroupBox() {}
+	explicit NotifyGroupBox(Notifier *Notificator, const QString &caption, QWidget *parent = nullptr);
+	virtual ~NotifyGroupBox();
 
-	Notifier * notificator() { return Notificator; }
+	Notifier * notificator() { return m_notificator; }
 
 	void setChecked(bool checked);
 	void addWidget(QWidget *widget);
@@ -53,6 +49,17 @@ public:
 signals:
 	void toggled(Notifier *notificator, bool toggled);
 
-};
+private:
+	QPointer<IconsManager> m_iconsManager;
 
-#endif // NOTIFY_GROUP_BOX
+	owned_qptr<QCheckBox> m_notifierCheckBox;
+	Notifier *m_notificator;
+
+private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_INIT void init();
+
+	void toggledSlot(bool toggled);
+	void iconThemeChanged();
+
+};
