@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,22 +18,24 @@
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-/* This classes are based on the KNotifyEventList* classes, which are the part
+/* This classes are based on the KNotificationEventList* classes, which are the part
  * of KDE libraries (see kde.org) and distributed under the terms
  * of the GNU Library General Public License version 2 as published
  * by the Free Software Foundation
  *  Copyright (C) 2005 Olivier Goffart <ogoffart at kde.org>
  */
 
-#include <QtGui/QApplication>
 #include <QtGui/QFontMetrics>
-#include <QtGui/QHeaderView>
 #include <QtGui/QPainter>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QHeaderView>
 
-#include "notify/notification-manager.h"
-#include "notify/notifier.h"
-#include "notify/notify-configuration-ui-handler.h"
-#include "notify/notify-event.h"
+#include "core/injected-factory.h"
+#include "notification/notifier-repository.h"
+#include "notification/notifier.h"
+#include "notification/notify-configuration-ui-handler.h"
+#include "notification/notification-event.h"
+#include "notification/notification-event-repository.h"
 
 #include "notify-tree-widget.h"
 
@@ -43,6 +45,20 @@ NotifyTreeWidgetDelegate::NotifyTreeWidgetDelegate(QObject *parent) : QStyledIte
 {
 }
 
+NotifyTreeWidgetDelegate::~NotifyTreeWidgetDelegate()
+{
+}
+
+void NotifyTreeWidgetDelegate::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void NotifyTreeWidgetDelegate::setNotifierRepository(NotifierRepository *notifierRepository)
+{
+	m_notifierRepository = notifierRepository;
+}
+
 void NotifyTreeWidgetDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
 	if (index.column() != 1)
@@ -59,10 +75,10 @@ void NotifyTreeWidgetDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 	int iconWidth = option.decorationSize.width();
 	int iconHeight = option.decorationSize.height();
 
-	foreach (Notifier *notifier, NotificationManager::instance()->notifiers())
+	for (auto notifier : m_notifierRepository)
 	{
 		if (notifiers.contains(notifier->name()))
-			notifier->icon().icon().paint(painter, rect.left() + position + 4, rect.top() + (rect.height() - iconHeight) / 2, iconWidth, iconHeight);
+			m_iconsManager->iconByPath(notifier->icon()).paint(painter, rect.left() + position + 4, rect.top() + (rect.height() - iconHeight) / 2, iconWidth, iconHeight);
 		position += iconWidth + 4;
 	}
 
@@ -70,17 +86,41 @@ void NotifyTreeWidgetDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 
 NotifyTreeWidget::NotifyTreeWidget(NotifyConfigurationUiHandler *uiHandler, QWidget *parent)
 	: QTreeWidget(parent), UiHandler(uiHandler)
+{
+}
+
+void NotifyTreeWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void NotifyTreeWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void NotifyTreeWidget::setNotificationEventRepository(NotificationEventRepository *notificationEventRepository)
+{
+	m_notificationEventRepository = notificationEventRepository;
+}
+
+void NotifyTreeWidget::setNotifierRepository(NotifierRepository *notifierRepository)
+{
+	m_notifierRepository = notifierRepository;
+}
+
+void NotifyTreeWidget::init()
 {
 	QStringList headerLabels;
 	headerLabels << tr("Event") << tr("Notification");
 	setHeaderLabels(headerLabels);
 
-	setItemDelegate(new NotifyTreeWidgetDelegate(this));
+	setItemDelegate(m_injectedFactory->makeInjected<NotifyTreeWidgetDelegate>(this));
 	setAlternatingRowColors(true);
 	setItemsExpandable(true);
 	setExpandsOnDoubleClick(true);
 
-	connect(IconsManager::instance(), SIGNAL(themeChanged()), this, SLOT(refresh()));
+	connect(m_iconsManager, SIGNAL(themeChanged()), this, SLOT(refresh()));
 
 	//Extract icon size as the font height (as h=w on icons)
 	QStyleOptionViewItem iconOption;
@@ -104,28 +144,28 @@ void NotifyTreeWidget::refresh()
 	clear();
 	TreeItems.clear();
 
-	ColumnWidth = (IconWidth + 4) * NotificationManager::instance()->notifiers().count();
+	ColumnWidth = (IconWidth + 4) * m_notifierRepository->size();
 	header()->resizeSection(0, eventColumnWidth());
 
 	const QMap<Notifier *, NotifierConfigurationGuiItem> &notifierGuiItems = UiHandler->notifierGui();
-	const QMap<QString, NotifyEventConfigurationItem> &notifyEventItem = UiHandler->notifyEvents();
+	const QMap<QString, NotificationEventConfigurationItem> &notifyEventItem = UiHandler->notifyEvents();
 
 	QStringList notifiersNames;
 	QString eventName;
-	foreach (NotifyEvent *notifyEvent, NotificationManager::instance()->notifyEvents())
+	for (auto &&notifyEvent : m_notificationEventRepository->notificationEvents())
 	{
-		eventName = notifyEvent->name();
-		foreach (Notifier *notifier, NotificationManager::instance()->notifiers())
+		eventName = notifyEvent.name();
+		for (auto notifier : m_notifierRepository)
 			if (notifierGuiItems[notifier].Events[eventName])
 				notifiersNames << notifier->name();
 
-		if (notifyEvent->category().isEmpty())
+		if (notifyEvent.category().isEmpty())
 			TreeItems.insert(eventName, new NotifyTreeWidgetItem(this, eventName,
-						notifyEvent->description(), notifiersNames));
+						notifyEvent.description(), notifiersNames));
 		else
 		{
-			TreeItems[eventName] = new NotifyTreeWidgetItem(TreeItems[notifyEvent->category()], eventName,
-						notifyEvent->description(), notifiersNames);
+			TreeItems[eventName] = new NotifyTreeWidgetItem(TreeItems[notifyEvent.category()], eventName,
+						notifyEvent.description(), notifiersNames);
 			TreeItems[eventName]->useCustomSettingsChecked(notifyEventItem[eventName].useCustomSettings);
 		}
 		notifiersNames.clear();
@@ -172,24 +212,24 @@ void NotifyTreeWidget::resizeEvent(QResizeEvent *event)
 	header()->resizeSection(0, eventColumnWidth());
 }
 
-NotifyTreeWidgetItem::NotifyTreeWidgetItem(QTreeWidget *parent, const QString &eventName, const char *name, QStringList &notifiers)
+NotifyTreeWidgetItem::NotifyTreeWidgetItem(QTreeWidget *parent, const QString &eventName, const QString &name, QStringList &notifiers)
 	: QTreeWidgetItem(parent), ActiveNotifiers(notifiers), useCustomSettings(true)
 {
 	setChildIndicatorPolicy(QTreeWidgetItem::DontShowIndicatorWhenChildless);
 
 	setData(1, Qt::UserRole, QVariant(ActiveNotifiers));
 	setData(0, Qt::UserRole, QVariant(eventName));
-	setText(0, QCoreApplication::translate("@default", name));
+	setText(0, QCoreApplication::translate("@default", name.toUtf8()));
 }
 
-NotifyTreeWidgetItem::NotifyTreeWidgetItem(NotifyTreeWidgetItem *parent, const QString &eventName, const char *name, QStringList &notifiers)
+NotifyTreeWidgetItem::NotifyTreeWidgetItem(NotifyTreeWidgetItem *parent, const QString &eventName, const QString &name, QStringList &notifiers)
 	: QTreeWidgetItem(parent), ActiveNotifiers(notifiers), useCustomSettings(true)
 {
 	setChildIndicatorPolicy(QTreeWidgetItem::DontShowIndicatorWhenChildless);
 
 	setData(1, Qt::UserRole, QVariant(ActiveNotifiers));
 	setData(0, Qt::UserRole, QVariant(eventName));
-	setText(0, QCoreApplication::translate("@default", name));
+	setText(0, QCoreApplication::translate("@default", name.toUtf8()));
 }
 
 void NotifyTreeWidgetItem::notifierChecked(Notifier *notifier, bool checked)
