@@ -2,9 +2,9 @@
  * %kadu copyright begin%
  * Copyright 2011 SÅawomir StÄpieÅ (s.stepien@interia.pl)
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2011 Slawomir Stepien (s.stepien@interia.pl)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QMenu>
+#include <QtWidgets/QMenu>
 
 #include "gui/actions/action-context-provider.h"
 #include "gui/actions/action-context.h"
@@ -30,18 +30,13 @@
 
 #include "custom-input-menu-manager.h"
 
-CustomInputMenuManager * CustomInputMenuManager::Instance = 0;
-
-CustomInputMenuManager * CustomInputMenuManager::instance()
+CustomInputMenuManager::CustomInputMenuManager(QObject *parent) :
+		QObject{parent},
+		InputContextMenuSorted{true}
 {
-	if (!Instance)
-		Instance = new CustomInputMenuManager();
-
-	return Instance;
 }
 
-CustomInputMenuManager::CustomInputMenuManager() :
-		InputContextMenuSorted(true)
+CustomInputMenuManager::~CustomInputMenuManager()
 {
 }
 
