@@ -1,14 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2006 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2011 Slawomir Stepien (s.stepien@interia.pl)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,15 +27,19 @@
 #include <QtCore/QMimeData>
 #include <QtCore/QScopedPointer>
 #include <QtCore/QUrl>
-#include <QtGui/QAction>
 #include <QtGui/QImageReader>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QMenu>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QMenu>
 
-#include "configuration/chat-configuration-holder.h"
 #include "core/core.h"
 #include "formatted-string/formatted-string-factory.h"
+#include "formatted-string/formatted-string-html-visitor.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "gui/hot-key.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "html/normalized-html-string.h"
 #include "protocols/protocol.h"
 #include "protocols/services/chat-image-service.h"
 #include "services/image-storage-service.h"
@@ -63,22 +63,37 @@ CustomInput::CustomInput(Chat chat, QWidget *parent) :
 	kdebugf2();
 }
 
+void CustomInput::setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder)
+{
+	m_chatConfigurationHolder = chatConfigurationHolder;
+}
+
+void CustomInput::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void CustomInput::setCustomInputMenuManager(CustomInputMenuManager *customInputMenuManager)
+{
+	m_customInputMenuManager = customInputMenuManager;
+}
+
 void CustomInput::setImageStorageService(ImageStorageService *imageStorageService)
 {
-	CurrentImageStorageService = imageStorageService;
+	m_imageStorageService = imageStorageService;
 }
 
 void CustomInput::setFormattedStringFactory(FormattedStringFactory *formattedStringFactory)
 {
-	CurrentFormattedStringFactory = formattedStringFactory;
+	m_formattedStringFactory = formattedStringFactory;
 }
 
-std::unique_ptr<FormattedString> CustomInput::formattedString() const
+NormalizedHtmlString CustomInput::htmlMessage() const
 {
-	if (CurrentFormattedStringFactory)
-		return CurrentFormattedStringFactory->fromTextDocument(document());
-	else
-		return 0;
+	auto formattedString = m_formattedStringFactory->fromTextDocument(*document());
+	FormattedStringHtmlVisitor visitor{};
+	formattedString->accept(&visitor);
+	return normalizeHtml(visitor.result());
 }
 
 void CustomInput::showEvent(QShowEvent *e)
@@ -86,7 +101,7 @@ void CustomInput::showEvent(QShowEvent *e)
 	QTextEdit::showEvent(e);
 
 	// see #2837 - windows bug
-	setFont(ChatConfigurationHolder::instance()->chatFont());
+	setFont(m_chatConfigurationHolder->chatFont());
 }
 
 void CustomInput::keyPressEvent(QKeyEvent *e)
@@ -103,7 +118,7 @@ void CustomInput::keyPressEvent(QKeyEvent *e)
 	if ((autosend_enabled
 			&& ((e->key() == Qt::Key_Return && e->modifiers() == Qt::NoModifier)
 				|| (e->key() == Qt::Key_Enter && e->modifiers() == Qt::KeypadModifier)))
-		|| (!autosend_enabled && isCtrlEnter) || HotKey::shortCut(e, "ShortCuts", "chat_sendmessage"))
+		|| (!autosend_enabled && isCtrlEnter) || HotKey::shortCut(m_configuration, e, "ShortCuts", "chat_sendmessage"))
 	{
 		kdebugmf(KDEBUG_INFO, "emit sendMessage()\n");
 		emit sendMessage();
@@ -121,7 +136,7 @@ void CustomInput::keyPressEvent(QKeyEvent *e)
 		kdebugf2();
 		return;
 	}
-	else if (HotKey::shortCut(e, "ShortCuts", "chat_bold"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "chat_bold"))
 	{
 		if (QFont::Normal == fontWeight())
 			setFontWeight(QFont::Bold);
@@ -134,7 +149,7 @@ void CustomInput::keyPressEvent(QKeyEvent *e)
 		kdebugf2();
 		return;
 	}
-	else if (HotKey::shortCut(e, "ShortCuts", "chat_italic"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "chat_italic"))
 	{
 		setFontItalic(!fontItalic());
 
@@ -144,7 +159,7 @@ void CustomInput::keyPressEvent(QKeyEvent *e)
 		kdebugf2();
 		return;
 	}
-	else if (HotKey::shortCut(e, "ShortCuts", "chat_underline"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "chat_underline"))
 	{
 		setFontUnderline(!fontUnderline());
 
@@ -168,6 +183,11 @@ void CustomInput::keyPressEvent(QKeyEvent *e)
 		kdebugf2();
 		return;
 	}
+	else if (e->key() == Qt::Key_Tab)
+	{
+		e->accept();
+		return;
+	}
 
 	bool handled = false;
 	emit keyPressed(e, this, handled);
@@ -191,13 +211,19 @@ void CustomInput::keyReleaseEvent(QKeyEvent *e)
 		e->accept();
 		return;
 	}
+	if (e->key() == Qt::Key_Tab)
+	{
+		insertPlainText("    ");
+		e->accept();
+		return;
+	}
 
 	QTextEdit::keyReleaseEvent(e);
 }
 
 void CustomInput::contextMenuEvent(QContextMenuEvent *e)
 {
-	QScopedPointer<QMenu> menu(CustomInputMenuManager::instance()->menu(this));
+	QScopedPointer<QMenu> menu(m_customInputMenuManager->menu(this));
 
 	QAction *undo = new QAction(tr("Undo"), menu.data());
 	undo->setShortcut(QKeySequence::Undo);
@@ -226,6 +252,10 @@ void CustomInput::contextMenuEvent(QContextMenuEvent *e)
 	connect(paste, SIGNAL(triggered()), this, SLOT(paste()));
 	menu->addAction(paste);
 
+	auto pasteAndSend = new QAction(tr("Paste and send"), menu.data());
+	connect(pasteAndSend, SIGNAL(triggered()), this, SLOT(pasteAndSend()));
+	menu->addAction(pasteAndSend);
+
 	QAction *clear = new QAction(tr("Clear"), menu.data());
 	connect(clear, SIGNAL(triggered()), this, SLOT(clear()));
 	menu->addAction(clear);
@@ -255,72 +285,70 @@ void CustomInput::setCopyPossible(bool available)
 	CopyPossible = available;
 }
 
+void CustomInput::pasteAndSend()
+{
+	paste();
+	emit sendMessage();
+}
+
 bool CustomInput::canInsertFromMimeData(const QMimeData *source) const
 {
 	if (CurrentChat.chatAccount().protocolHandler() && CurrentChat.chatAccount().protocolHandler()->chatImageService())
 	{
 		if (source->hasUrls())
 			return true;
-		if (source->hasFormat(QLatin1String("application/x-qt-image")))
+		if (source->hasFormat(QStringLiteral("application/x-qt-image")))
 			return true;
 	}
 	return QTextEdit::canInsertFromMimeData(source);
 }
 
-void CustomInput::insertFromMimeData(const QMimeData *source)
+void CustomInput::acceptPlainText(QString plainText)
+{
+	insertPlainText(plainText.replace("\t", "    "));
+}
+
+void CustomInput::acceptFileUrl(QUrl imageUrl)
 {
 	if (!CurrentChat.chatAccount().protocolHandler() || !CurrentChat.chatAccount().protocolHandler()->chatImageService())
-	{
-		QTextEdit::insertFromMimeData(source);
 		return;
-	}
 
-	QString path;
-
-	if (source->hasUrls() && !source->urls().isEmpty())
+	imageUrl = m_imageStorageService->toFileUrl(imageUrl);
+	if (!imageUrl.toString().isEmpty() && imageUrl.scheme() == "file")
 	{
-		QUrl url = source->urls().first();
-		if (CurrentImageStorageService)
-			url = CurrentImageStorageService->toFileUrl(url);
-
-		if (!url.isEmpty() && url.scheme() == "file")
-		{
-			path = QDir::cleanPath(url.path());
-			if (QImage(path).isNull())
-				path.clear();
-		}
+		auto path = QDir::cleanPath(imageUrl.path());
+		if (QImage(path).isNull())
+			return;
+		insertHtml(QString{"<img src='%1' />"}.arg(path));
 	}
+}
 
-	if (path.isEmpty() && source->hasFormat(QLatin1String("application/x-qt-image")))
-	{
-		QByteArray imagedata = source->data(QLatin1String("application/x-qt-image"));
-		QBuffer buffer(&imagedata);
-		buffer.open(QIODevice::ReadOnly);
-		QString ext = QImageReader(&buffer).format().toLower();
-		QString filename = "drop" + QString::number(QDateTime::currentDateTime().toTime_t()) + "." + ext;
-
-		if (CurrentImageStorageService)
-			path = CurrentImageStorageService->fullPath(filename);
-		else
-			path = filename;
-
-		QFile file(path);
-		if (file.open(QIODevice::WriteOnly | QIODevice::Truncate))
-		{
-			file.write(imagedata);
-			file.close();
-		}
-		else
-			path.clear();
-	}
-
-	if (!path.isEmpty())
-	{
-		insertHtml(QString("<img src='%1' />").arg(path));
+void CustomInput::acceptImageData(QByteArray imageData)
+{
+	if (!CurrentChat.chatAccount().protocolHandler() || !CurrentChat.chatAccount().protocolHandler()->chatImageService())
 		return;
-	}
 
-	QTextEdit::insertFromMimeData(source);
+	QBuffer buffer{&imageData};
+	buffer.open(QIODevice::ReadOnly);
+	auto ext = QString::fromUtf8(QImageReader{&buffer}.format().toLower());
+	auto filename = QString{"drop%1.%2"}.arg(QDateTime::currentDateTime().toTime_t()).arg(ext);
+
+	auto path = m_imageStorageService->fullPath(filename);
+	QFile file(path);
+	if (file.open(QIODevice::WriteOnly | QIODevice::Truncate))
+	{
+		file.write(imageData);
+		file.close();
+
+		insertHtml(QString{"<img src='%1' />"}.arg(path));
+	}
+	else
+		return;
+}
+
+void CustomInput::insertFromMimeData(const QMimeData *source)
+{
+	acceptPasteData(source, this);
 }
 
 #include "moc_custom-input.cpp"
