@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,35 +19,66 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QFormLayout>
-#include <QtGui/QIcon>
-#include <QtGui/QLabel>
+#include "merge-buddies-dialog-widget.h"
 
 #include "buddies/buddy-manager.h"
 #include "buddies/model/buddy-list-model.h"
 #include "buddies/model/buddy-manager-adapter.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/widgets/select-talkable-combo-box.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "talkable/filter/exclude-buddy-talkable-filter.h"
+#include "talkable/talkable-converter.h"
 
-
-#include "merge-buddies-dialog-widget.h"
+#include <QtGui/QIcon>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
 
 MergeBuddiesDialogWidget::MergeBuddiesDialogWidget(Buddy buddy, const QString &message, QWidget *parent) :
 		DialogWidget(tr("Merge Buddies"), message, QPixmap(), parent), MyBuddy(buddy)
 {
-	QIcon icon = KaduIcon("kadu_icons/kadu").icon();
-	Pixmap = icon.pixmap(icon.actualSize(QSize(64, 64)));
-
-	createGui();
 }
 
 MergeBuddiesDialogWidget::~MergeBuddiesDialogWidget()
 {
 }
 
+void MergeBuddiesDialogWidget::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void MergeBuddiesDialogWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void MergeBuddiesDialogWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void MergeBuddiesDialogWidget::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void MergeBuddiesDialogWidget::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void MergeBuddiesDialogWidget::init()
+{
+	QIcon icon = m_iconsManager->iconByPath(KaduIcon("kadu_icons/kadu"));
+	Pixmap = icon.pixmap(icon.actualSize(QSize(64, 64)));
+
+	createGui();
+}
+
 void MergeBuddiesDialogWidget::createGui()
 {
 	QFormLayout *formLayout = new QFormLayout(this);
@@ -55,14 +86,14 @@ void MergeBuddiesDialogWidget::createGui()
 
 	QLabel *selectLabel = new QLabel(tr("Buddy to merge") + ":", this);
 
-	SelectCombo = new SelectTalkableComboBox(this);
+	SelectCombo = m_injectedFactory->makeInjected<SelectTalkableComboBox>(this);
 	SelectCombo->addBeforeAction(new QAction(tr(" - Select buddy - "), SelectCombo));
 
-	BuddyListModel *buddyListModel = new BuddyListModel(SelectCombo);
-	new BuddyManagerAdapter(buddyListModel);
+	auto buddyListModel = m_injectedFactory->makeInjected<BuddyListModel>(SelectCombo);
+	m_injectedFactory->makeInjected<BuddyManagerAdapter>(buddyListModel);
 	SelectCombo->setBaseModel(buddyListModel);
 	SelectCombo->addFilter(new ExcludeBuddyTalkableFilter(MyBuddy, SelectCombo));
-	SelectCombo->addFilter(new ExcludeBuddyTalkableFilter(Core::instance()->myself(), SelectCombo));
+	SelectCombo->addFilter(new ExcludeBuddyTalkableFilter(m_myself->buddy(), SelectCombo));
 	connect(SelectCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(selectedBuddyChanged()));
 	formLayout->addRow(selectLabel, SelectCombo);
 
@@ -76,12 +107,12 @@ void MergeBuddiesDialogWidget::selectedBuddyChanged()
 
 void MergeBuddiesDialogWidget::dialogAccepted()
 {
-	Buddy mergeWith = SelectCombo->currentTalkable().toBuddy();
+	Buddy mergeWith = m_talkableConverter->toBuddy(SelectCombo->currentTalkable());
 
 	if (mergeWith.isNull() || MyBuddy.isNull())
 		return;
 
-	BuddyManager::instance()->mergeBuddies(mergeWith, MyBuddy);
+	m_buddyManager->mergeBuddies(mergeWith, MyBuddy);
 }
 
 void MergeBuddiesDialogWidget::dialogRejected()
