@@ -1,12 +1,11 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,15 +22,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FILTERWIDGET_H
-#define FILTERWIDGET_H
+#pragma once
 
-#include <QtGui/QWidget>
 #include "exports.h"
 
-#ifdef Q_OS_MAC
-#	include <Carbon/Carbon.h>
-#endif
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
+class InjectedFactory;
 
 class QAbstractItemView;
 class QLabel;
@@ -41,13 +40,10 @@ class KADUAPI FilterWidget : public QWidget
 {
 	Q_OBJECT
 
-#ifdef Q_OS_MAC
-	CFStringRef searchFieldText;
-	HIViewRef searchField;
-#else
+	QPointer<InjectedFactory> m_injectedFactory;
+
 	QLabel *Label;
 	QLineEdit *NameFilterEdit;
-#endif
 
 	QAbstractItemView *View;
 	bool AutoVisibility;
@@ -56,13 +52,16 @@ class KADUAPI FilterWidget : public QWidget
 	bool sendKeyEventToView(QKeyEvent *);
 
 private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
 	void filterTextChanged(const QString &);
 
 protected:
 	virtual void keyPressEvent(QKeyEvent *);
 
 public:
-	explicit FilterWidget(QWidget *parent = 0);
+	explicit FilterWidget(QWidget *parent = nullptr);
 	virtual ~FilterWidget();
 
 	void setLabel(const QString &label);
@@ -75,20 +74,4 @@ public:
 signals:
 	void textChanged(const QString &text);
 
-#ifdef Q_OS_MAC
-
-public:
-	void activate(void);
-	QSize sizeHint (void) const;
-	QString text(void) const;
-
-public slots:
-	void clear(void);
-	void setText(const QString &text);
-	void emitTextChanged(void);
-
-#endif
-
 };
-
-#endif // FILTERWIDGET_H
