@@ -1,15 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2009, 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2009 Longer (longer89@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,9 +19,10 @@
  */
 
 #include <QtGui/QKeyEvent>
-#include <QtGui/QTreeView>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QTreeView>
+#include <QtWidgets/QVBoxLayout>
 
+#include "core/injected-factory.h"
 #include "gui/widgets/filter-widget.h"
 
 #include "filtered-tree-view.h"
@@ -41,20 +34,34 @@ bool FilteredTreeView::shouldEventGoToFilter(QKeyEvent *event)
 
 FilteredTreeView::FilteredTreeView(FilteredTreeView::FilterPosition filterPosition, QWidget *parent, Qt::WindowFlags f) :
 		QWidget(parent, f), CurrentFilterPosition(filterPosition), View(0)
+{
+}
+
+FilteredTreeView::~FilteredTreeView()
+{
+}
+
+void FilteredTreeView::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void FilteredTreeView::init()
 {
 	Layout = new QVBoxLayout(this);
 	Layout->setMargin(0);
 	Layout->setSpacing(0);
 
-	NameFilterWidget = new FilterWidget(this);
+	NameFilterWidget = m_injectedFactory->makeInjected<FilterWidget>(this);
 	connect(NameFilterWidget, SIGNAL(textChanged(const QString &)),
 		this, SIGNAL(filterChanged(const QString &)));
 
 	Layout->addWidget(NameFilterWidget);
 }
 
-FilteredTreeView::~FilteredTreeView()
+InjectedFactory * FilteredTreeView::injectedFactory() const
 {
+	return m_injectedFactory;
 }
 
 void FilteredTreeView::removeView()
