@@ -1,15 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +21,9 @@
 #ifndef FILTERED_TREE_VIEW_H
 #define FILTERED_TREE_VIEW_H
 
-#include <QtGui/QWidget>
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 #include "exports.h"
 
@@ -37,6 +31,7 @@ class QAbstractItemView;
 class QVBoxLayout;
 
 class FilterWidget;
+class InjectedFactory;
 
 class KADUAPI FilteredTreeView : public QWidget
 {
@@ -50,6 +45,8 @@ public:
 	};
 
 private:
+	QPointer<InjectedFactory> m_injectedFactory;
+
 	FilterPosition CurrentFilterPosition;
 
 	QVBoxLayout *Layout;
@@ -59,13 +56,19 @@ private:
 	void removeView();
 	void insertView();
 
+private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
 protected:
+	InjectedFactory * injectedFactory() const;
+
 	virtual void keyPressEvent(QKeyEvent *event);
 
 public:
 	static bool shouldEventGoToFilter(QKeyEvent *event);
 
-	explicit FilteredTreeView(FilterPosition filterPosition, QWidget *parent = 0, Qt::WindowFlags f = 0);
+	explicit FilteredTreeView(FilterPosition filterPosition, QWidget *parent = nullptr, Qt::WindowFlags f = 0);
 	virtual ~FilteredTreeView();
 
 	FilterWidget * filterWidget() { return NameFilterWidget; }
