@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,24 +19,33 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "buddies/group-manager.h"
-
 #include "group-list.h"
 
+#include "buddies/group-manager.h"
+
 GroupList::GroupList(QWidget *parent) :
 		QListWidget(parent)
 {
-	foreach (const Group &group, GroupManager::instance()->items())
-	{
-		QListWidgetItem * const groupItem = new QListWidgetItem(this);
-		groupItem->setText(group.name());
-	}
 }
 
 GroupList::~GroupList()
 {
 }
 
+void GroupList::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
+}
+
+void GroupList::init()
+{
+	for (auto const &group : m_groupManager->items())
+	{
+		auto groupItem = new QListWidgetItem(this);
+		groupItem->setText(group.name());
+	}
+}
+
 void GroupList::setCheckedGroups(const QSet<Group> groups)
 {
 	QSet<QString> checkedNames;
@@ -63,7 +72,7 @@ QSet<Group> GroupList::checkedGroups()
 	{
 		const QListWidgetItem * const groupItem = item(i);
 		if (Qt::Checked == groupItem->checkState())
-			result.insert(GroupManager::instance()->byName(groupItem->text()));
+			result.insert(m_groupManager->byName(groupItem->text()));
 	}
 
 	return result;
