@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,9 +18,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
 #include <QtGui/QIcon>
+#include <QtWidgets/QApplication>
 
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 
 #include "group-filter-tab-data.h"
@@ -51,14 +52,14 @@ QString GroupFilterTabData::tabName() const
 	}
 }
 
-QIcon GroupFilterTabData::tabIcon() const
+QIcon GroupFilterTabData::tabIcon(IconsManager *iconsManager) const
 {
 	switch (Filter.filterType())
 	{
 		case GroupFilterRegular:
 			return Filter.group().showIcon() ? QIcon(Filter.group().icon()) : QIcon();
 		case GroupFilterEverybody:
-			return KaduIcon("x-office-address-book").icon();
+			return iconsManager->iconByPath(KaduIcon("x-office-address-book"));
 		case GroupFilterUngroupped:
 		case GroupFilterInvalid:
 		default:
