@@ -1,19 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Tomasz Jarzynka (tomee@cpi.pl)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2002, 2003, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2002, 2003 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2002, 2003 Dariusz Jagodzik (mast3r@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -30,42 +18,37 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QMimeData>
-#include <QtGui/QApplication>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QInputDialog>
-#include <QtGui/QMenu>
+#include "group-filter-tab-data.h"
+#include "group-tab-bar.h"
 
-#include "buddies/buddy-list-mime-data-helper.h"
+#include "buddies/buddy-list-mime-data-service.h"
 #include "buddies/group-manager.h"
 #include "buddies/group.h"
-#include "chat/chat-list-mime-data-helper.h"
+#include "chat/chat-list-mime-data-service.h"
 #include "core/core.h"
-#include "gui/widgets/dialog/add-group-dialog-widget.h"
-#include "gui/widgets/dialog/edit-group-dialog-widget.h"
+#include "core/injected-factory.h"
 #include "gui/windows/add-buddy-window.h"
-#include "gui/windows/group-properties-window.h"
+#include "gui/windows/group-edit-window.h"
 #include "gui/windows/kadu-dialog.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "talkable/filter/group-filter.h"
-
 #include "debug.h"
 
-#include "group-tab-bar.h"
-#include "group-filter-tab-data.h"
+#include <QtCore/QMimeData>
+#include <QtGui/QDragEnterEvent>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QMenu>
 
 GroupTabBar::GroupTabBar(QWidget *parent) :
 		QTabBar(parent)
 {
 	setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding));
 
-#ifdef Q_OS_MAC
-	setDocumentMode(true);
-	setUsesScrollButtons(true);
-#endif
-
  	setAcceptDrops(true);
 	setDrawBase(false);
 	setMovable(true);
@@ -74,22 +57,55 @@ GroupTabBar::GroupTabBar(QWidget *parent) :
 	setIconSize(QSize(16, 16));
 
 	connect(this, SIGNAL(currentChanged(int)), this, SLOT(currentChangedSlot(int)));
-
-	connect(GroupManager::instance(), SIGNAL(groupAdded(Group)), this, SLOT(addGroup(Group)));
-	connect(GroupManager::instance(), SIGNAL(groupAboutToBeRemoved(Group)), this, SLOT(removeGroup(Group)));
-	connect(GroupManager::instance(), SIGNAL(groupUpdated(Group)), this, SLOT(updateGroup(Group)));
 }
 
 GroupTabBar::~GroupTabBar()
 {
 }
 
+void GroupTabBar::setBuddyListMimeDataService(BuddyListMimeDataService *buddyListMimeDataService)
+{
+	m_buddyListMimeDataService = buddyListMimeDataService;
+}
+
+void GroupTabBar::setChatListMimeDataService(ChatListMimeDataService *chatListMimeDataService)
+{
+	m_chatListMimeDataService = chatListMimeDataService;
+}
+
+void GroupTabBar::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
+}
+
+void GroupTabBar::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void GroupTabBar::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void GroupTabBar::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void GroupTabBar::init()
+{
+	connect(m_groupManager, SIGNAL(groupAdded(Group)), this, SLOT(addGroup(Group)));
+	connect(m_groupManager, SIGNAL(groupAboutToBeRemoved(Group)), this, SLOT(removeGroup(Group)));
+	connect(m_groupManager, SIGNAL(groupUpdated(Group)), this, SLOT(updateGroup(Group)));
+}
+
 void GroupTabBar::setInitialConfiguration(GroupTabBarConfiguration configuration)
 {
 	foreach (const auto &groupFilter, configuration.groupFilters())
 		insertGroupFilter(count(), groupFilter);
 
-	foreach (const Group &group, GroupManager::instance()->items())
+	foreach (const Group &group, m_groupManager->items())
 		addGroup(group);
 
 	setConfiguration(configuration);
@@ -97,18 +113,18 @@ void GroupTabBar::setInitialConfiguration(GroupTabBarConfiguration configuration
 
 void GroupTabBar::setConfiguration(GroupTabBarConfiguration configuration)
 {
-	Configuration = configuration;
+	m_groupTabBarConfiguration = configuration;
 
-	setVisible(Configuration.displayGroupTabs());
+	setVisible(m_groupTabBarConfiguration.displayGroupTabs());
 
-	if (Configuration.showGroupTabEverybody())
+	if (m_groupTabBarConfiguration.showGroupTabEverybody())
 		insertGroupFilter(0, GroupFilter(GroupFilterEverybody));
 	else
 		removeGroupFilter(GroupFilter(GroupFilterEverybody));
 
 	updateUngrouppedTab();
 
-	if (Configuration.displayGroupTabs())
+	if (m_groupTabBarConfiguration.displayGroupTabs())
 	{
 		if (currentIndex() == configuration.currentGroupTab())
 			currentChangedSlot(configuration.currentGroupTab());
@@ -116,7 +132,10 @@ void GroupTabBar::setConfiguration(GroupTabBarConfiguration configuration)
 			setCurrentIndex(configuration.currentGroupTab());
 	}
 	else
-		emit currentGroupFilterChanged(GroupFilter{GroupFilterEverybody});
+	{
+		m_groupFilter = GroupFilter{GroupFilterEverybody};
+		emit currentGroupFilterChanged(m_groupFilter);
+	}
 }
 
 void GroupTabBar::updateUngrouppedTab()
@@ -129,15 +148,15 @@ void GroupTabBar::updateUngrouppedTab()
 
 bool GroupTabBar::shouldShowUngrouppedTab() const
 {
-	return Configuration.alwaysShowGroupTabUngroupped()
+	return m_groupTabBarConfiguration.alwaysShowGroupTabUngroupped()
 			? true
-			: !Configuration.showGroupTabEverybody();
+			: !m_groupTabBarConfiguration.showGroupTabEverybody();
 }
 
 GroupTabBarConfiguration GroupTabBar::configuration()
 {
-	Configuration.setGroupFilters(groupFilters()); // update only if needed
-	return Configuration;
+	m_groupTabBarConfiguration.setGroupFilters(groupFilters()); // update only if needed
+	return m_groupTabBarConfiguration;
 }
 
 Group GroupTabBar::groupAt(int index) const
@@ -147,7 +166,7 @@ Group GroupTabBar::groupAt(int index) const
 
 GroupFilter GroupTabBar::groupFilter() const
 {
-	if (Configuration.displayGroupTabs())
+	if (m_groupTabBarConfiguration.displayGroupTabs())
 		return groupFilterAt(currentIndex());
 	else
 		return GroupFilter{GroupFilterEverybody};
@@ -171,12 +190,14 @@ QVector<GroupFilter> GroupTabBar::groupFilters() const
 
 void GroupTabBar::currentChangedSlot(int index)
 {
-	Configuration.setCurrentGroupTab(index);
-	if (Configuration.displayGroupTabs())
-		emit currentGroupFilterChanged(groupFilterAt(index));
+	m_groupTabBarConfiguration.setCurrentGroupTab(index);
+	if (m_groupTabBarConfiguration.displayGroupTabs())
+		m_groupFilter = groupFilterAt(index);
 	else
-		emit currentGroupFilterChanged(GroupFilter{GroupFilterEverybody});
-		
+		m_groupFilter = GroupFilter{GroupFilterEverybody};
+
+	emit currentGroupFilterChanged(m_groupFilter);
+
 }
 
 void GroupTabBar::contextMenuEvent(QContextMenuEvent *event)
@@ -189,18 +210,12 @@ void GroupTabBar::contextMenuEvent(QContextMenuEvent *event)
 	addBuddyAction->setEnabled(group);
 	addBuddyAction->setData(group);
 
-	QAction *renameGroupAction = menu.addAction(tr("Rename Group"), this, SLOT(renameGroup()));
-	renameGroupAction->setEnabled(group);
-	renameGroupAction->setData(group);
-
-	menu.addSeparator();
+	menu.addAction(tr("Add Group"), this, SLOT(createNewGroup()));
 
 	QAction *deleteGroupAction = menu.addAction(tr("Delete Group"), this, SLOT(deleteGroup()));
 	deleteGroupAction->setEnabled(group);
 	deleteGroupAction->setData(group);
 
-	menu.addAction(tr("Add Group"), this, SLOT(createNewGroup()));
-
 	menu.addSeparator();
 
 	QAction *propertiesAction = menu.addAction(tr("Properties"), this, SLOT(groupProperties()));
@@ -257,8 +272,8 @@ void GroupTabBar::dropEvent(QDropEvent *event)
 
 	event->acceptProposedAction();
 
-	BuddyList buddies = BuddyListMimeDataHelper::fromMimeData(event->mimeData());
-	QList<Chat> chats = ChatListMimeDataHelper::fromMimeData(event->mimeData());
+	auto buddies = m_buddyListMimeDataService->fromMimeData(event->mimeData());
+	auto chats = m_chatListMimeDataService->fromMimeData(event->mimeData());
 
 	QApplication::setOverrideCursor(Qt::ArrowCursor);
 	int tabIndex = tabAt(event->pos());
@@ -279,11 +294,11 @@ void GroupTabBar::dropEvent(QDropEvent *event)
 				return;
 			}
 
-			ok = GroupManager::instance()->acceptableGroupName(newGroupName);
+			ok = m_groupManager->acceptableGroupName(newGroupName);
 		}
 		while (!ok);
 
-		Group group = GroupManager::instance()->byName(newGroupName);
+		Group group = m_groupManager->byName(newGroupName);
 
 		foreach (const Buddy &buddy, buddies)
 			buddy.addToGroup(group);
@@ -303,7 +318,8 @@ void GroupTabBar::dropEvent(QDropEvent *event)
 	if (clickedGroup)
 	{
 		QMenu menu;
-		menu.addAction(tr("Move to group %1").arg(clickedGroup.name()), this, SLOT(moveToGroup()))->setData(clickedGroup);
+		if (m_groupFilter.filterType() == GroupFilterRegular)
+			menu.addAction(tr("Move to group %1").arg(clickedGroup.name()), this, SLOT(moveToGroup()))->setData(clickedGroup);
 		menu.addAction(tr("Add to group %1").arg(clickedGroup.name()), this, SLOT(addToGroup()))->setData(clickedGroup);
 		menu.exec(QCursor::pos());
 	}
@@ -319,29 +335,11 @@ void GroupTabBar::addBuddy()
 	if (!action)
 		return;
 
-	AddBuddyWindow *addBuddyWindow = new AddBuddyWindow(Core::instance()->kaduWindow());
+	auto addBuddyWindow = m_injectedFactory->makeInjected<AddBuddyWindow>(m_kaduWindowService->kaduWindow());
 	addBuddyWindow->setGroup(action->data().value<Group>());
 	addBuddyWindow->show();
 }
 
-void GroupTabBar::renameGroup()
-{
-	QAction *action = qobject_cast<QAction *>(sender());
-	if (!action)
-		return;
-
-	const Group &group = action->data().value<Group>();
-	if (!group)
-		return;
-
-	EditGroupDialogWidget *groupWidget = new EditGroupDialogWidget(group,
-								       tr("Please enter a new name for the <i>%0</i> group").arg(group.name()),
-								       Core::instance()->kaduWindow());
-	KaduDialog *window = new KaduDialog(groupWidget, Core::instance()->kaduWindow());
-	window->setAcceptButtonText(tr("Edit Group"));
-	window->exec();
-}
-
 void GroupTabBar::deleteGroup()
 {
 	QAction *action = qobject_cast<QAction *>(sender());
@@ -352,23 +350,21 @@ void GroupTabBar::deleteGroup()
 	if (!group)
 		return;
 
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"),
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")),
 						      tr("Delete group"),
 						      tr("Group <i>%0</i> will be deleted, but without buddies. Are you sure?").arg(group.name()),
-						      Core::instance()->kaduWindow());
+						      m_kaduWindowService->kaduWindow());
 	dialog->addButton(QMessageBox::Yes, tr("Delete group"));
 	dialog->addButton(QMessageBox::No, tr("Cancel"));
 
 	if (group && dialog->ask())
-		GroupManager::instance()->removeItem(group);
+		m_groupManager->removeItem(group);
 }
 
 void GroupTabBar::createNewGroup()
 {
-	AddGroupDialogWidget *groupWidget = new AddGroupDialogWidget(tr("Please enter the name for the new group"), Core::instance()->kaduWindow());
-	KaduDialog *window = new KaduDialog(groupWidget, Core::instance()->kaduWindow());
-	window->setAcceptButtonText(tr("Add Group"));
-	window->exec();
+	auto editWindow = m_injectedFactory->makeInjected<GroupEditWindow>(Group::null, m_kaduWindowService->kaduWindow());
+	editWindow->show();
 }
 
 void GroupTabBar::groupProperties()
@@ -377,9 +373,12 @@ void GroupTabBar::groupProperties()
 	if (!action)
 		return;
 
-	const Group &group = action->data().value<Group>();
-	if (group)
-		(new GroupPropertiesWindow(group, Core::instance()->kaduWindow()))->show();
+	auto group = action->data().value<Group>();
+	if (!group)
+		return;
+
+	auto editWindow = m_injectedFactory->makeInjected<GroupEditWindow>(group, m_kaduWindowService->kaduWindow());
+	editWindow->show();
 }
 
 void GroupTabBar::addToGroup()
@@ -402,7 +401,7 @@ void GroupTabBar::moveToGroup()
 	if (!action)
 		return;
 
-	const Group &removeFromGroup = GroupManager::instance()->byUuid(tabData(currentIndex()).toString());
+	const Group &removeFromGroup = m_groupManager->byUuid(tabData(currentIndex()).toString());
 	const Group &group = action->data().value<Group>();
 
 	foreach (const Buddy &buddy, DNDBuddies)
@@ -466,7 +465,7 @@ void GroupTabBar::updateTabData(int tabIndex, GroupFilter groupFilter)
 {
 	auto tabData = GroupFilterTabData(groupFilter);
 	setTabText(tabIndex, tabData.tabName());
-	setTabIcon(tabIndex, tabData.tabIcon());
+	setTabIcon(tabIndex, tabData.tabIcon(m_iconsManager));
 }
 
 #include "moc_group-tab-bar.cpp"
