@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,13 +20,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QInputDialog>
-#include <QtGui/QLineEdit>
-#include <QtGui/QSortFilterProxyModel>
+#include <QtCore/QSortFilterProxyModel>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QLineEdit>
 
 #include "buddies/group-manager.h"
 #include "buddies/model/groups-model.h"
+#include "core/core.h"
 #include "model/model-chain.h"
 #include "model/roles.h"
 
@@ -34,19 +35,32 @@
 
 GroupsComboBox::GroupsComboBox(QWidget *parent) :
 		ActionsComboBox(parent)
+{
+}
+
+GroupsComboBox::~GroupsComboBox()
+{
+}
+
+void GroupsComboBox::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
+}
+
+void GroupsComboBox::init()
 {
 	addBeforeAction(new QAction(tr(" - Do not add - "), this));
 
-	CreateNewGroupAction = new QAction(tr("Create a new group..."), this);
-	QFont createNewGroupActionFont = CreateNewGroupAction->font();
+	m_createNewGroupAction = new QAction(tr("Create a new group..."), this);
+	QFont createNewGroupActionFont = m_createNewGroupAction->font();
 	createNewGroupActionFont.setItalic(true);
-	CreateNewGroupAction->setFont(createNewGroupActionFont);
-	CreateNewGroupAction->setData(true);
-	connect(CreateNewGroupAction, SIGNAL(triggered()), this, SLOT(createNewGroup()));
-	addAfterAction(CreateNewGroupAction);
+	m_createNewGroupAction->setFont(createNewGroupActionFont);
+	m_createNewGroupAction->setData(true);
+	connect(m_createNewGroupAction, SIGNAL(triggered()), this, SLOT(createNewGroup()));
+	addAfterAction(m_createNewGroupAction);
 
 	ModelChain *chain = new ModelChain(this);
-	chain->setBaseModel(new GroupsModel(chain));
+	chain->setBaseModel(new GroupsModel(m_groupManager, chain));
 	QSortFilterProxyModel *proxyModel = new QSortFilterProxyModel(this);
 	chain->addProxyModel(proxyModel);
 	setUpModel(GroupRole, chain);
@@ -56,10 +70,6 @@ GroupsComboBox::GroupsComboBox(QWidget *parent) :
 	setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
 }
 
-GroupsComboBox::~GroupsComboBox()
-{
-}
-
 void GroupsComboBox::setCurrentGroup(Group group)
 {
 	setCurrentValue(group);
@@ -81,11 +91,11 @@ void GroupsComboBox::createNewGroup()
 	if (!ok)
 		return;
 
-	ok = GroupManager::instance()->acceptableGroupName(newGroupName, true);
+	ok = m_groupManager->acceptableGroupName(newGroupName, true);
 	if (!ok)
 		return;
 
-	Group newGroup = GroupManager::instance()->byName(newGroupName, ok);
+	Group newGroup = m_groupManager->byName(newGroupName, ok);
 	if (newGroup)
 		setCurrentGroup(newGroup);
 }
