@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,22 +19,42 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QInputDialog>
-#include <QtGui/QLineEdit>
+#include "identities-combo-box.h"
 
+#include "core/injected-factory.h"
 #include "gui/windows/message-dialog.h"
 #include "identities/identity-manager.h"
 #include "identities/model/identity-model.h"
 #include "model/model-chain.h"
 #include "model/roles.h"
 
-#include "identities-combo-box.h"
+#include <QtWidgets/QAction>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QLineEdit>
 
 IdentitiesComboBox::IdentitiesComboBox(QWidget *parent) :
 		ActionsComboBox(parent)
 {
-	IdentityManager::instance()->removeUnused();
+}
+
+IdentitiesComboBox::~IdentitiesComboBox()
+{
+	m_identityManager->removeUnused();
+}
+
+void IdentitiesComboBox::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void IdentitiesComboBox::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void IdentitiesComboBox::init()
+{
+	m_identityManager->removeUnused();
 
 	CreateNewIdentityAction = new QAction(tr("Create a new identity..."), this);
 	QFont createNewIdentityActionFont = CreateNewIdentityAction->font();
@@ -46,17 +65,12 @@ IdentitiesComboBox::IdentitiesComboBox(QWidget *parent) :
 	addAfterAction(CreateNewIdentityAction);
 
 	ModelChain *chain = new ModelChain(this);
-	chain->setBaseModel(new IdentityModel(chain));
+	chain->setBaseModel(m_injectedFactory->makeInjected<IdentityModel>(chain));
 	setUpModel(IdentityRole, chain);
 
 	setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
 }
 
-IdentitiesComboBox::~IdentitiesComboBox()
-{
-	IdentityManager::instance()->removeUnused();
-}
-
 void IdentitiesComboBox::setCurrentIdentity(Identity identity)
 {
 	setCurrentValue(identity);
@@ -78,7 +92,7 @@ void IdentitiesComboBox::createNewIdentity()
 	if (!ok)
 		return;
 
-	Identity newIdentity = IdentityManager::instance()->byName(identityName, true);
+	Identity newIdentity = m_identityManager->byName(identityName, true);
 	if (newIdentity)
 		setCurrentIdentity(newIdentity);
 }
