@@ -1,12 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,29 +20,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IDENTITIES_COMBO_BOX_H
-#define IDENTITIES_COMBO_BOX_H
+#pragma once
 
 #include "gui/widgets/actions-combo-box.h"
 #include "identities/identity.h"
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class IdentityManager;
+class InjectedFactory;
+
 class KADUAPI IdentitiesComboBox : public ActionsComboBox
 {
 	Q_OBJECT
 
-	QAction *CreateNewIdentityAction;
-
-private slots:
-	void createNewIdentity();
-
 public:
-	explicit IdentitiesComboBox(QWidget *parent = 0);
+	explicit IdentitiesComboBox(QWidget *parent = nullptr);
 	virtual ~IdentitiesComboBox();
 
 	void setCurrentIdentity(Identity identity);
 	Identity currentIdentity();
 
-};
+private:
+	QPointer<IdentityManager> m_identityManager;
+	QPointer<InjectedFactory> m_injectedFactory;
 
-#endif // IDENTITIES_COMBO_BOX_H
+	QAction *CreateNewIdentityAction;
+
+private slots:
+	INJEQT_SET void setIdentityManager(IdentityManager *identityManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
+	void createNewIdentity();
+
+};
