@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,9 +18,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAbstractItemView>
+#include <QtWidgets/QAbstractItemView>
 
 #include "accounts/account-manager.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/talkable-painter.h"
 #include "gui/widgets/talkable-tree-view.h"
 #include "identities/identity-manager.h"
@@ -29,29 +30,49 @@
 #include "kadu-tree-view-delegate.h"
 
 KaduTreeViewDelegate::KaduTreeViewDelegate(TalkableTreeView *parent) :
-		QItemDelegate(parent), Configuration(parent)
+		QItemDelegate(parent)
 {
-	// force initial signal/slot connection to happen
-	ShowIdentityNameIfMany = false;
-	setShowIdentityNameIfMany(true);
 }
 
 KaduTreeViewDelegate::~KaduTreeViewDelegate()
 {
 }
 
+void KaduTreeViewDelegate::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void KaduTreeViewDelegate::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void KaduTreeViewDelegate::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void KaduTreeViewDelegate::init()
+{
+	Configuration = m_injectedFactory->makeOwned<TalkableDelegateConfiguration>(static_cast<TalkableTreeView*>(parent()), this);
+	// force initial signal/slot connection to happen
+	ShowIdentityNameIfMany = false;
+	setShowIdentityNameIfMany(true);
+}
+
 void KaduTreeViewDelegate::updateShowIdentityName()
 {
 	if (!ShowIdentityNameIfMany)
 		return;
 
 	int activeIdentitiesCount = 0;
-	foreach (const Identity &identity, IdentityManager::instance()->items())
+	foreach (const Identity &identity, m_identityManager->items())
 		if (identity.hasAnyAccountWithDetails())
 			if (++activeIdentitiesCount > 1)
 				break;
 
-	Configuration.setShowIdentityName(activeIdentitiesCount > 1);
+	Configuration->setShowIdentityName(activeIdentitiesCount > 1);
 }
 
 void KaduTreeViewDelegate::setShowIdentityNameIfMany(bool showIdentityNameIfMany)
@@ -62,21 +83,21 @@ void KaduTreeViewDelegate::setShowIdentityNameIfMany(bool showIdentityNameIfMany
 	ShowIdentityNameIfMany = showIdentityNameIfMany;
 	if (ShowIdentityNameIfMany)
 	{
-		connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)), this, SLOT(updateShowIdentityName()));
-		connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)), this, SLOT(updateShowIdentityName()));
-		connect(AccountManager::instance(), SIGNAL(accountUpdated(Account)), this, SLOT(updateShowIdentityName()));
+		connect(m_accountManager, SIGNAL(accountRegistered(Account)), this, SLOT(updateShowIdentityName()));
+		connect(m_accountManager, SIGNAL(accountUnregistered(Account)), this, SLOT(updateShowIdentityName()));
+		connect(m_accountManager, SIGNAL(accountUpdated(Account)), this, SLOT(updateShowIdentityName()));
 		updateShowIdentityName();
 	}
 	else
 	{
-		disconnect(AccountManager::instance(), 0, this, 0);
-		Configuration.setShowIdentityName(false);
+		disconnect(m_accountManager, 0, this, 0);
+		Configuration->setShowIdentityName(false);
 	}
 }
 
 void KaduTreeViewDelegate::setUseConfigurationColors(bool use)
 {
-	Configuration.setUseConfigurationColors(use);
+	Configuration->setUseConfigurationColors(use);
 }
 
 QStyleOptionViewItemV4 KaduTreeViewDelegate::getOptions(const QModelIndex &index, const QStyleOptionViewItem &option) const
@@ -115,5 +136,4 @@ void KaduTreeViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
 	talkablePainter.paint(painter);
 }
 
-
 #include "moc_kadu-tree-view-delegate.cpp"
