@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,8 +24,10 @@
 #include <QtGui/QDrag>
 #include <QtGui/QKeyEvent>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/widgets/filtered-tree-view.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 
 #include "kadu-tree-view.h"
@@ -46,17 +46,35 @@ KaduTreeView::KaduTreeView(QWidget *parent) :
 	setSelectionMode(QAbstractItemView::ExtendedSelection);
 	setUniformRowHeights(false);
 	setWordWrap(true);
-
-	configurationUpdated();
 }
 
 KaduTreeView::~KaduTreeView()
 {
 }
 
+void KaduTreeView::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void KaduTreeView::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void KaduTreeView::init()
+{
+	configurationUpdated();
+}
+
+Configuration * KaduTreeView::configuration() const
+{
+	return m_configuration;
+}
+
 void KaduTreeView::configurationUpdated()
 {
-	bool showExpandingControl = config_file.readBoolEntry("Look", "ShowExpandingControl", false);
+	bool showExpandingControl = m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowExpandingControl", false);
 
 	if (rootIsDecorated() && !showExpandingControl)
 		collapseAll();
@@ -80,19 +98,19 @@ void KaduTreeView::updateBackground()
 	style.append("QTreeView::branch:has-siblings:!adjoins-item { border-image: none; image: none }");
 	style.append("QTreeView::branch:has-siblings:adjoins-item { border-image: none; image: none }");
 	style.append("QTreeView::branch:has-childres:!has-siblings:adjoins-item { border-image: none; image: none }");
-	if (config_file.readBoolEntry("Look", "AlignUserboxIconsTop"))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Look", "AlignUserboxIconsTop"))
 	{
 		style.append("QTreeView::branch:has-children:!has-siblings:closed, QTreeView::branch:closed:has-children:has-siblings "
-		     "{ border-image: none; image: url(" + KaduIcon("kadu_icons/stylesheet-branch-closed", "16x16").fullPath() + "); margin-top: 4px; image-position: top }");
+		     "{ border-image: none; image: url(" + m_iconsManager->iconPath(KaduIcon{"kadu_icons/stylesheet-branch-closed", "16x16"}) + "); margin-top: 4px; image-position: top }");
 		style.append("QTreeView::branch:open:has-children:!has-siblings, QTreeView::branch:open:has-children:has-siblings "
-			"{ border-image: none; image: url(" + KaduIcon("kadu_icons/stylesheet-branch-open", "16x16").fullPath() + "); image-position: top; margin-top: 8px }");
+			"{ border-image: none; image: url(" + m_iconsManager->iconPath(KaduIcon{"kadu_icons/stylesheet-branch-open", "16x16"}) + "); image-position: top; margin-top: 8px }");
 	}
 	else
 	{
  		style.append("QTreeView::branch:has-children:!has-siblings:closed, QTreeView::branch:closed:has-children:has-siblings "
-		     "{ border-image: none; image: url(" + KaduIcon("kadu_icons/stylesheet-branch-closed", "16x16").fullPath() + ") }");
+		     "{ border-image: none; image: url(" + m_iconsManager->iconPath(KaduIcon{"kadu_icons/stylesheet-branch-closed", "16x16"}) + ") }");
 		style.append("QTreeView::branch:open:has-children:!has-siblings, QTreeView::branch:open:has-children:has-siblings "
-			"{ border-image: none; image: url(" + KaduIcon("kadu_icons/stylesheet-branch-open", "16x16").fullPath() + ") }");
+			"{ border-image: none; image: url(" + m_iconsManager->iconPath(KaduIcon{"kadu_icons/stylesheet-branch-open", "16x16"}) + ") }");
 	}
 
 	style.append("QTreeView { background-color: transparent;");
