@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,14 +18,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KADU_TREE_VIEW_H
-#define KADU_TREE_VIEW_H
-
-#include <QtGui/QTreeView>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QTreeView>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+class IconsManager;
+
 class QTemporaryFile;
 
 class KADUAPI KaduTreeView : public QTreeView, ConfigurationAwareObject
@@ -46,28 +46,35 @@ public:
 		BackgroundStretched
 	};
 
-private:
-	QString BackgroundColor;
-	QString AlternateBackgroundColor;
-	BackgroundMode BackgroundImageMode;
-	QString BackgroundImageFile;
-	QTemporaryFile *BackgroundTemporaryFile;
-
-protected:
-	virtual void configurationUpdated();
-
-	virtual void keyPressEvent(QKeyEvent *event);
-	virtual void resizeEvent(QResizeEvent *event);
-	virtual void startDrag(Qt::DropActions supportedActions);
-
-public:
-	explicit KaduTreeView(QWidget *parent = 0);
+	explicit KaduTreeView(QWidget *parent = nullptr);
 	virtual ~KaduTreeView();
 
 	void setBackground(const QString& backgroundColor, const QString& alternateColor,
 	                   const QString& file = QString(), KaduTreeView::BackgroundMode mode = BackgroundNone);
 	void updateBackground();
 
-};
+protected:
+	Configuration * configuration() const;
 
-#endif // KADU_TREE_VIEW_H
+	virtual void configurationUpdated();
+
+	virtual void keyPressEvent(QKeyEvent *event);
+	virtual void resizeEvent(QResizeEvent *event);
+	virtual void startDrag(Qt::DropActions supportedActions);
+
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+
+	QString BackgroundColor;
+	QString AlternateBackgroundColor;
+	BackgroundMode BackgroundImageMode;
+	QString BackgroundImageFile;
+	QTemporaryFile *BackgroundTemporaryFile;
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_INIT void init();
+
+};
