@@ -1,14 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2008, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,12 +21,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KADU_TEXT_BROWSER_H
-#define KADU_TEXT_BROWSER_H
+#pragma once
 
 #include <QtCore/QPointer>
 #include <QtGui/QClipboard>
-#include <QtWebKit/QWebView>
+#include <QtWebKitWidgets/QWebView>
+#include <injeqt/injeqt.h>
 
 #include "exports.h"
 
@@ -38,13 +34,21 @@ class QPoint;
 class QTimer;
 class QUrl;
 
+class ClipboardHtmlTransformerService;
+class Configuration;
+class IconsManager;
 class ImageStorageService;
+class UrlHandlerManager;
 
 class KADUAPI KaduWebView : public QWebView
 {
 	Q_OBJECT
 
-	QPointer<ImageStorageService> CurrentImageStorageService;
+	QPointer<ClipboardHtmlTransformerService> m_clipboardHtmlTransformerService;
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<ImageStorageService> m_imageStorageService;
+	QPointer<UrlHandlerManager> m_urlHandlerManager;
 
 	bool DraggingPossible;
 	bool IsLoading;
@@ -52,9 +56,15 @@ class KADUAPI KaduWebView : public QWebView
 	QPoint DragStartPosition;
 	QTimer *RefreshTimer;
 
-	static void convertClipboardHtml(QClipboard::Mode mode);
+	void convertClipboardHtml(QClipboard::Mode mode) const;
 
 private slots:
+	INJEQT_SET void setClipboardHtmlTransformerService(ClipboardHtmlTransformerService *clipboardHtmlTransformerService);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setImageStorageService(ImageStorageService *imageStorageService);
+	INJEQT_SET void setUrlHandlerManager(UrlHandlerManager *urlHandlerManager);
+
 	void hyperlinkClicked(const QUrl &anchor) const;
 	void loadStarted();
 	void loadFinishedSlot(bool success);
@@ -67,24 +77,20 @@ private slots:
 #endif
 
 protected:
+	Configuration * configuration();
+
 	virtual void contextMenuEvent(QContextMenuEvent *e);
 	virtual void mouseMoveEvent(QMouseEvent *e);
 	virtual void mousePressEvent(QMouseEvent *e);
 	virtual void mouseReleaseEvent(QMouseEvent *e);
 
 public:
-	explicit KaduWebView(QWidget *parent = 0);
+	explicit KaduWebView(QWidget *parent = nullptr);
 	virtual ~KaduWebView();
 
-	void setImageStorageService(ImageStorageService *imageStorageService);
 	ImageStorageService * imageStorageService() const;
 
-	// hides QWebPage::setPage() (non-virtual)
-	void setPage(QWebPage *page);
-
 	void setUserFont(const QString &fontString, bool force);
 	QString userFontStyle(const QFont &font, bool force);
 
 };
-
-#endif
