@@ -1,11 +1,10 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Pełzowski (floss@pelzowski.eu)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,9 +22,10 @@
  */
 
 #include <QtGui/QMouseEvent>
-#include <QtGui/QStyle>
+#include <QtWidgets/QStyle>
 
 #include "gui/widgets/line-edit-clear-button.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 
 #include "line-edit-with-clear-button.h"
@@ -43,6 +43,11 @@ LineEditWithClearButton::~LineEditWithClearButton()
 {
 }
 
+void LineEditWithClearButton::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
 void LineEditWithClearButton::createClearButton()
 {
 	if (ClearButton)
@@ -69,9 +74,9 @@ void LineEditWithClearButton::updateClearButton()
 		return;
 
 	if (layoutDirection() == Qt::LeftToRight)
-		ClearButton->setPixmap(KaduIcon("edit-clear-locationbar-rtl").icon().pixmap(16, 16));
+		ClearButton->setPixmap(m_iconsManager->iconByPath(KaduIcon("edit-clear-locationbar-rtl")).pixmap(16, 16));
 	else
-		ClearButton->setPixmap(KaduIcon("edit-clear-locationbar-ltr").icon().pixmap(16, 16));
+		ClearButton->setPixmap(m_iconsManager->iconByPath(KaduIcon("edit-clear-locationbar-ltr")).pixmap(16, 16));
 
 	const QSize geom = size();
 	const int frameWidth = style()->pixelMetric(QStyle::PM_DefaultFrameWidth, 0, this);
