@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,15 +19,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QFileDialog>
-#include <QtGui/QGridLayout>
-#include <QtGui/QHBoxLayout>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLineEdit>
-#include <QtGui/QListWidget>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QListWidget>
 
 #include "configuration/config-file-variant-wrapper.h"
+#include "configuration/configuration.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "os/generic/window-geometry-manager.h"
 #include "debug.h"
@@ -68,14 +66,34 @@ void PathListEdit::setPathList(const QStringList &pathList)
 		Dialog->setPathList(PathList);
 }
 
-PathListEditWindow::PathListEditWindow(const QStringList &pathList, QWidget *parent)
-	: QWidget(parent)
+PathListEditWindow::PathListEditWindow(const QStringList &pathList, QWidget *parent) :
+		QWidget(parent), PathList{pathList}
 {
-	kdebugf();
-
 	setWindowTitle(tr("Select paths"));
 	setAttribute(Qt::WA_DeleteOnClose);
+}
 
+PathListEditWindow::~PathListEditWindow()
+{
+}
+
+void PathListEditWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void PathListEditWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void PathListEditWindow::init()
+{
+	createGui();
+}
+
+void PathListEditWindow::createGui()
+{
 	QGridLayout *Layout = new QGridLayout(this);
 	Layout->setMargin(5);
 	Layout->setSpacing(5);
@@ -83,10 +101,9 @@ PathListEditWindow::PathListEditWindow(const QStringList &pathList, QWidget *par
 	PathListWidget = new QListWidget(this);
 	Layout->addWidget(PathListWidget, 0, 0, 4, 1);
 
-
-	QPushButton *add = new QPushButton(KaduIcon("list-add").icon(), tr("Add"), this);
-	QPushButton *change = new QPushButton(KaduIcon("view-refresh").icon(), tr("Change"), this);
-	QPushButton *remove = new QPushButton(KaduIcon("list-remove").icon(), tr("Remove"), this);
+	QPushButton *add = new QPushButton(m_iconsManager->iconByPath(KaduIcon("list-add")), tr("Add"), this);
+	QPushButton *change = new QPushButton(m_iconsManager->iconByPath(KaduIcon("view-refresh")), tr("Change"), this);
+	QPushButton *remove = new QPushButton(m_iconsManager->iconByPath(KaduIcon("list-remove")), tr("Remove"), this);
 
 	Layout->addWidget(add, 0, 1);
 	Layout->addWidget(change, 1, 1);
@@ -114,13 +131,9 @@ PathListEditWindow::PathListEditWindow(const QStringList &pathList, QWidget *par
 	connect(ok, SIGNAL(clicked()), this, SLOT(okClicked()));
 	connect(cancel, SIGNAL(clicked()), this, SLOT(close()));
 
-	setPathList(pathList);
+	setPathList(PathList);
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "SelectPathDialogGeometry"), QRect(0, 50, 330, 330), this);
-}
-
-PathListEditWindow::~PathListEditWindow()
-{
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "SelectPathDialogGeometry"), QRect(0, 50, 330, 330), this);
 }
 
 void PathListEditWindow::setPathList(const QStringList &list)
