@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,13 +21,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QHBoxLayout>
+#include "preview.h"
 
-#include "core/core.h"
+#include "buddies/buddy-dummy-factory.h"
 #include "gui/widgets/kadu-web-view.h"
 #include "parser/parser.h"
 
-#include "preview.h"
+#include <QtWidgets/QHBoxLayout>
 
 #define PREVIEW_DEFAULT_HEIGHT 250
 
@@ -41,31 +41,41 @@ Preview::Preview(QWidget *parent) :
 	QHBoxLayout *layout = new QHBoxLayout(this);
 	layout->setContentsMargins(0, 0, 0, 0);
 
-	WebView = new KaduWebView(this);
-	layout->addWidget(WebView);
+	m_webView = new KaduWebView(this);
+	layout->addWidget(m_webView);
 
 	QPalette p = palette();
 	p.setBrush(QPalette::Base, Qt::transparent);
-	WebView->page()->setPalette(p);
-	WebView->setAttribute(Qt::WA_OpaquePaintEvent, false);
+	m_webView->page()->setPalette(p);
+	m_webView->setAttribute(Qt::WA_OpaquePaintEvent, false);
 }
 
 Preview::~Preview()
 {
 }
 
+void Preview::setBuddyDummyFactory(BuddyDummyFactory *buddyDummyFactory)
+{
+	m_buddyDummyFactory = buddyDummyFactory;
+}
+
+void Preview::setParser(Parser *parser)
+{
+	m_parser = parser;
+}
+
 KaduWebView * Preview::webView() const
 {
-	return WebView;
+	return m_webView;
 }
 
 void Preview::syntaxChanged(const QString &content)
 {
 	QString syntax = content;
-	QString text = Parser::parse(syntax, Talkable(Buddy::dummy()), ParserEscape::HtmlEscape);
+	QString text = m_parser->parse(syntax, Talkable(m_buddyDummyFactory->dummy()), ParserEscape::HtmlEscape);
 	emit needFixup(text);
 
-	WebView->setHtml(text);
+	m_webView->setHtml(text);
 }
 
 #include "moc_preview.cpp"
