@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,21 +20,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PREVIEW_H
-#define PREVIEW_H
+#pragma once
 
-#include <QtGui/QFrame>
+#include <QtCore/QPointer>
+#include <QtWidgets/QFrame>
+#include <injeqt/injeqt.h>
 
+class BuddyDummyFactory;
 class KaduWebView;
+class Parser;
 
 class Preview : public QFrame
 {
 	Q_OBJECT
 
-	KaduWebView *WebView;
-
 public:
-	explicit Preview(QWidget *parent = 0);
+	explicit Preview(QWidget *parent = nullptr);
 	virtual ~Preview();
 
 	KaduWebView * webView() const;
@@ -46,6 +46,14 @@ public slots:
 signals:
 	void needFixup(QString &syntax);
 
-};
+private:
+	QPointer<BuddyDummyFactory> m_buddyDummyFactory;
+	QPointer<Parser> m_parser;
 
-#endif // PREVIEW_H
+	KaduWebView *m_webView;
+
+private slots:
+	INJEQT_SET void setBuddyDummyFactory(BuddyDummyFactory *buddyDummyFactory);
+	INJEQT_SET void setParser(Parser *parser);
+
+};
