@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,31 +20,47 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
+#include "protocols-combo-box.h"
 
+#include "core/injected-factory.h"
 #include "model/model-chain.h"
 #include "model/roles.h"
 #include "protocols/model/protocols-model-proxy.h"
 #include "protocols/model/protocols-model.h"
+#include "protocols/protocols-manager.h"
 
-#include "protocols-combo-box.h"
+#include <QtWidgets/QAction>
 
 ProtocolsComboBox::ProtocolsComboBox(QWidget *parent) :
 		ActionsComboBox(parent)
 {
-	addBeforeAction(new QAction(tr(" - Select network - "), this), NotVisibleWithOneRowSourceModel);
-
-	ProxyModel = new ProtocolsModelProxy(this);
-	ModelChain *chain = new ModelChain(this);
-	chain->setBaseModel(new ProtocolsModel(chain));
-	chain->addProxyModel(ProxyModel);
-	setUpModel(ProtocolRole, chain);
 }
 
 ProtocolsComboBox::~ProtocolsComboBox()
 {
 }
 
+void ProtocolsComboBox::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ProtocolsComboBox::setProtocolsManager(ProtocolsManager *protocolsManager)
+{
+	m_protocolsManager = protocolsManager;
+}
+
+void ProtocolsComboBox::init()
+{
+	addBeforeAction(make_owned<QAction>(tr(" - Select network - "), this), NotVisibleWithOneRowSourceModel);
+
+	m_proxyModel = make_owned<ProtocolsModelProxy>(this);
+	auto chain = make_owned<ModelChain>(this);
+	chain->setBaseModel(m_injectedFactory->makeOwned<ProtocolsModel>(m_protocolsManager, chain));
+	chain->addProxyModel(m_proxyModel);
+	setUpModel(ProtocolRole, chain);
+}
+
 void ProtocolsComboBox::setCurrentProtocol(ProtocolFactory *protocol)
 {
 	setCurrentValue(QVariant::fromValue<ProtocolFactory *>(protocol));
@@ -57,12 +73,12 @@ ProtocolFactory * ProtocolsComboBox::currentProtocol()
 
 void ProtocolsComboBox::addFilter(AbstractProtocolFilter *filter)
 {
-	ProxyModel->addFilter(filter);
+	m_proxyModel->addFilter(filter);
 }
 
 void ProtocolsComboBox::removeFilter(AbstractProtocolFilter *filter)
 {
-	ProxyModel->removeFilter(filter);
+	m_proxyModel->removeFilter(filter);
 }
 
 #include "moc_protocols-combo-box.cpp"
