@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,59 +18,74 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
+#include "proxy-combo-box.h"
 
-#include "gui/windows/proxy-edit-window.h"
+#include "core/injected-factory.h"
+#include "gui/windows/proxy-edit-window-service.h"
 #include "model/model-chain.h"
 #include "model/roles.h"
 #include "network/proxy/model/network-proxy-model.h"
 #include "network/proxy/model/network-proxy-proxy-model.h"
 
-#include "proxy-combo-box.h"
+#include <QtWidgets/QAction>
 
 #define DEFAULT_PROXY_INDEX 1
 
 ProxyComboBox::ProxyComboBox(QWidget *parent) :
-		ActionsComboBox(parent), DefaultProxyAction(0)
+		ActionsComboBox{parent}
 {
-	addBeforeAction(new QAction(tr(" - No proxy - "), this));
-
-	ModelChain *chain = new ModelChain(this);
-	Model = new NetworkProxyModel(chain);
-	chain->setBaseModel(Model);
-	chain->addProxyModel(new NetworkProxyProxyModel(this));
-	setUpModel(NetworkProxyRole, chain);
-
-	EditProxyAction = new QAction(tr("Edit proxy configuration..."), this);
-	QFont editProxyActionFont = EditProxyAction->font();
-	editProxyActionFont.setItalic(true);
-	EditProxyAction->setFont(editProxyActionFont);
-	EditProxyAction->setData(true);
-	connect(EditProxyAction, SIGNAL(triggered()), this, SLOT(editProxy()));
-
-	addAfterAction(EditProxyAction);
 }
 
 ProxyComboBox::~ProxyComboBox()
 {
 }
 
+void ProxyComboBox::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ProxyComboBox::setProxyEditWindowService(ProxyEditWindowService *proxyEditWindowService)
+{
+	m_proxyEditWindowService = proxyEditWindowService;
+}
+
+void ProxyComboBox::init()
+{
+	addBeforeAction(make_owned<QAction>(tr(" - No proxy - "), this));
+
+	auto chain = make_owned<ModelChain>(this);
+	m_model = m_injectedFactory->makeOwned<NetworkProxyModel>(chain);
+	chain->setBaseModel(m_model);
+	chain->addProxyModel(make_owned<NetworkProxyProxyModel>(this));
+	setUpModel(NetworkProxyRole, chain);
+
+	m_editProxyAction = make_owned<QAction>(tr("Edit proxy configuration..."), this);
+	auto editProxyActionFont = m_editProxyAction->font();
+	editProxyActionFont.setItalic(true);
+	m_editProxyAction->setFont(editProxyActionFont);
+	m_editProxyAction->setData(true);
+	connect(m_editProxyAction, SIGNAL(triggered()), this, SLOT(editProxy()));
+
+	addAfterAction(m_editProxyAction);
+}
+
 void ProxyComboBox::enableDefaultProxyAction()
 {
-	DefaultProxyAction = new QAction(tr(" - Use Default Proxy - "), this);
-	DefaultProxyAction->setFont(QFont());
-	addBeforeAction(DefaultProxyAction);
+	m_defaultProxyAction = make_owned<QAction>(tr(" - Use Default Proxy - "), this);
+	m_defaultProxyAction->setFont(QFont());
+	addBeforeAction(m_defaultProxyAction);
 }
 
 void ProxyComboBox::selectDefaultProxy()
 {
-	if (DefaultProxyAction)
+	if (m_defaultProxyAction)
 		setCurrentIndex(DEFAULT_PROXY_INDEX);
 }
 
 bool ProxyComboBox::isDefaultProxySelected()
 {
-	if (DefaultProxyAction)
+	if (m_defaultProxyAction)
 		return DEFAULT_PROXY_INDEX == currentIndex();
 	else
 		return false;
@@ -88,7 +103,7 @@ NetworkProxy ProxyComboBox::currentProxy()
 
 void ProxyComboBox::editProxy()
 {
-	ProxyEditWindow::show();
+	m_proxyEditWindowService->show();
 }
 
 #include "moc_proxy-combo-box.cpp"
