@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,9 +20,8 @@
  */
 
 #include "chat/model/chat-data-extractor.h"
-#include "chat/recent-chat-manager.h"
+#include "chat/recent-chat-repository.h"
 #include "chat/type/chat-type-manager.h"
-#include "core/core.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/chat-widget/chat-widget-repository.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
@@ -35,26 +34,55 @@
 RecentChatsMenu::RecentChatsMenu(QWidget *parent) :
 		QMenu(parent)
 {
-	setIcon(KaduIcon("internet-group-chat").icon());
-	setTitle(tr("Recent chats"));
-
-	RecentChatsMenuNeedsUpdate = true;
-
-	connect(IconsManager::instance(), SIGNAL(themeChanged()), this, SLOT(iconThemeChanged()));
-	connect(Core::instance()->chatWidgetRepository(), SIGNAL(chatWidgetAdded(ChatWidget*)), this, SLOT(invalidate()));
-	connect(Core::instance()->chatWidgetRepository(), SIGNAL(chatWidgetRemoved(ChatWidget*)), this, SLOT(invalidate()));
-	connect(RecentChatManager::instance(), SIGNAL(recentChatAdded(Chat)), this, SLOT(invalidate()));
-	connect(RecentChatManager::instance(), SIGNAL(recentChatRemoved(Chat)), this, SLOT(invalidate()));
-	connect(this, SIGNAL(aboutToShow()), this, SLOT(update()));
 }
 
 RecentChatsMenu::~RecentChatsMenu()
 {
 }
 
+void RecentChatsMenu::setChatDataExtractor(ChatDataExtractor *chatDataExtractor)
+{
+	m_chatDataExtractor = chatDataExtractor;
+}
+
+void RecentChatsMenu::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
+void RecentChatsMenu::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
+{
+	m_chatWidgetRepository = chatWidgetRepository;
+}
+
+void RecentChatsMenu::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void RecentChatsMenu::setRecentChatRepository(RecentChatRepository *recentChatRepository)
+{
+	m_recentChatRepository = recentChatRepository;
+}
+
+void RecentChatsMenu::init()
+{
+	setIcon(m_iconsManager->iconByPath(KaduIcon("internet-group-chat")));
+	setTitle(tr("Recent chats"));
+
+	connect(m_iconsManager, SIGNAL(themeChanged()), this, SLOT(iconThemeChanged()));
+	connect(m_chatWidgetRepository, SIGNAL(chatWidgetAdded(ChatWidget*)), this, SLOT(invalidate()));
+	connect(m_chatWidgetRepository, SIGNAL(chatWidgetRemoved(ChatWidget*)), this, SLOT(invalidate()));
+	connect(m_recentChatRepository, SIGNAL(recentChatAdded(Chat)), this, SLOT(invalidate()));
+	connect(m_recentChatRepository, SIGNAL(recentChatRemoved(Chat)), this, SLOT(invalidate()));
+	connect(this, SIGNAL(aboutToShow()), this, SLOT(update()));
+
+	invalidate();
+}
+
 void RecentChatsMenu::invalidate()
 {
-	RecentChatsMenuNeedsUpdate = true;
+	m_recentChatsMenuNeedsUpdate = true;
 
 	checkIfListAvailable();
 }
@@ -62,8 +90,8 @@ void RecentChatsMenu::invalidate()
 void RecentChatsMenu::checkIfListAvailable()
 {
 	//check if all recent chats are opened -> disable button
-	foreach (const Chat &chat, RecentChatManager::instance()->recentChats())
-		if (!Core::instance()->chatWidgetRepository()->widgetForChat(chat))
+	for (auto const &chat : m_recentChatRepository)
+		if (!m_chatWidgetRepository->widgetForChat(chat))
 		{
 			emit chatsListAvailable(true);
 			return;
@@ -74,17 +102,17 @@ void RecentChatsMenu::checkIfListAvailable()
 
 void RecentChatsMenu::update()
 {
-	if (!RecentChatsMenuNeedsUpdate)
+	if (!m_recentChatsMenuNeedsUpdate)
 		return;
 
 	clear();
 
-	foreach (const Chat &chat, RecentChatManager::instance()->recentChats())
-		if (!Core::instance()->chatWidgetRepository()->widgetForChat(chat))
+	for (auto const &chat : m_recentChatRepository)
+		if (!m_chatWidgetRepository->widgetForChat(chat))
 		{
-			ChatType *type = ChatTypeManager::instance()->chatType(chat.type());
-			QAction *action = new QAction(type ? type->icon().icon() : QIcon(),
-			                              ChatDataExtractor::data(chat, Qt::DisplayRole).toString(),
+			ChatType *type = m_chatTypeManager->chatType(chat.type());
+			QAction *action = new QAction(type ? m_iconsManager->iconByPath(type->icon()) : QIcon(),
+			                              m_chatDataExtractor->data(chat, Qt::DisplayRole).toString(),
 			                              this);
 			action->setData(QVariant::fromValue<Chat>(chat));
 			this->addAction(action);
@@ -92,12 +120,12 @@ void RecentChatsMenu::update()
 
 	emit chatsListAvailable(!actions().isEmpty());
 
-	RecentChatsMenuNeedsUpdate = false;
+	m_recentChatsMenuNeedsUpdate = false;
 }
 
 void RecentChatsMenu::iconThemeChanged()
 {
-	setIcon(KaduIcon("internet-group-chat").icon());
+	setIcon(m_iconsManager->iconByPath(KaduIcon("internet-group-chat")));
 }
 
 #include "moc_recent-chats-menu.cpp"
