@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,17 +19,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QButtonGroup>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QPushButton>
-#include <QtGui/QScrollBar>
-#include <QtGui/QStackedWidget>
+#include "roster-widget.h"
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/filter-widget.h"
 #include "gui/widgets/filtered-tree-view.h"
-#include "gui/widgets/group-tab-bar/group-tab-bar.h"
 #include "gui/widgets/group-tab-bar/group-tab-bar-configurator.h"
+#include "gui/widgets/group-tab-bar/group-tab-bar.h"
 #include "gui/widgets/talkable-tree-view.h"
 #include "gui/windows/proxy-action-context.h"
 #include "model/model-chain.h"
@@ -39,21 +37,19 @@
 #include "talkable/filter/hide-temporary-talkable-filter.h"
 #include "talkable/filter/name-talkable-filter.h"
 #include "talkable/filter/unread-messages-talkable-filter.h"
-#include "talkable/model/talkable-model-factory.h"
+#include "talkable/model/talkable-model.h"
 #include "talkable/model/talkable-proxy-model.h"
+#include "status/status-container-manager.h"
 
-#include "roster-widget.h"
+#include <QtWidgets/QButtonGroup>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QScrollBar>
+#include <QtWidgets/QStackedWidget>
 
 RosterWidget::RosterWidget(QWidget *parent) :
 	QWidget(parent), CompositingEnabled(false)
 {
-	Context = new ProxyActionContext();
-	createGui();
-
-	Context->setForwardActionContext(TalkableTree->actionContext());
-	MyGroupFilter->setGroupFilter(GroupBar->groupFilter());
-
-	configurationUpdated();
 }
 
 RosterWidget::~RosterWidget()
@@ -64,17 +60,43 @@ RosterWidget::~RosterWidget()
 	Context = 0;
 }
 
+void RosterWidget::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void RosterWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void RosterWidget::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void RosterWidget::init()
+{
+	Context = new ProxyActionContext(m_statusContainerManager);
+	createGui();
+
+	Context->setForwardActionContext(TalkableTree->actionContext());
+	MyGroupFilter->setGroupFilter(GroupBar->groupFilter());
+
+	configurationUpdated();
+}
+
 void RosterWidget::createGui()
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
 	layout->setMargin(0);
 	layout->setSpacing(0);
 
-	GroupBar = new GroupTabBar(this);
+	GroupBar = m_injectedFactory->makeInjected<GroupTabBar>(this);
 	connect(GroupBar, SIGNAL(currentChanged(int)), this, SLOT(storeConfiguration()));
 	connect(GroupBar, SIGNAL(tabMoved(int,int)), this, SLOT(storeConfiguration()));
 
-	TabBarConfigurator.reset(new GroupTabBarConfigurator());
+	TabBarConfigurator.reset(m_injectedFactory->makeInjected<GroupTabBarConfigurator>());
 	TabBarConfigurator->setGroupTabBar(GroupBar);
 
 	createTalkableWidget(this);
@@ -90,12 +112,12 @@ void RosterWidget::createGui()
 
 void RosterWidget::configurationUpdated()
 {
-	QString bgColor = config_file.readColorEntry("Look","UserboxBgColor").name();
-	QString alternateBgColor = config_file.readColorEntry("Look","UserboxAlternateBgColor").name();
+	QString bgColor = m_configuration->deprecatedApi()->readColorEntry("Look","UserboxBgColor").name();
+	QString alternateBgColor = m_configuration->deprecatedApi()->readColorEntry("Look","UserboxAlternateBgColor").name();
 
-	if (CompositingEnabled && config_file.readBoolEntry("Look", "UserboxTransparency"))
+	if (CompositingEnabled && m_configuration->deprecatedApi()->readBoolEntry("Look", "UserboxTransparency"))
 	{
-		int alpha = config_file.readNumEntry("Look", "UserboxAlpha");
+		int alpha = m_configuration->deprecatedApi()->readNumEntry("Look", "UserboxAlpha");
 
 		QColor color(bgColor);
 		bgColor = QString("rgba(%1,%2,%3,%4)").arg(color.red()).arg(color.green()).arg(color.blue()).arg(alpha);
@@ -107,9 +129,9 @@ void RosterWidget::configurationUpdated()
 			alternateBgColor = QString("transparent");
 	}
 
-	if (config_file.readBoolEntry("Look", "UseUserboxBackground", true))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Look", "UseUserboxBackground", true))
 	{
-		QString typeName = config_file.readEntry("Look", "UserboxBackgroundDisplayStyle");
+		QString typeName = m_configuration->deprecatedApi()->readEntry("Look", "UserboxBackgroundDisplayStyle");
 
 		KaduTreeView::BackgroundMode type;
 		if (typeName == "Centered")
@@ -123,7 +145,7 @@ void RosterWidget::configurationUpdated()
 		else
 			type = KaduTreeView::BackgroundNone;
 
-		TalkableTree->setBackground(bgColor, alternateBgColor, config_file.readEntry("Look", "UserboxBackground"), type);
+		TalkableTree->setBackground(bgColor, alternateBgColor, m_configuration->deprecatedApi()->readEntry("Look", "UserboxBackground"), type);
 	}
 	else
 	{
@@ -141,7 +163,7 @@ void RosterWidget::storeConfiguration()
 
 void RosterWidget::compositingEnabled()
 {
-	if (!config_file.readBoolEntry("Look", "UserboxTransparency"))
+	if (!m_configuration->deprecatedApi()->readBoolEntry("Look", "UserboxTransparency"))
 	{
 		compositingDisabled();
 		return;
@@ -178,10 +200,10 @@ void RosterWidget::compositingDisabled()
 
 ModelChain * RosterWidget::createModelChain()
 {
-	ModelChain *chain = new ModelChain(TalkableTree);
-	chain->setBaseModel(TalkableModelFactory::createInstance(chain));
+	auto chain = new ModelChain(TalkableTree);
+	chain->setBaseModel(m_injectedFactory->makeInjected<TalkableModel>(chain));
 
-	ProxyModel = new TalkableProxyModel(chain);
+	ProxyModel = m_injectedFactory->makeInjected<TalkableProxyModel>(chain);
 	ProxyModel->addFilter(new HideContactChatsTalkableFilter(ProxyModel));
 	ProxyModel->addFilter(new HideTemporaryTalkableFilter(ProxyModel));
 	ProxyModel->addFilter(new UnreadMessagesTalkableFilter(ProxyModel));
@@ -202,9 +224,9 @@ ModelChain * RosterWidget::createModelChain()
 
 void RosterWidget::createTalkableWidget(QWidget *parent)
 {
-	TalkableWidget = new FilteredTreeView(FilteredTreeView::FilterAtTop, parent);
+	TalkableWidget = m_injectedFactory->makeInjected<FilteredTreeView>(FilteredTreeView::FilterAtTop, parent);
 
-	TalkableTree = new TalkableTreeView(TalkableWidget);
+	TalkableTree = m_injectedFactory->makeInjected<TalkableTreeView>(TalkableWidget);
 	TalkableTree->setUseConfigurationColors(true);
 	TalkableTree->setContextMenuEnabled(true);
 	TalkableTree->setChain(createModelChain());
