@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 #define SEARCH_BAR_H
 
 #include <QtCore/QPointer>
-#include <QtGui/QToolBar>
+#include <QtWidgets/QToolBar>
 
 #include "exports.h"
 
@@ -76,7 +76,7 @@ public:
 	 * SearchBar is hidden by default. Use show() to make it visible or set up search widget to allow use show it by using Ctrl+F
 	 * shortcut.
 	 */
-	explicit SearchBar(QWidget *parent = 0);
+	explicit SearchBar(QWidget *parent = nullptr);
 	virtual ~SearchBar();
 
 	/**
