@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Zamazal Jiri (zamazal.jiri@gmail.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,11 +20,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QFileDialog>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QToolButton>
 
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "misc/misc.h"
 
@@ -35,35 +34,46 @@
 SelectFile::SelectFile(const QString &type, QWidget *parent)
 	: QWidget(parent), Type(type)
 {
-	QHBoxLayout *layout = new QHBoxLayout;
-
-	LineEdit = new QLineEdit(this);
-	connect(LineEdit, SIGNAL(editingFinished()), this, SLOT(fileEdited()));
-
-	QPushButton *selectFile = new QPushButton(KaduIcon("document-open").icon(), QString(), this);
-	connect(selectFile, SIGNAL(clicked()), this, SLOT(selectFileClicked()));
-
-	layout->addWidget(LineEdit);
-	layout->addWidget(selectFile);
-
-	setLayout(layout);
 }
 
 SelectFile::SelectFile(QWidget *parent)
 	: QWidget(parent)
+{
+}
+
+SelectFile::~SelectFile()
+{
+}
+
+void SelectFile::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void SelectFile::init()
+{
+	createGui();
+}
+
+void SelectFile::createGui()
 {
 	QHBoxLayout *layout = new QHBoxLayout;
 
 	LineEdit = new QLineEdit(this);
 	connect(LineEdit, SIGNAL(editingFinished()), this, SLOT(fileEdited()));
 
-	QPushButton *selectFile = new QPushButton(KaduIcon("document-open").icon(), QString(), this);
+	QToolButton *selectFile = new QToolButton(this);
+	selectFile->setAutoRaise(true);
+	selectFile->setIcon(m_iconsManager->iconByPath(KaduIcon("document-open")));
+	selectFile->setIconSize(QSize{14, 14});
 	connect(selectFile, SIGNAL(clicked()), this, SLOT(selectFileClicked()));
 
 	layout->addWidget(LineEdit);
 	layout->addWidget(selectFile);
 
 	setLayout(layout);
+	layout->setMargin(0);
+	layout->setSpacing(0);
 }
 
 void SelectFile::selectFileClicked()
