@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,15 +17,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SELECT_TALKABLE_COMBO_BOX_H
-#define SELECT_TALKABLE_COMBO_BOX_H
+#pragma once
 
 #include "talkable/talkable.h"
 #include "exports.h"
 
 #include "gui/widgets/actions-combo-box.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class HideAnonymousTalkableFilter;
+class InjectedFactory;
 class ModelChain;
 class SelectTalkablePopup;
 class TalkableFilter;
@@ -40,17 +38,25 @@ class KADUAPI SelectTalkableComboBox : public ActionsComboBox
 {
 	Q_OBJECT
 
+	QPointer<InjectedFactory> m_injectedFactory;
+
 	HideAnonymousTalkableFilter *HideAnonymousFilter;
 	ModelChain *Chain;
 	SelectTalkablePopup *Popup;
 	TalkableProxyModel *ProxyModel;
 
+private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
 protected:
+	InjectedFactory * injectedFactory() const;
+
 	virtual void showPopup();
 	virtual void hidePopup();
 
 public:
-	explicit SelectTalkableComboBox(QWidget *parent = 0);
+	explicit SelectTalkableComboBox(QWidget *parent = nullptr);
 	virtual ~SelectTalkableComboBox();
 
 	void setBaseModel(QAbstractItemModel *model);
@@ -65,5 +71,3 @@ public slots:
 	void setCurrentTalkable(const Talkable &talkable);
 
 };
-
-#endif // SELECT_TALKABLE_COMBO_BOX_H
