@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +19,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QLineEdit>
+#include "select-talkable-popup.h"
 
+#include "core/injected-factory.h"
 #include "gui/widgets/filter-widget.h"
 #include "gui/widgets/talkable-tree-view.h"
 #include "model/model-chain.h"
@@ -31,20 +30,27 @@
 #include "talkable/filter/name-talkable-filter.h"
 #include "talkable/model/talkable-proxy-model.h"
 
-#include "select-talkable-popup.h"
+#include <QtWidgets/QLineEdit>
 
 SelectTalkablePopup::SelectTalkablePopup(QWidget *parent) :
 		FilteredTreeView(FilterAtBottom, parent, Qt::Popup)
 {
 	setAttribute(Qt::WA_WindowPropagation);
 	setAttribute(Qt::WA_X11NetWmWindowTypeCombo);
+}
 
-	View = new TalkableTreeView(this);
+SelectTalkablePopup::~SelectTalkablePopup()
+{
+}
+
+void SelectTalkablePopup::init()
+{
+	View = injectedFactory()->makeInjected<TalkableTreeView>(this);
 	setView(View);
 
 	Chain = new ModelChain(this);
 
-	ProxyModel = new TalkableProxyModel(Chain);
+	ProxyModel = injectedFactory()->makeInjected<TalkableProxyModel>(Chain);
 	ProxyModel->setSortByStatusAndUnreadMessages(false);
 
 	HideAnonymousFilter = new HideAnonymousTalkableFilter(ProxyModel);
@@ -66,10 +72,6 @@ SelectTalkablePopup::SelectTalkablePopup(QWidget *parent) :
 	View->setSelectionMode(QAbstractItemView::SingleSelection);
 }
 
-SelectTalkablePopup::~SelectTalkablePopup()
-{
-}
-
 QSize SelectTalkablePopup::sizeHint() const
 {
 	QSize newSizeHint = FilteredTreeView::sizeHint();
