@@ -1,13 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,25 +23,58 @@
 
 #include <QtCore/QEvent>
 #include <QtCore/QTimer>
-#include <QtGui/QMenu>
 #include <QtGui/QTextDocument>
-#include <QtGui/QWidgetAction>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QWidgetAction>
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "configuration/main-configuration-holder.h"
+#include "core/injected-factory.h"
 #include "gui/status-icon.h"
 #include "gui/widgets/status-menu.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "protocols/protocol.h"
+#include "status/status-configuration-holder.h"
 #include "status/status-container.h"
+#include "status/status-type-data.h"
+#include "status/status-type-manager.h"
+
 
 #include "status-button.h"
 
 StatusButton::StatusButton(StatusContainer *statusContainer, QWidget *parent) :
 		QToolButton(parent), MyStatusContainer(statusContainer), DisplayStatusName(false), MenuTitleAction{nullptr}
 {
-	Icon = new StatusIcon(MyStatusContainer, this);
+}
+
+StatusButton::~StatusButton()
+{
+}
+
+void StatusButton::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void StatusButton::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void StatusButton::setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder)
+{
+	m_statusConfigurationHolder = statusConfigurationHolder;
+}
+
+void StatusButton::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void StatusButton::init()
+{
+	Icon = m_injectedFactory->makeInjected<StatusIcon>(MyStatusContainer, this);
 
 	createGui();
 	setPopupMode(InstantPopup);
@@ -54,19 +84,15 @@ StatusButton::StatusButton(StatusContainer *statusContainer, QWidget *parent) :
 	connect(Icon, SIGNAL(iconUpdated(KaduIcon)), this, SLOT(iconUpdated(KaduIcon)));
 }
 
-StatusButton::~StatusButton()
-{
-}
-
 void StatusButton::createGui()
 {
 	QMenu *menu = new QMenu(this);
 	if (!MyStatusContainer->statusContainerName().isEmpty())
 		addTitleToMenu(MyStatusContainer->statusContainerName(), menu);
-	new StatusMenu(MyStatusContainer, false, menu);
+	m_injectedFactory->makeInjected<StatusMenu>(MyStatusContainer, false, menu);
 
 	setMenu(menu);
-	setIcon(Icon->icon().icon());
+	setIcon(m_iconsManager->iconByPath(Icon->icon()));
 }
 
 void StatusButton::addTitleToMenu(const QString &title, QMenu *menu)
@@ -77,7 +103,7 @@ void StatusButton::addTitleToMenu(const QString &title, QMenu *menu)
 
 	MenuTitleAction->setFont(font);
 	MenuTitleAction->setText(title);
-	MenuTitleAction->setIcon(MyStatusContainer->statusIcon().icon());
+	MenuTitleAction->setIcon(m_iconsManager->iconByPath(MyStatusContainer->statusIcon()));
 
 	QWidgetAction *action = new QWidgetAction(this);
 	action->setObjectName("status_menu_title");
@@ -110,11 +136,11 @@ void StatusButton::updateStatus()
 	if (DisplayStatusName)
 	{
 		setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-		setText(MyStatusContainer->status().displayName());
+		setText(m_statusTypeManager->statusTypeData(MyStatusContainer->status().type()).displayName());
 	}
 	else
 	{
-		if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
+		if (m_statusConfigurationHolder->isSetStatusPerIdentity())
 		{
 			setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 			setText(MyStatusContainer->statusContainerName());
@@ -134,7 +160,7 @@ void StatusButton::updateStatus()
 
 	tooltip +=
 		QString("<tr><td align='right' style='font-weight:bold; white-space:nowrap;'>%1:</td><td style='white-space:nowrap;'>%2</td></tr>")
-			.arg(tr("Status"), MyStatusContainer->status().displayName());
+			.arg(tr("Status"), m_statusTypeManager->statusTypeData(MyStatusContainer->status().type()).displayName());
 	tooltip
 		+= QString("<tr><td align='right' style='font-weight:bold; white-space:nowrap;'>%1:</td><td>%2</td></tr>")
 			.arg(tr("Description"), prepareDescription(MyStatusContainer->status().description()));
@@ -167,9 +193,9 @@ void StatusButton::setDisplayStatusName(bool displayStatusName)
 
 void StatusButton::iconUpdated(const KaduIcon &icon)
 {
-	setIcon(icon.icon());
+	setIcon(m_iconsManager->iconByPath(icon));
 	if (MenuTitleAction)
-		MenuTitleAction->setIcon(icon.icon());
+		MenuTitleAction->setIcon(m_iconsManager->iconByPath(icon));
 }
 
 QString StatusButton::prepareDescription(const QString &description) const
@@ -179,7 +205,7 @@ QString StatusButton::prepareDescription(const QString &description) const
 	QString colorString = QString("rgba(%1,%2,%3,%4)").arg(color.red()).arg(color.green()).arg(color.blue()).arg(color.alpha());
 
 	QString html = Qt::escape(description);
-	html.replace('\n', QString(QLatin1String("<span style='color:%1;'> ") + QChar(0x21B5) + QLatin1String("</span><br />")).arg(colorString));
+	html.replace('\n', QString(QStringLiteral("<span style='color:%1;'> ") + QChar(0x21B5) + QStringLiteral("</span><br />")).arg(colorString));
 
 	return html;
 }
