@@ -3,8 +3,8 @@
  * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,8 +22,9 @@
  */
 
 #include "accounts/account-manager.h"
-#include "configuration/main-configuration-holder.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/status-button.h"
+#include "status/status-configuration-holder.h"
 #include "status/status-container-manager.h"
 
 #include "status-buttons.h"
@@ -31,18 +32,37 @@
 StatusButtons::StatusButtons(QWidget *parent) :
 		QToolBar(parent)//, Layout(0), HasStretch(0)
 {
-	setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-
-	triggerAllStatusContainerRegistered();
 }
 
 StatusButtons::~StatusButtons()
 {
 }
 
+void StatusButtons::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void StatusButtons::setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder)
+{
+	m_statusConfigurationHolder = statusConfigurationHolder;
+}
+
+void StatusButtons::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void StatusButtons::init()
+{
+	setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
+
+	triggerAllStatusContainerRegistered(m_statusContainerManager);
+}
+
 void StatusButtons::enableStatusName()
 {
-	if (MainConfigurationHolder::instance()->setStatusMode() != SetStatusPerAccount && 1 == Buttons.count())
+	if (m_statusConfigurationHolder->setStatusMode() != SetStatusPerAccount && 1 == Buttons.count())
 		Buttons.begin().value()->setDisplayStatusName(true);
 }
 
@@ -59,7 +79,7 @@ void StatusButtons::statusContainerRegistered(StatusContainer *statusContainer)
 
 	disableStatusName();
 
-	StatusButton *button = new StatusButton(statusContainer);
+	StatusButton *button = m_injectedFactory->makeInjected<StatusButton>(statusContainer);
 	addWidget(button);
 	Buttons[statusContainer] = button;
 
