@@ -1,11 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,26 +22,54 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QActionGroup>
-#include <QtGui/QMenu>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QActionGroup>
+#include <QtWidgets/QMenu>
 
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/window-manager.h"
+#include "gui/windows/status-window-service.h"
 #include "gui/windows/status-window.h"
 #include "protocols/protocol.h"
 #include "status/status-actions.h"
 #include "status/status-container.h"
 #include "status/status-setter.h"
-#include "status/status-type-manager.h"
 #include "status/status-type.h"
 
 #include "status-menu.h"
 
 StatusMenu::StatusMenu(StatusContainer *statusContainer, bool includePrefix, QMenu *menu) :
-		QObject(menu), Menu(menu), Container(statusContainer)
+		QObject(menu), Menu(menu), Container(statusContainer), m_includePrefix{includePrefix}
 {
-	Actions = new StatusActions(statusContainer, includePrefix, this);
+}
+
+StatusMenu::~StatusMenu()
+{
+}
+
+void StatusMenu::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void StatusMenu::setStatusSetter(StatusSetter *statusSetter)
+{
+	m_statusSetter = statusSetter;
+}
+
+void StatusMenu::setStatusWindowService(StatusWindowService *statusWindowService)
+{
+	m_statusWindowService = statusWindowService;
+}
+
+void StatusMenu::setWindowManager(WindowManager *windowManager)
+{
+	m_windowManager = windowManager;
+}
+
+void StatusMenu::init()
+{
+	Actions = m_injectedFactory->makeInjected<StatusActions>(Container, m_includePrefix, false, this);
 
 	connect(Actions, SIGNAL(statusActionsRecreated()), this, SLOT(addStatusActions()));
 	connect(Actions, SIGNAL(statusActionsRecreated()), this, SIGNAL(menuRecreated()));
@@ -53,10 +81,6 @@ StatusMenu::StatusMenu(StatusContainer *statusContainer, bool includePrefix, QMe
 	addStatusActions();
 }
 
-StatusMenu::~StatusMenu()
-{
-}
-
 void StatusMenu::addStatusActions()
 {
 	foreach (QAction *action, Actions->actions())
@@ -72,20 +96,20 @@ void StatusMenu::changeStatus(QAction *action)
 {
 	StatusType statusType = action->data().value<StatusType>();
 
-	foreach (StatusContainer *container, Container->subStatusContainers())
+	for (auto &&container : Container->subStatusContainers())
 	{
-		Status status(StatusSetter::instance()->manuallySetStatus(container));
+		Status status(m_statusSetter->manuallySetStatus(container));
 		status.setType(statusType);
 
-		StatusSetter::instance()->setStatus(container, status);
+		m_statusSetter->setStatusManually(container, status);
 		container->storeStatus(status);
 	}
 }
 
 void StatusMenu::changeDescription()
 {
-	QWidget *statusWindow = StatusWindow::showDialog(Container, Menu);
-	WindowManager::instance()->moveToPosition(statusWindow, MousePositionBeforeMenuHide);
+	auto statusWindow = m_statusWindowService->showDialog(Container, Menu);
+	m_windowManager->moveToPosition(statusWindow, MousePositionBeforeMenuHide);
 }
 
 #include "moc_status-menu.cpp"
