@@ -3,8 +3,8 @@
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,11 +21,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STATUS_MENU_H
-#define STATUS_MENU_H
+#pragma once
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtCore/QPoint>
+#include <injeqt/injeqt.h>
 
 #include "exports.h"
 
@@ -33,21 +34,37 @@ class QAction;
 class QActionGroup;
 class QMenu;
 
+class InjectedFactory;
 class StatusActions;
 class StatusContainer;
+class StatusSetter;
+class StatusWindowService;
+class WindowManager;
 
 class KADUAPI StatusMenu : public QObject
 {
 	Q_OBJECT
 
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<StatusSetter> m_statusSetter;
+	QPointer<StatusWindowService> m_statusWindowService;
+	QPointer<WindowManager> m_windowManager;
+
 	QMenu *Menu;
 	StatusActions *Actions;
 
 	QPoint MousePositionBeforeMenuHide;
 
 	StatusContainer *Container;
+	bool m_includePrefix;
 
 private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setStatusSetter(StatusSetter *statusSetter);
+	INJEQT_SET void setStatusWindowService(StatusWindowService *statusWindowService);
+	INJEQT_SET void setWindowManager(WindowManager *windowManager);
+	INJEQT_INIT void init();
+
 	void addStatusActions();
 	void aboutToHide();
 	void changeStatus(QAction *action);
@@ -61,5 +78,3 @@ signals:
 	void menuRecreated();
 
 };
-
-#endif // STATUS_MENU_H
