@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,12 +22,13 @@
 
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
-#include <QtGui/QComboBox>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QPushButton>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QPushButton>
 
+#include "core/injected-factory.h"
 #include "gui/windows/message-dialog.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 #include "misc/syntax-list.h"
 
 #include "syntax-editor.h"
@@ -47,6 +48,16 @@ SyntaxEditor::~SyntaxEditor()
 {
 }
 
+void SyntaxEditor::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void SyntaxEditor::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
 void SyntaxEditor::setCurrentSyntax(const QString &syntax)
 {
 	syntaxListCombo->setCurrentIndex(syntaxListCombo->findText(syntax));
@@ -86,9 +97,9 @@ void SyntaxEditor::syntaxChangedSlot(const QString &newSyntax)
 
 	SyntaxInfo info = (*syntaxList)[newSyntax];
 	if (info.global)
-		fileName = KaduPaths::instance()->dataPath() + QLatin1String("syntax/") + category.toLower() + '/' + newSyntax + QLatin1String(".syntax");
+		fileName = m_pathsProvider->dataPath() + QStringLiteral("syntax/") + category.toLower() + '/' + newSyntax + QStringLiteral(".syntax");
 	else
-		fileName = KaduPaths::instance()->profilePath() + QLatin1String("syntax/") + category.toLower() + '/' + newSyntax + QLatin1String(".syntax");
+		fileName = m_pathsProvider->profilePath() + QStringLiteral("syntax/") + category.toLower() + '/' + newSyntax + QStringLiteral(".syntax");
 
 	file.setFileName(fileName);
 	if (!file.open(QIODevice::ReadOnly))
@@ -104,7 +115,7 @@ void SyntaxEditor::syntaxChangedSlot(const QString &newSyntax)
 
 void SyntaxEditor::updateSyntaxList()
 {
-	syntaxList = QSharedPointer<SyntaxList>(new SyntaxList(category.toLower()));
+	syntaxList = QSharedPointer<SyntaxList>(m_injectedFactory->makeInjected<SyntaxList>(category.toLower()));
 
 	syntaxListCombo->clear();
 	syntaxListCombo->addItems(syntaxList->keys());
