@@ -1,16 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2009, 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2009 Longer (longer89@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,22 +23,21 @@
 #include <QtCore/QModelIndex>
 #include <QtCore/QScopedPointer>
 #include <QtCore/QTemporaryFile>
-#include <QtGui/QApplication>
 #include <QtGui/QContextMenuEvent>
 #include <QtGui/QImage>
-#include <QtGui/QMenu>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account.h"
-#include "buddies/buddy-list-mime-data-helper.h"
 #include "buddies/buddy-list.h"
 #include "buddies/buddy-manager.h"
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy-set.h"
 #include "buddies/buddy.h"
 #include "chat/chat-manager.h"
-#include "configuration/configuration-file.h"
-#include "configuration/main-configuration-holder.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/injected-factory.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/actions/base-action-context.h"
@@ -57,8 +48,9 @@
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/filtered-tree-view.h"
 #include "gui/widgets/talkable-delegate.h"
-#include "gui/widgets/tool-tip-class-manager.h"
+#include "gui/widgets/tool-tip-manager.h"
 #include "gui/windows/kadu-window-actions.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity.h"
@@ -70,6 +62,7 @@
 #include "protocols/protocol-menu-manager.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
+#include "status/status-configuration-holder.h"
 #include "status/status-container-manager.h"
 
 #include "talkable-tree-view.h"
@@ -77,10 +70,52 @@
 TalkableTreeView::TalkableTreeView(QWidget *parent) :
 		KaduTreeView(parent), Delegate(0), Chain(0), ContextMenuEnabled(false)
 {
-	Context = new BaseActionContext();
-	connect(MainConfigurationHolder::instance(), SIGNAL(setStatusModeChanged()), this, SLOT(updateContext()));
+}
 
-	Delegate = new TalkableDelegate(this);
+TalkableTreeView::~TalkableTreeView()
+{
+	disconnect(m_statusConfigurationHolder, 0, this, 0);
+
+	delete Context;
+	Context = 0;
+}
+
+void TalkableTreeView::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void TalkableTreeView::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void TalkableTreeView::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void TalkableTreeView::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void TalkableTreeView::setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder)
+{
+	m_statusConfigurationHolder = statusConfigurationHolder;
+}
+
+void TalkableTreeView::setToolTipManager(ToolTipManager *toolTipManager)
+{
+	m_toolTipManager = toolTipManager;
+}
+
+void TalkableTreeView::init()
+{
+	Context = new BaseActionContext{this};
+	connect(m_statusConfigurationHolder, SIGNAL(setStatusModeChanged()), this, SLOT(updateContext()));
+
+	Delegate = m_injectedFactory->makeInjected<TalkableDelegate>(this);
 	setItemDelegate(Delegate);
 
 	ToolTipTimeoutTimer.setSingleShot(true);
@@ -91,14 +126,6 @@ TalkableTreeView::TalkableTreeView(QWidget *parent) :
 	updateContext();
 }
 
-TalkableTreeView::~TalkableTreeView()
-{
-	disconnect(MainConfigurationHolder::instance(), 0, this, 0);
-
-	delete Context;
-	Context = 0;
-}
-
 void TalkableTreeView::setChain(ModelChain *chain)
 {
 	Chain = chain;
@@ -132,7 +159,7 @@ void TalkableTreeView::setUseConfigurationColors(bool use)
 	Delegate->setUseConfigurationColors(use);
 }
 
-TalkableDelegateConfiguration & TalkableTreeView::delegateConfiguration()
+TalkableDelegateConfiguration * TalkableTreeView::delegateConfiguration()
 {
 	return Delegate->configuration();
 }
@@ -175,18 +202,18 @@ void TalkableTreeView::contextMenuEvent(QContextMenuEvent *event)
 		return;
 
 	QScopedPointer<QMenu> menu(new QMenu());
-	MenuInventory::instance()->menu("buddy-list")->attachToMenu(menu.data());
-	MenuInventory::instance()->menu("buddy-list")->applyTo(menu.data(), Context);
+	m_menuInventory->menu("buddy-list")->attachToMenu(menu.data());
+	m_menuInventory->menu("buddy-list")->applyTo(menu.data(), Context);
 	menu->exec(event->globalPos());
 }
 
 void TalkableTreeView::keyPressEvent(QKeyEvent *event)
 {
 	// TODO 0.10.0: add proper shortcuts handling
-	if (HotKey::shortCut(event, "ShortCuts", "kadu_deleteuser"))
-		Core::instance()->kaduWindow()->kaduWindowActions()->deleteTalkable()->trigger(Context);
-	else if (HotKey::shortCut(event, "ShortCuts", "kadu_persinfo"))
-		Core::instance()->kaduWindow()->kaduWindowActions()->editTalkable()->trigger(Context);
+	if (HotKey::shortCut(configuration(), event, "ShortCuts", "kadu_deleteuser"))
+		m_kaduWindowService->kaduWindow()->kaduWindowActions()->deleteTalkable()->trigger(Context);
+	else if (HotKey::shortCut(configuration(), event, "ShortCuts", "kadu_persinfo"))
+		m_kaduWindowService->kaduWindow()->kaduWindowActions()->editTalkable()->trigger(Context);
 	else
 	{
 		switch (event->key())
@@ -245,12 +272,12 @@ void TalkableTreeView::mouseMoveEvent(QMouseEvent *event)
 
 StatusContainer * TalkableTreeView::statusContainerForChat(const Chat &chat) const
 {
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
-		return chat.chatAccount().accountIdentity().data();
-	else if (MainConfigurationHolder::instance()->isSetStatusPerAccount())
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity())
+		return chat.chatAccount().accountIdentity().statusContainer();
+	else if (m_statusConfigurationHolder->isSetStatusPerAccount())
 		return chat.chatAccount().statusContainer();
 	else
-		return StatusContainerManager::instance();
+		return m_statusContainerManager;
 }
 
 void TalkableTreeView::setCurrentTalkable(const Talkable &talkable)
@@ -267,15 +294,15 @@ void TalkableTreeView::updateContext()
 	// cuurent index is part of context
 	setCurrentTalkable(talkableAt(currentIndex()));
 
-	ModelIndexListConverter converter(selectedIndexes());
+	auto converter = m_injectedFactory->makeNotOwned<ModelIndexListConverter>(selectedIndexes());
 
 	ChangeNotifierLock lock(Context->changeNotifier());
 
-	Context->setRoles(converter.roles());
-	Context->setBuddies(converter.buddies());
-	Context->setContacts(converter.contacts());
-	Context->setChat(converter.chat());
-	Context->setStatusContainer(statusContainerForChat(converter.chat()));
+	Context->setRoles(converter->roles());
+	Context->setBuddies(converter->buddies());
+	Context->setContacts(converter->contacts());
+	Context->setChat(converter->chat());
+	Context->setStatusContainer(statusContainerForChat(converter->chat()));
 }
 
 ActionContext * TalkableTreeView::actionContext()
@@ -295,7 +322,7 @@ void TalkableTreeView::toolTipTimeout()
 {
 	if (Talkable::ItemNone != ToolTipItem.type())
 	{
-		ToolTipClassManager::instance()->showToolTip(QCursor::pos(), ToolTipItem);
+		m_toolTipManager->showToolTip(QCursor::pos(), ToolTipItem);
 		ToolTipTimeoutTimer.stop();
 	}
 }
@@ -323,7 +350,7 @@ void TalkableTreeView::toolTipRestart(QPoint pos)
 
 void TalkableTreeView::toolTipHide(bool waitForAnother)
 {
-	ToolTipClassManager::instance()->hideToolTip();
+	m_toolTipManager->hideToolTip();
 
 	if (waitForAnother)
 		ToolTipTimeoutTimer.start(TOOL_TIP_TIMEOUT);
