@@ -1,15 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,21 +18,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TALKABLE_TREE_VIEW_H
-#define TALKABLE_TREE_VIEW_H
+#pragma once
 
-#include <QtCore/QDateTime>
-#include <QtCore/QTimer>
+#include "gui/widgets/kadu-tree-view.h"
 
 #include "buddies/buddy.h"
 #include "chat/chat.h"
 #include "contacts/contact.h"
-#include "exports.h"
 #include "gui/actions/action-context-provider.h"
 #include "gui/actions/action-context.h"
 #include "talkable/talkable.h"
+#include "exports.h"
 
-#include "gui/widgets/kadu-tree-view.h"
+#include <QtCore/QDateTime>
+#include <QtCore/QPointer>
+#include <QtCore/QTimer>
+#include <injeqt/injeqt.h>
 
 class QContextMenuEvent;
 class QModelIndex;
@@ -50,16 +43,68 @@ class Buddy;
 class BuddySet;
 class BuddiesModelProxy;
 class ContactSet;
+class InjectedFactory;
+class KaduWindowService;
+class MenuInventory;
 class ModelChain;
+class StatusConfigurationHolder;
+class StatusContainerManager;
 class TalkableDelegate;
 class TalkableDelegateConfiguration;
+class ToolTipManager;
 
 class KADUAPI TalkableTreeView : public KaduTreeView, public ActionContextProvider
 {
 	Q_OBJECT
 
+public:
+	explicit TalkableTreeView(QWidget *parent = nullptr);
+	virtual ~TalkableTreeView();
+
+	virtual void setChain(ModelChain *chain);
+	virtual ModelChain * chain() const;
+
+	void setShowIdentityNameIfMany(bool show);
+	void setUseConfigurationColors(bool use);
+
+	TalkableDelegateConfiguration * delegateConfiguration();
+
+	void updateLayout() { updateGeometries(); }
+
+	void setContextMenuEnabled(bool enabled);
+
+	// ActionContextProvider implementation
+	virtual ActionContext * actionContext() override;
+
+signals:
+	void talkableActivated(const Talkable &talkable);
+	void currentChanged(const Talkable &talkable);
+
+protected:
+	virtual void contextMenuEvent(QContextMenuEvent *event) override;
+	virtual void keyPressEvent(QKeyEvent *event) override;
+
+	virtual void wheelEvent(QWheelEvent *event) override;
+	virtual void leaveEvent(QEvent *event) override;
+
+	virtual void mousePressEvent(QMouseEvent *event) override;
+	virtual void mouseReleaseEvent(QMouseEvent *event) override;
+	virtual void mouseMoveEvent(QMouseEvent *event) override;
+
+	virtual void hideEvent(QHideEvent *event) override;
+
+	virtual void currentChanged(const QModelIndex &current, const QModelIndex &previous) override;
+
+private:
 	friend class TalkableDelegateConfiguration;
 
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<KaduWindowService> m_kaduWindowService;
+	QPointer<MenuInventory> m_menuInventory;
+	QPointer<StatusContainerManager> m_statusContainerManager;
+	QPointer<StatusConfigurationHolder> m_statusConfigurationHolder;
+	QPointer<ToolTipManager> m_toolTipManager;
+
 	TalkableDelegate *Delegate;
 	ModelChain *Chain;
 
@@ -80,6 +125,14 @@ class KADUAPI TalkableTreeView : public KaduTreeView, public ActionContextProvid
 	void setCurrentTalkable(const Talkable &talkable);
 
 private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setKaduWindowService(KaduWindowService *kaduWindowService);
+	INJEQT_SET void setMenuInventory(MenuInventory *menuInventory);
+	INJEQT_SET void setStatusContainerManager(StatusContainerManager *statusContainerManager);
+	INJEQT_SET void setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder);
+	INJEQT_SET void setToolTipManager(ToolTipManager *toolTipManager);
+	INJEQT_INIT void init();
+
 	void doubleClickedSlot(const QModelIndex &index);
 
 	// Tool tips
@@ -90,44 +143,4 @@ private slots:
 	// Actions
 	void updateContext();
 
-protected:
-	virtual void contextMenuEvent(QContextMenuEvent *event);
-	virtual void keyPressEvent(QKeyEvent *event);
-
-	virtual void wheelEvent(QWheelEvent *event);
-	virtual void leaveEvent(QEvent *event);
-
-	virtual void mousePressEvent(QMouseEvent *event);
-	virtual void mouseReleaseEvent(QMouseEvent *event);
-	virtual void mouseMoveEvent(QMouseEvent *event);
-
-	virtual void hideEvent(QHideEvent *event);
-
-	virtual void currentChanged(const QModelIndex &current, const QModelIndex &previous);
-
-public:
-	explicit TalkableTreeView(QWidget *parent = 0);
-	virtual ~TalkableTreeView();
-
-	virtual void setChain(ModelChain *chain);
-	virtual ModelChain * chain() const;
-
-	void setShowIdentityNameIfMany(bool show);
-	void setUseConfigurationColors(bool use);
-
-	TalkableDelegateConfiguration & delegateConfiguration();
-
-	void updateLayout() { updateGeometries(); }
-
-	void setContextMenuEnabled(bool enabled);
-
-	// ActionContextProvider implementation
-	virtual ActionContext * actionContext();
-
-signals:
-	void talkableActivated(const Talkable &talkable);
-	void currentChanged(const Talkable &talkable);
-
 };
-
-#endif // TALKABLE_TREE_VIEW_H
