@@ -1,15 +1,12 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2005, 2006 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,20 +28,21 @@
 #include <QtGui/QContextMenuEvent>
 #include <QtGui/QCursor>
 #include <QtGui/QDragEnterEvent>
-#include <QtGui/QMenu>
 #include <QtGui/QPainter>
-#include <QtGui/QToolButton>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QToolButton>
 #include <QtXml/QDomElement>
 
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/actions/actions.h"
 #include "gui/windows/main-window.h"
 #include "gui/windows/message-dialog.h"
 #include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
-#include "misc/change-notifier.h"
 #include "misc/change-notifier-lock.h"
+#include "misc/change-notifier.h"
 #include "misc/misc.h"
 #include "debug.h"
 
@@ -99,30 +97,42 @@ QMap< QString, QList<ToolBar::ToolBarAction> > ToolBar::DefaultActions;
 ToolBar::ToolBar(QWidget *parent) :
 		QToolBar(parent), XOffset(0), YOffset(0)
 {
-	kdebugf();
+}
 
+
+ToolBar::~ToolBar()
+{
+}
+
+void ToolBar::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void ToolBar::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ToolBar::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void ToolBar::init()
+{
 	connect(&MyChangeNotifier, SIGNAL(changed()), this, SIGNAL(updated()));
 
 	dragging = false;
 	dropmarker.visible = false;
 
 	setAcceptDrops(true);
-	setIconSize(IconsManager::instance()->getIconsSize());
+	setIconSize(m_iconsManager->getIconsSize());
 
 	if (!watcher)
 		watcher = new DisabledActionsWatcher();
 
 	configurationUpdated();
-
-	kdebugf2();
-}
-
-
-ToolBar::~ToolBar()
-{
-	kdebugf();
-
-	kdebugf2();
 }
 
 ToolBarSeparator * ToolBar::createSeparator(QAction *before, ToolBarAction &action)
@@ -147,17 +157,21 @@ ToolBarSpacer * ToolBar::createSpacer(QAction *before, ToolBarAction &action)
 
 QToolButton * ToolBar::createPushButton(QAction *before, ToolBarAction &action)
 {
-	if (!Actions::instance()->contains(action.actionName))
-		return 0;
+	if (!m_actions->contains(action.actionName))
+		return nullptr;
 
 	MainWindow *kaduMainWindow = qobject_cast<MainWindow *>(parentWidget());
 	if (!kaduMainWindow)
-		return 0;
+		return nullptr;
 
-	if (!kaduMainWindow->supportsActionType(Actions::instance()->value(action.actionName)->type()))
-		return 0;
+	auto actionByName = m_actions->value(action.actionName);
+	if (!actionByName)
+		return nullptr;
 
-	action.action = Actions::instance()->createAction(action.actionName, kaduMainWindow->actionContext(), kaduMainWindow);
+	if (!kaduMainWindow->supportsActionType(actionByName->type()))
+		return nullptr;
+
+	action.action = m_actions->createAction(action.actionName, kaduMainWindow->actionContext(), kaduMainWindow);
 	insertAction(before, action.action);
 
 	QToolButton *button = qobject_cast<QToolButton *>(widgetForAction(action.action));
@@ -169,9 +183,9 @@ QToolButton * ToolBar::createPushButton(QAction *before, ToolBarAction &action)
 		button->installEventFilter(watcher);
 		button->setToolButtonStyle(action.style);
 
-		if (action.action->menu() && Actions::instance()->contains(action.actionName))
+		if (action.action->menu() && m_actions->contains(action.actionName))
 		{
-			ActionDescription *actionDescription = Actions::instance()->value(action.actionName);
+			ActionDescription *actionDescription = m_actions->value(action.actionName);
 			if (actionDescription)
 				button->setPopupMode(actionDescription->buttonPopupMode());
 		}
@@ -182,9 +196,9 @@ QToolButton * ToolBar::createPushButton(QAction *before, ToolBarAction &action)
 
 QWidget * ToolBar::createActionWidget(QAction *before, ToolBarAction &action)
 {
-	if (action.actionName.startsWith(QLatin1String("__separator")))
+	if (action.actionName.startsWith(QStringLiteral("__separator")))
 		return createSeparator(before, action);
-	else if (action.actionName.startsWith(QLatin1String("__spacer")))
+	else if (action.actionName.startsWith(QStringLiteral("__spacer")))
 		return createSpacer(before, action);
 	else
 		return createPushButton(before, action);
@@ -306,14 +320,21 @@ void ToolBar::dragEnterEvent(QDragEnterEvent *event)
 		QString actionName;
 		Qt::ToolButtonStyle style;
 
-		MainWindow *mainWindow = 0;
-		if (ActionDrag::decode(event, actionName, style) &&
-				(event->source() == this ||
-				(Actions::instance()->contains(actionName) &&
-					(mainWindow = qobject_cast<MainWindow *>(parentWidget())) &&
-					mainWindow->supportsActionType(Actions::instance()->value(actionName)->type())) ||
-				actionName.startsWith(QLatin1String("__separator")) ||
-				actionName.startsWith(QLatin1String("__spacer"))))
+		auto decoded = ActionDrag::decode(event, actionName, style);
+		if (!decoded)
+		{
+			event->ignore();
+			return;
+		}
+
+		auto mine = source == this;
+		auto action = m_actions->value(actionName);
+		auto mainWindow = qobject_cast<MainWindow *>(parentWidget());
+		auto supportedAction = action && mainWindow && mainWindow->supportsActionType(action->type());
+		auto isSeparator = actionName.startsWith(QStringLiteral("__separator"));
+		auto isSpacer = actionName.startsWith(QStringLiteral("__spacer"));
+
+		if (mine || supportedAction || isSeparator || isSpacer)
 		{
 			dragging = true;
 			updateDropMarker();
@@ -557,7 +578,7 @@ void ToolBar::contextMenuEvent(QContextMenuEvent *e)
 
 void ToolBar::configurationUpdated()
 {
-	QDomElement toolbarsConfig = xml_config_file->findElement(xml_config_file->rootElement(), "Toolbars");
+	QDomElement toolbarsConfig = m_configuration->api()->findElement(m_configuration->api()->rootElement(), "Toolbars");
 
 	if (!toolbarsConfig.hasAttribute("blocked"))
 		toolbarsConfig.setAttribute("blocked", "1");
@@ -566,23 +587,23 @@ void ToolBar::configurationUpdated()
 		return setMovable(false);
 
 	setMovable(!toolbarsConfig.attribute("blocked").toInt());
-	setIconSize(IconsManager::instance()->getIconsSize());
+	setIconSize(m_iconsManager->getIconsSize());
 }
 
 void ToolBar::writeToConfig(const QDomElement &parent_element)
 {
 	kdebugf();
-	QDomElement toolbar_elem = xml_config_file->createElement(parent_element, "ToolBar");
+	QDomElement toolbar_elem = m_configuration->api()->createElement(parent_element, "ToolBar");
 
 	toolbar_elem.setAttribute("x_offset", pos().x());
 	toolbar_elem.setAttribute("y_offset", pos().y());
 
 	foreach (const ToolBarAction &toolBarAction, ToolBarActions)
 	{
-		QDomElement button_elem = xml_config_file->createElement(toolbar_elem, "ToolButton");
-		if (toolBarAction.actionName.startsWith(QLatin1String("__separator")))
+		QDomElement button_elem = m_configuration->api()->createElement(toolbar_elem, "ToolButton");
+		if (toolBarAction.actionName.startsWith(QStringLiteral("__separator")))
 			button_elem.setAttribute("action_name", "__separator");
-		else if (toolBarAction.actionName.startsWith(QLatin1String("__spacer")))
+		else if (toolBarAction.actionName.startsWith(QStringLiteral("__spacer")))
 			button_elem.setAttribute("action_name", "__spacer");
 		else
 			button_elem.setAttribute("action_name", toolBarAction.actionName);
@@ -623,10 +644,6 @@ void ToolBar::loadFromConfig(const QDomElement &toolbar_element)
 
 	ChangeNotifierLock lock(MyChangeNotifier, ChangeNotifierLock::ModeForget);
 
-//	QString align = toolbar_element.attribute("align");
-//	if (align == "right")
-//		setLayoutDirection(Qt::RightToLeft);
-
 	bool offset_ok;
 	int offset = toolbar_element.attribute("offset").toInt(&offset_ok);
 
@@ -734,7 +751,7 @@ QMenu * ToolBar::createContextMenu(QWidget *widget)
 
 		QMenu *actionsMenu = new QMenu(tr("Add new button"), menu);
 		QList<QAction *> actions;
-		foreach (ActionDescription *actionDescription, Actions::instance()->values())
+		foreach (ActionDescription *actionDescription, m_actions->values())
 		{
 			bool supportsAction;
 			MainWindow *kaduMainWindow = qobject_cast<MainWindow *>(parentWidget());
@@ -749,7 +766,7 @@ QMenu * ToolBar::createContextMenu(QWidget *widget)
 
 			if (!windowHasAction(actionDescription->name(), false))
 			{
-				QAction *action = new QAction(actionDescription->icon().icon(), actionDescription->text(), actionsMenu);
+				QAction *action = new QAction(m_iconsManager->iconByPath(actionDescription->icon()), actionDescription->text(), actionsMenu);
 				action->setData(actionDescription->name());
 
 				actions.append(action);
@@ -817,7 +834,7 @@ void ToolBar::removeToolbar()
 {
 	kdebugf();
 
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Kadu"), tr("Do you really want to remove this toolbar?"), this);
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Do you really want to remove this toolbar?"), this);
 	dialog->addButton(QMessageBox::Yes, tr("Remove toolbar"));
 	dialog->addButton(QMessageBox::No, tr("Cancel"));
 
@@ -826,20 +843,20 @@ void ToolBar::removeToolbar()
 	kdebugf2();
 }
 
-bool ToolBar::isBlockToolbars()
+bool ToolBar::isBlockToolbars(Configuration *configuration)
 {
-	QDomElement toolbarsConfig = xml_config_file->findElement(xml_config_file->rootElement(), "Toolbars");
+	QDomElement toolbarsConfig = configuration->api()->findElement(configuration->api()->rootElement(), "Toolbars");
 	if (toolbarsConfig.isNull())
-		toolbarsConfig = xml_config_file->createElement(xml_config_file->rootElement(), "Toolbars");
+		toolbarsConfig = configuration->api()->createElement(configuration->api()->rootElement(), "Toolbars");
 
 	return toolbarsConfig.attribute("blocked") == "1";
 }
 
 void ToolBar::setBlockToolbars(bool checked)
 {
-	QDomElement toolbarsConfig = xml_config_file->findElement(xml_config_file->rootElement(), "Toolbars");
+	QDomElement toolbarsConfig = m_configuration->api()->findElement(m_configuration->api()->rootElement(), "Toolbars");
 	if (toolbarsConfig.isNull())
-		toolbarsConfig = xml_config_file->createElement(xml_config_file->rootElement(), "Toolbars");
+		toolbarsConfig = m_configuration->api()->createElement(m_configuration->api()->rootElement(), "Toolbars");
 
 	toolbarsConfig.setAttribute("blocked", checked ? "1" : "0");
 	ConfigurationAwareObject::notifyAll();
