@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,32 +18,42 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QTimer>
-#include <QtGui/QLabel>
-#include <QtGui/QMovie>
-#include <QtGui/QResizeEvent>
+#include "wait-overlay.h"
 
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 
-#include "wait-overlay.h"
+#include <QtCore/QTimer>
+#include <QtGui/QMovie>
+#include <QtGui/QResizeEvent>
+#include <QtWidgets/QLabel>
 
 WaitOverlay::WaitOverlay(QWidget *parent) :
 		QLabel(parent)
 {
-	setAlignment(Qt::AlignCenter);
-	setMovie(new QMovie(KaduIcon("kadu_icons/please-wait", "64x64").fullPath(), QByteArray(), this));
-	setStyleSheet("background-color: rgba(127, 127, 127, 127)");
-
-	hide();
-
-	if (parent)
-		QTimer::singleShot(500, this, SLOT(timeoutPassed()));
 }
 
 WaitOverlay::~WaitOverlay()
 {
 }
 
+void WaitOverlay::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void WaitOverlay::init()
+{
+	setAlignment(Qt::AlignCenter);
+	setMovie(new QMovie(m_iconsManager->iconPath(KaduIcon("kadu_icons/please-wait", "64x64")), QByteArray(), this));
+	setStyleSheet("background-color: rgba(127, 127, 127, 127)");
+
+	hide();
+
+	if (parent())
+		QTimer::singleShot(500, this, SLOT(timeoutPassed()));
+}
+
 void WaitOverlay::timeoutPassed()
 {
 	if (!parentWidget()) // in case of reparenting
