@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,10 +20,9 @@
 #include "webkit-messages-view-factory.h"
 
 #include "chat-style/engine/chat-style-renderer-factory-provider.h"
-#include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/webkit-messages-view/webkit-messages-view-handler-factory.h"
-#include "services/chat-image-request-service.h"
-#include "services/image-storage-service.h"
+#include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
 
 WebkitMessagesViewFactory::WebkitMessagesViewFactory(QObject *parent) :
 		QObject{parent}
@@ -34,19 +33,14 @@ WebkitMessagesViewFactory::~WebkitMessagesViewFactory()
 {
 }
 
-void WebkitMessagesViewFactory::setChatImageRequestService(ChatImageRequestService *chatImageRequestService)
-{
-	m_chatImageRequestService = chatImageRequestService;
-}
-
 void WebkitMessagesViewFactory::setChatStyleRendererFactoryProvider(ChatStyleRendererFactoryProvider *chatStyleRendererFactoryProvider)
 {
 	m_chatStyleRendererFactoryProvider = chatStyleRendererFactoryProvider;
 }
 
-void WebkitMessagesViewFactory::setImageStorageService(ImageStorageService *imageStorageService)
+void WebkitMessagesViewFactory::setInjectedFactory(InjectedFactory *injectedFactory)
 {
-	m_imageStorageService = imageStorageService;
+	m_injectedFactory = injectedFactory;
 }
 
 void WebkitMessagesViewFactory::setWebkitMessagesViewHandlerFactory(WebkitMessagesViewHandlerFactory *webkitMessagesViewHandlerFactory)
@@ -54,17 +48,15 @@ void WebkitMessagesViewFactory::setWebkitMessagesViewHandlerFactory(WebkitMessag
 	m_webkitMessagesViewHandlerFactory = webkitMessagesViewHandlerFactory;
 }
 
-qobject_ptr<WebkitMessagesView> WebkitMessagesViewFactory::createWebkitMessagesView(Chat chat, bool supportTransparency, QWidget *parent)
+owned_qptr<WebkitMessagesView> WebkitMessagesViewFactory::createWebkitMessagesView(Chat chat, bool supportTransparency, QWidget *parent)
 {
-	auto result = make_qobject<WebkitMessagesView>(chat, supportTransparency, parent);
-	result->setChatImageRequestService(m_chatImageRequestService);
+	auto result = m_injectedFactory->makeOwned<WebkitMessagesView>(chat, supportTransparency, parent);
 	result->setChatStyleRendererFactory(m_chatStyleRendererFactoryProvider->chatStyleRendererFactory());
-	result->setImageStorageService(m_imageStorageService);
 	result->setWebkitMessagesViewHandlerFactory(m_webkitMessagesViewHandlerFactory);
 	result->refreshView();
 
 	connect(m_chatStyleRendererFactoryProvider, SIGNAL(chatStyleRendererFactoryChanged(std::shared_ptr<ChatStyleRendererFactory>)),
 			result.get(), SLOT(setChatStyleRendererFactory(std::shared_ptr<ChatStyleRendererFactory>)));
 
-	return std::move(result);
+	return result;
 }
