@@ -1,13 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010 Michał Obrembski (byku@byku.com.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,25 +20,25 @@
 #include "webkit-messages-view.h"
 
 #include "chat-style/chat-style-manager.h"
-#include "chat-style/engine/chat-style-renderer.h"
 #include "chat-style/engine/chat-style-renderer-configuration.h"
 #include "chat-style/engine/chat-style-renderer-factory.h"
-#include "configuration/chat-configuration-holder.h"
+#include "chat-style/engine/chat-style-renderer.h"
 #include "contacts/contact-set.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "gui/scoped-updates-disabler.h"
 #include "gui/widgets/chat-view-network-access-manager.h"
 #include "gui/widgets/webkit-messages-view/message-limit-policy.h"
-#include "gui/widgets/webkit-messages-view/webkit-messages-view-handler.h"
 #include "gui/widgets/webkit-messages-view/webkit-messages-view-handler-factory.h"
-#include "misc/kadu-paths.h"
+#include "gui/widgets/webkit-messages-view/webkit-messages-view-handler.h"
+#include "misc/paths-provider.h"
 #include "protocols/protocol.h"
 #include "protocols/services/chat-image-service.h"
 #include "protocols/services/chat-service.h"
 #include "services/chat-image-request-service.h"
 
 #include <QtGui/QKeyEvent>
-#include <QtWebKit/QWebFrame>
+#include <QtWebKitWidgets/QWebFrame>
 
 WebkitMessagesView::WebkitMessagesView(const Chat &chat, bool supportTransparency, QWidget *parent) :
 		KaduWebView{parent},
@@ -54,9 +47,49 @@ WebkitMessagesView::WebkitMessagesView(const Chat &chat, bool supportTransparenc
 		m_supportTransparency{supportTransparency},
 		m_atBottom{true}
 {
+}
+
+WebkitMessagesView::~WebkitMessagesView()
+{
+	disconnectChat();
+}
+
+void WebkitMessagesView::setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder)
+{
+	m_chatConfigurationHolder = chatConfigurationHolder;
+}
+
+void WebkitMessagesView::setChatImageRequestService(ChatImageRequestService *chatImageRequestService)
+{
+	m_chatImageRequestService = chatImageRequestService;
+}
+
+void WebkitMessagesView::setChatStyleManager(ChatStyleManager *chatStyleManager)
+{
+	m_chatStyleManager = chatStyleManager;
+}
+
+void WebkitMessagesView::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void WebkitMessagesView::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void WebkitMessagesView::setWebkitMessagesViewHandlerFactory(WebkitMessagesViewHandlerFactory *webkitMessagesViewHandlerFactory)
+{
+	m_webkitMessagesViewHandlerFactory = webkitMessagesViewHandlerFactory;
+}
+
+void WebkitMessagesView::init()
+{
+	connect(m_chatImageRequestService.data(), SIGNAL(chatImageStored(ChatImage,QString)), this, SLOT(chatImageStored(ChatImage,QString)));
+
 	auto oldManager = page()->networkAccessManager();
-	auto newManager = make_qobject<ChatViewNetworkAccessManager>(oldManager, this);
-	newManager->setImageStorageService(Core::instance()->imageStorageService());
+	auto newManager = m_injectedFactory->makeOwned<ChatViewNetworkAccessManager>(oldManager, this);
 	page()->setNetworkAccessManager(newManager.get());
 
 	// TODO: for me with empty styleSheet if has artifacts on scrollbars...
@@ -86,32 +119,11 @@ WebkitMessagesView::WebkitMessagesView(const Chat &chat, bool supportTransparenc
 	);
 
 	connect(this->page()->mainFrame(), SIGNAL(contentsSizeChanged(const QSize &)), this, SLOT(scrollToBottom()));
-	connect(ChatStyleManager::instance(), SIGNAL(chatStyleConfigurationUpdated()),
-			this, SLOT(chatStyleConfigurationUpdated()));
+	connect(m_chatStyleManager, SIGNAL(chatStyleConfigurationUpdated()), this, SLOT(chatStyleConfigurationUpdated()));
 
 	configurationUpdated();
 	connectChat();
-}
-
-WebkitMessagesView::~WebkitMessagesView()
-{
-	disconnectChat();
-}
-
-void WebkitMessagesView::setChatImageRequestService(ChatImageRequestService *chatImageRequestService)
-{
-	if (m_chatImageRequestService)
-		disconnect(m_chatImageRequestService.data(), nullptr, this, nullptr);
-
-	m_chatImageRequestService = chatImageRequestService;
-
-	if (m_chatImageRequestService)
-		connect(m_chatImageRequestService.data(), SIGNAL(chatImageStored(ChatImage,QString)), this, SLOT(chatImageStored(ChatImage,QString)));
-}
-
-void WebkitMessagesView::setWebkitMessagesViewHandlerFactory(WebkitMessagesViewHandlerFactory *webkitMessagesViewHandlerFactory)
-{
-	m_webkitMessagesViewHandlerFactory = webkitMessagesViewHandlerFactory;
+	refreshView();
 }
 
 void WebkitMessagesView::mouseReleaseEvent(QMouseEvent *e)
@@ -195,7 +207,7 @@ void WebkitMessagesView::setForcePruneDisabled(bool disable)
 
 void WebkitMessagesView::chatStyleConfigurationUpdated()
 {
-	m_handler->setMessageLimit(ChatStyleManager::instance()->prune());
+	m_handler->setMessageLimit(m_chatStyleManager->prune());
 }
 
 void WebkitMessagesView::refreshView()
@@ -210,15 +222,15 @@ void WebkitMessagesView::refreshView()
 
 ChatStyleRendererConfiguration WebkitMessagesView::rendererConfiguration()
 {
-	QFile file{KaduPaths::instance()->dataPath() + QLatin1String("scripts/chat-scripts.js")};
+	QFile file{m_pathsProvider->dataPath() + QStringLiteral("scripts/chat-scripts.js")};
 	auto javaScript = file.open(QIODevice::ReadOnly | QIODevice::Text)
 			? file.readAll()
 			: QString{};
-	auto transparency = ChatConfigurationHolder::instance()->useTransparency() && supportTransparency() && isCompositingEnabled();
+	auto transparency = m_chatConfigurationHolder->useTransparency() && supportTransparency() && isCompositingEnabled();
 	return ChatStyleRendererConfiguration{chat(), *page()->mainFrame(), javaScript, transparency};
 }
 
-void WebkitMessagesView::setWebkitMessagesViewHandler(qobject_ptr<WebkitMessagesViewHandler> handler)
+void WebkitMessagesView::setWebkitMessagesViewHandler(owned_qptr<WebkitMessagesViewHandler> handler)
 {
 	ScopedUpdatesDisabler updatesDisabler{*this};
 	auto scrollBarPosition = page()->mainFrame()->scrollBarValue(Qt::Vertical);
@@ -264,6 +276,11 @@ void WebkitMessagesView::add(const SortedMessages &messages)
 	emit messagesUpdated();
 }
 
+SortedMessages WebkitMessagesView::messages() const
+{
+	return m_handler->messages();
+}
+
 void WebkitMessagesView::setChatStyleRendererFactory(std::shared_ptr<ChatStyleRendererFactory> chatStyleRendererFactory)
 {
 	m_chatStyleRendererFactory = chatStyleRendererFactory;
@@ -293,7 +310,7 @@ void WebkitMessagesView::sentMessageStatusChanged(const Message &message)
 	m_handler->displayMessageStatus(message.id(), message.status());
 }
 
-void WebkitMessagesView::contactActivityChanged(const Contact &contact, ChatStateService::State state)
+void WebkitMessagesView::contactActivityChanged(const Contact &contact, ChatState state)
 {
 	m_handler->displayChatState(contact, state);
 }
@@ -318,7 +335,7 @@ void WebkitMessagesView::forceScrollToBottom()
 
 void WebkitMessagesView::configurationUpdated()
 {
-	setUserFont(ChatConfigurationHolder::instance()->chatFont().toString(), ChatConfigurationHolder::instance()->forceCustomChatFont());
+	setUserFont(m_chatConfigurationHolder->chatFont().toString(), m_chatConfigurationHolder->forceCustomChatFont());
 	refreshView();
 }
 
