@@ -1,13 +1,13 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
  * Copyright 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,16 +24,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QSortFilterProxyModel>
+#include "add-buddy-window.h"
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
@@ -43,6 +34,7 @@
 #include "accounts/model/accounts-proxy-model.h"
 #include "buddies/buddy-manager.h"
 #include "buddies/buddy-preferred-manager.h"
+#include "buddies/buddy-storage.h"
 #include "buddies/buddy.h"
 #include "buddies/model/buddy-list-model.h"
 #include "buddies/model/buddy-manager-adapter.h"
@@ -50,24 +42,36 @@
 #include "configuration/config-file-variant-wrapper.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
+#include "gui/scoped-updates-disabler.h"
 #include "gui/widgets/accounts-combo-box.h"
 #include "gui/widgets/groups-combo-box.h"
 #include "gui/widgets/select-talkable-combo-box.h"
-#include "gui/scoped-updates-disabler.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity.h"
 #include "model/roles.h"
 #include "os/generic/window-geometry-manager.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
-#include "protocols/roster.h"
-#include "protocols/services/roster/roster-service.h"
 #include "protocols/services/subscription-service.h"
+#include "roster/roster-service.h"
+#include "roster/roster.h"
 #include "talkable/filter/exclude-buddy-talkable-filter.h"
+#include "talkable/talkable-converter.h"
 #include "url-handlers/url-handler-manager.h"
 
-#include "add-buddy-window.h"
+#include <QtCore/QSortFilterProxyModel>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
 
 AddBuddyWindow::AddBuddyWindow(QWidget *parent, const Buddy &buddy, bool forceBuddyAccount) :
 		QDialog(parent, Qt::Window), DesktopAwareObject(this), UserNameLabel(0), UserNameEdit(0),
@@ -75,6 +79,69 @@ AddBuddyWindow::AddBuddyWindow(QWidget *parent, const Buddy &buddy, bool forceBu
 		GroupCombo(0), DisplayNameEdit(0), MergeBuddy(0), SelectBuddy(0), AskForAuthorization(0),
 		AllowToSeeMeCheck(0), ErrorLabel(0), AddContactButton(0), MyBuddy(buddy),
 		ForceBuddyAccount(forceBuddyAccount)
+{
+}
+
+AddBuddyWindow::~AddBuddyWindow()
+{
+}
+
+void AddBuddyWindow::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void AddBuddyWindow::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void AddBuddyWindow::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void AddBuddyWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void AddBuddyWindow::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void AddBuddyWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void AddBuddyWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void AddBuddyWindow::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void AddBuddyWindow::setRoster(Roster *roster)
+{
+	m_roster = roster;
+}
+
+void AddBuddyWindow::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void AddBuddyWindow::setUrlHandlerManager(UrlHandlerManager *urlHandlerManager)
+{
+	m_urlHandlerManager = urlHandlerManager;
+}
+
+void AddBuddyWindow::init()
 {
 	setWindowRole("kadu-add-buddy");
 	setWindowTitle(tr("Add buddy"));
@@ -82,7 +149,7 @@ AddBuddyWindow::AddBuddyWindow(QWidget *parent, const Buddy &buddy, bool forceBu
 
 	if (MyBuddy)
 	{
-		MyAccount = BuddyPreferredManager::instance()->preferredAccount(MyBuddy);
+		MyAccount = m_buddyPreferredManager->preferredAccount(MyBuddy);
 		if (!MyAccount)
 			MyBuddy = Buddy::null;
 	}
@@ -91,11 +158,7 @@ AddBuddyWindow::AddBuddyWindow(QWidget *parent, const Buddy &buddy, bool forceBu
 	if (!MyBuddy)
 		addFakeAccountsToComboBox();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "AddBuddyWindowGeometry"), QRect(0, 50, 425, 430), this);
-}
-
-AddBuddyWindow::~AddBuddyWindow()
-{
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "AddBuddyWindowGeometry"), QRect(0, 50, 425, 430), this);
 }
 
 void AddBuddyWindow::createGui()
@@ -108,7 +171,7 @@ void AddBuddyWindow::createGui()
 
 	Layout = new QFormLayout(mainWidget);
 
-	AccountCombo = new AccountsComboBox(MyBuddy.isNull(), AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
+	AccountCombo = m_injectedFactory->makeInjected<AccountsComboBox>(MyBuddy.isNull(), AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
 	AccountCombo->setIncludeIdInDisplay(true);
 	AccountCombo->addFilter(new WriteableContactsListFilter(AccountCombo));
 
@@ -167,20 +230,20 @@ void AddBuddyWindow::createGui()
 
 	NonMergeWidgets.append(hintLabel);
 
-	GroupCombo = new GroupsComboBox(this);
+	GroupCombo = m_injectedFactory->makeInjected<GroupsComboBox>(this);
 	Layout->addRow(tr("Add in group:"), GroupCombo);
 
 	NonMergeWidgets.append(GroupCombo);
 
-	SelectBuddy = new SelectTalkableComboBox(this);
+	SelectBuddy = m_injectedFactory->makeInjected<SelectTalkableComboBox>(this);
 	SelectBuddy->addBeforeAction(new QAction(tr(" - Select buddy - "), SelectBuddy));
 
-	BuddyListModel *buddyListModel = new BuddyListModel(SelectBuddy);
-	new BuddyManagerAdapter(buddyListModel);
+	auto buddyListModel = m_injectedFactory->makeInjected<BuddyListModel>(SelectBuddy);
+	m_injectedFactory->makeInjected<BuddyManagerAdapter>(buddyListModel);
 	SelectBuddy->setBaseModel(buddyListModel);
 	SelectBuddy->setEnabled(false);
 	SelectBuddy->setVisible(false);
-	SelectBuddy->addFilter(new ExcludeBuddyTalkableFilter(Core::instance()->myself(), SelectBuddy));
+	SelectBuddy->addFilter(new ExcludeBuddyTalkableFilter(m_myself->buddy(), SelectBuddy));
 	Layout->addRow(tr("Merge with:"), SelectBuddy);
 
 	MergeWidgets.append(SelectBuddy);
@@ -239,10 +302,10 @@ void AddBuddyWindow::createGui()
 
 void AddBuddyWindow::addFakeAccountsToComboBox()
 {
-	MobileAccountAction = new QAction(KaduIcon("phone").icon(), tr("Mobile"), AccountCombo);
+	MobileAccountAction = new QAction(m_iconsManager->iconByPath(KaduIcon("phone")), tr("Mobile"), AccountCombo);
 	AccountCombo->addAfterAction(MobileAccountAction);
 
-	EmailAccountAction = new QAction(KaduIcon("mail-message-new").icon(), tr("E-mail"), AccountCombo);
+	EmailAccountAction = new QAction(m_iconsManager->iconByPath(KaduIcon("mail-message-new")), tr("E-mail"), AccountCombo);
 	AccountCombo->addAfterAction(EmailAccountAction);
 }
 
@@ -351,7 +414,7 @@ void AddBuddyWindow::validateData()
 		return;
 	}
 
-	Contact contact = ContactManager::instance()->byId(account, UserNameEdit->text(), ActionReturnNull);
+	Contact contact = m_contactManager->byId(account, UserNameEdit->text(), ActionReturnNull);
 	if (!contact.isAnonymous())
 	{
 		displayErrorMessage(tr("This contact is already available as <i>%1</i>").arg(contact.display(true)));
@@ -375,7 +438,7 @@ void AddBuddyWindow::validateData()
 		}
 		else
 		{
-			Buddy existingBuddy = BuddyManager::instance()->byDisplay(DisplayNameEdit->text(), ActionReturnNull);
+			Buddy existingBuddy = m_buddyManager->byDisplay(DisplayNameEdit->text(), ActionReturnNull);
 			if (existingBuddy && existingBuddy != MyBuddy)
 			{
 				displayErrorMessage(tr("Visible name is already used for another buddy"));
@@ -417,7 +480,7 @@ void AddBuddyWindow::validateEmailData()
 {
 	Q_ASSERT(!MergeBuddy->isChecked());
 
-	if (!UrlHandlerManager::instance()->mailRegExp().exactMatch(UserNameEdit->text()))
+	if (!m_urlHandlerManager->mailRegExp().exactMatch(UserNameEdit->text()))
 	{
 		if (!UserNameEdit->text().isEmpty())
 			displayErrorMessage(tr("Entered e-mail is invalid"));
@@ -488,13 +551,13 @@ bool AddBuddyWindow::addContact()
 	{
 		if (MyBuddy.isNull())
 		{
-			buddy = Buddy::create();
+			buddy = m_buddyStorage->create();
 			buddy.data()->setState(StorableObject::StateNew);
 		}
 		else
 			buddy = MyBuddy;
 
-		BuddyManager::instance()->addItem(buddy);
+		m_buddyManager->addItem(buddy);
 
 		buddy.setAnonymous(false);
 		buddy.setOfflineTo(!AllowToSeeMeCheck->isChecked());
@@ -505,7 +568,7 @@ bool AddBuddyWindow::addContact()
 	}
 	else
 	{
-		buddy = SelectBuddy->currentTalkable().toBuddy();
+		buddy = m_talkableConverter->toBuddy(SelectBuddy->currentTalkable());
 		if (buddy.isNull())
 			return false;
 	}
@@ -514,13 +577,13 @@ bool AddBuddyWindow::addContact()
 			? ActionCreateAndAdd
 			: ActionReturnNull;
 
-	Contact contact = ContactManager::instance()->byId(account, UserNameEdit->text(), action);
+	Contact contact = m_contactManager->byId(account, UserNameEdit->text(), action);
 
 	if (contact)
 	{
 		contact.setOwnerBuddy(buddy);
 
-		Roster::instance()->addContact(contact);
+		m_roster->addContact(contact);
 
 		if (!buddy.isOfflineTo())
 			sendAuthorization(contact);
@@ -534,28 +597,28 @@ bool AddBuddyWindow::addContact()
 
 bool AddBuddyWindow::addMobile()
 {
-	Buddy buddy = Buddy::create();
+	Buddy buddy = m_buddyStorage->create();
 	buddy.data()->setState(StorableObject::StateNew);
 	buddy.setAnonymous(false);
 	buddy.setMobile(UserNameEdit->text());
 	buddy.setDisplay(DisplayNameEdit->text().isEmpty() ? UserNameEdit->text() : DisplayNameEdit->text());
 	buddy.addToGroup(GroupCombo->currentGroup());
 
-	BuddyManager::instance()->addItem(buddy);
+	m_buddyManager->addItem(buddy);
 
 	return true;
 }
 
 bool AddBuddyWindow::addEmail()
 {
-	Buddy buddy = Buddy::create();
+	Buddy buddy = m_buddyStorage->create();
 	buddy.data()->setState(StorableObject::StateNew);
 	buddy.setAnonymous(false);
 	buddy.setEmail(UserNameEdit->text());
 	buddy.setDisplay(DisplayNameEdit->text().isEmpty() ? UserNameEdit->text() : DisplayNameEdit->text());
 	buddy.addToGroup(GroupCombo->currentGroup());
 
-	BuddyManager::instance()->addItem(buddy);
+	m_buddyManager->addItem(buddy);
 
 	return true;
 }
