@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,25 +18,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QVBoxLayout>
+#include "add-conference-window.h"
 
 #include "accounts/filter/protocol-filter.h"
 #include "buddies/model/buddy-list-model.h"
 #include "buddies/model/buddy-manager-adapter.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact-set.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/account-buddy-list-widget.h"
 #include "gui/widgets/accounts-combo-box.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/filtered-tree-view.h"
 #include "gui/widgets/talkable-tree-view.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "model/model-chain.h"
 #include "os/generic/window-geometry-manager.h"
@@ -48,7 +45,12 @@
 // will be used when Qt 4.8 .is required
 // #include "buddies/model/checkable-buddies-proxy-model.h"
 
-#include "add-conference-window.h"
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QVBoxLayout>
 
 AddConferenceWindow::AddConferenceWindow(QWidget *parent) :
 		QDialog(parent)
@@ -56,17 +58,50 @@ AddConferenceWindow::AddConferenceWindow(QWidget *parent) :
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowRole("kadu-add-conference");
 	setWindowTitle(tr("Add Conference"));
+}
 
+AddConferenceWindow::~AddConferenceWindow()
+{
+}
+
+void AddConferenceWindow::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void AddConferenceWindow::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void AddConferenceWindow::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void AddConferenceWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void AddConferenceWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void AddConferenceWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void AddConferenceWindow::init()
+{
 	createGui();
 
 	accountChanged();
 	validateData();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "AddConferenceWindowGeometry"), QRect(0, 50, 430, 400), this);
-}
-
-AddConferenceWindow::~AddConferenceWindow()
-{
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "AddConferenceWindowGeometry"), QRect(0, 50, 430, 400), this);
 }
 
 void AddConferenceWindow::createGui()
@@ -78,7 +113,7 @@ void AddConferenceWindow::createGui()
 
 	QFormLayout *layout = new QFormLayout(mainWidget);
 
-	AccountCombo = new AccountsComboBox(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
+	AccountCombo = m_injectedFactory->makeInjected<AccountsComboBox>(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
 	AccountCombo->setIncludeIdInDisplay(true);
 
 	// only gadu supports conferences for now
@@ -105,15 +140,15 @@ void AddConferenceWindow::createGui()
 
 	ModelChain *chain = new ModelChain(this);
 
-	Model = new BuddyListModel(chain);
-	new BuddyManagerAdapter(Model);
+	Model = m_injectedFactory->makeInjected<BuddyListModel>(chain);
+	m_injectedFactory->makeInjected<BuddyManagerAdapter>(Model);
 
 	// will be removed when Qt 4.8 .is required
 	Model->setCheckable(true);
 	connect(Model, SIGNAL(checkedBuddiesChanged(BuddySet)), this, SLOT(validateData()));
 
 	chain->setBaseModel(Model);
-	TalkableProxyModel *proxyModel = new TalkableProxyModel(chain);
+	TalkableProxyModel *proxyModel = m_injectedFactory->makeInjected<TalkableProxyModel>(chain);
 	proxyModel->setSortByStatusAndUnreadMessages(false);
 
 	AccountFilter = new AccountTalkableFilter(proxyModel);
@@ -128,13 +163,13 @@ void AddConferenceWindow::createGui()
 
 	// chain->addProxyModel(CheckableProxy);
 
-	FilteredTreeView *buddiesWidget = new FilteredTreeView(FilteredTreeView::FilterAtBottom, this);
+	FilteredTreeView *buddiesWidget = m_injectedFactory->makeInjected<FilteredTreeView>(FilteredTreeView::FilterAtBottom, this);
 
 	NameTalkableFilter *nameFilter = new NameTalkableFilter(NameTalkableFilter::UndecidedMatching, proxyModel);
 	connect(buddiesWidget, SIGNAL(filterChanged(QString)), nameFilter, SLOT(setName(QString)));
 	proxyModel->addFilter(nameFilter);
 
-	TalkableTreeView *view = new TalkableTreeView(buddiesWidget);
+	TalkableTreeView *view = m_injectedFactory->makeInjected<TalkableTreeView>(buddiesWidget);
 	view->setModel(chain->lastModel());
 	view->setRootIsDecorated(false);
 	view->setShowIdentityNameIfMany(false);
@@ -156,7 +191,7 @@ void AddConferenceWindow::createGui()
 	AddButton->setDefault(true);
 	connect(AddButton, SIGNAL(clicked(bool)), this, SLOT(accept()));
 
-	StartButton = new QPushButton(KaduIcon("internet-group-chat").icon(), tr("Start Conference"), this);
+	StartButton = new QPushButton(m_iconsManager->iconByPath(KaduIcon("internet-group-chat")), tr("Start Conference"), this);
 	connect(StartButton, SIGNAL(clicked(bool)), this, SLOT(start()));
 
 	QPushButton *cancel = new QPushButton(qApp->style()->standardIcon(QStyle::SP_DialogCancelButton), tr("Cancel"), this);
@@ -202,7 +237,7 @@ void AddConferenceWindow::validateData()
 	StartButton->setEnabled(true);
 
 	const QString &display = DisplayNameEdit->text();
-	if (!display.isEmpty() && ChatManager::instance()->byDisplay(display))
+	if (!display.isEmpty() && m_chatManager->byDisplay(display))
 	{
 		displayErrorMessage(tr("Visible name is already used for another chat"));
 		return;
@@ -240,7 +275,7 @@ Chat AddConferenceWindow::computeChat() const
 	foreach (const Buddy &buddy, conferenceBuddies)
 		conferenceContacts.insert(buddy.contacts(account).first());
 
-	return ChatTypeContactSet::findChat(conferenceContacts, ActionCreateAndAdd);
+	return ChatTypeContactSet::findChat(m_chatManager, m_chatStorage, conferenceContacts, ActionCreateAndAdd);
 }
 
 // we need to filter by account here because CheckableBuddiesProxyModel does not do filtering at all
@@ -277,7 +312,7 @@ void AddConferenceWindow::start()
 	if (!DisplayNameEdit->text().isEmpty())
 		chat.setDisplay(DisplayNameEdit->text());
 
-	Core::instance()->chatWidgetManager()->openChat(computeChat(), OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(computeChat(), OpenChatActivation::Activate);
 	QDialog::accept();
 }
 
