@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,27 +18,50 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ADD_CONFERENCE_WINDOW_H
-#define ADD_CONFERENCE_WINDOW_H
-
-#include <QtGui/QDialog>
+#pragma once
 
 #include "buddies/buddy-set.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QDialog>
+#include <injeqt/injeqt.h>
+
 class QLabel;
 class QLineEdit;
 
 class AccountsComboBox;
 class AccountTalkableFilter;
 class BuddyListModel;
+class ChatManager;
+class ChatStorage;
+class ChatWidgetManager;
 class Chat;
 class CheckableBuddiesProxyModel;
+class Configuration;
+class IconsManager;
+class InjectedFactory;
 class ModelChain;
 
 class AddConferenceWindow : public QDialog
 {
 	Q_OBJECT
 
+public:
+	explicit AddConferenceWindow(QWidget *parent = nullptr);
+	virtual ~AddConferenceWindow();
+
+public slots:
+	void accept();
+	void start();
+
+private:
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+	QPointer<ChatWidgetManager> m_chatWidgetManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<InjectedFactory> m_injectedFactory;
+
 	AccountsComboBox *AccountCombo;
 	QLineEdit *DisplayNameEdit;
 	QLabel *ErrorLabel;
@@ -55,17 +79,15 @@ class AddConferenceWindow : public QDialog
 	BuddySet filterByAccount(const Account &account, const BuddySet &buddies) const;
 
 private slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
 	void accountChanged();
 	void validateData();
 
-public:
-	explicit AddConferenceWindow(QWidget *parent = 0);
-	virtual ~AddConferenceWindow();
-
-public slots:
-	void accept();
-	void start();
-
 };
-
-#endif // ADD_CONFERENCE_WINDOW_H
