@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,27 +18,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QVBoxLayout>
+#include "add-room-chat-window.h"
 
 #include "accounts/filter/protocol-filter.h"
 #include "chat/chat-details-room.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-room.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/accounts-combo-box.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "os/generic/window-geometry-manager.h"
 #include "protocols/protocol.h"
 
-#include "add-room-chat-window.h"
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QVBoxLayout>
 
 AddRoomChatWindow::AddRoomChatWindow(QWidget *parent) :
 		QDialog(parent)
@@ -46,18 +48,49 @@ AddRoomChatWindow::AddRoomChatWindow(QWidget *parent) :
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowRole("kadu-add-room-chat");
 	setWindowTitle(tr("Join Room"));
-
-	createGui();
-
-	validateData();
-
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "AddRoomChatWindowGeometry"), QRect(0, 50, 430, 250), this);
 }
 
 AddRoomChatWindow::~AddRoomChatWindow()
 {
 }
 
+void AddRoomChatWindow::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void AddRoomChatWindow::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void AddRoomChatWindow::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void AddRoomChatWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void AddRoomChatWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void AddRoomChatWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void AddRoomChatWindow::init()
+{
+	createGui();
+	validateData();
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "AddRoomChatWindowGeometry"), QRect(0, 50, 430, 250), this);
+}
+
 void AddRoomChatWindow::createGui()
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -67,7 +100,7 @@ void AddRoomChatWindow::createGui()
 
 	QFormLayout *layout = new QFormLayout(mainWidget);
 
-	AccountCombo = new AccountsComboBox(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
+	AccountCombo = m_injectedFactory->makeInjected<AccountsComboBox>(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, this);
 	AccountCombo->setIncludeIdInDisplay(true);
 
 	// only xmpp rooms for now
@@ -119,7 +152,7 @@ void AddRoomChatWindow::createGui()
 	AddButton->setDefault(true);
 	connect(AddButton, SIGNAL(clicked(bool)), this, SLOT(accept()));
 
-	StartButton = new QPushButton(KaduIcon("internet-group-chat").icon(), tr("Start Room Chat"), this);
+	StartButton = new QPushButton(m_iconsManager->iconByPath(KaduIcon("internet-group-chat")), tr("Start Room Chat"), this);
 	connect(StartButton, SIGNAL(clicked(bool)), this, SLOT(start()));
 
 	QPushButton *cancel = new QPushButton(qApp->style()->standardIcon(QStyle::SP_DialogCancelButton), tr("Cancel"), this);
@@ -170,7 +203,7 @@ void AddRoomChatWindow::validateData()
 	StartButton->setEnabled(true);
 
 	const QString &display = DisplayNameEdit->text();
-	if (!display.isEmpty() && ChatManager::instance()->byDisplay(display))
+	if (!display.isEmpty() && m_chatManager->byDisplay(display))
 	{
 		displayErrorMessage(tr("Visible name is already used for another chat"));
 		return;
@@ -195,7 +228,7 @@ void AddRoomChatWindow::validateData()
 
 Chat AddRoomChatWindow::computeChat() const
 {
-	Chat chat = ChatTypeRoom::findChat(AccountCombo->currentAccount(), RoomEdit->text(), ActionCreateAndAdd);
+	Chat chat = ChatTypeRoom::findChat(m_chatManager, m_chatStorage, AccountCombo->currentAccount(), RoomEdit->text(), ActionCreateAndAdd);
 	if (!chat)
 		return Chat::null;
 
@@ -228,7 +261,7 @@ void AddRoomChatWindow::start()
 	if (!DisplayNameEdit->text().isEmpty())
 		chat.setDisplay(DisplayNameEdit->text());
 
-	Core::instance()->chatWidgetManager()->openChat(computeChat(), OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(computeChat(), OpenChatActivation::Activate);
 
 	ChatDetailsRoom *details = qobject_cast<ChatDetailsRoom *>(chat.details());
 	Q_ASSERT(details);
