@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,7 +17,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/windows/buddy-data-window.h"
 
 #include "buddy-data-window-repository.h"
@@ -31,16 +32,25 @@ BuddyDataWindowRepository::~BuddyDataWindowRepository()
 {
 }
 
+void BuddyDataWindowRepository::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void BuddyDataWindowRepository::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
 
 BuddyDataWindow * BuddyDataWindowRepository::windowForBuddy(const Buddy &buddy)
 {
 	if (Windows.contains(buddy))
 		return Windows.value(buddy);
 
-	if (buddy == Core::instance()->myself())
+	if (buddy == m_myself->buddy())
 		return 0;
 
-	BuddyDataWindow *result = new BuddyDataWindow(Core::instance()->buddyConfigurationWidgetFactoryRepository(), buddy);
+	auto result = m_injectedFactory->makeInjected<BuddyDataWindow>(buddy);
 	connect(result, SIGNAL(destroyed(Buddy)), this, SLOT(windowDestroyed(Buddy)));
 	Windows.insert(buddy, result);
 
