@@ -1,20 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2002, 2004 Tomasz Jarzynka (tomee@cpi.pl)
- * Copyright 2004, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2004 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2003, 2004 Dariusz Jagodzik (mast3r@kadu.net)
+ * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,20 +22,20 @@
  */
 
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
 #include <QtGui/QIntValidator>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QScrollArea>
-#include <QtGui/QScrollBar>
-#include <QtGui/QTabWidget>
-#include <QtGui/QVBoxLayout>
 #include <QtNetwork/QHostInfo>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QScrollArea>
+#include <QtWidgets/QScrollBar>
+#include <QtWidgets/QTabWidget>
+#include <QtWidgets/QVBoxLayout>
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
@@ -53,13 +43,16 @@
 #include "buddies/group-manager.h"
 #include "buddies/group.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/widgets/buddy-configuration-widget-factory-repository.h"
 #include "gui/widgets/buddy-configuration-widget-factory.h"
-#include "gui/widgets/buddy-configuration-widget-tab-adapter.h"
+#include "gui/widgets/buddy-configuration-widget-group-boxes-adapter.h"
 #include "gui/widgets/buddy-configuration-widget.h"
 #include "gui/widgets/buddy-general-configuration-widget.h"
 #include "gui/widgets/buddy-groups-configuration-widget.h"
@@ -67,8 +60,8 @@
 #include "gui/widgets/buddy-personal-info-configuration-widget.h"
 #include "gui/widgets/composite-configuration-value-state-notifier.h"
 #include "gui/windows/message-dialog.h"
-#include "misc/change-notifier.h"
 #include "misc/change-notifier-lock.h"
+#include "misc/change-notifier.h"
 #include "os/generic/window-geometry-manager.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
@@ -79,11 +72,47 @@
 
 #include "buddy-data-window.h"
 
-BuddyDataWindow::BuddyDataWindow(BuddyConfigurationWidgetFactoryRepository *buddyConfigurationWidgetFactoryRepository, const Buddy &buddy) :
-		QWidget(0, Qt::Dialog), MyBuddyConfigurationWidgetFactoryRepository(buddyConfigurationWidgetFactoryRepository), MyBuddy(buddy),
+BuddyDataWindow::BuddyDataWindow(const Buddy &buddy) :
+		QWidget(0, Qt::Dialog), MyBuddy(buddy),
 		ValueStateNotifier(new CompositeConfigurationValueStateNotifier(this))
 {
-	Q_ASSERT(MyBuddy != Core::instance()->myself());
+}
+
+BuddyDataWindow::~BuddyDataWindow()
+{
+	kdebugf();
+	emit destroyed(MyBuddy);
+	kdebugf2();
+}
+
+void BuddyDataWindow::setBuddyConfigurationWidgetFactoryRepository(BuddyConfigurationWidgetFactoryRepository *buddyConfigurationWidgetFactoryRepository)
+{
+	m_buddyConfigurationWidgetFactoryRepository = buddyConfigurationWidgetFactoryRepository;
+}
+
+void BuddyDataWindow::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyDataWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void BuddyDataWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void BuddyDataWindow::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void BuddyDataWindow::init()
+{
+	Q_ASSERT(MyBuddy != m_myself->buddy());
 
 	kdebugf();
 
@@ -93,31 +122,21 @@ BuddyDataWindow::BuddyDataWindow(BuddyConfigurationWidgetFactoryRepository *budd
 
 	createGui();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "ManageUsersDialogGeometry"), QRect(0, 50, 425, 500), this);
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "ManageUsersDialogGeometry"), QRect(0, 50, 425, 500), this);
 
-	connect(BuddyManager::instance(), SIGNAL(buddyRemoved(Buddy)),
+	connect(m_buddyManager, SIGNAL(buddyRemoved(Buddy)),
 			this, SLOT(buddyRemoved(Buddy)));
 
 	connect(ValueStateNotifier, SIGNAL(stateChanged(ConfigurationValueState)), this, SLOT(stateChangedSlot(ConfigurationValueState)));
 	stateChangedSlot(ValueStateNotifier->state());
 
-	if (MyBuddyConfigurationWidgetFactoryRepository)
-	{
-		connect(MyBuddyConfigurationWidgetFactoryRepository, SIGNAL(factoryRegistered(BuddyConfigurationWidgetFactory*)),
-				this, SLOT(factoryRegistered(BuddyConfigurationWidgetFactory*)));
-		connect(MyBuddyConfigurationWidgetFactoryRepository, SIGNAL(factoryUnregistered(BuddyConfigurationWidgetFactory*)),
-				this, SLOT(factoryUnregistered(BuddyConfigurationWidgetFactory*)));
+	connect(m_buddyConfigurationWidgetFactoryRepository, SIGNAL(factoryRegistered(BuddyConfigurationWidgetFactory*)),
+			this, SLOT(factoryRegistered(BuddyConfigurationWidgetFactory*)));
+	connect(m_buddyConfigurationWidgetFactoryRepository, SIGNAL(factoryUnregistered(BuddyConfigurationWidgetFactory*)),
+			this, SLOT(factoryUnregistered(BuddyConfigurationWidgetFactory*)));
 
-		foreach (BuddyConfigurationWidgetFactory *factory, MyBuddyConfigurationWidgetFactoryRepository->factories())
-			factoryRegistered(factory);
-	}
-}
-
-BuddyDataWindow::~BuddyDataWindow()
-{
-	kdebugf();
-	emit destroyed(MyBuddy);
-	kdebugf2();
+	foreach (BuddyConfigurationWidgetFactory *factory, m_buddyConfigurationWidgetFactoryRepository->factories())
+		factoryRegistered(factory);
 }
 
 void BuddyDataWindow::factoryRegistered(BuddyConfigurationWidgetFactory *factory)
@@ -137,11 +156,14 @@ void BuddyDataWindow::factoryUnregistered(BuddyConfigurationWidgetFactory *facto
 	if (BuddyConfigurationWidgets.contains(factory))
 	{
 		BuddyConfigurationWidget *widget = BuddyConfigurationWidgets.value(factory);
-		if (widget->stateNotifier())
-			ValueStateNotifier->removeConfigurationValueStateNotifier(widget->stateNotifier());
-		emit widgetRemoved(widget);
-		widget->deleteLater();
 		BuddyConfigurationWidgets.remove(factory);
+		if (widget)
+		{
+			if (widget->stateNotifier())
+				ValueStateNotifier->removeConfigurationValueStateNotifier(widget->stateNotifier());
+			emit widgetRemoved(widget);
+			widget->deleteLater();
+		}
 	}
 }
 
@@ -160,7 +182,7 @@ void BuddyDataWindow::show()
 {
 	QWidget::show();
 
-	_activateWindow(this);
+	_activateWindow(m_configuration, this);
 }
 
 void BuddyDataWindow::createGui()
@@ -175,18 +197,18 @@ void BuddyDataWindow::createTabs(QLayout *layout)
 {
 	TabWidget = new QTabWidget(this);
 
-	new BuddyConfigurationWidgetTabAdapter(this, TabWidget, this);
-
 	createGeneralTab(TabWidget);
 	createGroupsTab(TabWidget);
 	createPersonalInfoTab(TabWidget);
 	createOptionsTab(TabWidget);
 	layout->addWidget(TabWidget);
+
+	new BuddyConfigurationWidgetGroupBoxesAdapter(this, OptionsTab);
 }
 
 void BuddyDataWindow::createGeneralTab(QTabWidget *tabWidget)
 {
-	ContactTab = new BuddyGeneralConfigurationWidget(MyBuddy, this);
+	ContactTab = m_injectedFactory->makeInjected<BuddyGeneralConfigurationWidget>(MyBuddy, this);
 	ValueStateNotifier->addConfigurationValueStateNotifier(ContactTab->valueStateNotifier());
 
 	tabWidget->addTab(ContactTab, tr("General"));
@@ -194,13 +216,13 @@ void BuddyDataWindow::createGeneralTab(QTabWidget *tabWidget)
 
 void BuddyDataWindow::createGroupsTab(QTabWidget *tabWidget)
 {
-	GroupsTab = new BuddyGroupsConfigurationWidget(MyBuddy, this);
+	GroupsTab = m_injectedFactory->makeInjected<BuddyGroupsConfigurationWidget>(MyBuddy, this);
 	tabWidget->addTab(GroupsTab, tr("Groups"));
 }
 
 void BuddyDataWindow::createPersonalInfoTab(QTabWidget *tabWidget)
 {
-	PersonalInfoTab = new BuddyPersonalInfoConfigurationWidget(MyBuddy, this);
+	PersonalInfoTab = m_injectedFactory->makeInjected<BuddyPersonalInfoConfigurationWidget>(MyBuddy, this);
 	tabWidget->addTab(PersonalInfoTab, tr("Personal Information"));
 }
 
@@ -239,11 +261,11 @@ void BuddyDataWindow::updateBuddy()
 
 	ChangeNotifierLock lock(MyBuddy.changeNotifier());
 
-	applyBuddyConfigurationWidgets();
-
-	ContactTab->save();
+	ContactTab->save(); // first update contacts
 	GroupsTab->save();
 	OptionsTab->save();
+
+	applyBuddyConfigurationWidgets();
 }
 
 void BuddyDataWindow::updateBuddyAndClose()
