@@ -1,19 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004, 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2002, 2003, 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2002, 2003 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2002, 2003 Dariusz Jagodzik (mast3r@kadu.net)
+ * Copyright 2010, 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -30,18 +20,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_DATA_WINDOW_H
-#define BUDDY_DATA_WINDOW_H
-
-#include <QtCore/QMap>
-#include <QtGui/QWidget>
+#pragma once
 
 #include "buddies/buddy.h"
 #include "gui/widgets/buddy-options-configuration-widget.h"
 #include "gui/widgets/configuration-value-state-notifier.h"
-
 #include "exports.h"
 
+#include <QtCore/QMap>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
 class QCheckBox;
 class QHostInfo;
 class QLabel;
@@ -52,20 +41,29 @@ class QScrollArea;
 class QTabWidget;
 class QVBoxLayout;
 
-class Buddy;
 class BuddyConfigurationWidget;
 class BuddyConfigurationWidgetFactory;
 class BuddyConfigurationWidgetFactoryRepository;
 class BuddyGeneralConfigurationWidget;
 class BuddyGroupsConfigurationWidget;
+class BuddyManager;
 class BuddyPersonalInfoConfigurationWidget;
+class Buddy;
 class CompositeConfigurationValueStateNotifier;
+class Configuration;
+class InjectedFactory;
+class Myself;
 
 class KADUAPI BuddyDataWindow : public QWidget
 {
 	Q_OBJECT
 
-	BuddyConfigurationWidgetFactoryRepository *MyBuddyConfigurationWidgetFactoryRepository;
+	QPointer<BuddyConfigurationWidgetFactoryRepository> m_buddyConfigurationWidgetFactoryRepository;
+	QPointer<BuddyManager> m_buddyManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<Myself> m_myself;
+
 	QMap<BuddyConfigurationWidgetFactory *, BuddyConfigurationWidget *> BuddyConfigurationWidgets;
 
 	Buddy MyBuddy;
@@ -92,6 +90,13 @@ class KADUAPI BuddyDataWindow : public QWidget
 	void applyBuddyConfigurationWidgets();
 
 private slots:
+	INJEQT_SET void setBuddyConfigurationWidgetFactoryRepository(BuddyConfigurationWidgetFactoryRepository *buddyConfigurationWidgetFactoryRepository);
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setMyself(Myself *myself);
+	INJEQT_INIT void init();
+
 	void factoryRegistered(BuddyConfigurationWidgetFactory *factory);
 	void factoryUnregistered(BuddyConfigurationWidgetFactory *factory);
 
@@ -105,7 +110,7 @@ protected:
 	virtual void keyPressEvent(QKeyEvent *event);
 
 public:
-	explicit BuddyDataWindow(BuddyConfigurationWidgetFactoryRepository *buddyConfigurationWidgetFactoryRepository, const Buddy &buddy);
+	explicit BuddyDataWindow(const Buddy &buddy);
 	virtual ~BuddyDataWindow();
 
 	QList<BuddyConfigurationWidget *> buddyConfigurationWidgets() const;
@@ -123,5 +128,3 @@ signals:
 	void destroyed(const Buddy &buddy);
 
 };
-
-#endif // BUDDY_DATA_WINDOW_H
