@@ -1,13 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,21 +20,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QLabel>
-#include <QtGui/QListWidget>
-#include <QtGui/QPushButton>
-#include <QtGui/QStyle>
-#include <QtGui/QVBoxLayout>
+#include "buddy-delete-window.h"
 
 #include "buddies/buddy-additional-data-delete-handler-manager.h"
 #include "buddies/buddy-additional-data-delete-handler.h"
 #include "buddies/buddy-manager.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
-#include "protocols/roster.h"
+#include "roster/roster.h"
 
-#include "buddy-delete-window.h"
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStyle>
+#include <QtWidgets/QVBoxLayout>
 
 BuddyDeleteWindow::BuddyDeleteWindow(const BuddySet &buddiesToDelete, QWidget *parent) :
 		QDialog(parent), BuddiesToDelete(buddiesToDelete)
@@ -47,9 +44,6 @@ BuddyDeleteWindow::BuddyDeleteWindow(const BuddySet &buddiesToDelete, QWidget *p
 
 	setAttribute(Qt::WA_DeleteOnClose);
 	setModal(false);
-
-	createGui();
-
 	setMaximumHeight(250);
 }
 
@@ -58,6 +52,31 @@ BuddyDeleteWindow::~BuddyDeleteWindow()
 
 }
 
+void BuddyDeleteWindow::setBuddyAdditionalDataDeleteHandlerManager(BuddyAdditionalDataDeleteHandlerManager *buddyAdditionalDataDeleteHandlerManager)
+{
+	m_buddyAdditionalDataDeleteHandlerManager = buddyAdditionalDataDeleteHandlerManager;
+}
+
+void BuddyDeleteWindow::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void BuddyDeleteWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void BuddyDeleteWindow::setRoster(Roster *roster)
+{
+	m_roster = roster;
+}
+
+void BuddyDeleteWindow::init()
+{
+	createGui();
+}
+
 void BuddyDeleteWindow::createGui()
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -68,7 +87,7 @@ void BuddyDeleteWindow::createGui()
 	QHBoxLayout *topLayout = new QHBoxLayout(topWidget);
 
 	QLabel *iconLabel = new QLabel(topWidget);
-	iconLabel->setPixmap(KaduIcon("dialog-warning").icon().pixmap(32, 32));
+	iconLabel->setPixmap(m_iconsManager->iconByPath(KaduIcon("dialog-warning")).pixmap(32, 32));
 	topLayout->addWidget(iconLabel, 0, Qt::AlignTop);
 
 	QWidget *contentWidget = new QWidget(topWidget);
@@ -106,7 +125,7 @@ void BuddyDeleteWindow::createGui()
 
 void BuddyDeleteWindow::fillAdditionalDataListView()
 {
-	foreach (BuddyAdditionalDataDeleteHandler *handler, BuddyAdditionalDataDeleteHandlerManager::instance()->items())
+	for (auto handler : m_buddyAdditionalDataDeleteHandlerManager->items())
 	{
 		QListWidgetItem *item = new QListWidgetItem(AdditionalDataListView);
 		item->setText(handler->displayName());
@@ -134,7 +153,7 @@ void BuddyDeleteWindow::deleteBuddy(Buddy buddy)
 		if (Qt::Checked == item->checkState())
 		{
 			QString deleteHandlerName = item->data(Qt::UserRole).toString();
-			BuddyAdditionalDataDeleteHandler *handler = BuddyAdditionalDataDeleteHandlerManager::instance()->byName(deleteHandlerName);
+			BuddyAdditionalDataDeleteHandler *handler = m_buddyAdditionalDataDeleteHandlerManager->byName(deleteHandlerName);
 			if (handler)
 				handler->deleteBuddyAdditionalData(buddy);
 		}
@@ -143,10 +162,10 @@ void BuddyDeleteWindow::deleteBuddy(Buddy buddy)
 	QList<Contact> contacts = buddy.contacts();
 
 	// this set owner buddy on all of the contacts
-	BuddyManager::instance()->removeItem(buddy);
+	m_buddyManager->removeItem(buddy);
 
 	foreach (const Contact &contact, contacts)
-		Roster::instance()->removeContact(contact);
+		m_roster->removeContact(contact);
 }
 
 void BuddyDeleteWindow::accept()
@@ -155,7 +174,7 @@ void BuddyDeleteWindow::accept()
 
 	foreach (const Buddy &buddy, BuddiesToDelete)
 		deleteBuddy(buddy);
-	BuddyManager::instance()->ensureStored();
+	m_buddyManager->ensureStored();
 }
 
 void BuddyDeleteWindow::reject()
