@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/windows/chat-data-window.h"
 
 #include "chat-data-window-repository.h"
@@ -31,13 +31,17 @@ ChatDataWindowRepository::~ChatDataWindowRepository()
 {
 }
 
+void ChatDataWindowRepository::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
 
 ChatDataWindow * ChatDataWindowRepository::windowForChat(const Chat &chat)
 {
 	if (Windows.contains(chat))
 		return Windows.value(chat);
 
-	ChatDataWindow *result = new ChatDataWindow(Core::instance()->chatConfigurationWidgetFactoryRepository(), chat);
+	auto result = m_injectedFactory->makeInjected<ChatDataWindow>(chat);
 	connect(result, SIGNAL(destroyed(Chat)), this, SLOT(windowDestroyed(Chat)));
 	Windows.insert(chat, result);
 
