@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,26 +17,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHAT_DATA_WINDOW_REPOSITORY_H
-#define CHAT_DATA_WINDOW_REPOSITORY_H
-
-#include <QtCore/QObject>
+#pragma once
 
 #include "chat/chat.h"
 
+#include <QtCore/QObject>
+
 class ChatDataWindow;
+class InjectedFactory;
 
 class ChatDataWindowRepository : public QObject
 {
 	Q_OBJECT
 
-	QMap<Chat, ChatDataWindow *> Windows;
-
-private slots:
-	void windowDestroyed(const Chat &chat);
-
 public:
-	explicit ChatDataWindowRepository(QObject *parent = 0);
+	Q_INVOKABLE explicit ChatDataWindowRepository(QObject *parent = nullptr);
 	virtual ~ChatDataWindowRepository();
 
 	ChatDataWindow * windowForChat(const Chat &chat);
@@ -47,6 +40,14 @@ public:
 public slots:
 	void showChatWindow(const Chat &chat);
 
-};
+private:
+	QPointer<InjectedFactory> m_injectedFactory;
 
-#endif // CHAT_DATA_WINDOW_REPOSITORY_H
+	QMap<Chat, ChatDataWindow *> Windows;
+
+private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+
+	void windowDestroyed(const Chat &chat);
+
+};
