@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,40 +18,77 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QDialogButtonBox>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QVBoxLayout>
 
 #include "buddies/group.h"
 #include "chat/chat-manager.h"
 #include "chat/type/chat-type-manager.h"
 #include "configuration/config-file-variant-wrapper.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/chat-configuration-widget-factory-repository.h"
 #include "gui/widgets/chat-configuration-widget-factory.h"
-#include "gui/widgets/chat-configuration-widget-tab-adapter.h"
+#include "gui/widgets/chat-configuration-widget-group-boxes-adapter.h"
 #include "gui/widgets/chat-configuration-widget.h"
 #include "gui/widgets/chat-edit-widget.h"
+#include "gui/widgets/chat-groups-configuration-widget.h"
 #include "gui/widgets/composite-configuration-value-state-notifier.h"
 #include "gui/widgets/group-list.h"
 #include "gui/widgets/simple-configuration-value-state-notifier.h"
 #include "icons/icons-manager.h"
-#include "misc/change-notifier.h"
 #include "misc/change-notifier-lock.h"
+#include "misc/change-notifier.h"
 #include "os/generic/window-geometry-manager.h"
 #include "activate.h"
 
 #include "chat-data-window.h"
 
-ChatDataWindow::ChatDataWindow(ChatConfigurationWidgetFactoryRepository *chatConfigurationWidgetFactoryRepository, const Chat &chat) :
-		QWidget(0, Qt::Dialog), MyChatConfigurationWidgetFactoryRepository(chatConfigurationWidgetFactoryRepository),
+ChatDataWindow::ChatDataWindow(const Chat &chat) :
+		QWidget(0, Qt::Dialog),
 		ValueStateNotifier(new CompositeConfigurationValueStateNotifier(this)),
 		SimpleStateNotifier(new SimpleConfigurationValueStateNotifier(this)),
 		MyChat(chat), EditWidget(0)
+{
+}
+
+ChatDataWindow::~ChatDataWindow()
+{
+	emit destroyed(MyChat);
+}
+
+void ChatDataWindow::setChatConfigurationWidgetFactoryRepository(ChatConfigurationWidgetFactoryRepository *chatConfigurationWidgetFactoryRepository)
+{
+	m_chatConfigurationWidgetFactoryRepository = chatConfigurationWidgetFactoryRepository;
+}
+
+void ChatDataWindow::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void ChatDataWindow::setChatTypeManager(ChatTypeManager *chatTypeManager)
+{
+	m_chatTypeManager = chatTypeManager;
+}
+
+void ChatDataWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ChatDataWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ChatDataWindow::init()
 {
 	setWindowRole("kadu-chat-data");
 	setAttribute(Qt::WA_DeleteOnClose);
@@ -64,10 +96,9 @@ ChatDataWindow::ChatDataWindow(ChatConfigurationWidgetFactoryRepository *chatCon
 
 	createGui();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "ChatDataWindowGeometry"), QRect(0, 50, 425, 500), this);
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "ChatDataWindowGeometry"), QRect(0, 50, 425, 500), this);
 
-	connect(ChatManager::instance(), SIGNAL(chatRemoved(Chat)),
-			this, SLOT(chatRemoved(Chat)));
+	connect(m_chatManager, SIGNAL(chatRemoved(Chat)), this, SLOT(chatRemoved(Chat)));
 
 	SimpleStateNotifier->setState(StateNotChanged);
 	ValueStateNotifier->addConfigurationValueStateNotifier(SimpleStateNotifier);
@@ -75,21 +106,13 @@ ChatDataWindow::ChatDataWindow(ChatConfigurationWidgetFactoryRepository *chatCon
 	connect(ValueStateNotifier, SIGNAL(stateChanged(ConfigurationValueState)), this, SLOT(stateChangedSlot(ConfigurationValueState)));
 	stateChangedSlot(ValueStateNotifier->state());
 
-	if (MyChatConfigurationWidgetFactoryRepository)
-	{
-		connect(MyChatConfigurationWidgetFactoryRepository, SIGNAL(factoryRegistered(ChatConfigurationWidgetFactory*)),
-				this, SLOT(factoryRegistered(ChatConfigurationWidgetFactory*)));
-		connect(MyChatConfigurationWidgetFactoryRepository, SIGNAL(factoryUnregistered(ChatConfigurationWidgetFactory*)),
-				this, SLOT(factoryUnregistered(ChatConfigurationWidgetFactory*)));
+	connect(m_chatConfigurationWidgetFactoryRepository, SIGNAL(factoryRegistered(ChatConfigurationWidgetFactory*)),
+			this, SLOT(factoryRegistered(ChatConfigurationWidgetFactory*)));
+	connect(m_chatConfigurationWidgetFactoryRepository, SIGNAL(factoryUnregistered(ChatConfigurationWidgetFactory*)),
+			this, SLOT(factoryUnregistered(ChatConfigurationWidgetFactory*)));
 
-		foreach (ChatConfigurationWidgetFactory *factory, MyChatConfigurationWidgetFactoryRepository->factories())
-			factoryRegistered(factory);
-	}
-}
-
-ChatDataWindow::~ChatDataWindow()
-{
-	emit destroyed(MyChat);
+	foreach (ChatConfigurationWidgetFactory *factory, m_chatConfigurationWidgetFactoryRepository->factories())
+		factoryRegistered(factory);
 }
 
 void ChatDataWindow::factoryRegistered(ChatConfigurationWidgetFactory *factory)
@@ -109,11 +132,14 @@ void ChatDataWindow::factoryUnregistered(ChatConfigurationWidgetFactory *factory
 	if (ChatConfigurationWidgets.contains(factory))
 	{
 		ChatConfigurationWidget *widget = ChatConfigurationWidgets.value(factory);
-		if (widget->stateNotifier())
-			ValueStateNotifier->removeConfigurationValueStateNotifier(widget->stateNotifier());
-		emit widgetRemoved(widget);
-		widget->deleteLater();
 		ChatConfigurationWidgets.remove(factory);
+		if (widget)
+		{
+			if (widget->stateNotifier())
+				ValueStateNotifier->removeConfigurationValueStateNotifier(widget->stateNotifier());
+			emit widgetRemoved(widget);
+			widget->deleteLater();
+		}
 	}
 }
 
@@ -132,7 +158,7 @@ void ChatDataWindow::show()
 {
 	QWidget::show();
 
-	_activateWindow(this);
+	_activateWindow(m_configuration, this);
 }
 
 void ChatDataWindow::createGui()
@@ -141,8 +167,6 @@ void ChatDataWindow::createGui()
 
 	TabWidget = new QTabWidget(this);
 
-	new ChatConfigurationWidgetTabAdapter(this, TabWidget, this);
-
 	GeneralTab = new QWidget(TabWidget);
 	QVBoxLayout *generalLayout = new QVBoxLayout(GeneralTab);
 
@@ -158,30 +182,41 @@ void ChatDataWindow::createGui()
 	nameLayout->addWidget(numberLabel);
 	nameLayout->addWidget(DisplayEdit);
 
-	QLabel *groupsLabel = new QLabel(tr("Add this chat to the groups below by checking the box next to the appropriate groups."), this);
-	groupsLabel->setWordWrap(true);
-
-	ChatGroupList = new GroupList(this);
-	ChatGroupList->setCheckedGroups(MyChat.groups());
-
 	generalLayout->addWidget(nameWidget);
-	generalLayout->addWidget(groupsLabel);
-	generalLayout->addWidget(ChatGroupList);
 
 	TabWidget->addTab(GeneralTab, tr("General"));
 
-	ChatType *chatType = ChatTypeManager::instance()->chatType(MyChat.type());
+	auto chatType = m_chatTypeManager->chatType(MyChat.type());
 	if (chatType)
 	{
 		EditWidget = chatType->createEditWidget(MyChat, TabWidget);
 		if (EditWidget)
 		{
-			TabWidget->addTab(EditWidget, tr("Chat"));
+			auto groupBox = new QGroupBox{GeneralTab};
+			groupBox->setFlat(true);
+			groupBox->setTitle(tr("Chat"));
+
+			auto groupBoxLayout = new QVBoxLayout{groupBox};
+			groupBoxLayout->setMargin(0);
+			groupBoxLayout->setSpacing(4);
+			groupBoxLayout->addWidget(EditWidget);
+
+			generalLayout->addWidget(groupBox);
 			if (EditWidget->stateNotifier())
 				ValueStateNotifier->addConfigurationValueStateNotifier(EditWidget->stateNotifier());
 		}
 	}
 
+	generalLayout->addStretch(100);
+
+	GroupsTab = m_injectedFactory->makeInjected<ChatGroupsConfigurationWidget>(MyChat, this);
+	TabWidget->addTab(GroupsTab, tr("Groups"));
+
+	auto optionsTab = new QWidget{this};
+	(new QVBoxLayout{optionsTab})->addStretch(100);
+	new ChatConfigurationWidgetGroupBoxesAdapter(this, optionsTab);
+	TabWidget->addTab(optionsTab, tr("Options"));
+
 	layout->addWidget(TabWidget);
 
 	createButtons(layout);
@@ -220,10 +255,11 @@ void ChatDataWindow::updateChat()
 	if (EditWidget)
 		EditWidget->apply();
 
+	GroupsTab->save();
+
 	applyChatConfigurationWidgets();
 
 	MyChat.setDisplay(DisplayEdit->text());
-	MyChat.setGroups(ChatGroupList->checkedGroups());
 
 	emit save();
 }
@@ -259,7 +295,7 @@ void ChatDataWindow::displayEditChanged()
 		return;
 	}
 
-	const Chat &chat = ChatManager::instance()->byDisplay(DisplayEdit->text());
+	const Chat &chat = m_chatManager->byDisplay(DisplayEdit->text());
 	if (chat)
 		SimpleStateNotifier->setState(StateChangedDataInvalid);
 	else
