@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +22,7 @@
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class ChatWidgetManager;
 class ChatWindowStorage;
@@ -36,13 +33,9 @@ class ChatWindowManager : public QObject
 	Q_OBJECT
 
 public:
-	explicit ChatWindowManager(QObject *parent = 0);
+	Q_INVOKABLE explicit ChatWindowManager(QObject *parent = nullptr);
 	virtual ~ChatWindowManager();
 
-	void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
-	void setChatWindowRepository(ChatWindowRepository *chatWindowRepository);
-	void setChatWindowStorage(ChatWindowStorage *chatWindowStorage);
-
 	void openStoredChatWindows();
 	void storeOpenedChatWindows();
 
@@ -51,4 +44,9 @@ private:
 	QPointer<ChatWindowRepository> m_chatWindowRepository;
 	QPointer<ChatWindowStorage> m_chatWindowStorage;
 
+private slots:
+	INJEQT_SET void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
+	INJEQT_SET void setChatWindowRepository(ChatWindowRepository *chatWindowRepository);
+	INJEQT_SET void setChatWindowStorage(ChatWindowStorage *chatWindowStorage);
+
 };
