@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,11 +19,13 @@
 
 #include "chat-window-storage-configurator.h"
 
-#include "configuration/configuration-file.h"
-#include "gui/windows/chat-window/chat-window-storage.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/windows/chat-window/chat-window-storage-configuration.h"
+#include "gui/windows/chat-window/chat-window-storage.h"
 
-ChatWindowStorageConfigurator::ChatWindowStorageConfigurator()
+ChatWindowStorageConfigurator::ChatWindowStorageConfigurator(Configuration *configuration) :
+		m_configuration{configuration}
 {
 	createDefaultConfiguration();
 }
@@ -42,12 +44,12 @@ void ChatWindowStorageConfigurator::configurationUpdated()
 
 void ChatWindowStorageConfigurator::createDefaultConfiguration() const
 {
-	config_file.addVariable("Chat", "SaveOpenedWindows", true);
+	m_configuration->deprecatedApi()->addVariable("Chat", "SaveOpenedWindows", true);
 }
 
 ChatWindowStorageConfiguration ChatWindowStorageConfigurator::loadConfiguration() const
 {
 	auto configuration = ChatWindowStorageConfiguration();
-	configuration.setStoreOpenedChatWindows(config_file.readBoolEntry("Chat", "SaveOpenedWindows", true));
+	configuration.setStoreOpenedChatWindows(m_configuration->deprecatedApi()->readBoolEntry("Chat", "SaveOpenedWindows", true));
 	return configuration;
 }
