@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -51,16 +51,16 @@ std::unique_ptr<StoragePoint> ChatWindowStorage::storagePoint() const
 {
 	if (!m_storagePointFactory)
 		return {};
-	return m_storagePointFactory.data()->createStoragePoint(QLatin1String("ChatWindows"));
+	return m_storagePointFactory.data()->createStoragePoint(QStringLiteral("ChatWindows"));
 }
 
 QVector<Chat> ChatWindowStorage::loadChats() const
 {
 	auto storage = storagePoint();
-	if (!storage)
+	if (!storage || !m_configuration.storeOpenedChatWindows())
 		return {};
 
-	auto chatListStorage = ChatListStorage{storage.get(), QLatin1String("Chat")};
+	auto chatListStorage = ChatListStorage{storage.get(), QStringLiteral("Chat")};
 	chatListStorage.setChatManager(m_chatManager.data());
 	return chatListStorage.load();
 }
@@ -68,10 +68,10 @@ QVector<Chat> ChatWindowStorage::loadChats() const
 void ChatWindowStorage::storeChats(const QVector<Chat> &chats)
 {
 	auto storage = storagePoint();
-	if (!storage)
+	if (!storage || !m_configuration.storeOpenedChatWindows())
 		return;
 
-	auto chatListStorage = ChatListStorage{storage.get(), QLatin1String("Chat")};
+	auto chatListStorage = ChatListStorage{storage.get(), QStringLiteral("Chat")};
 	chatListStorage.store(chats);
 }
 
