@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,10 +22,11 @@
 
 #include "gui/windows/chat-window/chat-window-storage-configuration.h"
 
-#include <memory>
 #include <QtCore/QObject>
-#include <QtCore/QVector>
 #include <QtCore/QPointer>
+#include <QtCore/QVector>
+#include <injeqt/injeqt.h>
+#include <memory>
 
 class Chat;
 class ChatManager;
@@ -49,12 +50,9 @@ class ChatWindowStorage : public QObject
 	Q_OBJECT
 
 public:
-	explicit ChatWindowStorage(QObject *parent = nullptr);
+	Q_INVOKABLE explicit ChatWindowStorage(QObject *parent = nullptr);
 	virtual ~ChatWindowStorage();
 
-	void setChatManager(ChatManager *chatManager);
-	void setStoragePointFactory(StoragePointFactory *storagePointFactory);
-
 	void setConfiguration(ChatWindowStorageConfiguration configuration);
 
 	/**
@@ -74,6 +72,10 @@ private:
 
 	std::unique_ptr<StoragePoint> storagePoint() const;
 
+private slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setStoragePointFactory(StoragePointFactory *storagePointFactory);
+
 };
 
 /**
