@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2007, 2008, 2009, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,24 +20,29 @@
 
 #pragma once
 
-#include <QtGui/QWidget>
-
+#include "chat/chat.h"
 #include "configuration/configuration-aware-object.h"
 #include "os/generic/compositing-aware-object.h"
 #include "os/generic/desktop-aware-object.h"
 #include "exports.h"
 
-class QTimer;
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
-class Chat;
+class ChatConfigurationHolder;
 class ChatWidget;
+class Chat;
+class Configuration;
+class IconsManager;
+class InjectedFactory;
 
 class KADUAPI ChatWindow : public QWidget, ConfigurationAwareObject, CompositingAwareObject, DesktopAwareObject
 {
 	Q_OBJECT
 
 public:
-	explicit ChatWindow(ChatWidget *chatWidget, QWidget *parent = 0);
+	explicit ChatWindow(Chat chat, QWidget *parent = nullptr);
 	virtual ~ChatWindow();
 
 	Chat chat() const;
@@ -52,11 +52,6 @@ public:
 
 	void setWindowTitle(QString title);
 
-public slots:
-	// TODO: rename
-	void blinkTitle();
-	void showNewMessagesNumInTitle();
-
 signals:
 	void activated(ChatWindow *chatWindow);
 	void windowDestroyed(ChatWindow *chatWindow);
@@ -71,17 +66,23 @@ protected:
 	virtual void compositingDisabled() override;
 
 private:
-	ChatWidget *m_chatWidget;
-	QTimer *m_titleTimer;
+	QPointer<ChatConfigurationHolder> m_chatConfigurationHolder;
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<InjectedFactory> m_injectedFactory;
 
-	bool m_showNewMessagesNum;
-	bool m_blinkChatTitle;
+	Chat m_chat;
+	ChatWidget *m_chatWidget;
 
 	QRect defaultGeometry() const;
 
 private slots:
-	void unreadMessagesCountChanged(ChatWidget *chatWidget);
-	void updateIcon();
+	INJEQT_SET void setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
 	void updateTitle();
 
 };
