@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,11 +19,14 @@
 
 #include "window-chat-widget-container-handler.h"
 
-#include "activate.h"
+#include "core/injected-factory.h"
+#include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
-#include "gui/windows/chat-window/chat-window.h"
-#include "gui/windows/chat-window/chat-window-factory.h"
 #include "gui/windows/chat-window/chat-window-repository.h"
+#include "gui/windows/chat-window/chat-window.h"
+#include "activate.h"
+
+#include <QtWidgets/QApplication>
 
 WindowChatWidgetContainerHandler::WindowChatWidgetContainerHandler(QObject *parent) :
 		ChatWidgetContainerHandler{parent}
@@ -39,48 +37,65 @@ WindowChatWidgetContainerHandler::~WindowChatWidgetContainerHandler()
 {
 }
 
-void WindowChatWidgetContainerHandler::setChatWindowFactory(ChatWindowFactory *chatWindowFactory)
-{
-	m_chatWindowFactory = chatWindowFactory;
-}
-
 void WindowChatWidgetContainerHandler::setChatWindowRepository(ChatWindowRepository *chatWindowRepository)
 {
 	m_chatWindowRepository = chatWindowRepository;
 }
 
-bool WindowChatWidgetContainerHandler::acceptChatWidget(ChatWidget *chatWidget) const
+void WindowChatWidgetContainerHandler::setConfiguration(Configuration *configuration)
 {
-	return chatWidget && m_chatWindowFactory && m_chatWindowRepository;
+	m_configuration = configuration;
 }
 
-void WindowChatWidgetContainerHandler::addChatWidget(ChatWidget *chatWidget)
+void WindowChatWidgetContainerHandler::setInjectedFactory(InjectedFactory *injectedFactory)
 {
-	if (!chatWidget || !m_chatWindowFactory || !m_chatWindowRepository)
-		return;
+	m_injectedFactory = injectedFactory;
+}
 
-	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chatWidget->chat());
+bool WindowChatWidgetContainerHandler::acceptChat(Chat chat) const
+{
+	return chat;
+}
+
+ChatWidget * WindowChatWidgetContainerHandler::addChat(Chat chat, OpenChatActivation activation)
+{
+	if (!acceptChat(chat))
+		return nullptr;
+
+	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chat);
 	if (!chatWindow)
 	{
-		auto newChatWindow = m_chatWindowFactory.data()->createChatWindow(chatWidget);
-		chatWindow = newChatWindow.get();
+		chatWindow = m_injectedFactory->makeInjected<ChatWindow>(chat);
 		if (!chatWindow)
-			return;
+			return nullptr;
 
-		m_chatWindowRepository.data()->addChatWindow(std::move(newChatWindow));
+		m_chatWindowRepository.data()->addChatWindow(chatWindow);
 		connect(chatWindow, SIGNAL(activated(ChatWindow*)), this, SLOT(chatWindowActivated(ChatWindow*)));
 	}
 
-	chatWindow->show();
+	switch (activation)
+	{
+		case OpenChatActivation::Minimize:
+			chatWindow->showMinimized();
+			break;
+		default:
+			chatWindow->show();
+			break;
+	}
+
+	if (chat.unreadMessagesCount() != 0)
+		qApp->alert(chatWindow);
+
+	return chatWindow->chatWidget();
 }
 
-void WindowChatWidgetContainerHandler::removeChatWidget(ChatWidget *chatWidget)
+void WindowChatWidgetContainerHandler::removeChat(Chat chat)
 {
-	if (!chatWidget || !m_chatWindowRepository)
+	if (!chat || !m_chatWindowRepository)
 		return;
 
-	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chatWidget->chat());
-	m_chatWindowRepository.data()->removeChatWindow(chatWindow);
+	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chat);
+	chatWindow->deleteLater();
 }
 
 bool WindowChatWidgetContainerHandler::isChatWidgetActive(ChatWidget *chatWidget)
@@ -89,7 +104,7 @@ bool WindowChatWidgetContainerHandler::isChatWidgetActive(ChatWidget *chatWidget
 		return false;
 
 	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chatWidget->chat());
-	return chatWindow ? _isWindowActiveOrFullyVisible(chatWindow) : false;
+	return chatWindow ? chatWindow->isChatWidgetActive(chatWidget) : false;
 }
 
 void WindowChatWidgetContainerHandler::tryActivateChatWidget(ChatWidget *chatWidget)
@@ -99,7 +114,17 @@ void WindowChatWidgetContainerHandler::tryActivateChatWidget(ChatWidget *chatWid
 
 	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chatWidget->chat());
 	if (chatWindow)
-		_activateWindow(chatWindow);
+		_activateWindow(m_configuration, chatWindow);
+}
+
+void WindowChatWidgetContainerHandler::tryMinimizeChatWidget(ChatWidget* chatWidget)
+{
+	if (!chatWidget || !m_chatWindowRepository)
+		return;
+
+	auto chatWindow = m_chatWindowRepository.data()->windowForChat(chatWidget->chat());
+	if (chatWindow)
+		chatWindow->showMinimized();
 }
 
 void WindowChatWidgetContainerHandler::chatWindowActivated(ChatWindow *chatWindow)
