@@ -27,8 +27,9 @@
 #include <injeqt/injeqt.h>
 
 class ChatWindow;
-class ChatWindowFactory;
 class ChatWindowRepository;
+class Configuration;
+class InjectedFactory;
 
 class WindowChatWidgetContainerHandler : public ChatWidgetContainerHandler
 {
@@ -47,12 +48,14 @@ public:
     virtual void tryMinimizeChatWidget(ChatWidget *chatWidget) override;
 
 private:
-	QPointer<ChatWindowFactory> m_chatWindowFactory;
 	QPointer<ChatWindowRepository> m_chatWindowRepository;
+	QPointer<Configuration> m_configuration;
+	QPointer<InjectedFactory> m_injectedFactory;
 
 private slots:
-	INJEQT_SETTER void setChatWindowFactory(ChatWindowFactory *chatWindowFactory);
-	INJEQT_SETTER void setChatWindowRepository(ChatWindowRepository *chatWindowRepository);
+	INJEQT_SET void setChatWindowRepository(ChatWindowRepository *chatWindowRepository);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
 
 	void chatWindowActivated(ChatWindow *chatWindow);
 
