@@ -1,12 +1,12 @@
 /*
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Maciej Płaza (plaza.maciej@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,18 +23,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QHBoxLayout>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QListWidget>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QWidget>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QVBoxLayout>
+#include <QtWidgets/QWidget>
 #include <QtXml/QDomElement>
 
 #include "configuration/config-file-variant-wrapper.h"
 #include "configuration/configuration-manager.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/configuration/config-action-button.h"
 #include "gui/widgets/configuration/config-check-box.h"
 #include "gui/widgets/configuration/config-color-button.h"
@@ -62,17 +62,43 @@
 
 #include "activate.h"
 
-ConfigurationWindow::ConfigurationWindow(const QString &name, const QString &caption, const QString &section, ConfigurationWindowDataManager *dataManager)
-	: QDialog(Core::instance()->kaduWindow(), Qt::Window), DesktopAwareObject(this),  Name(name), Section(section)
+ConfigurationWindow::ConfigurationWindow(const QString &name, const QString &caption, const QString &section, ConfigurationWindowDataManager *dataManager, QWidget *parent) :
+		QDialog(parent, Qt::Window),
+		DesktopAwareObject(this),
+		m_dataManager{dataManager},
+		Name(name),
+		Section(section)
 {
 	setWindowRole("kadu-configuration");
 
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(caption);
+}
 
+ConfigurationWindow::~ConfigurationWindow()
+{
+}
+
+void ConfigurationWindow::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void ConfigurationWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ConfigurationWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void ConfigurationWindow::init()
+{
 	QVBoxLayout *main_layout = new QVBoxLayout(this);
 
-	configurationWidget = new ConfigurationWidget(dataManager, this);
+	configurationWidget = m_injectedFactory->makeInjected<ConfigurationWidget>(dataManager(), this);
 
 	QDialogButtonBox *buttons_layout = new QDialogButtonBox(Qt::Horizontal, this);
 
@@ -92,24 +118,25 @@ ConfigurationWindow::ConfigurationWindow(const QString &name, const QString &cap
 	main_layout->addSpacing(16);
 	main_layout->addWidget(buttons_layout);
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper(section, name + "_Geometry"), QRect(0, 50, 790, 580), this);
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, section(), name() + "_Geometry"), QRect(0, 50, 790, 580), this);
 }
 
-ConfigurationWindow::~ConfigurationWindow()
+InjectedFactory * ConfigurationWindow::injectedFactory() const
 {
+	return m_injectedFactory;
 }
 
 void ConfigurationWindow::show()
 {
 	if (!isVisible())
   	{
-		widget()->init();
+		widget()->beforeShow();
 		widget()->loadConfiguration();
 		QWidget::show();
 	}
 	else
 	{
-		_activateWindow(this);
+		_activateWindow(m_configuration, this);
 	}
 }
 
@@ -129,7 +156,7 @@ void ConfigurationWindow::updateConfig()
 	emit configurationSaved();
 	ConfigurationAwareObject::notifyAll();
 
-	ConfigurationManager::instance()->flush();
+	m_configurationManager->flush();
 }
 
 void ConfigurationWindow::keyPressEvent(QKeyEvent *e)
