@@ -1,13 +1,13 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010 Radosław Szymczyszyn (lavrin@gmail.com)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2009 Longer (longer89@gmail.com)
  * %kadu copyright end%
  *
@@ -26,18 +26,20 @@
  */
 
 #include <QtCore/QLocale>
-#include <QtGui/QApplication>
 #include <QtGui/QClipboard>
-#include <QtGui/QInputDialog>
-#include <QtGui/QMenu>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
 #include "buddies/buddy-manager.h"
-#include "buddies/group-manager.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/application.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
 #include "gui/actions/change-status-action.h"
@@ -47,12 +49,13 @@
 #include "gui/actions/delete-talkable-action.h"
 #include "gui/actions/edit-talkable-action.h"
 #include "gui/actions/recent-chats-action.h"
+#include "gui/actions/talkable-tree-view/collapse-action.h"
+#include "gui/actions/talkable-tree-view/expand-action.h"
 #include "gui/menu/menu-inventory.h"
 #include "gui/status-icon.h"
 #include "gui/widgets/buddy-info-panel.h"
 #include "gui/widgets/chat-widget/chat-widget-actions.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
-#include "gui/widgets/dialog/add-group-dialog-widget.h"
 #include "gui/widgets/dialog/merge-buddies-dialog-widget.h"
 #include "gui/widgets/status-menu.h"
 #include "gui/widgets/talkable-delegate-configuration.h"
@@ -60,12 +63,14 @@
 #include "gui/windows/add-buddy-window.h"
 #include "gui/windows/buddy-delete-window.h"
 #include "gui/windows/kadu-dialog.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
-#include "gui/windows/main-configuration-window.h"
+#include "gui/windows/group-edit-window.h"
+#include "gui/windows/main-configuration-window-service.h"
 #include "gui/windows/message-dialog.h"
-#include "gui/windows/multilogon-window.h"
+#include "gui/windows/multilogon-window-service.h"
 #include "gui/windows/search-window.h"
-#include "gui/windows/your-accounts.h"
+#include "gui/windows/your-accounts-window-service.h"
 #include "icons/kadu-icon.h"
 #include "misc/misc.h"
 #include "model/roles.h"
@@ -80,17 +85,16 @@
 #include "talkable/model/talkable-model.h"
 #include "talkable/model/talkable-proxy-model.h"
 #include "url-handlers/url-handler-manager.h"
-#include "kadu-application.h"
 
 #include "about.h"
 #include "debug.h"
 
 #include "kadu-window-actions.h"
 
-void hideNoMultilogonAccounts(Action *action)
+void hideNoMultilogonAccounts(AccountManager *accountManager, Action *action)
 {
-	bool hasMultilogonAccount = false;
-	foreach (const Account &account, AccountManager::instance()->items())
+	auto hasMultilogonAccount = false;
+	for (auto const &account : accountManager->items())
 		if (account.protocolHandler() && account.protocolHandler()->multilogonService())
 		{
 			hasMultilogonAccount = true;
@@ -100,10 +104,10 @@ void hideNoMultilogonAccounts(Action *action)
 	action->setVisible(hasMultilogonAccount);
 }
 
-void hideNoSearchServiceAccounts(Action *action)
+void hideNoSearchServiceAccounts(AccountManager *accountManager, Action *action)
 {
-	bool hasSearchServiceAccount = false;
-	foreach (const Account &account, AccountManager::instance()->items())
+	auto hasSearchServiceAccount = false;
+	for (auto const &account : accountManager->items())
 		if (account.protocolHandler() && account.protocolHandler()->searchService())
 		{
 			hasSearchServiceAccount = true;
@@ -131,35 +135,44 @@ void disableNoDescription(Action *action)
 	action->setEnabled(!action->context()->contacts().toContact().currentStatus().description().isEmpty());
 }
 
-void disableNoDescriptionUrl(Action *action)
+void disableNoDescriptionUrl(UrlHandlerManager *urlHandlerManager, Action *action)
 {
-	action->setEnabled(action->context()->contacts().toContact().currentStatus().description().indexOf(UrlHandlerManager::instance()->urlRegExp()) >= 0);
+	action->setEnabled(action->context()->contacts().toContact().currentStatus().description().indexOf(urlHandlerManager->urlRegExp()) >= 0);
 }
 
-void disableNoEMail(Action *action)
+void disableNoEMail(UrlHandlerManager *urlHandlerManager, Action *action)
 {
 	const Buddy &buddy = action->context()->buddies().toBuddy();
-	bool hasMail = !buddy.email().isEmpty() && buddy.email().indexOf(UrlHandlerManager::instance()->mailRegExp()) == 0;
+	bool hasMail = !buddy.email().isEmpty() && buddy.email().indexOf(urlHandlerManager->mailRegExp()) == 0;
 
 	action->setEnabled(hasMail);
 }
 
-void disableIfContactSelected(Action *action)
+void disableIfContactSelected(Myself *myself, Action *action)
 {
 	if (!action || action->context())
 		return;
 
 	action->setEnabled(!action->context()->roles().contains(ContactRole) && !action->context()->buddies().isEmpty());
 
-	if (action->context()->buddies().contains(Core::instance()->myself()))
+	if (action->context()->buddies().contains(myself->buddy()))
 		action->setEnabled(false);
 	else
 		action->setEnabled(true);
 }
 
-void disableMerge(Action *action)
+void disableMerge(Myself *myself, Action *action)
 {
-	disableIfContactSelected(action);
+	if (action->context()->buddies().isAnyTemporary())
+	{
+		action->setEnabled(false);
+		return;
+	}
+
+	if (action->context()->buddies().contains(myself->buddy()))
+		action->setEnabled(false);
+	else
+		action->setEnabled(true);
 
 	if (1 != action->context()->buddies().size())
 		action->setEnabled(false);
@@ -167,162 +180,262 @@ void disableMerge(Action *action)
 
 KaduWindowActions::KaduWindowActions(QObject *parent) : QObject(parent)
 {
-	Actions::instance()->blockSignals();
+}
 
-	Configuration = new ActionDescription(this,
+KaduWindowActions::~KaduWindowActions()
+{
+}
+
+void KaduWindowActions::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void KaduWindowActions::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void KaduWindowActions::setApplication(Application *application)
+{
+	m_application = application;
+}
+
+void KaduWindowActions::setChatWidgetActions(ChatWidgetActions *chatWidgetActions)
+{
+	m_chatWidgetActions = chatWidgetActions;
+}
+
+void KaduWindowActions::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void KaduWindowActions::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void KaduWindowActions::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void KaduWindowActions::setMainConfigurationWindowService(MainConfigurationWindowService *mainConfigurationWindowService)
+{
+	m_mainConfigurationWindowService = mainConfigurationWindowService;
+}
+
+void KaduWindowActions::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void KaduWindowActions::setMultilogonWindowService(MultilogonWindowService *multilogonWindowService)
+{
+	m_multilogonWindowService = multilogonWindowService;
+}
+
+void KaduWindowActions::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void KaduWindowActions::setParser(Parser *parser)
+{
+	m_parser = parser;
+}
+
+void KaduWindowActions::setUrlHandlerManager(UrlHandlerManager *urlHandlerManager)
+{
+	m_urlHandlerManager = urlHandlerManager;
+}
+
+void KaduWindowActions::setUrlOpener(UrlOpener *urlOpener)
+{
+	m_urlOpener = urlOpener;
+}
+
+void KaduWindowActions::setYourAccountsWindowService(YourAccountsWindowService *yourAccountsWindowService)
+{
+	m_yourAccountsWindowService = yourAccountsWindowService;
+}
+
+void KaduWindowActions::init()
+{
+	m_actions->blockSignals();
+
+	ShowConfigurationWindow = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeGlobal, "configurationAction",
 		this, SLOT(configurationActionActivated(QAction *, bool)),
 		KaduIcon("preferences-other"), tr("Preferences")
 	);
-	Configuration->setShortcut("kadu_configure", Qt::ApplicationShortcut);
+	ShowConfigurationWindow->setShortcut("kadu_configure", Qt::ApplicationShortcut);
 
-	ShowYourAccounts = new ActionDescription(this,
+	ShowYourAccounts = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "yourAccountsAction",
 		this, SLOT(yourAccountsActionActivated(QAction *, bool)),
 		KaduIcon("x-office-address-book"), tr("Your Accounts")
 	);
 
-	RecentChats = new RecentChatsAction(this);
+	RecentChats = m_injectedFactory->makeInjected<RecentChatsAction>(this);
+	m_actions->insert(RecentChats);
 
-	ShowMultilogons = new ActionDescription(this,
+	ShowMultilogons = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "showMultilogonsAction",
 		this, SLOT(showMultilogonsActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/multilogon"), tr("Multilogons"), false,
-		hideNoMultilogonAccounts
+		[this](Action *action){ return hideNoMultilogonAccounts(m_accountManager, action); }
 	);
 	connect(ShowMultilogons, SIGNAL(actionCreated(Action *)), this, SLOT(showMultilogonsActionCreated(Action *)));
 
-	ExitKadu = new ActionDescription(this,
+	ExitKadu = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "exitKaduAction",
 		this, SLOT(exitKaduActionActivated(QAction *, bool)),
 		KaduIcon("application-exit"), tr("&Quit")
 	);
 	ExitKadu->setShortcut("kadu_exit", Qt::ApplicationShortcut);
 
-	AddUser = new ActionDescription(this,
+	AddUser = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeGlobal, "addUserAction",
 		this, SLOT(addUserActionActivated(QAction *, bool)),
 		KaduIcon("contact-new"), tr("Add Buddy...")
 	);
 	AddUser->setShortcut("kadu_adduser", Qt::ApplicationShortcut);
 
-	AddConference = new AddConferenceAction(this);
-	AddRoomChat = new AddRoomChatAction(this);
+	AddConference = m_injectedFactory->makeInjected<AddConferenceAction>(this);
+	m_actions->insert(AddConference);
 
-	AddGroup= new ActionDescription(this,
+	AddRoomChat = m_injectedFactory->makeInjected<AddRoomChatAction>(this);
+	m_actions->insert(AddRoomChat);
+
+	AddGroup = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeGlobal, "addGroupAction",
 		this, SLOT(addGroupActionActivated(QAction *, bool)),
 		KaduIcon("group-new"), tr("Add Group...")
 	);
 
-	OpenSearch = new ActionDescription(this,
+	OpenSearch = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeGlobal, "openSearchAction",
 		this, SLOT(openSearchActionActivated(QAction *, bool)),
 		KaduIcon("edit-find"), tr("Search for Buddy..."), false,
-		hideNoSearchServiceAccounts
+		[this](Action *action){ return hideNoSearchServiceAccounts(m_accountManager, action); }
 	);
 	connect(OpenSearch, SIGNAL(actionCreated(Action*)), this, SLOT(openSearchActionCreated(Action*)));
 
-	Forum = new ActionDescription(this,
+	Forum = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "forumAction",
 		this, SLOT(forumActionActivated(QAction *, bool)),
-		{}, tr("Forum")
+		KaduIcon{}, tr("Forum")
 	);
 
-	Bugs = new ActionDescription(this,
+	Bugs = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "bugsAction",
 		this, SLOT(bugsActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/report-a-bug"), tr("Report a Bug")
 	);
 
-	GetInvolved = new ActionDescription(this,
+	GetInvolved = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "getInvolvedAction",
 		this, SLOT(getInvolvedActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/get-involved"), tr("Get Involved")
 	);
 
-	Translate = new ActionDescription(this,
+	Translate = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "translateAction",
 		this, SLOT(translateActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/translate-kadu"), tr("Translate Kadu")
 	);
 
-	About = new ActionDescription(this,
+	About = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "aboutAction",
 		this, SLOT(aboutActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/about-kadu"), tr("A&bout Kadu")
 	);
 
-	ShowInfoPanel = new ActionDescription(this,
+	ShowInfoPanel = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "showInfoPanelAction",
 		this, SLOT(showInfoPanelActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/show-information-panel"), tr("Show Information Panel"), true
 	);
 	connect(ShowInfoPanel, SIGNAL(actionCreated(Action *)), this, SLOT(showInfoPanelActionCreated(Action *)));
 
-	ShowBlockedBuddies = new ActionDescription(this,
+	ShowBlockedBuddies = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "showIgnoredAction",
 		this, SLOT(showBlockedActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/show-blocked-buddies"), tr("Show Blocked Buddies"), true
 	);
 	connect(ShowBlockedBuddies, SIGNAL(actionCreated(Action *)), this, SLOT(showBlockedActionCreated(Action *)));
 
-	ShowMyself = new ActionDescription(this,
+	ShowMyself = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "showMyselfAction",
 		this, SLOT(showMyselfActionActivated(QAction *, bool)),
 		KaduIcon(), tr("Show Myself Buddy"), true
 	);
 	connect(ShowMyself, SIGNAL(actionCreated(Action *)), this, SLOT(showMyselfActionCreated(Action *)));
 
-	CopyDescription = new ActionDescription(this,
+	auto expandAction = m_injectedFactory->makeInjected<ExpandAction>(this);
+	m_actions->insert(expandAction);
+
+	auto collapseAction = m_injectedFactory->makeInjected<CollapseAction>(this);
+	m_actions->insert(collapseAction);
+
+	m_menuInventory
+		->menu("buddy-list")
+		->addAction(expandAction, KaduMenu::SectionActionsGui, 2);
+	m_menuInventory
+		->menu("buddy-list")
+		->addAction(collapseAction, KaduMenu::SectionActionsGui, 1);
+
+	CopyDescription = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "copyDescriptionAction",
 		this, SLOT(copyDescriptionActionActivated(QAction *, bool)),
 		KaduIcon("edit-copy"), tr("Copy Description"), false,
 		disableNoDescription
 	);
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(CopyDescription, KaduMenu::SectionActions, 10);
 
-	CopyPersonalInfo = new ActionDescription(this,
+	CopyPersonalInfo = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "copyPersonalInfoAction",
 		this, SLOT(copyPersonalInfoActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/copy-personal-info"), tr("Copy Personal Info")
 	);
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(CopyPersonalInfo, KaduMenu::SectionActions, 20);
 
-	OpenDescriptionLink = new ActionDescription(this,
+	OpenDescriptionLink = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "openDescriptionLinkAction",
 		this, SLOT(openDescriptionLinkActionActivated(QAction *, bool)),
 		KaduIcon("go-jump"), tr("Open Description Link in Browser"), false,
-		disableNoDescriptionUrl
+		[this](Action *action){ return disableNoDescriptionUrl(m_urlHandlerManager, action); }
 	);
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(OpenDescriptionLink, KaduMenu::SectionActions, 30);
 
-	WriteEmail = new ActionDescription(this,
+	WriteEmail = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "writeEmailAction",
 		this, SLOT(writeEmailActionActivated(QAction *, bool)),
 		KaduIcon("mail-message-new"), tr("Send E-Mail"), false,
-		disableNoEMail
+		[this](Action *action){ return disableNoEMail(m_urlHandlerManager, action); }
 	);
 	connect(WriteEmail, SIGNAL(actionCreated(Action *)), this, SLOT(writeEmailActionCreated(Action *)));
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(WriteEmail, KaduMenu::SectionSend, 200);
 
-	LookupUserInfo = new ActionDescription(this,
+	LookupUserInfo = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "lookupUserInfoAction",
 		this, SLOT(lookupInDirectoryActionActivated(QAction *, bool)),
 		KaduIcon("edit-find"), tr("Search in Directory"), false,
 		disableNoSearchService
 	);
 
-	InactiveUsers = new ActionDescription(this,
+	InactiveUsers = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUserList, "inactiveUsersAction",
 		this, SLOT(inactiveUsersActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/show-offline-buddies"), tr("Show Offline Buddies"),
@@ -331,7 +444,7 @@ KaduWindowActions::KaduWindowActions(QObject *parent) : QObject(parent)
 	connect(InactiveUsers, SIGNAL(actionCreated(Action *)), this, SLOT(inactiveUsersActionCreated(Action *)));
 	InactiveUsers->setShortcut("kadu_showoffline");
 
-	DescriptionUsers = new ActionDescription(this,
+	DescriptionUsers = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUserList, "descriptionUsersAction",
 		this, SLOT(descriptionUsersActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/only-show-with-description"), tr("Only Show Buddies with Description"),
@@ -340,7 +453,7 @@ KaduWindowActions::KaduWindowActions(QObject *parent) : QObject(parent)
 	connect(DescriptionUsers, SIGNAL(actionCreated(Action *)), this, SLOT(descriptionUsersActionCreated(Action *)));
 	DescriptionUsers->setShortcut("kadu_showonlydesc");
 
-	ShowDescriptions = new ActionDescription(this,
+	ShowDescriptions = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUserList, "descriptionsAction",
 		this, SLOT(showDescriptionsActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/show-descriptions"), tr("Show Descriptions"),
@@ -348,7 +461,7 @@ KaduWindowActions::KaduWindowActions(QObject *parent) : QObject(parent)
 	);
 	connect(ShowDescriptions, SIGNAL(actionCreated(Action *)), this, SLOT(showDescriptionsActionCreated(Action *)));
 
-	OnlineAndDescriptionUsers = new ActionDescription(this,
+	OnlineAndDescriptionUsers = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUserList, "onlineAndDescriptionUsersAction",
 		this, SLOT(onlineAndDescUsersActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/only-show-online-and-with-description"), tr("Only Show Online Buddies and Buddies with Description"),
@@ -356,56 +469,57 @@ KaduWindowActions::KaduWindowActions(QObject *parent) : QObject(parent)
 	);
 	connect(OnlineAndDescriptionUsers, SIGNAL(actionCreated(Action *)), this, SLOT(onlineAndDescUsersActionCreated(Action *)));
 
-	EditTalkable = new EditTalkableAction(this);
+	EditTalkable = m_injectedFactory->makeInjected<EditTalkableAction>(this);
+	m_actions->insert(EditTalkable);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(EditTalkable, KaduMenu::SectionView);
 
-	MergeContact = new ActionDescription(this,
+	MergeContact = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "mergeContactAction",
 		this, SLOT(mergeContactActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/merge-buddies"), tr("Merge Buddies..."), false,
-		disableMerge
+		[this](Action *action){ return disableMerge(m_myself, action); }
 	);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(MergeContact, KaduMenu::SectionManagement, 100);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
-		->addAction(Core::instance()->chatWidgetActions()->blockUser(), KaduMenu::SectionManagement, 500);
+		->addAction(m_chatWidgetActions->blockUser(), KaduMenu::SectionManagement, 500);
 
-	DeleteTalkable = new DeleteTalkableAction(this);
+	DeleteTalkable = m_injectedFactory->makeInjected<DeleteTalkableAction>(this);
+	m_actions->insert(DeleteTalkable);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(DeleteTalkable, KaduMenu::SectionManagement, 1000);
 
 	// The last ActionDescription will send actionLoaded() signal.
 	// TODO It will not reflect all action types (see MainWindow::actionLoadedOrUnloaded() method)
 	// but will work good since KaduActions is created very early. Of course we still need a better mechanism for that.
-	Actions::instance()->unblockSignals();
+	m_actions->unblockSignals();
 
-	ChangeStatus = new ChangeStatusAction(this);
-	DefaultProxy = new DefaultProxyAction(this);
-}
+	ChangeStatus = m_injectedFactory->makeInjected<ChangeStatusAction>(this);
+	m_actions->insert(ChangeStatus);
 
-KaduWindowActions::~KaduWindowActions()
-{
+	DefaultProxy = m_injectedFactory->makeInjected<DefaultProxyAction>(this);
+	m_actions->insert(DefaultProxy);
 }
 
 void KaduWindowActions::showMultilogonsActionCreated(Action *action)
 {
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)), action, SLOT(checkState()));
-	connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)), action, SLOT(checkState()));
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)), action, SLOT(checkState()));
+	connect(m_accountManager, SIGNAL(accountUnregistered(Account)), action, SLOT(checkState()));
 }
 
 void KaduWindowActions::openSearchActionCreated(Action *action)
 {
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)), action, SLOT(checkState()));
-	connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)), action, SLOT(checkState()));
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)), action, SLOT(checkState()));
+	connect(m_accountManager, SIGNAL(accountUnregistered(Account)), action, SLOT(checkState()));
 }
 
 void KaduWindowActions::inactiveUsersActionCreated(Action *action)
@@ -416,8 +530,8 @@ void KaduWindowActions::inactiveUsersActionCreated(Action *action)
 	if (!window->talkableProxyModel())
 		return;
 
-	bool enabled = config_file.readBoolEntry("General", "ShowOffline");
-	HideOfflineTalkableFilter *filter = new HideOfflineTalkableFilter(action);
+	bool enabled = m_configuration->deprecatedApi()->readBoolEntry("General", "ShowOffline");
+	auto filter = m_injectedFactory->makeInjected<HideOfflineTalkableFilter>(action);
 	filter->setEnabled(!enabled);
 
 	action->setData(QVariant::fromValue(filter));
@@ -434,8 +548,8 @@ void KaduWindowActions::descriptionUsersActionCreated(Action *action)
 	if (!window->talkableProxyModel())
 		return;
 
-	bool enabled = !config_file.readBoolEntry("General", "ShowWithoutDescription");
-	HideWithoutDescriptionTalkableFilter *filter = new HideWithoutDescriptionTalkableFilter(action);
+	bool enabled = !m_configuration->deprecatedApi()->readBoolEntry("General", "ShowWithoutDescription");
+	auto filter = m_injectedFactory->makeInjected<HideWithoutDescriptionTalkableFilter>(action);
 	filter->setEnabled(enabled);
 
 	action->setData(QVariant::fromValue(filter));
@@ -446,7 +560,7 @@ void KaduWindowActions::descriptionUsersActionCreated(Action *action)
 
 void KaduWindowActions::showDescriptionsActionCreated(Action *action)
 {
-	bool enabled = config_file.readBoolEntry("Look", "ShowDesc");
+	bool enabled = m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowDesc");
 	action->setChecked(enabled);
 }
 
@@ -458,8 +572,8 @@ void KaduWindowActions::onlineAndDescUsersActionCreated(Action *action)
 	if (!window->talkableProxyModel())
 		return;
 
-	bool enabled = config_file.readBoolEntry("General", "ShowOnlineAndDescription");
-	HideOfflineWithoutDescriptionTalkableFilter *filter = new HideOfflineWithoutDescriptionTalkableFilter(action);
+	bool enabled = m_configuration->deprecatedApi()->readBoolEntry("General", "ShowOnlineAndDescription");
+	auto filter = m_injectedFactory->makeInjected<HideOfflineWithoutDescriptionTalkableFilter>(action);
 	filter->setEnabled(enabled);
 
 	action->setData(QVariant::fromValue(filter));
@@ -470,7 +584,7 @@ void KaduWindowActions::onlineAndDescUsersActionCreated(Action *action)
 
 void KaduWindowActions::showInfoPanelActionCreated(Action *action)
 {
-	action->setChecked(config_file.readBoolEntry("Look", "ShowInfoPanel"));
+	action->setChecked(m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowInfoPanel"));
 }
 
 void KaduWindowActions::showBlockedActionCreated(Action *action)
@@ -481,7 +595,7 @@ void KaduWindowActions::showBlockedActionCreated(Action *action)
 	if (!window->talkableProxyModel())
 		return;
 
-	bool enabled = config_file.readBoolEntry("General", "ShowBlocked");
+	bool enabled = m_configuration->deprecatedApi()->readBoolEntry("General", "ShowBlocked");
 	BlockedTalkableFilter *blockedTalkableFilter = new BlockedTalkableFilter(action);
 	blockedTalkableFilter->setEnabled(!enabled);
 
@@ -499,8 +613,8 @@ void KaduWindowActions::showMyselfActionCreated(Action *action)
 	if (!window->talkableProxyModel())
 		return;
 
-	bool enabled = config_file.readBoolEntry("General", "ShowMyself", false);
-	TalkableModel *model = qobject_cast<TalkableModel *>(window->talkableProxyModel()->sourceModel());
+	auto enabled = m_configuration->deprecatedApi()->readBoolEntry("General", "ShowMyself", false);
+	auto model = qobject_cast<TalkableModel *>(window->talkableProxyModel()->sourceModel());
 	if (model)
 	{
 		model->setIncludeMyself(enabled);
@@ -520,7 +634,7 @@ void KaduWindowActions::configurationActionActivated(QAction *sender, bool toggl
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	MainConfigurationWindow::instance()->show();
+	m_mainConfigurationWindowService->show();
 }
 
 void KaduWindowActions::yourAccountsActionActivated(QAction *sender, bool toggled)
@@ -528,7 +642,7 @@ void KaduWindowActions::yourAccountsActionActivated(QAction *sender, bool toggle
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	YourAccounts::instance()->show();
+	m_yourAccountsWindowService->show();
 }
 
 void KaduWindowActions::showMultilogonsActionActivated(QAction *sender, bool toggled)
@@ -536,7 +650,7 @@ void KaduWindowActions::showMultilogonsActionActivated(QAction *sender, bool tog
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	MultilogonWindow::instance()->show();
+	m_multilogonWindowService->show();
 }
 
 void KaduWindowActions::exitKaduActionActivated(QAction *sender, bool toggled)
@@ -546,7 +660,7 @@ void KaduWindowActions::exitKaduActionActivated(QAction *sender, bool toggled)
 
 	kdebugf();
 
-	Core::instance()->application()->quit();
+	m_application->quit();
 }
 
 void KaduWindowActions::addUserActionActivated(QAction *sender, bool toggled)
@@ -562,9 +676,9 @@ void KaduWindowActions::addUserActionActivated(QAction *sender, bool toggled)
 	const Buddy &buddy = action->context()->buddies().toBuddy();
 
 	if (buddy.isAnonymous())
-		(new AddBuddyWindow(action->parentWidget(), buddy, true))->show();
+		(m_injectedFactory->makeInjected<AddBuddyWindow>(action->parentWidget(), buddy, true))->show();
 	else
-		(new AddBuddyWindow(action->parentWidget()))->show();
+		(m_injectedFactory->makeInjected<AddBuddyWindow>(action->parentWidget()))->show();
 
 	kdebugf2();
 }
@@ -583,7 +697,7 @@ void KaduWindowActions::mergeContactActionActivated(QAction *sender, bool toggle
 	if (!buddy)
 		return;
 
-	MergeBuddiesDialogWidget *mergeWidget = new MergeBuddiesDialogWidget(buddy,
+	MergeBuddiesDialogWidget *mergeWidget = m_injectedFactory->makeInjected<MergeBuddiesDialogWidget>(buddy,
 			tr("Choose which buddy would you like to merge with <i>%1</i>")
 			.arg(buddy.display()), sender->parentWidget());
 	KaduDialog *window = new KaduDialog(mergeWidget, sender->parentWidget());
@@ -597,17 +711,15 @@ void KaduWindowActions::addGroupActionActivated(QAction *sender, bool toggled)
 {
 	Q_UNUSED(toggled)
 
-	AddGroupDialogWidget *groupWidget = new AddGroupDialogWidget(tr("Please enter the name for the new group"), sender->parentWidget());
-	KaduDialog *window = new KaduDialog(groupWidget, sender->parentWidget());
-	window->setAcceptButtonText(tr("Add Group"));
-	window->exec();
+	auto window = m_injectedFactory->makeInjected<GroupEditWindow>(Group::null, sender->parentWidget());
+	window->show();
 }
 
 void KaduWindowActions::openSearchActionActivated(QAction *sender, bool toggled)
 {
 	Q_UNUSED(toggled)
 
-	(new SearchWindow(sender->parentWidget()))->show();
+	(m_injectedFactory->makeInjected<SearchWindow>(sender->parentWidget()))->show();
 }
 
 void KaduWindowActions::forumActionActivated(QAction *sender, bool toggled)
@@ -615,10 +727,10 @@ void KaduWindowActions::forumActionActivated(QAction *sender, bool toggled)
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	if (config_file.readEntry("General", "Language") == "pl")
-		UrlOpener::openUrl("http://www.kadu.im/forum/");
+	if (m_configuration->deprecatedApi()->readEntry("General", "Language") == "pl")
+		m_urlOpener->openUrl("http://www.kadu.im/forum/");
 	else
-		UrlOpener::openUrl("http://www.kadu.im/forum/viewforum.php?f=12");
+		m_urlOpener->openUrl("http://www.kadu.im/forum/viewforum.php?f=12");
 }
 
 void KaduWindowActions::bugsActionActivated(QAction *sender, bool toggled)
@@ -626,10 +738,10 @@ void KaduWindowActions::bugsActionActivated(QAction *sender, bool toggled)
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	if (config_file.readEntry("General", "Language") == "pl")
-		UrlOpener::openUrl("http://www.kadu.im/w/B%C5%82%C4%99dy");
+	if (m_configuration->deprecatedApi()->readEntry("General", "Language") == "pl")
+		m_urlOpener->openUrl("http://www.kadu.im/w/B%C5%82%C4%99dy");
 	else
-		UrlOpener::openUrl("http://www.kadu.im/w/English:Bugs");
+		m_urlOpener->openUrl("http://www.kadu.im/w/English:Bugs");
 }
 
 void KaduWindowActions::getInvolvedActionActivated(QAction *sender, bool toggled)
@@ -637,10 +749,10 @@ void KaduWindowActions::getInvolvedActionActivated(QAction *sender, bool toggled
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	if (config_file.readEntry("General", "Language") == "pl")
-		UrlOpener::openUrl("http://www.kadu.im/w/Do%C5%82%C4%85cz");
+	if (m_configuration->deprecatedApi()->readEntry("General", "Language") == "pl")
+		m_urlOpener->openUrl("http://www.kadu.im/w/Do%C5%82%C4%85cz");
 	else
-		UrlOpener::openUrl("http://www.kadu.im/w/English:GetInvolved");
+		m_urlOpener->openUrl("http://www.kadu.im/w/English:GetInvolved");
 }
 
 void KaduWindowActions::aboutActionActivated(QAction *sender, bool toggled)
@@ -648,7 +760,7 @@ void KaduWindowActions::aboutActionActivated(QAction *sender, bool toggled)
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	(new ::About(Core::instance()->kaduWindow()))->show();
+	m_injectedFactory->makeInjected<::About>(m_kaduWindowService->kaduWindow())->show();
 }
 
 void KaduWindowActions::translateActionActivated(QAction *sender, bool toggled)
@@ -656,7 +768,7 @@ void KaduWindowActions::translateActionActivated(QAction *sender, bool toggled)
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	UrlOpener::openUrl("http://www.transifex.net/projects/p/kadu/");
+	m_urlOpener->openUrl("http://www.transifex.net/projects/p/kadu/");
 }
 
 void KaduWindowActions::showInfoPanelActionActivated(QAction *sender, bool toggled)
@@ -664,9 +776,9 @@ void KaduWindowActions::showInfoPanelActionActivated(QAction *sender, bool toggl
 	Q_UNUSED(sender)
 	Q_UNUSED(toggled)
 
-	Core::instance()->kaduWindow()->infoPanel()->setVisible(toggled);
+	m_kaduWindowService->kaduWindow()->infoPanel()->setVisible(toggled);
 
-	config_file.writeEntry("Look", "ShowInfoPanel", toggled);
+	m_configuration->deprecatedApi()->writeEntry("Look", "ShowInfoPanel", toggled);
 }
 
 void KaduWindowActions::showBlockedActionActivated(QAction *sender, bool toggled)
@@ -676,23 +788,23 @@ void KaduWindowActions::showBlockedActionActivated(QAction *sender, bool toggled
 	{
 		BlockedTalkableFilter *blockedTalkableFilter = v.value<BlockedTalkableFilter *>();
 		blockedTalkableFilter->setEnabled(!toggled);
-		config_file.writeEntry("General", "ShowBlocked", toggled);
+		m_configuration->deprecatedApi()->writeEntry("General", "ShowBlocked", toggled);
 	}
 }
 
 void KaduWindowActions::showMyselfActionActivated(QAction *sender, bool toggled)
 {
-	MainWindow *window = qobject_cast<MainWindow *>(sender->parentWidget());
+	auto window = qobject_cast<MainWindow *>(sender->parentWidget());
 	if (!window)
 		return;
 	if (!window->talkableProxyModel())
 		return;
 
-	TalkableModel *model = qobject_cast<TalkableModel *>(window->talkableProxyModel()->sourceModel());
+	auto model = qobject_cast<TalkableModel *>(window->talkableProxyModel()->sourceModel());
 	if (model)
 	{
 		model->setIncludeMyself(toggled);
-		config_file.writeEntry("General", "ShowMyself", toggled);
+		m_configuration->deprecatedApi()->writeEntry("General", "ShowMyself", toggled);
 	}
 }
 
@@ -711,7 +823,7 @@ void KaduWindowActions::writeEmailActionActivated(QAction *sender, bool toggled)
 		return;
 
 	if (!buddy.email().isEmpty())
-		UrlOpener::openEmail(buddy.email().toUtf8());
+		m_urlOpener->openEmail(buddy.email().toUtf8());
 
 	kdebugf2();
 }
@@ -758,10 +870,10 @@ void KaduWindowActions::openDescriptionLinkActionActivated(QAction *sender, bool
 	if (description.isEmpty())
 		return;
 
-	QRegExp url = UrlHandlerManager::instance()->urlRegExp();
+	QRegExp url = m_urlHandlerManager->urlRegExp();
 	int idx_start = url.indexIn(description);
 	if (idx_start >= 0)
-		UrlOpener::openUrl(description.mid(idx_start, url.matchedLength()).toUtf8());
+		m_urlOpener->openUrl(description.mid(idx_start, url.matchedLength()).toUtf8());
 
 	kdebugf2();
 }
@@ -779,13 +891,13 @@ void KaduWindowActions::copyPersonalInfoActionActivated(QAction *sender, bool to
 	ContactSet contacts = action->context()->contacts();
 
 	QStringList infoList;
-	QString defaultSyntax = Parser::escape(tr("Contact:")) + " %a[ (%u)]\n["
-			+ Parser::escape(tr("First name:")) + " %f\n]["
-			+ Parser::escape(tr("Last name:")) + " %r\n]["
-			+ Parser::escape(tr("Mobile:")) + " %m\n]";
-	QString copyPersonalDataSyntax = config_file.readEntry("General", "CopyPersonalDataSyntax", defaultSyntax);
+	QString defaultSyntax = m_parser->escape(tr("Contact:")) + " %a[ (%u)]\n["
+			+ m_parser->escape(tr("First name:")) + " %f\n]["
+			+ m_parser->escape(tr("Last name:")) + " %r\n]["
+			+ m_parser->escape(tr("Mobile:")) + " %m\n]";
+	QString copyPersonalDataSyntax = m_configuration->deprecatedApi()->readEntry("General", "CopyPersonalDataSyntax", defaultSyntax);
 	foreach (Contact contact, contacts)
-		infoList.append(Parser::parse(copyPersonalDataSyntax, Talkable(contact), ParserEscape::NoEscape));
+		infoList.append(m_parser->parse(copyPersonalDataSyntax, Talkable(contact), ParserEscape::NoEscape));
 
 	QString info = infoList.join("\n");
 	if (info.isEmpty())
@@ -810,11 +922,11 @@ void KaduWindowActions::lookupInDirectoryActionActivated(QAction *sender, bool t
 	const Buddy &buddy = action->context()->buddies().toBuddy();
 	if (!buddy)
 	{
-		(new SearchWindow(Core::instance()->kaduWindow()))->show();
+		(m_injectedFactory->makeInjected<SearchWindow>(m_kaduWindowService->kaduWindow()))->show();
 		return;
 	}
 
-	SearchWindow *sd = new SearchWindow(Core::instance()->kaduWindow(), buddy);
+	auto sd = m_injectedFactory->makeInjected<SearchWindow>(m_kaduWindowService->kaduWindow(), buddy);
 	sd->show();
 	sd->firstSearch();
 
@@ -828,7 +940,7 @@ void KaduWindowActions::inactiveUsersActionActivated(QAction *sender, bool toggl
 	{
 		HideOfflineTalkableFilter *filter = v.value<HideOfflineTalkableFilter *>();
 		filter->setEnabled(!toggled);
-		config_file.writeEntry("General", "ShowOffline", toggled);
+		m_configuration->deprecatedApi()->writeEntry("General", "ShowOffline", toggled);
 	}
 }
 
@@ -837,7 +949,7 @@ void KaduWindowActions::descriptionUsersActionActivated(QAction *sender, bool to
 	QVariant v = sender->data();
 	if (v.canConvert<HideWithoutDescriptionTalkableFilter *>())
 	{
-		HideWithoutDescriptionTalkableFilter *filter = v.value<HideWithoutDescriptionTalkableFilter *>();
+		auto filter = v.value<HideWithoutDescriptionTalkableFilter *>();
 		filter->setEnabled(toggled);
 	}
 }
@@ -846,36 +958,36 @@ void KaduWindowActions::showDescriptionsActionActivated(QAction *sender, bool to
 {
 	Q_UNUSED(sender)
 
-	config_file.writeEntry("Look", "ShowDesc", toggled);
+	m_configuration->deprecatedApi()->writeEntry("Look", "ShowDesc", toggled);
 	ConfigurationAwareObject::notifyAll();
 }
 
 void KaduWindowActions::onlineAndDescUsersActionActivated(QAction *sender, bool toggled)
 {
-	config_file.writeEntry("General", "ShowOnlineAndDescription", toggled);
+	m_configuration->deprecatedApi()->writeEntry("General", "ShowOnlineAndDescription", toggled);
 
 	QVariant v = sender->data();
 	if (v.canConvert<HideOfflineWithoutDescriptionTalkableFilter *>())
 	{
-		HideOfflineWithoutDescriptionTalkableFilter *filter = v.value<HideOfflineWithoutDescriptionTalkableFilter *>();
+		auto filter = v.value<HideOfflineWithoutDescriptionTalkableFilter *>();
 		filter->setEnabled(toggled);
 	}
 }
 
 void KaduWindowActions::configurationUpdated()
 {
-	ActionContext *context = Core::instance()->kaduWindow()->actionContext();
+	ActionContext *context = m_kaduWindowService->kaduWindow()->actionContext();
 
-	if (ShowInfoPanel->action(context)->isChecked() != config_file.readBoolEntry("Look", "ShowInfoPanel"))
+	if (ShowInfoPanel->action(context)->isChecked() != m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowInfoPanel"))
 		ShowInfoPanel->action(context)->trigger();
 
-	if (InactiveUsers->action(context)->isChecked() != config_file.readBoolEntry("General", "ShowOffline"))
+	if (InactiveUsers->action(context)->isChecked() != m_configuration->deprecatedApi()->readBoolEntry("General", "ShowOffline"))
 		InactiveUsers->action(context)->trigger();
 
-	if (ShowBlockedBuddies->action(context)->isChecked() != config_file.readBoolEntry("General", "ShowBlocked"))
+	if (ShowBlockedBuddies->action(context)->isChecked() != m_configuration->deprecatedApi()->readBoolEntry("General", "ShowBlocked"))
 		ShowBlockedBuddies->action(context)->trigger();
 
-	if (ShowMyself->action(context)->isChecked() != config_file.readBoolEntry("General", "ShowMyself"))
+	if (ShowMyself->action(context)->isChecked() != m_configuration->deprecatedApi()->readBoolEntry("General", "ShowMyself"))
 		ShowMyself->action(context)->trigger();
 }
 
