@@ -1,14 +1,14 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010 Przemysław Rudy (prudy1@o2.pl)
+ * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,11 +25,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KADU_WINDOW_H
-#define KADU_WINDOW_H
+#pragma once
 
 #include <QtCore/QMap>
 #include <QtCore/QPair>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 #include "buddies/buddy-list.h"
 #include "chat/chat.h"
@@ -44,12 +45,25 @@ class QMenuBar;
 class QVBoxLayout;
 
 class ActionDescription;
+class Application;
 class BuddyInfoPanel;
-class ProxyActionContext;
+class ChatWidgetActions;
+class ChatWidgetManager;
+class Configuration;
+class FileTransferManager;
+class InjectedFactory;
 class KaduWindowActions;
+class MainWindowRepository;
+class MenuInventory;
+class Myself;
+class ProxyActionContext;
 class RosterWidget;
 class StatusButtons;
+class StatusContainerManager;
+class TalkableConverter;
 class TalkableTreeView;
+class UrlHandlerManager;
+class UrlOpener;
 
 class KADUAPI KaduWindow : public MainWindow, private ConfigurationAwareObject, CompositingAwareObject
 {
@@ -65,15 +79,24 @@ public:
 	};
 
 private:
+	QPointer<Application> m_application;
+	QPointer<ChatWidgetActions> m_chatWidgetActions;
+	QPointer<ChatWidgetManager> m_chatWidgetManager;
+	QPointer<FileTransferManager> m_fileTransferManager;
+	QPointer<MainWindowRepository> m_mainWindowRepository;
+	QPointer<MenuInventory> m_menuInventory;
+	QPointer<Myself> m_myself;
+	QPointer<StatusContainerManager> m_statusContainerManager;
+	QPointer<TalkableConverter> m_talkableConverter;
+	QPointer<UrlHandlerManager> m_urlHandlerManager;
+	QPointer<UrlOpener> m_urlOpener;
+
 	bool Docked; // TODO: 0.11.0 it is a hack
 	QSplitter *Split;
 
 	KaduWindowActions *Actions;
 
 	BuddyInfoPanel *InfoPanel;
-#ifdef Q_OS_MAC
-	QMenuBar *MenuBar;
-#endif
 	QMenu *KaduMenu;
 	QMenu *ContactsMenu;
 	QMenu *ToolsMenu;
@@ -86,7 +109,7 @@ private:
 	StatusButtons *ChangeStatusButtons;
 	QPoint LastPositionBeforeStatusMenuHide;
 
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
 	QWidget *HiddenParent;
 #endif
 	QWidget *WindowParent;
@@ -103,16 +126,29 @@ private:
 	void createToolsMenu();
 	void createHelpMenu();
 
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
 	void hideWindowFromTaskbar();
 #endif
 
-	void storeConfiguration();
-
 	virtual void compositingEnabled();
 	virtual void compositingDisabled();
 
-#ifdef Q_OS_WIN32
+private slots:
+	INJEQT_SET void setApplication(Application *application);
+	INJEQT_SET void setChatWidgetActions(ChatWidgetActions *chatWidgetActions);
+	INJEQT_SET void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
+	INJEQT_SET void setFileTransferManager(FileTransferManager *fileTransferManager);
+	INJEQT_SET void setMainWindowRepository(MainWindowRepository *mainWindowRepository);
+	INJEQT_SET void setMenuInventory(MenuInventory *menuInventory);
+	INJEQT_SET void setMyself(Myself *myself);
+	INJEQT_SET void setStatusContainerManager(StatusContainerManager *statusContainerManager);
+	INJEQT_SET void setTalkableConverter(TalkableConverter *talkableConverter);
+	INJEQT_SET void setUrlHandlerManager(UrlHandlerManager *urlHandlerManager);
+	INJEQT_SET void setUrlOpener(UrlOpener *urlOpener);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
+#ifdef Q_OS_WIN
 	void setHiddenParent();
 #endif
 
@@ -126,11 +162,13 @@ protected:
 	virtual void configurationUpdated();
 
 public:
-	static void createDefaultToolbars(QDomElement parentConfig);
+	static void createDefaultToolbars(Configuration *configuration, QDomElement parentConfig);
 
 	KaduWindow();
 	virtual ~KaduWindow();
 
+	void storeConfiguration();
+
 	virtual TalkableTreeView * talkableTreeView();
 	virtual TalkableProxyModel * talkableProxyModel();
 
@@ -141,10 +179,6 @@ public:
 
 	BuddyInfoPanel * infoPanel() { return InfoPanel; }
 
-#ifdef Q_OS_MAC
-	QMenuBar* menuBar() const;
-#endif
-
 public slots:
 	void talkableActivatedSlot(const Talkable &talkable);
 
@@ -155,5 +189,3 @@ signals:
 	void talkableActivated(const Talkable &talkable);
 
 };
-
-#endif // KADU_WINDOW_H
