@@ -1,17 +1,14 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010, 2011 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Przemysław Rudy (prudy1@o2.pl)
+ * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,22 +28,24 @@
 #include <QtCore/QDir>
 #include <QtCore/QList>
 #include <QtCore/QPair>
-#include <QtGui/QApplication>
-#include <QtGui/QFileDialog>
-#include <QtGui/QLabel>
-#include <QtGui/QStyleFactory>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QStyleFactory>
 
 #include "configuration/config-file-data-manager.h"
+#include "configuration/gui/configuration-ui-handler.h"
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
 #include "buddies/buddy.h"
-#include "chat-style/chat-style-manager.h"
-#include "chat-style/engine/chat-style-engine.h"
 #include "compression/archive-extractor.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "configuration/gui/configuration-ui-handler.h"
+#include "configuration/gui/configuration-ui-handler-repository.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/buddy-info-panel.h"
 #include "gui/widgets/configuration/buddy-list-background-colors-widget.h"
 #include "gui/widgets/configuration/config-check-box.h"
@@ -59,33 +58,27 @@
 #include "gui/widgets/configuration/config-syntax-editor.h"
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/widgets/proxy-combo-box.h"
-#include "gui/widgets/tool-tip-class-manager.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/message-dialog.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 #include "network/proxy/network-proxy.h"
 #include "plugin/gui/plugin-list/plugin-list-widget.h"
 #include "status/status-container.h"
 #include "status/status.h"
 #include "themes/icon-theme-manager.h"
 
-#include "icons/icons-manager.h"
 #include "debug.h"
 #include "languages-manager.h"
 
 #include "main-configuration-window.h"
 
-#ifdef Q_WS_X11
-#include "os/x11tools.h" // this should be included as last one,
+#if defined(Q_OS_UNIX)
+#include "os/x11/x11tools.h" // this should be included as last one,
 #undef KeyPress
 #undef Status            // and Status defined by Xlib.h must be undefined
 #endif
 
-MainConfigurationWindow *MainConfigurationWindow::Instance = 0;
-ConfigFileDataManager *MainConfigurationWindow::InstanceDataManager = 0;
-QList<QString> MainConfigurationWindow::UiFiles;
-QList<ConfigurationUiHandler *> MainConfigurationWindow::ConfigurationUiHandlers;
-
 const char *MainConfigurationWindow::SyntaxText = QT_TRANSLATE_NOOP
 (
 	"@default", "Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name\n"
@@ -102,78 +95,67 @@ const char *MainConfigurationWindow::SyntaxTextNotify = QT_TRANSLATE_NOOP
 	"#{event} - name of event,\n"
 );
 
-MainConfigurationWindow * MainConfigurationWindow::instance()
+void MainConfigurationWindow::configurationUiHandlerAdded(ConfigurationUiHandler *configurationUiHandler)
 {
-	if (!Instance)
-	{
-		InstanceDataManager = new ConfigFileDataManager();
-		Instance = new MainConfigurationWindow();
-		instanceCreated();
-	}
-
-	return Instance;
+	configurationUiHandler->mainConfigurationWindowCreated(this);
 }
 
-bool MainConfigurationWindow::hasInstance()
+void MainConfigurationWindow::configurationUiHandlerRemoved(ConfigurationUiHandler *configurationUiHandler)
 {
-	return Instance;
+	Q_UNUSED(configurationUiHandler)
 }
 
-ConfigFileDataManager * MainConfigurationWindow::instanceDataManager()
+MainConfigurationWindow::MainConfigurationWindow(ConfigurationWindowDataManager *dataManager, QWidget *parent) :
+		ConfigurationWindow("MainConfiguration", tr("Kadu configuration"), "General", dataManager, parent)
 {
-	if (!InstanceDataManager)
-		InstanceDataManager = new ConfigFileDataManager();
-
-	return InstanceDataManager;
 }
 
-void MainConfigurationWindow::registerUiFile(const QString &uiFile)
+MainConfigurationWindow::~MainConfigurationWindow()
 {
-	UiFiles.append(uiFile);
-	if (!Instance)
-		return;
-
-	Instance->widget()->appendUiFile(uiFile);
+	for (auto configurationUiHandler : m_configurationUiHandlerRepository)
+		configurationUiHandler->mainConfigurationWindowDestroyed();
 }
 
-void MainConfigurationWindow::unregisterUiFile(const QString &uiFile)
+void MainConfigurationWindow::setAccountManager(AccountManager *accountManager)
 {
-	UiFiles.removeAll(uiFile);
-	if (Instance)
-		Instance->widget()->removeUiFile(uiFile);
+	m_accountManager = accountManager;
 }
 
-void MainConfigurationWindow::registerUiHandler(ConfigurationUiHandler *uiHandler)
+void MainConfigurationWindow::setConfigurationUiHandlerRepository(ConfigurationUiHandlerRepository *configurationUiHandlerRepository)
 {
-	ConfigurationUiHandlers.append(uiHandler);
-	if (Instance)
-		uiHandler->mainConfigurationWindowCreated(Instance);
+	m_configurationUiHandlerRepository = configurationUiHandlerRepository;
 }
 
-void MainConfigurationWindow::unregisterUiHandler(ConfigurationUiHandler *uiHandler)
+void MainConfigurationWindow::setIconsManager(IconsManager *iconsManager)
 {
-	ConfigurationUiHandlers.removeAll(uiHandler);
+	m_iconsManager = iconsManager;
 }
 
-void MainConfigurationWindow::instanceCreated()
+void MainConfigurationWindow::setIconThemeManager(IconThemeManager *iconThemeManager)
 {
-	// TODO: move this to separate class, like ChatStylesConfigurationUiHandler
-	// and just register it here
-	ChatStyleManager::instance()->mainConfigurationWindowCreated(Instance);
-	foreach (const QString &uiFile, UiFiles)
-		Instance->widget()->appendUiFile(uiFile);
-
-	foreach (ConfigurationUiHandler *uiHandler, ConfigurationUiHandlers)
-		if (uiHandler)
-			uiHandler->mainConfigurationWindowCreated(Instance);
+	m_iconThemeManager = iconThemeManager;
 }
 
-MainConfigurationWindow::MainConfigurationWindow() :
-		ConfigurationWindow("MainConfiguration", tr("Kadu configuration"), "General", instanceDataManager())
+void MainConfigurationWindow::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void MainConfigurationWindow::setLanguagesManager(LanguagesManager *languagesManager)
+{
+	m_languagesManager = languagesManager;
+}
+
+void MainConfigurationWindow::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void MainConfigurationWindow::init()
 {
 	setWindowRole("kadu-configuration");
 
-	widget()->appendUiFile(KaduPaths::instance()->dataPath() + QLatin1String("configuration/dialog.ui"));
+	widget()->appendUiFile(m_pathsProvider->dataPath() + QStringLiteral("configuration/dialog.ui"));
 
 #ifndef DEBUG_ENABLED
 	widget()->widgetById("debug")->hide();
@@ -184,15 +166,15 @@ MainConfigurationWindow::MainConfigurationWindow() :
 	widget()->widgetById("hideMainWindowFromTaskbar")->hide();
 #endif
 
-#ifndef Q_WS_X11
+#if !defined(Q_OS_UNIX)
 	widget()->widgetById("windowActivationMethod")->hide();
 #endif
 
-#if !defined(Q_WS_X11) && !defined(Q_OS_WIN32)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_WIN)
 	widget()->widgetById("notify/fullscreenSilentMode")->hide();
 #endif
 
-#if !defined(Q_WS_X11)
+#if !defined(Q_OS_UNIX)
 	widget()->widgetById("useTransparency")->hide();
 	widget()->widgetById("userboxTransparency")->hide();
 	widget()->widgetById("userboxAlpha")->hide();
@@ -203,7 +185,7 @@ MainConfigurationWindow::MainConfigurationWindow() :
 	disconnectDescription = static_cast<QLineEdit *>(widget()->widgetById("disconnectDescription"));
 	onStartupSetDescription = static_cast<QLineEdit *>(widget()->widgetById("onStartupSetDescription"));
 
-	Account account = AccountManager::instance()->defaultAccount();
+	Account account = m_accountManager->defaultAccount();
 	if (!account.isNull() && account.protocolHandler())
 	{
 		disconnectDescription->setMaxLength(account.statusContainer()->maxDescriptionLength());
@@ -218,7 +200,7 @@ MainConfigurationWindow::MainConfigurationWindow() :
 	connect(widget()->widgetById("installIconTheme"), SIGNAL(clicked()), this, SLOT(installIconTheme()));
 
 	Preview *infoPanelSyntaxPreview = static_cast<Preview *>(widget()->widgetById("infoPanelSyntaxPreview"));
-	connect(infoPanelSyntaxPreview, SIGNAL(needFixup(QString &)), Core::instance()->kaduWindow()->infoPanel(), SLOT(styleFixup(QString &)));
+	connect(infoPanelSyntaxPreview, SIGNAL(needFixup(QString &)), m_kaduWindowService->kaduWindow()->infoPanel(), SLOT(styleFixup(QString &)));
 	connect(widget()->widgetById("infoPanelSyntax"), SIGNAL(syntaxChanged(const QString &)), infoPanelSyntaxPreview, SLOT(syntaxChanged(const QString &)));
 
 	widget()->widgetById("parseStatus")->setToolTip(QCoreApplication::translate("@default", SyntaxText));
@@ -230,20 +212,22 @@ MainConfigurationWindow::MainConfigurationWindow() :
 
 	buddyColors = new BuddyListBackgroundColorsWidget(this);
 
-	PluginList = new PluginListWidget(this);
-	PluginList->setPluginActivationService(Core::instance()->pluginActivationService());
-	PluginList->setPluginConflictResolver(Core::instance()->pluginConflictResolver());
-	PluginList->setPluginDependencyHandler(Core::instance()->pluginDependencyHandler());
-	PluginList->setPluginStateManager(Core::instance()->pluginStateManager());
-	PluginList->setPluginStateService(Core::instance()->pluginStateService());
+	PluginList = injectedFactory()->makeInjected<PluginListWidget>(this);
 	PluginList->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Maximum);
 
+	connect(this, SIGNAL(configurationWindowApplied()), this, SLOT(applied()));
+	connect(m_configurationUiHandlerRepository, SIGNAL(configurationUiHandlerAdded(ConfigurationUiHandler*)),
+	        this, SLOT(configurationUiHandlerAdded(ConfigurationUiHandler*)));
+	connect(m_configurationUiHandlerRepository, SIGNAL(configurationUiHandlerRemoved(ConfigurationUiHandler*)),
+	        this, SLOT(configurationUiHandlerRemoved(ConfigurationUiHandler*)));
+
 	triggerCompositingStateChanged();
 }
 
-MainConfigurationWindow::~MainConfigurationWindow()
+void MainConfigurationWindow::applied()
 {
-	Instance = 0;
+	for (auto configurationUiHandler : m_configurationUiHandlerRepository)
+		configurationUiHandler->mainConfigurationWindowApplied();
 }
 
 void MainConfigurationWindow::compositingEnabled()
@@ -272,7 +256,6 @@ void MainConfigurationWindow::show()
 	{
 		setLanguages();
 		setIconThemes();
-		setToolTipClasses();
 	}
 
 	ConfigurationWindow::show();
@@ -299,7 +282,7 @@ void MainConfigurationWindow::setLanguages()
 {
 	ConfigComboBox *languages = static_cast<ConfigComboBox *>(widget()->widgetById("languages"));
 
-	languages->setItems(LanguagesManager::languages().keys(), LanguagesManager::languages().values());
+	languages->setItems(m_languagesManager->languages().keys(), m_languagesManager->languages().values());
 }
 
 void MainConfigurationWindow::installIconTheme()
@@ -309,7 +292,7 @@ void MainConfigurationWindow::installIconTheme()
 	if (fileName.isEmpty())
 		return;
 
-	const QString &profilePath = KaduPaths::instance()->profilePath();
+	const QString &profilePath = m_pathsProvider->profilePath();
 	ArchiveExtractor extractor;
 	bool success = extractor.extract(fileName, profilePath + "icons");
 	if (success)
@@ -318,7 +301,7 @@ void MainConfigurationWindow::installIconTheme()
 	}
 	else
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Installation failed"), tr(extractor.message().toLocal8Bit().data()), QMessageBox::Ok, widget());
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Installation failed"), tr(extractor.message().toLocal8Bit().data()), QMessageBox::Ok, widget());
 	}
 }
 
@@ -327,20 +310,20 @@ void MainConfigurationWindow::setIconThemes()
 	ConfigListWidget *iconThemes = static_cast<ConfigListWidget *>(widget()->widgetById("iconThemes"));
 	iconThemes->clear();
 
-	IconsManager::instance()->themeManager()->loadThemes();
+	m_iconThemeManager->loadThemes();
 
 	(void)QT_TRANSLATE_NOOP("@default", "default");
 
 	QStringList values;
 	QStringList captions;
-	foreach (const Theme &theme, IconsManager::instance()->themeManager()->themes())
+	foreach (const Theme &theme, m_iconThemeManager->themes())
 	{
 		values.append(theme.name());
 		captions.append(QCoreApplication::translate("@default", theme.name().toUtf8().constData()));
 	}
 
 	iconThemes->setItems(values, captions);
-	iconThemes->setCurrentItem(IconsManager::instance()->themeManager()->currentTheme().name());
+	iconThemes->setCurrentItem(m_iconThemeManager->currentTheme().name());
 
 	QStringList iconPaths;
 	iconPaths
@@ -350,7 +333,7 @@ void MainConfigurationWindow::setIconThemes()
 			<< "preferences-other";
 
 	QList<QIcon> icons;
-	foreach (const Theme &theme, IconsManager::instance()->themeManager()->themes())
+	foreach (const Theme &theme, m_iconThemeManager->themes())
 	{
 		QPixmap combinedIcon(iconPaths.count() * 36, 36);
 		combinedIcon.fill(Qt::transparent);
@@ -361,7 +344,7 @@ void MainConfigurationWindow::setIconThemes()
 		{
 			KaduIcon kaduIcon(iconPaths.at(i));
 			kaduIcon.setThemePath(theme.path());
-			QIcon icon = kaduIcon.icon();
+			QIcon icon = m_iconsManager->iconByPath(kaduIcon);
 			icon.paint(&iconPainter, 2 + 36 * i, 2, 32, 32);
 		}
 
@@ -372,33 +355,12 @@ void MainConfigurationWindow::setIconThemes()
 	iconThemes->setIcons(icons);
 }
 
-void MainConfigurationWindow::setToolTipClasses()
-{
-	QStringList captions;
-	QStringList values;
-	captions << tr("None");
-	values << QLatin1String("none");
-
-	QStringList toolTipClasses = ToolTipClassManager::instance()->getToolTipClasses();
-	foreach(const QString &toolTipClass, toolTipClasses)
-	{
-		captions << QCoreApplication::translate("@default", toolTipClass.toUtf8().constData());
-		values << toolTipClass;
-	}
-
-	static_cast<ConfigComboBox *>(widget()->widgetById("toolTipClasses"))->setItems(values, captions);
-}
-
 void MainConfigurationWindow::showLookChatAdvanced()
 {
 	if (!lookChatAdvanced)
 	{
-		lookChatAdvanced = new ConfigurationWindow("LookChatAdvanced", tr("Advanced chat's look configuration"), "General", instanceDataManager());
-		lookChatAdvanced.data()->widget()->appendUiFile(KaduPaths::instance()->dataPath() + QLatin1String("configuration/dialog-look-chat-advanced.ui"));
-
-		lookChatAdvanced.data()->widget()->widgetById("chatSyntax")->setToolTip(QCoreApplication::translate("@default", SyntaxText));
-		lookChatAdvanced.data()->widget()->widgetById("conferencePrefix")->setToolTip(QCoreApplication::translate("@default", SyntaxText));
-		lookChatAdvanced.data()->widget()->widgetById("conferenceSyntax")->setToolTip(QCoreApplication::translate("@default", SyntaxText));
+		lookChatAdvanced = injectedFactory()->makeInjected<ConfigurationWindow>("LookChatAdvanced", tr("Advanced chat's look configuration"), "General", dataManager());
+		lookChatAdvanced.data()->widget()->appendUiFile(m_pathsProvider->dataPath() + QStringLiteral("configuration/dialog-look-chat-advanced.ui"));
 	}
 
 	lookChatAdvanced.data()->show();
