@@ -1,11 +1,11 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2010, 2011 Przemysław Rudy (prudy1@o2.pl)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Przemysław Rudy (prudy1@o2.pl)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,29 +22,31 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 #include <QtGui/QContextMenuEvent>
-#include <QtGui/QMenu>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account-manager.h"
 #include "buddies/buddy-set.h"
 #include "buddies/buddy.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration-api.h"
 #include "configuration/configuration-manager.h"
-#include "configuration/toolbar-configuration-manager.h"
-#include "configuration/xml-configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/injected-factory.h"
+#include "core/session-service.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
+#include "gui/configuration/toolbar-configuration-manager.h"
 #include "gui/widgets/talkable-tree-view.h"
 #include "gui/widgets/toolbar.h"
-
 #include "debug.h"
 
 #include "main-window.h"
 
-#ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#if defined(Q_OS_UNIX)
+#include <QtX11Extras/QX11Info>
 
-#include "os/x11tools.h" // this should be included as last one,
+#include "os/x11/x11tools.h" // this should be included as last one,
 #undef KeyPress
 #undef Status            // and Status defined by Xlib.h must be undefined
 #endif
@@ -66,25 +68,64 @@ MainWindow::MainWindow(ActionContext *context, const QString &windowName, QWidge
 		QMainWindow(parent), DesktopAwareObject(this),  WindowName(windowName), TransparencyEnabled(false), BlurEnabled(false),
 		Context(context)
 {
-	Q_ASSERT(0 != Context);
-
-	connect(ConfigurationManager::instance()->toolbarConfigurationManager(), SIGNAL(configurationUpdated()),
-			this, SLOT(refreshToolBars()));
-	connect(Actions::instance(), SIGNAL(actionLoaded(ActionDescription*)),
-			this, SLOT(actionLoadedOrUnloaded(ActionDescription*)));
-	connect(Actions::instance(), SIGNAL(actionUnloaded(ActionDescription*)),
-			this, SLOT(actionLoadedOrUnloaded(ActionDescription*)));
 }
 
 MainWindow::~MainWindow()
 {
-	disconnect(Actions::instance(), 0, this, 0);
-	disconnect(ConfigurationManager::instance()->toolbarConfigurationManager(), 0, this, 0);
-
 	delete Context;
 	Context = 0;
 }
 
+void MainWindow::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void MainWindow::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void MainWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+Configuration * MainWindow::configuration() const
+{
+	return m_configuration;
+}
+
+void MainWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void MainWindow::setSessionService(SessionService *sessionService)
+{
+	m_sessionService = sessionService;
+}
+
+void MainWindow::init()
+{
+	connect(m_configurationManager->toolbarConfigurationManager(), SIGNAL(configurationUpdated()),
+			this, SLOT(refreshToolBars()));
+	connect(m_actions, SIGNAL(actionLoaded(ActionDescription*)),
+			this, SLOT(actionLoadedOrUnloaded(ActionDescription*)));
+	connect(m_actions, SIGNAL(actionUnloaded(ActionDescription*)),
+			this, SLOT(actionLoadedOrUnloaded(ActionDescription*)));
+}
+
+InjectedFactory * MainWindow::injectedFactory() const
+{
+	return m_injectedFactory;
+}
+
+void MainWindow::setActionContext(ActionContext *actionContext)
+{
+	Context = actionContext;
+}
+
 void MainWindow::loadToolBarsFromConfig()
 {
 	// lame, i know
@@ -179,12 +220,12 @@ void MainWindow::loadToolBarsFromConfig(Qt::ToolBarArea area)
 
 bool MainWindow::loadOldToolBarsFromConfig(const QString &configName, Qt::ToolBarArea area)
 {
-	QDomElement toolbarsConfig = xml_config_file->findElement(xml_config_file->rootElement(), "Toolbars");
+	QDomElement toolbarsConfig = m_configuration->api()->findElement(m_configuration->api()->rootElement(), "Toolbars");
 
 	if (toolbarsConfig.isNull())
 		return false;
 
-	QDomElement dockareaConfig = xml_config_file->findElementByProperty(toolbarsConfig, "DockArea", "name", configName);
+	QDomElement dockareaConfig = m_configuration->api()->findElementByProperty(toolbarsConfig, "DockArea", "name", configName);
 	if (dockareaConfig.isNull())
 		return false;
 
@@ -194,11 +235,11 @@ bool MainWindow::loadOldToolBarsFromConfig(const QString &configName, Qt::ToolBa
 	return true;
 }
 
-QDomElement MainWindow::getToolbarsConfigElement()
+QDomElement MainWindow::getToolbarsConfigElement(Configuration *configuration)
 {
-	QDomElement toolbarsConfig = xml_config_file->findElement(xml_config_file->rootElement(), "Toolbars");
+	QDomElement toolbarsConfig = configuration->api()->findElement(configuration->api()->rootElement(), "Toolbars");
 	if (toolbarsConfig.isNull())
-		toolbarsConfig = xml_config_file->createElement(xml_config_file->rootElement(), "Toolbars");
+		toolbarsConfig = configuration->api()->createElement(configuration->api()->rootElement(), "Toolbars");
 
 	return toolbarsConfig;
 }
@@ -229,71 +270,71 @@ QDomElement MainWindow::getDockAreaConfigElement(Qt::ToolBarArea area)
 			return QDomElement();
 	}
 
-	return getDockAreaConfigElement(getToolbarsConfigElement(), realPrefix + suffix);
+	return getDockAreaConfigElement(m_configuration, getToolbarsConfigElement(m_configuration), realPrefix + suffix);
 }
 
-QDomElement MainWindow::getDockAreaConfigElement(QDomElement toolbarsConfig, const QString &name)
+QDomElement MainWindow::getDockAreaConfigElement(Configuration *configuration, QDomElement toolbarsConfig, const QString &name)
 {
-	QDomElement dockAreaConfig = xml_config_file->findElementByProperty(toolbarsConfig, "DockArea", "name", name);
+	QDomElement dockAreaConfig = configuration->api()->findElementByProperty(toolbarsConfig, "DockArea", "name", name);
 	if (dockAreaConfig.isNull())
 	{
-		dockAreaConfig = xml_config_file->createElement(toolbarsConfig, "DockArea");
+		dockAreaConfig = configuration->api()->createElement(toolbarsConfig, "DockArea");
 		dockAreaConfig.setAttribute("name", name);
 	}
 
 	return dockAreaConfig;
 }
 
-void MainWindow::addToolButton(QDomElement toolbarConfig, const QString &actionName, Qt::ToolButtonStyle style)
+void MainWindow::addToolButton(Configuration *configuration, QDomElement toolbarConfig, const QString &actionName, Qt::ToolButtonStyle style)
 {
-	QDomElement buttonConfig = xml_config_file->findElementByProperty(toolbarConfig, "ToolButton", "action_name", actionName);
+	QDomElement buttonConfig = configuration->api()->findElementByProperty(toolbarConfig, "ToolButton", "action_name", actionName);
 //don't add element if exists
 	if (!buttonConfig.isNull())
 		return;
-	buttonConfig = xml_config_file->createElement(toolbarConfig, "ToolButton");
+	buttonConfig = configuration->api()->createElement(toolbarConfig, "ToolButton");
 	buttonConfig.setAttribute("action_name", actionName);
 	buttonConfig.setAttribute("toolbutton_style", style);
 }
 
-QDomElement MainWindow::findExistingToolbarOnArea(const QString &areaName)
+QDomElement MainWindow::findExistingToolbarOnArea(Configuration *configuration, const QString &areaName)
 {
-	QDomElement dockAreaConfig = xml_config_file->findElementByProperty(getToolbarsConfigElement(), "DockArea", "name", areaName);
+	QDomElement dockAreaConfig = configuration->api()->findElementByProperty(getToolbarsConfigElement(configuration), "DockArea", "name", areaName);
 	QDomElement nullResult;
 
 	if (dockAreaConfig.isNull())
 		return nullResult;
 
-	QDomElement toolbarElement = xml_config_file->findElement(dockAreaConfig, "ToolBar");
+	QDomElement toolbarElement = configuration->api()->findElement(dockAreaConfig, "ToolBar");
 	if (toolbarElement.isNull())
 		return nullResult;
 
 	return toolbarElement;
 }
 
-QDomElement MainWindow::findExistingToolbar(const QString &prefix)
+QDomElement MainWindow::findExistingToolbar(Configuration *configuration, const QString &prefix)
 {
 	QString realPrefix;
 	if (!prefix.isEmpty())
 		realPrefix = prefix + '_';
 
-	QDomElement toolbarElement = findExistingToolbarOnArea(realPrefix + "topDockArea");
+	QDomElement toolbarElement = findExistingToolbarOnArea(configuration, realPrefix + "topDockArea");
 	if (!toolbarElement.isNull())
 		return toolbarElement;
 
-	toolbarElement = findExistingToolbarOnArea(realPrefix + "leftDockArea");
+	toolbarElement = findExistingToolbarOnArea(configuration, realPrefix + "leftDockArea");
 	if (!toolbarElement.isNull())
 		return toolbarElement;
 
-	toolbarElement = findExistingToolbarOnArea(realPrefix + "rightDockArea");
+	toolbarElement = findExistingToolbarOnArea(configuration, realPrefix + "rightDockArea");
 	if (!toolbarElement.isNull())
 		return toolbarElement;
 
-	toolbarElement = findExistingToolbarOnArea(realPrefix + "bottomDockArea");
+	toolbarElement = findExistingToolbarOnArea(configuration, realPrefix + "bottomDockArea");
 	if (!toolbarElement.isNull())
 		return toolbarElement;
 
-	QDomElement dockAreaConfig = getDockAreaConfigElement(getToolbarsConfigElement(), realPrefix + "topDockArea");
-	return xml_config_file->createElement(dockAreaConfig, "ToolBar");
+	QDomElement dockAreaConfig = getDockAreaConfigElement(configuration, getToolbarsConfigElement(configuration), realPrefix + "topDockArea");
+	return configuration->api()->createElement(dockAreaConfig, "ToolBar");
 }
 
 void MainWindow::writeToolBarsToConfig()
@@ -307,7 +348,7 @@ void MainWindow::writeToolBarsToConfig()
 void MainWindow::writeToolBarsToConfig(Qt::ToolBarArea area)
 {
 	QDomElement dockAreaConfig = getDockAreaConfigElement(area);
-	xml_config_file->removeChildren(dockAreaConfig);
+	m_configuration->api()->removeChildren(dockAreaConfig);
 
 	// TODO: laaaaame
 	foreach(QObject *child, children())
@@ -333,7 +374,7 @@ void MainWindow::refreshToolBars()
 {
 	// We don't need it when closing.
 	// BTW, on Mac it caused crashes on exit. TODO: check out why, as there is probably a bug somewhere.
-	if (Core::instance()->isClosing())
+	if (m_sessionService->isClosing())
 		return;
 
 	loadToolBarsFromConfig();
@@ -341,7 +382,7 @@ void MainWindow::refreshToolBars()
 
 void MainWindow::contextMenuEvent(QContextMenuEvent *event)
 {
-	if (!ToolBar::isBlockToolbars())
+	if (!ToolBar::isBlockToolbars(m_configuration))
 	{
 		QMenu menu;
 		menu.addAction(tr("Create new toolbar"), this, SLOT(addTopToolbar()));
@@ -351,7 +392,7 @@ void MainWindow::contextMenuEvent(QContextMenuEvent *event)
 
 ToolBar *MainWindow::newToolbar(QWidget *parent)
 {
-	ToolBar *toolBar = new ToolBar(parent);
+	auto toolBar = m_injectedFactory->makeInjected<ToolBar>(parent);
 	toolBar->setAttribute(Qt::WA_NoSystemBackground, !TransparencyEnabled);
 	toolBar->setAutoFillBackground(TransparencyEnabled);
 
@@ -454,7 +495,7 @@ void MainWindow::toolbarUpdated()
 {
 	writeToolBarsToConfig();
 
-	ConfigurationManager::instance()->toolbarConfigurationManager()->notifyConfigurationUpdated();
+	m_configurationManager->toolbarConfigurationManager()->notifyConfigurationUpdated();
 }
 
 void MainWindow::toolbarRemoved(ToolBar *toolBar)
@@ -473,7 +514,7 @@ ActionContext * MainWindow::actionContext()
 
 void MainWindow::setBlur(bool enable)
 {
-#if !defined(Q_WS_X11)
+#if !defined(Q_OS_UNIX)
 	Q_UNUSED(enable);
 #else
 	BlurEnabled = enable;
