@@ -1,17 +1,12 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Tomasz Jarzynka (tomee@cpi.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2003, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2003 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,30 +24,30 @@
  */
 
 #include <QtGui/QPixmap>
-#include <QtGui/QStyle>
+#include <QtWidgets/QStyle>
 
 #include "message-dialog.h"
 
 
-MessageDialog * MessageDialog::create(const KaduIcon &icon, const QString &title, const QString &text, QWidget *parent, Qt::WindowFlags f)
+MessageDialog * MessageDialog::create(const QIcon &icon, const QString &title, const QString &text, QWidget *parent, Qt::WindowFlags f)
 {
 	return new MessageDialog(icon, title, text, QMessageBox::NoButton, parent, f);
 }
 
-void MessageDialog::show(const KaduIcon &icon, const QString &title, const QString &text, QMessageBox::StandardButtons buttons, QWidget *parent, Qt::WindowFlags f)
+void MessageDialog::show(const QIcon &icon, const QString &title, const QString &text, QMessageBox::StandardButtons buttons, QWidget *parent, Qt::WindowFlags f)
 {
 	auto dialog = new MessageDialog(icon, title, text, buttons, parent, f);
 	dialog->exec();
 }
 
-MessageDialog::MessageDialog(const KaduIcon &icon, const QString &title, const QString &text, QMessageBox::StandardButtons buttons, QWidget *parent, Qt::WindowFlags f)
+MessageDialog::MessageDialog(const QIcon &icon, const QString &title, const QString &text, QMessageBox::StandardButtons buttons, QWidget *parent, Qt::WindowFlags f)
 {
 	Box = new QMessageBox(QMessageBox::NoIcon, title, text, buttons, parent, f);
 	connect(Box, SIGNAL(finished(int)), this, SLOT(messageBoxFinished(int)));
 	Box->setAttribute(Qt::WA_DeleteOnClose, true);
 
 	int iconSize = Box->style()->pixelMetric(QStyle::PM_MessageBoxIconSize, 0, Box);
-	QPixmap pixmap(icon.icon().pixmap(iconSize, iconSize));
+	QPixmap pixmap(icon.pixmap(iconSize, iconSize));
 	if (!pixmap.isNull())
 		Box->setIconPixmap(pixmap);
 }
