@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,18 +19,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QHeaderView>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
-#include <QtGui/QTableView>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QHeaderView>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTableView>
+#include <QtWidgets/QVBoxLayout>
 
 #include "accounts/filter/have-multilogon-filter.h"
 #include "configuration/config-file-variant-wrapper.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/accounts-combo-box.h"
 #include "icons/icons-manager.h"
 #include "model/roles.h"
@@ -39,12 +40,9 @@
 #include "os/generic/window-geometry-manager.h"
 #include "protocols/protocol.h"
 #include "protocols/services/multilogon-service.h"
-#include "activate.h"
 
 #include "multilogon-window.h"
 
-MultilogonWindow *MultilogonWindow::Instance = 0;
-
 MultilogonWindow::MultilogonWindow(QWidget *parent) :
 		QWidget(parent), DesktopAwareObject(this)
 {
@@ -52,30 +50,27 @@ MultilogonWindow::MultilogonWindow(QWidget *parent) :
 
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(tr("Multilogon window"));
-
-	createGui();
-
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "MultilogonWindowGeometry"), QRect(0, 50, 450, 300), this);
 }
 
 MultilogonWindow::~MultilogonWindow()
 {
-	Instance = 0;
 }
 
-MultilogonWindow * MultilogonWindow::instance()
+void MultilogonWindow::setConfiguration(Configuration *configuration)
 {
-	if (!Instance)
-		Instance = new MultilogonWindow();
-
-	return Instance;
+	m_configuration = configuration;
 }
 
-void MultilogonWindow::show()
+void MultilogonWindow::setInjectedFactory(InjectedFactory *injectedFactory)
 {
-	QWidget::show();
+	m_injectedFactory = injectedFactory;
+}
 
-	_activateWindow(this);
+void MultilogonWindow::init()
+{
+	createGui();
+
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "MultilogonWindowGeometry"), QRect(0, 50, 450, 300), this);
 }
 
 void MultilogonWindow::createGui()
@@ -88,7 +83,7 @@ void MultilogonWindow::createGui()
 	selectAccountLayout->addWidget(new QLabel(tr("Account:"), selectAccountWidget));
 	selectAccountLayout->setMargin(0);
 
-	Accounts = new AccountsComboBox(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, selectAccountWidget);
+	Accounts = m_injectedFactory->makeInjected<AccountsComboBox>(true, AccountsComboBox::NotVisibleWithOneRowSourceModel, selectAccountWidget);
 	Accounts->addFilter(new HaveMultilogonFilter(Accounts));
 	Accounts->setIncludeIdInDisplay(true);
 	selectAccountLayout->addWidget(Accounts);
@@ -145,14 +140,14 @@ MultilogonService * MultilogonWindow::multilogonService()
 	return protocol->multilogonService();
 }
 
-MultilogonSession * MultilogonWindow::multilogonSession()
+MultilogonSession MultilogonWindow::multilogonSession()
 {
 	QItemSelectionModel *selectionModel = SessionsTable->selectionModel();
 	if (!selectionModel)
-		return 0;
+		return {};
 
 	QModelIndex index = selectionModel->currentIndex();
-	return index.data(MultilogonSessionRole).value<MultilogonSession *>();
+	return index.data(MultilogonSessionRole).value<MultilogonSession>();
 }
 
 void MultilogonWindow::accountChanged()
@@ -171,7 +166,7 @@ void MultilogonWindow::accountChanged()
 
 void MultilogonWindow::selectionChanged()
 {
-	KillSessionButton->setEnabled(0 != multilogonSession());
+	KillSessionButton->setEnabled(multilogonSession() != MultilogonSession{});
 }
 
 void MultilogonWindow::killSession()
@@ -180,9 +175,7 @@ void MultilogonWindow::killSession()
 	if (!service)
 		return;
 
-	MultilogonSession *session = multilogonSession();
-	if (session)
-		service->killSession(session);
+	service->killSession(multilogonSession());
 }
 
 #include "moc_multilogon-window.cpp"
