@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,16 +17,30 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OPEN_CHAT_WITH_CONTACT_LIST_RUNNER_H
-#define OPEN_CHAT_WITH_CONTACT_LIST_RUNNER_H
+#pragma once
+
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 #include "open-chat-with-runner.h"
 
-class KADUAPI OpenChatWithContactListRunner : public OpenChatWithRunner
+class BuddyManager;
+
+class KADUAPI OpenChatWithContactListRunner : public QObject, public OpenChatWithRunner
 {
+	Q_OBJECT
 
 public:
-	virtual BuddyList matchingContacts(const QString &query);
-};
+	explicit OpenChatWithContactListRunner(QObject *parent = nullptr);
+	virtual ~OpenChatWithContactListRunner();
 
-#endif // OPEN_CHAT_WITH_CONTACT_LIST_RUNNER_H
+	virtual BuddyList matchingContacts(const QString &query);
+
+private:
+	QPointer<BuddyManager> m_buddyManager;
+
+private slots:
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+
+};
