@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,57 +21,96 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtDeclarative/QDeclarativeContext>
-#include <QtDeclarative/QDeclarativeView>
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QGraphicsObject>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
-#include <QtGui/QStyle>
-#include <QtGui/QVBoxLayout>
+#include "open-chat-with.h"
+
+#include "open-chat-with-contact-list-runner.h"
+#include "open-chat-with-runner-manager.h"
 
 #include "buddies/buddy-manager.h"
 #include "buddies/buddy-set.h"
 #include "buddies/model/buddy-list-model.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/filtered-tree-view.h"
 #include "gui/widgets/line-edit-with-clear-button.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 #include "model/model-chain.h"
 #include "model/roles.h"
 #include "talkable/model/talkable-proxy-model.h"
-
 #include "activate.h"
 #include "debug.h"
 
-#include "open-chat-with-contact-list-runner.h"
-#include "open-chat-with-runner-manager.h"
+#include <QtCore/QTimer>
+#include <QtQml/QQmlContext>
+#include <QtQuick/QQuickItem>
+#include <QtQuickWidgets/QQuickWidget>
+#include <QtGui/QKeyEvent>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QGraphicsObject>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStyle>
+#include <QtWidgets/QVBoxLayout>
 
-#include "open-chat-with.h"
-
-OpenChatWith *OpenChatWith::Instance = 0;
-
-OpenChatWith * OpenChatWith::instance()
+OpenChatWith::OpenChatWith(QWidget *parent) :
+		QWidget{parent, Qt::Window},
+		DesktopAwareObject{this}
 {
-	if (!Instance)
-		Instance = new OpenChatWith();
-
-	return Instance;
 }
 
-OpenChatWith::OpenChatWith() :
-		QWidget(0, Qt::Window), DesktopAwareObject(this)
+OpenChatWith::~OpenChatWith()
 {
-	kdebugf();
+	OpenChatWithRunnerManager::instance()->unregisterRunner(OpenChatRunner);
 
+	delete OpenChatRunner;
+	OpenChatRunner = 0;
+}
+
+void OpenChatWith::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void OpenChatWith::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void OpenChatWith::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void OpenChatWith::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void OpenChatWith::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void OpenChatWith::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void OpenChatWith::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void OpenChatWith::init()
+{
 	setWindowRole("kadu-open-chat-with");
 
 	setWindowTitle(tr("Open chat with..."));
@@ -90,25 +129,25 @@ OpenChatWith::OpenChatWith() :
 	idLayout->setMargin(0);
 	idLayout->addWidget(new QLabel(tr("User name:"), idWidget));
 
-	ContactID = new LineEditWithClearButton(this);
+	ContactID = m_injectedFactory->makeInjected<LineEditWithClearButton>(this);
 	connect(ContactID, SIGNAL(textChanged(const QString &)), this, SLOT(inputChanged(const QString &)));
 	idLayout->addWidget(ContactID);
 
 	MainLayout->addWidget(idWidget);
 
-	BuddiesView = new QDeclarativeView();
+	BuddiesView = new QQuickWidget();
 
 	Chain = new ModelChain(this);
-	ListModel = new BuddyListModel(Chain);
+	ListModel = m_injectedFactory->makeInjected<BuddyListModel>(Chain);
 	Chain->setBaseModel(ListModel);
-	Chain->addProxyModel(new TalkableProxyModel(Chain));
+	Chain->addProxyModel(m_injectedFactory->makeInjected<TalkableProxyModel>(Chain));
 
-	QDeclarativeContext *declarativeContext = BuddiesView->rootContext();
+	QQmlContext *declarativeContext = BuddiesView->rootContext();
 	declarativeContext->setContextProperty("buddies", Chain->lastModel());
 
 	BuddiesView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	BuddiesView->setResizeMode(QDeclarativeView::SizeRootObjectToView);
-	BuddiesView->setSource(QUrl("file:///" + KaduPaths::instance()->dataPath() + "qml/openChatWith.qml"));
+	BuddiesView->setResizeMode(QQuickWidget::SizeRootObjectToView);
+	BuddiesView->setSource(QUrl("file:///" + m_pathsProvider->dataPath() + "qml/openChatWith.qml"));
 
 	if (BuddiesView->rootObject())
 		connect(BuddiesView->rootObject(), SIGNAL(itemActivated(int)), this, SLOT(itemActivated(int)));
@@ -128,21 +167,12 @@ OpenChatWith::OpenChatWith() :
 	MainLayout->addSpacing(16);
 	MainLayout->addWidget(buttons);
 
-	OpenChatRunner = new OpenChatWithContactListRunner();
+	OpenChatRunner = m_injectedFactory->makeInjected<OpenChatWithContactListRunner>();
 	OpenChatWithRunnerManager::instance()->registerRunner(OpenChatRunner);
 
 	inputChanged(QString());
 }
 
-OpenChatWith::~OpenChatWith()
-{
-	OpenChatWithRunnerManager::instance()->unregisterRunner(OpenChatRunner);
-	Instance = 0;
-
-	delete OpenChatRunner;
-	OpenChatRunner = 0;
-}
-
 void OpenChatWith::keyPressEvent(QKeyEvent *e)
 {
 	kdebugf();
@@ -202,7 +232,7 @@ void OpenChatWith::inputChanged(const QString &text)
 	kdebugf();
 
 	BuddyList matchingContacts = text.isEmpty()
-			? BuddyManager::instance()->items().toList()
+			? m_buddyManager->items().toList()
 			: OpenChatWithRunnerManager::instance()->matchingContacts(text);
 
 	ListModel->setBuddyList(matchingContacts);
@@ -218,12 +248,12 @@ void OpenChatWith::itemActivated(int index)
 	if (!contact)
 		return;
 
-	Chat chat = ChatTypeContact::findChat(contact, ActionCreateAndAdd);
+	Chat chat = ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd);
 	if (!chat)
 		return;
 
-	Core::instance()->chatWidgetManager()->openChat(chat, OpenChatActivation::Activate);
-	deleteLater();
+	m_chatWidgetManager->openChat(chat, OpenChatActivation::Activate);
+	QTimer::singleShot(50, this, SLOT(close()));
 }
 
 void OpenChatWith::inputAccepted()
@@ -237,7 +267,7 @@ void OpenChatWith::show()
   	if (!isVisible())
 		QWidget::show();
 	else
-		_activateWindow(this);
+		_activateWindow(m_configuration, this);
 }
 
 #include "moc_open-chat-with.cpp"
