@@ -3,8 +3,8 @@
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,17 +21,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
 #include <QtGui/QCloseEvent>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QLabel>
-#include <QtGui/QListWidget>
-#include <QtGui/QProgressBar>
-#include <QtGui/QPushButton>
-#include <QtGui/QStyle>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QProgressBar>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStyle>
+#include <QtWidgets/QVBoxLayout>
 
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 
 #include "progress-window.h"
@@ -50,6 +51,11 @@ ProgressWindow::~ProgressWindow()
 {
 }
 
+void ProgressWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
 void ProgressWindow::createGui()
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -148,7 +154,7 @@ void ProgressWindow::showDetailsClicked()
 
 void ProgressWindow::addProgressEntry(const QString &entryIcon, const QString &entryMessage)
 {
-	QListWidgetItem *item = new QListWidgetItem(KaduIcon(entryIcon).icon(), entryMessage, TextListWidget);
+	QListWidgetItem *item = new QListWidgetItem(m_iconsManager->iconByPath(KaduIcon(entryIcon)), entryMessage, TextListWidget);
 	TextListWidget->addItem(item);
 }
 
@@ -178,7 +184,7 @@ void ProgressWindow::progressFinished(bool ok, const QString &entryIcon, const Q
 	qApp->alert(this);
 
 	if (!ok && !entryMessage.isEmpty())
-		MessageDialog::show(KaduIcon(entryIcon), Label, entryMessage);
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon(entryIcon)), Label, entryMessage);
 }
 
 #include "moc_progress-window.cpp"
