@@ -1,6 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,13 +21,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PROGRESS_WINDOW_H
-#define PROGRESS_WINDOW_H
-
-#include <QtGui/QDialog>
+#pragma once
 
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QDialog>
+#include <injeqt/injeqt.h>
+
+class IconsManager;
+
 class QLabel;
 class QListWidget;
 class QProgressBar;
@@ -55,6 +62,8 @@ class KADUAPI ProgressWindow : public QDialog
 {
 	Q_OBJECT
 
+	QPointer<IconsManager> m_iconsManager;
+
 	QProgressBar *ProgressBar;
 	QListWidget *TextListWidget;
 	QPushButton *ShowDetailsButton;
@@ -67,6 +76,8 @@ class KADUAPI ProgressWindow : public QDialog
 	void createGui();
 
 private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+
 	void showDetailsClicked();
 
 protected:
@@ -80,7 +91,7 @@ public:
 	 * @param label label of progress window
 	 * @param parent parent QWidget of progress window
 	 */
-	explicit ProgressWindow(const QString &label, QWidget *parent = 0);
+	explicit ProgressWindow(const QString &label, QWidget *parent = nullptr);
 	virtual ~ProgressWindow();
 
 	/**
@@ -137,5 +148,3 @@ signals:
 /**
  * @}
  */
-
-#endif // PROGRESS_WINDOW_H
