@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +25,8 @@
 
 #include "proxy-action-context.h"
 
-ProxyActionContext::ProxyActionContext() :
+ProxyActionContext::ProxyActionContext(StatusContainer *statusContainer) :
+		m_statusContainer{statusContainer},
 		ForwardActionContext(0)
 {
 }
@@ -47,6 +48,13 @@ void ProxyActionContext::setForwardActionContext(ActionContext *forwardActionCon
 	emit changed();
 }
 
+QWidget * ProxyActionContext::widget()
+{
+	return ForwardActionContext
+			? ForwardActionContext->widget()
+			: nullptr;
+}
+
 ContactSet ProxyActionContext::contacts()
 {
 	return ForwardActionContext
@@ -70,7 +78,7 @@ Chat ProxyActionContext::chat()
 
 StatusContainer * ProxyActionContext::statusContainer()
 {
-	return StatusContainerManager::instance();
+	return m_statusContainer;
 }
 
 RoleSet ProxyActionContext::roles()
