@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,19 +26,21 @@ class ProxyActionContext : public ActionContext
 {
 	Q_OBJECT
 
+	StatusContainer *m_statusContainer;
 	ActionContext *ForwardActionContext;
 
 public:
-	ProxyActionContext();
+	explicit ProxyActionContext(StatusContainer *statusContainer);
 	virtual ~ProxyActionContext();
 
 	void setForwardActionContext(ActionContext *forwardActionContext);
 
-	virtual ContactSet contacts();
-	virtual BuddySet buddies();
-	virtual Chat chat();
-	virtual StatusContainer * statusContainer();
-	virtual RoleSet roles();
+	virtual QWidget * widget() override;
+	virtual ContactSet contacts() override;
+	virtual BuddySet buddies() override;
+	virtual Chat chat() override;
+	virtual StatusContainer * statusContainer() override;
+	virtual RoleSet roles() override;
 
 };
 
