@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,11 +19,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PROXY_EDIT_WINDOW_H
-#define PROXY_EDIT_WINDOW_H
+#pragma once
 
-#include <QtGui/QItemSelection>
-#include <QtGui/QWidget>
+#include <QtCore/QItemSelection>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 #include "gui/widgets/modal-configuration-widget.h"
 #include "network/proxy/network-proxy.h"
@@ -32,6 +33,9 @@ class QLineEdit;
 class QListView;
 class QPushButton;
 
+class Configuration;
+class InjectedFactory;
+class NetworkProxyManager;
 class NetworkProxyModel;
 class NetworkProxyProxyModel;
 
@@ -39,7 +43,17 @@ class ProxyEditWindow : public QWidget
 {
 	Q_OBJECT
 
-	static ProxyEditWindow *Instance;
+public:
+	explicit ProxyEditWindow(QWidget *parent = nullptr);
+	virtual ~ProxyEditWindow();
+
+protected:
+	virtual void keyPressEvent(QKeyEvent *e);
+
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<NetworkProxyManager> m_networkProxyManager;
 
 	QListView *ProxyView;
 	NetworkProxyModel *ProxyModel;
@@ -65,8 +79,6 @@ class ProxyEditWindow : public QWidget
 	 */
 	bool ForceProxyChange;
 
-	explicit ProxyEditWindow(QWidget *parent = 0);
-
 	void createGui();
 	void updateProxyView();
 	void saveProxy(NetworkProxy proxy);
@@ -78,6 +90,11 @@ class ProxyEditWindow : public QWidget
 	void selectProxy(NetworkProxy proxy);
 
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setNetworkProxyManager(NetworkProxyManager *networkProxyManager);
+	INJEQT_INIT void init();
+
 	void saveProxyButtonClicked();
 	void cancelButtonClicked();
 	void removeButtonClicked();
@@ -85,14 +102,4 @@ private slots:
 	void dataChanged();
 	void proxySelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
 
-protected:
-	virtual void keyPressEvent(QKeyEvent *e);
-
-public:
-	static void show();
-
-	virtual ~ProxyEditWindow();
-
 };
-
-#endif // PROXY_EDIT_WINDOW_H
