@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,62 +19,72 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QList>
-#include <QtGui/QAction>
-#include <QtGui/QLineEdit>
-#include <QtGui/QRadioButton>
-#include <QtGui/QTreeWidget>
+#include "search-window-actions.h"
 
+#include "core/injected-factory.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
 #include "gui/windows/search-window.h"
 
-#include "search-window-actions.h"
+#include <QtCore/QList>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QTreeWidget>
 
-SearchWindowActions * SearchWindowActions::Instance = 0;
-
-SearchWindowActions * SearchWindowActions::instance()
+SearchWindowActions::SearchWindowActions(QObject *parent) :
+		QObject{parent}
 {
-	if (!Instance)
-		Instance = new SearchWindowActions();
-	
-	return Instance;
 }
 
-SearchWindowActions::SearchWindowActions()
+SearchWindowActions::~SearchWindowActions()
 {
-	Actions::instance()->blockSignals();
+}
 
-	FirstSearch = new ActionDescription(this,
+void SearchWindowActions::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void SearchWindowActions::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void SearchWindowActions::init()
+{
+	m_actions->blockSignals();
+
+	FirstSearch = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeSearch, "firstSearchAction",
 		this, SLOT(firstSearchActionActivated(QAction*)),
 		KaduIcon("edit-find"), tr("&Search")
 	);
 	connect(FirstSearch, SIGNAL(actionCreated(Action*)), this, SLOT(firstSearchActionCreated(Action*)));
 
-	NextResults = new ActionDescription(this,
+	NextResults = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeSearch, "nextResultsAction",
 		this, SLOT(nextResultsActionActivated(QAction*)),
 		KaduIcon("go-next"), tr("&Next results")
 	);
 	connect(NextResults, SIGNAL(actionCreated(Action*)), this, SLOT(nextResultsActionCreated(Action*)));
 
-	StopSearch = new ActionDescription(this,
+	StopSearch = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeSearch, "stopSearchAction",
 		this, SLOT(stopSearchActionActivated(QAction*)),
 		KaduIcon("dialog-cancel"), tr("Stop")
 	);
 	connect(StopSearch, SIGNAL(actionCreated(Action*)), this, SLOT(stopSearchActionCreated(Action*)));
 
-	ClearResults = new ActionDescription(this,
+	ClearResults = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeSearch, "clearSearchAction",
 		this, SLOT(clearResultsActionActivated(QAction*)),
 		KaduIcon("edit-clear"), tr("Clear results")
 	);
 	connect(ClearResults, SIGNAL(actionCreated(Action*)), this, SLOT(clearResultsActionCreated(Action*)));
 
-	AddFound = new ActionDescription(this,
+	AddFound = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeSearch, "addSearchedAction",
 		this, SLOT(addFoundActionActivated(QAction*)),
 		KaduIcon("contact-new"), tr("Add selected user")
@@ -82,9 +92,9 @@ SearchWindowActions::SearchWindowActions()
 	connect(AddFound, SIGNAL(actionCreated(Action*)), this, SLOT(actionsFoundActionCreated(Action*)));
 
 	// The last ActionDescription will send actionLoaded() signal.
-	Actions::instance()->unblockSignals();
+	m_actions->unblockSignals();
 
-	ChatFound = new ActionDescription(this,
+	ChatFound = m_injectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeSearch, "chatSearchedAction",
 		this, SLOT(chatFoundActionActivated(QAction*)),
 		KaduIcon("internet-group-chat"), tr("&Chat")
@@ -92,9 +102,14 @@ SearchWindowActions::SearchWindowActions()
 	connect(ChatFound, SIGNAL(actionCreated(Action*)), this, SLOT(actionsFoundActionCreated(Action*)));
 }
 
-SearchWindowActions::~SearchWindowActions()
+void SearchWindowActions::done()
 {
-	Instance = 0;
+	delete FirstSearch;
+	delete NextResults;
+	delete StopSearch;
+	delete ClearResults;
+	delete AddFound;
+	delete ChatFound;
 }
 
 void SearchWindowActions::firstSearchActionCreated(Action *action)
