@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,23 +19,32 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SEARCH_WINDOW_ACTIONS_H
-#define SEARCH_WINDOW_ACTIONS_H
+#pragma once
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class ActionDescription;
+class Actions;
+class Action;
+class InjectedFactory;
 
 class QAction;
 
-class Action;
-class ActionDescription;
-
 class SearchWindowActions : public QObject
 {
 	Q_OBJECT
 
+public:
+	Q_INVOKABLE explicit SearchWindowActions(QObject *parent = nullptr);
+	virtual ~SearchWindowActions();
+
+private:
 	friend class SearchWindow;
 
-	static SearchWindowActions *Instance;
+	QPointer<Actions> m_actions;
+	QPointer<InjectedFactory> m_injectedFactory;
 
 	ActionDescription *FirstSearch;
 	ActionDescription *NextResults;
@@ -43,11 +52,13 @@ class SearchWindowActions : public QObject
 	ActionDescription *ClearResults;
 	ActionDescription *AddFound;
 	ActionDescription *ChatFound;
-	
-	SearchWindowActions();
-	virtual ~SearchWindowActions();
 
 private slots:
+	INJEQT_SET void setActions(Actions *actions);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
 	void firstSearchActionCreated(Action *action);
 	void nextResultsActionCreated(Action *action);
 	void stopSearchActionCreated(Action *action);
@@ -61,9 +72,4 @@ private slots:
 	void addFoundActionActivated(QAction *sender);
 	void chatFoundActionActivated(QAction *sender);
 
-public:
-	static SearchWindowActions * instance();
-
 };
-
-#endif // SEARCH_WINDOW_ACTIONS_H
