@@ -23,6 +23,39 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "search-window.h"
+
+#include "accounts/account-manager.h"
+#include "buddies/buddy-manager.h"
+#include "buddies/buddy-preferred-manager.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
+#include "chat/type/chat-type-contact-set.h"
+#include "chat/type/chat-type-contact.h"
+#include "configuration/config-file-variant-wrapper.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "contacts/contact-manager.h"
+#include "contacts/contact-set.h"
+#include "contacts/contact.h"
+#include "core/injected-factory.h"
+#include "gui/actions/base-action-context.h"
+#include "gui/widgets/chat-widget/chat-widget-manager.h"
+#include "gui/widgets/toolbar.h"
+#include "gui/windows/add-buddy-window.h"
+#include "gui/windows/kadu-window-service.h"
+#include "gui/windows/kadu-window.h"
+#include "gui/windows/message-dialog.h"
+#include "gui/windows/search-window-actions.h"
+#include "icons/icons-manager.h"
+#include "icons/kadu-icon.h"
+#include "os/generic/window-geometry-manager.h"
+#include "protocols/protocol-factory.h"
+#include "protocols/protocol.h"
+#include "protocols/services/search-service.h"
+#include "qt/long-validator.h"
+#include "status/status-container.h"
+
 #include <QtGui/QKeyEvent>
 #include <QtWidgets/QAction>
 #include <QtWidgets/QButtonGroup>
@@ -37,52 +70,22 @@
 #include <QtWidgets/QTreeWidget>
 #include <QtWidgets/QTreeWidgetItem>
 
-#include "accounts/account-manager.h"
-#include "buddies/buddy-manager.h"
-#include "buddies/buddy-preferred-manager.h"
-#include "chat/chat-manager.h"
-#include "chat/type/chat-type-contact-set.h"
-#include "chat/type/chat-type-contact.h"
-#include "configuration/config-file-variant-wrapper.h"
-#include "configuration/configuration.h"
-#include "configuration/deprecated-configuration-api.h"
-#include "contacts/contact-manager.h"
-#include "contacts/contact-set.h"
-#include "contacts/contact.h"
-#include "core/application.h"
-#include "core/core.h"
-#include "gui/actions/base-action-context.h"
-#include "gui/widgets/chat-widget/chat-widget-manager.h"
-#include "gui/widgets/toolbar.h"
-#include "gui/windows/add-buddy-window.h"
-#include "gui/windows/kadu-window.h"
-#include "gui/windows/message-dialog.h"
-#include "gui/windows/search-window-actions.h"
-#include "icons/kadu-icon.h"
-#include "os/generic/window-geometry-manager.h"
-#include "protocols/protocol-factory.h"
-#include "protocols/protocol.h"
-#include "protocols/services/search-service.h"
-#include "qt/long-validator.h"
-#include "status/status-container.h"
-
-#include "search-window.h"
-
-void SearchWindow::createDefaultToolbars(const QDomElement &toolbarsConfig)
+void SearchWindow::createDefaultToolbars(Configuration *configuration, const QDomElement &toolbarsConfig)
 {
-	QDomElement dockAreaConfig = getDockAreaConfigElement(toolbarsConfig, "search_bottomDockArea");
-	QDomElement toolbarConfig = Application::instance()->configuration()->api()->createElement(dockAreaConfig, "ToolBar");
+	QDomElement dockAreaConfig = getDockAreaConfigElement(configuration, toolbarsConfig, "search_bottomDockArea");
+	QDomElement toolbarConfig = configuration->api()->createElement(dockAreaConfig, "ToolBar");
 
-	addToolButton(toolbarConfig, "firstSearchAction", Qt::ToolButtonTextUnderIcon);
-	addToolButton(toolbarConfig, "nextResultsAction", Qt::ToolButtonTextUnderIcon);
-	addToolButton(toolbarConfig, "stopSearchAction", Qt::ToolButtonTextUnderIcon);
-	addToolButton(toolbarConfig, "clearSearchAction", Qt::ToolButtonTextUnderIcon);
-	addToolButton(toolbarConfig, "addSearchedAction", Qt::ToolButtonTextUnderIcon);
-	addToolButton(toolbarConfig, "chatSearchedAction", Qt::ToolButtonTextUnderIcon);
+	addToolButton(configuration, toolbarConfig, "firstSearchAction", Qt::ToolButtonTextUnderIcon);
+	addToolButton(configuration, toolbarConfig, "nextResultsAction", Qt::ToolButtonTextUnderIcon);
+	addToolButton(configuration, toolbarConfig, "stopSearchAction", Qt::ToolButtonTextUnderIcon);
+	addToolButton(configuration, toolbarConfig, "clearSearchAction", Qt::ToolButtonTextUnderIcon);
+	addToolButton(configuration, toolbarConfig, "addSearchedAction", Qt::ToolButtonTextUnderIcon);
+	addToolButton(configuration, toolbarConfig, "chatSearchedAction", Qt::ToolButtonTextUnderIcon);
 }
 
 SearchWindow::SearchWindow(QWidget *parent, Buddy buddy) :
 		MainWindow(new BaseActionContext(this), "search", parent),
+		m_buddy{buddy},
 		CurrentSearchService(0), UinEdit(0), FirstNameEdit(0), LastNameEdit(0), NickNameEdit(0),
 		StartBirthYearEdit(0), EndBirthYearEdit(0), CityEdit(0),
 		GenderComboBox(0), OnlyActiveCheckBox(0), UinRadioButton(0), PersonalDataRadioButton(0),
@@ -92,21 +95,85 @@ SearchWindow::SearchWindow(QWidget *parent, Buddy buddy) :
 
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(tr("Search User in Directory"));
+}
 
+SearchWindow::~SearchWindow()
+{
+}
+
+void SearchWindow::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void SearchWindow::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void SearchWindow::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void SearchWindow::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void SearchWindow::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void SearchWindow::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void SearchWindow::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void SearchWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void SearchWindow::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void SearchWindow::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void SearchWindow::setSearchWindowActions(SearchWindowActions *searchWindowActions)
+{
+	m_searchWindowActions = searchWindowActions;
+}
+
+void SearchWindow::init()
+{
 	RoleSet roles;
 	roles.insert(ContactRole);
 	static_cast<BaseActionContext *>(actionContext())->setRoles(roles);
 
-	if (buddy)
-	{
-		CurrentAccount = BuddyPreferredManager::instance()->preferredAccount(buddy);
+	CurrentSearchCriteria = m_injectedFactory->makeOwned<BuddySearchCriteria>(this);
 
-		CurrentSearchCriteria.SearchBuddy = buddy;
+	if (m_buddy)
+	{
+		CurrentAccount = m_buddyPreferredManager->preferredAccount(m_buddy);
+
+		CurrentSearchCriteria->SearchBuddy = m_buddy;
 	}
 	else
 	{
 		// TODO choose proper account
-		foreach (const Account &account, AccountManager::instance()->items())
+		foreach (const Account &account, m_accountManager->items())
 			if (account.protocolHandler() && account.protocolHandler()->isConnected() &&
 					account.protocolHandler()->searchService())
 			{
@@ -115,7 +182,7 @@ SearchWindow::SearchWindow(QWidget *parent, Buddy buddy) :
 			}
 
 		if (CurrentAccount.isNull())
-			CurrentAccount = AccountManager::instance()->defaultAccount();
+			CurrentAccount = m_accountManager->defaultAccount();
 	}
 
 	if (CurrentAccount.protocolHandler())
@@ -131,9 +198,9 @@ SearchWindow::SearchWindow(QWidget *parent, Buddy buddy) :
 	else
 		loadToolBarsFromConfig();
 
-	if (CurrentSearchCriteria.SearchBuddy)
+	if (CurrentSearchCriteria->SearchBuddy)
 	{
-		QVector<Contact> contacts = CurrentSearchCriteria.SearchBuddy.contacts(CurrentAccount);
+		QVector<Contact> contacts = CurrentSearchCriteria->SearchBuddy.contacts(CurrentAccount);
 		Contact contact = contacts.isEmpty() ? Contact::null : contacts.at(0);
 		if (contact)
 			// it should call uinTyped() slot
@@ -143,11 +210,7 @@ SearchWindow::SearchWindow(QWidget *parent, Buddy buddy) :
 	if (UinEdit->text().isEmpty())
 		personalDataTyped();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "SearchWindowGeometry"), QRect(0, 50, 800, 350), this);
-}
-
-SearchWindow::~SearchWindow()
-{
+	new WindowGeometryManager(new ConfigFileVariantWrapper(configuration(), "General", "SearchWindowGeometry"), QRect(0, 50, 800, 350), this);
 }
 
 void SearchWindow::createGui()
@@ -311,8 +374,8 @@ ContactSet SearchWindow::selectedContacts() const
 	else
 		altNick = uin;
 
-	Contact contact = ContactManager::instance()->byId(CurrentAccount, uin, ActionCreateAndAdd);
-	Buddy buddy = BuddyManager::instance()->byContact(contact, ActionCreateAndAdd);
+	Contact contact = m_contactManager->byId(CurrentAccount, uin, ActionCreateAndAdd);
+	Buddy buddy = m_buddyManager->byContact(contact, ActionCreateAndAdd);
 
 	if (buddy.isAnonymous())
 	{
@@ -328,7 +391,7 @@ ContactSet SearchWindow::selectedContacts() const
 void SearchWindow::addFound()
 {
 	foreach (const Buddy &buddy, selectedContacts().toBuddySet())
-		(new AddBuddyWindow(Core::instance()->kaduWindow(), buddy))->show();
+		(m_injectedFactory->makeInjected<AddBuddyWindow>(m_kaduWindowService->kaduWindow(), buddy))->show();
 }
 
 void SearchWindow::chatFound()
@@ -337,9 +400,9 @@ void SearchWindow::chatFound()
 	if (!contacts.isEmpty())
 	{
 		const Chat &chat = 1 == contacts.size()
-				? ChatTypeContact::findChat(*contacts.constBegin(), ActionCreateAndAdd)
-				: ChatTypeContactSet::findChat(contacts, ActionCreateAndAdd);
-		Core::instance()->chatWidgetManager()->openChat(chat, OpenChatActivation::Activate);
+				? ChatTypeContact::findChat(m_chatManager, m_chatStorage, *contacts.constBegin(), ActionCreateAndAdd)
+				: ChatTypeContactSet::findChat(m_chatManager, m_chatStorage, contacts, ActionCreateAndAdd);
+		m_chatWidgetManager->openChat(chat, OpenChatActivation::Activate);
 	}
 }
 
@@ -347,32 +410,32 @@ void SearchWindow::clearResults()
 {
 	ResultsListWidget->clear();
 
-	setActionEnabled(SearchWindowActions::instance()->AddFound, false);
-	setActionEnabled(SearchWindowActions::instance()->ClearResults, false);
-	setActionEnabled(SearchWindowActions::instance()->ChatFound, false);
+	setActionEnabled(m_searchWindowActions->AddFound, false);
+	setActionEnabled(m_searchWindowActions->ClearResults, false);
+	setActionEnabled(m_searchWindowActions->ChatFound, false);
 }
 
 void SearchWindow::stopSearch()
 {
 	CurrentSearchService->stop();
 
-	setActionEnabled(SearchWindowActions::instance()->StopSearch, false);
+	setActionEnabled(m_searchWindowActions->StopSearch, false);
 
 	if ((PersonalDataRadioButton->isChecked() && !isPersonalDataEmpty()) ||
 			(UinRadioButton->isChecked() && !UinEdit->text().isEmpty()))
-		setActionEnabled(SearchWindowActions::instance()->FirstSearch, true);
+		setActionEnabled(m_searchWindowActions->FirstSearch, true);
 
 	if (!ResultsListWidget->selectedItems().isEmpty())
 	{
 		if (PersonalDataRadioButton->isChecked() && !isPersonalDataEmpty())
-			setActionEnabled(SearchWindowActions::instance()->NextResults, true);
+			setActionEnabled(m_searchWindowActions->NextResults, true);
 
-		setActionEnabled(SearchWindowActions::instance()->AddFound, true);
-		setActionEnabled(SearchWindowActions::instance()->ChatFound, true);
+		setActionEnabled(m_searchWindowActions->AddFound, true);
+		setActionEnabled(m_searchWindowActions->ChatFound, true);
 	}
 
 	if (ResultsListWidget->topLevelItemCount() > 0)
-		setActionEnabled(SearchWindowActions::instance()->ClearResults, true);
+		setActionEnabled(m_searchWindowActions->ClearResults, true);
 }
 
 void SearchWindow::firstSearch()
@@ -382,21 +445,21 @@ void SearchWindow::firstSearch()
 
 	if (!CurrentAccount)
 	{
-		MessageDialog::show(KaduIcon("dialog-error"), windowTitle(),
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-error")), windowTitle(),
 				tr("To be able to search you have to set up an account first."), QMessageBox::Ok, this);
 		return;
 	}
 
 	if (!CurrentSearchService)
 	{
-		MessageDialog::show(KaduIcon("dialog-error"), windowTitle(),
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-error")), windowTitle(),
 				tr("We don't offer contacts search feature for your network yet."), QMessageBox::Ok, this);
 		return;
 	}
 
 	if (!CurrentAccount.protocolHandler() || !CurrentAccount.protocolHandler()->isConnected())
 	{
-		MessageDialog::show(KaduIcon("dialog-error"), windowTitle(),
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-error")), windowTitle(),
 				tr("Cannot search contacts in offline mode."), QMessageBox::Ok, this);
 		return;
 	}
@@ -407,42 +470,42 @@ void SearchWindow::firstSearch()
 	if (SearchInProgress)
 		CurrentSearchService->stop();
 
-	CurrentSearchCriteria.clearData();
+	CurrentSearchCriteria->clearData();
 
 	if (PersonalDataRadioButton->isChecked())
 	{
-		CurrentSearchCriteria.reqFirstName(FirstNameEdit->text());
-		CurrentSearchCriteria.reqLastName(LastNameEdit->text());
-		CurrentSearchCriteria.reqNickName(NickNameEdit->text());
-		CurrentSearchCriteria.reqCity(CityEdit->text());
+		CurrentSearchCriteria->reqFirstName(FirstNameEdit->text());
+		CurrentSearchCriteria->reqLastName(LastNameEdit->text());
+		CurrentSearchCriteria->reqNickName(NickNameEdit->text());
+		CurrentSearchCriteria->reqCity(CityEdit->text());
 		if (((EndBirthYearEdit->text().isEmpty()) && (!StartBirthYearEdit->text().isEmpty()))
 				|| ((EndBirthYearEdit->text().toInt()) < (StartBirthYearEdit->text().toInt())))
 			EndBirthYearEdit->setText(StartBirthYearEdit->text());
-		CurrentSearchCriteria.reqBirthYear(StartBirthYearEdit->text(), EndBirthYearEdit->text());
+		CurrentSearchCriteria->reqBirthYear(StartBirthYearEdit->text(), EndBirthYearEdit->text());
 
 		switch (GenderComboBox->currentIndex())
 		{
 			case 1:
-				CurrentSearchCriteria.reqGender(false);
+				CurrentSearchCriteria->reqGender(false);
 				break;
 			case 2:
-				CurrentSearchCriteria.reqGender(true);
+				CurrentSearchCriteria->reqGender(true);
 				break;
 		}
 
 		if (OnlyActiveCheckBox->isChecked())
-			CurrentSearchCriteria.reqActive();
+			CurrentSearchCriteria->reqActive();
 	}
 	else if (UinRadioButton->isChecked())
-		CurrentSearchCriteria.reqUin(CurrentAccount, UinEdit->text());
+		CurrentSearchCriteria->reqUin(CurrentAccount, UinEdit->text());
 
 	SearchInProgress = true;
 
-	setActionEnabled(SearchWindowActions::instance()->StopSearch, true);
-	setActionEnabled(SearchWindowActions::instance()->FirstSearch, false);
-	setActionEnabled(SearchWindowActions::instance()->NextResults, false);
-	setActionEnabled(SearchWindowActions::instance()->AddFound, false);
-	setActionEnabled(SearchWindowActions::instance()->ChatFound, false);
+	setActionEnabled(m_searchWindowActions->StopSearch, true);
+	setActionEnabled(m_searchWindowActions->FirstSearch, false);
+	setActionEnabled(m_searchWindowActions->NextResults, false);
+	setActionEnabled(m_searchWindowActions->AddFound, false);
+	setActionEnabled(m_searchWindowActions->ChatFound, false);
 
 	CurrentSearchService->searchFirst(CurrentSearchCriteria);
 
@@ -456,11 +519,11 @@ void SearchWindow::nextSearch()
 
 	SearchInProgress = true;
 
-	setActionEnabled(SearchWindowActions::instance()->StopSearch, true);
-	setActionEnabled(SearchWindowActions::instance()->FirstSearch, false);
-	setActionEnabled(SearchWindowActions::instance()->NextResults, false);
-	setActionEnabled(SearchWindowActions::instance()->AddFound, false);
-	setActionEnabled(SearchWindowActions::instance()->ChatFound, false);
+	setActionEnabled(m_searchWindowActions->StopSearch, true);
+	setActionEnabled(m_searchWindowActions->FirstSearch, false);
+	setActionEnabled(m_searchWindowActions->NextResults, false);
+	setActionEnabled(m_searchWindowActions->AddFound, false);
+	setActionEnabled(m_searchWindowActions->ChatFound, false);
 
 	CurrentSearchService->searchNext();
 
@@ -490,7 +553,7 @@ void SearchWindow::newSearchResults(const BuddyList &buddies)
 			strings << QString() << contact.id() << buddy.firstName()
 					<< buddy.city() << buddy.nickName() << QString::number(buddy.birthYear());
 			treeItem = new QTreeWidgetItem(ResultsListWidget, strings);
-			treeItem->setIcon(0, contact.contactAccount().statusContainer()->statusIcon(contact.currentStatus()).icon());
+			treeItem->setIcon(0, m_iconsManager->iconByPath(contact.contactAccount().statusContainer()->statusIcon(contact.currentStatus())));
 		}
 	}
 
@@ -498,26 +561,26 @@ void SearchWindow::newSearchResults(const BuddyList &buddies)
 
 	if ((PersonalDataRadioButton->isChecked() && !isPersonalDataEmpty()) ||
 			(UinRadioButton->isChecked() && !UinEdit->text().isEmpty()))
-		setActionEnabled(SearchWindowActions::instance()->FirstSearch, true);
+		setActionEnabled(m_searchWindowActions->FirstSearch, true);
 
-	setActionEnabled(SearchWindowActions::instance()->StopSearch, false);
+	setActionEnabled(m_searchWindowActions->StopSearch, false);
 
 	if (buddies.isEmpty())
-		MessageDialog::show(KaduIcon("dialog-information"), windowTitle(),
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-information")), windowTitle(),
 				tr("There were no results of your search."), QMessageBox::Ok, this);
 	else
 	{
 		if (PersonalDataRadioButton->isChecked() && !isPersonalDataEmpty())
-			setActionEnabled(SearchWindowActions::instance()->NextResults, true);
+			setActionEnabled(m_searchWindowActions->NextResults, true);
 
 		if (ResultsListWidget->topLevelItemCount() > 0)
-			setActionEnabled(SearchWindowActions::instance()->ClearResults, true);
+			setActionEnabled(m_searchWindowActions->ClearResults, true);
 	}
 
 	if (!ResultsListWidget->selectedItems().isEmpty())
 	{
-		setActionEnabled(SearchWindowActions::instance()->AddFound, true);
-		setActionEnabled(SearchWindowActions::instance()->ChatFound, true);
+		setActionEnabled(m_searchWindowActions->AddFound, true);
+		setActionEnabled(m_searchWindowActions->ChatFound, true);
 	}
 
 	SearchInProgress = false;
@@ -527,7 +590,7 @@ void SearchWindow::uinTyped()
 {
 	UinRadioButton->setChecked(true);
 
-	setActionEnabled(SearchWindowActions::instance()->FirstSearch, !UinEdit->text().isEmpty());
+	setActionEnabled(m_searchWindowActions->FirstSearch, !UinEdit->text().isEmpty());
 }
 
 void SearchWindow::personalDataTyped()
@@ -542,8 +605,8 @@ void SearchWindow::personalDataTyped()
 	else
 		PersonalDataRadioButton->setChecked(true);
 
-	setActionEnabled(SearchWindowActions::instance()->FirstSearch, !isPersonalDataEmpty());
-	setActionEnabled(SearchWindowActions::instance()->NextResults, false);
+	setActionEnabled(m_searchWindowActions->FirstSearch, !isPersonalDataEmpty());
+	setActionEnabled(m_searchWindowActions->NextResults, false);
 }
 
 void SearchWindow::endBirthYearTyped()
@@ -567,7 +630,7 @@ void SearchWindow::personalDataToggled(bool toggled)
 	if (!DoNotTransferFocus)
 		NickNameEdit->setFocus();
 
-	setActionEnabled(SearchWindowActions::instance()->FirstSearch, !isPersonalDataEmpty());
+	setActionEnabled(m_searchWindowActions->FirstSearch, !isPersonalDataEmpty());
 }
 
 void SearchWindow::uinToggled(bool toggled)
@@ -578,8 +641,8 @@ void SearchWindow::uinToggled(bool toggled)
 	OnlyActiveCheckBox->setEnabled(false);
 	UinEdit->setFocus();
 
-	setActionEnabled(SearchWindowActions::instance()->FirstSearch, !UinEdit->text().isEmpty());
-	setActionEnabled(SearchWindowActions::instance()->NextResults, false);
+	setActionEnabled(m_searchWindowActions->FirstSearch, !UinEdit->text().isEmpty());
+	setActionEnabled(m_searchWindowActions->NextResults, false);
 }
 
 bool SearchWindow::isPersonalDataEmpty() const
@@ -595,8 +658,8 @@ bool SearchWindow::isPersonalDataEmpty() const
 void SearchWindow::selectionChanged()
 {
 	bool enableActions = !ResultsListWidget->selectedItems().isEmpty();
-	setActionEnabled(SearchWindowActions::instance()->AddFound, enableActions);
-	setActionEnabled(SearchWindowActions::instance()->ChatFound, enableActions);
+	setActionEnabled(m_searchWindowActions->AddFound, enableActions);
+	setActionEnabled(m_searchWindowActions->ChatFound, enableActions);
 }
 
 void SearchWindow::setActionEnabled(ActionDescription *actionDescription, bool enable)
