@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010, 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,23 +20,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QMessageBox>
-#include <QtGui/QPushButton>
-#include <QtGui/QTextEdit>
+#include "status-window.h"
 
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/myself.h"
 #include "gui/widgets/kadu-text-edit.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/message-dialog.h"
 #include "gui/windows/status-window-description-proxy-model.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "parser/parser.h"
 #include "status/description-manager.h"
@@ -46,41 +38,68 @@
 #include "status/status-setter.h"
 #include "status/status-type-data.h"
 #include "status/status-type-manager.h"
-
 #include "activate.h"
 #include "debug.h"
 
-#include "status-window.h"
-
-QMap<StatusContainer *, StatusWindow *> StatusWindow::Dialogs;
-
-StatusWindow * StatusWindow::showDialog(StatusContainer *statusContainer, QWidget *parent)
-{
-	if (!statusContainer)
-		return 0;
-
-	StatusWindow *dialog;
-	if (Dialogs.contains(statusContainer))
-		dialog = Dialogs.value(statusContainer);
-	else
-	{
-		dialog = new StatusWindow(statusContainer, parent);
-		Dialogs.insert(statusContainer, dialog);
-	}
-
-	dialog->show();
-	_activateWindow(dialog);
-
-	return dialog;
-}
+#include <QtGui/QKeyEvent>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTextEdit>
 
 StatusWindow::StatusWindow(StatusContainer *statusContainer, QWidget *parent) :
 		QDialog(parent), DesktopAwareObject(this), Container(statusContainer), IgnoreNextTextChange(false)
 {
 	Q_ASSERT(Container);
+}
 
-	kdebugf();
+StatusWindow::~StatusWindow()
+{
+	emit statusWindowClosed(Container);
+}
 
+void StatusWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void StatusWindow::setDescriptionManager(DescriptionManager *descriptionManager)
+{
+	m_descriptionManager = descriptionManager;
+}
+
+void StatusWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void StatusWindow::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void StatusWindow::setParser(Parser *parser)
+{
+	m_parser = parser;
+}
+
+void StatusWindow::setStatusSetter(StatusSetter *statusSetter)
+{
+	m_statusSetter = statusSetter;
+}
+
+void StatusWindow::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void StatusWindow::init()
+{
 	setWindowRole("kadu-status-window");
 
 	QString windowTitle = Container->subStatusContainers().count() > 1
@@ -95,7 +114,7 @@ StatusWindow::StatusWindow(StatusContainer *statusContainer, QWidget *parent) :
 
 	setupStatusSelect();
 
-	QString description = StatusSetter::instance()->manuallySetStatus(Container->subStatusContainers().first()).description();
+	QString description = m_statusSetter->manuallySetStatus(Container->subStatusContainers().first()).description();
 
 	setupDescriptionSelect(description);
 
@@ -119,13 +138,6 @@ StatusWindow::StatusWindow(StatusContainer *statusContainer, QWidget *parent) :
 	connect(this, SIGNAL(accepted()), this, SLOT(applyStatus()));
 
 	setFixedSize(sizeHint().expandedTo(QSize(460, 1)));
-
-	kdebugf2();
-}
-
-StatusWindow::~StatusWindow()
-{
-	Dialogs.remove(Container);
 }
 
 void StatusWindow::createLayout()
@@ -157,7 +169,7 @@ void StatusWindow::createLayout()
 	DescriptionSelect->setToolTip(tr("Select Previously Used Description"));
 	descriptionSelectLayout->addWidget(DescriptionSelect);
 
-	ClearDescriptionsHistoryButton = new QPushButton(KaduIcon("edit-clear").icon(), "", this);
+	ClearDescriptionsHistoryButton = new QPushButton(m_iconsManager->iconByPath(KaduIcon("edit-clear")), "", this);
 	ClearDescriptionsHistoryButton->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 	ClearDescriptionsHistoryButton->setToolTip(tr("Clear Descriptions History"));
 	descriptionSelectLayout->addWidget(ClearDescriptionsHistoryButton);
@@ -194,7 +206,7 @@ void StatusWindow::createLayout()
 	descriptionEraseLayout->setMargin(0);
 	descriptionEraseLayout->setSpacing(0);
 	descriptionEraseLayout->addStretch();
-	EraseButton = new QPushButton(KaduIcon("edit-clear-locationbar-rtl").icon(), "", this);
+	EraseButton = new QPushButton(m_iconsManager->iconByPath(KaduIcon("edit-clear-locationbar-rtl")), "", this);
 	EraseButton->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 	EraseButton->setToolTip(tr("Erase Description"));
 	descriptionEraseLayout->addWidget(EraseButton);
@@ -222,24 +234,24 @@ void StatusWindow::createLayout()
 void StatusWindow::setupStatusSelect()
 {
 	StatusType commonStatusType = findCommonStatusType(Container->subStatusContainers());
-	if (commonStatusType == StatusTypeNone)
-		StatusSelect->addItem(tr("do not change"), QVariant(StatusTypeNone));
+	if (commonStatusType == StatusType::None)
+		StatusSelect->addItem(tr("do not change"), QVariant(static_cast<int>(StatusType::None)));
 
 	foreach (StatusType statusType, Container->supportedStatusTypes())
 	{
-		if (StatusTypeNone == statusType)
+		if (StatusType::None == statusType)
 			continue;
-		const StatusTypeData &typeData = StatusTypeManager::instance()->statusTypeData(statusType);
-		StatusSelect->addItem(Container->statusIcon(typeData.type()).icon(), typeData.displayName(), QVariant(typeData.type()));
+		const StatusTypeData &typeData = m_statusTypeManager->statusTypeData(statusType);
+		StatusSelect->addItem(m_iconsManager->iconByPath(Container->statusIcon(Status{typeData.type()})), typeData.displayName(), QVariant(static_cast<int>(typeData.type())));
 	}
 
-	StatusSelect->setCurrentIndex(StatusSelect->findData(QVariant(commonStatusType)));
+	StatusSelect->setCurrentIndex(StatusSelect->findData(QVariant(static_cast<int>(commonStatusType))));
 }
 
 void StatusWindow::setupDescriptionSelect(const QString &description)
 {
 	StatusWindowDescriptionProxyModel *proxyModel = new StatusWindowDescriptionProxyModel(this);
-	proxyModel->setSourceModel(DescriptionManager::instance()->model());
+	proxyModel->setSourceModel(m_descriptionManager->model());
 
 	DescriptionSelect->setModel(proxyModel);
 	DescriptionSelect->setEnabled(false);
@@ -247,13 +259,13 @@ void StatusWindow::setupDescriptionSelect(const QString &description)
 
 	Q_ASSERT(Container->subStatusContainers().count() > 0);
 
-	if (DescriptionManager::instance()->model()->rowCount() > 0)
+	if (m_descriptionManager->model()->rowCount() > 0)
 	{
 		DescriptionSelect->setEnabled(true);
 		ClearDescriptionsHistoryButton->setEnabled(true);
 
-		QModelIndexList matching = DescriptionManager::instance()->model()->match(
-			DescriptionManager::instance()->model()->index(0, 0),
+		QModelIndexList matching = m_descriptionManager->model()->match(
+			m_descriptionManager->model()->index(0, 0),
 			DescriptionRole, QVariant(description),
 			1,
 			Qt::MatchFixedString | Qt::MatchCaseSensitive
@@ -272,15 +284,15 @@ QSize StatusWindow::sizeHint() const
 
 StatusType StatusWindow::findCommonStatusType(const QList<StatusContainer *> &containers)
 {
-	StatusType commonStatusType = StatusTypeNone;
+	StatusType commonStatusType = StatusType::None;
 	foreach (StatusContainer *container, containers)
 	{
 		StatusType statusType = container->status().type();
-		if (commonStatusType == StatusTypeNone)
+		if (commonStatusType == StatusType::None)
 			commonStatusType = statusType;
 		else if (commonStatusType != statusType)
 		{
-			commonStatusType = StatusTypeNone;
+			commonStatusType = StatusType::None;
 			break;
 		}
 	}
@@ -292,21 +304,21 @@ void StatusWindow::applyStatus()
 	disconnect(DescriptionSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(descriptionSelected(int)));
 
 	QString description = DescriptionEdit->toPlainText();
-	DescriptionManager::instance()->addDescription(description);
+	m_descriptionManager->addDescription(description);
 
-	if (config_file.readBoolEntry("General", "ParseStatus", false))
-		description = Parser::parse(description, Talkable(Core::instance()->myself()), ParserEscape::NoEscape);
+	if (m_configuration->deprecatedApi()->readBoolEntry("General", "ParseStatus", false))
+		description = m_parser->parse(description, Talkable(m_myself->buddy()), ParserEscape::NoEscape);
 
-	foreach (StatusContainer *container, Container->subStatusContainers())
+	for (auto &&container : Container->subStatusContainers())
 	{
-		Status status = StatusSetter::instance()->manuallySetStatus(container);
+		Status status = m_statusSetter->manuallySetStatus(container);
 		status.setDescription(description);
 
 		StatusType statusType = static_cast<StatusType>(StatusSelect->itemData(StatusSelect->currentIndex()).toInt());
-		if (statusType != StatusTypeNone)
+		if (statusType != StatusType::None)
 			status.setType(statusType);
 
-		StatusSetter::instance()->setStatus(container, status);
+		m_statusSetter->setStatusManually(container, status);
 		container->storeStatus(status);
 	}
 }
@@ -316,7 +328,7 @@ void StatusWindow::descriptionSelected(int index)
 	if (index < 0)
 		return;
 
-	QString description = DescriptionManager::instance()->model()->data(DescriptionManager::instance()->model()->index(index, 0), DescriptionRole).toString();
+	QString description = m_descriptionManager->model()->data(m_descriptionManager->model()->index(index, 0), DescriptionRole).toString();
 
 	IgnoreNextTextChange = true;
 	DescriptionEdit->setPlainText(description);
@@ -392,7 +404,7 @@ void StatusWindow::eraseDescription()
 void StatusWindow::clearDescriptionsHistory()
 {
 	MessageDialog *dialog = MessageDialog::create(
-		KaduIcon("dialog-warning"),
+		m_iconsManager->iconByPath(KaduIcon("dialog-warning")),
 		tr("Clear Descriptions History"),
 		tr("Do you really want to clear the descriptions history?"),
 		this);
@@ -402,8 +414,8 @@ void StatusWindow::clearDescriptionsHistory()
 	if (!dialog->ask())
 		return;
 
-	DescriptionManager::instance()->clearDescriptions();
-	DescriptionSelect->setModel(DescriptionManager::instance()->model());
+	m_descriptionManager->clearDescriptions();
+	DescriptionSelect->setModel(m_descriptionManager->model());
 	DescriptionSelect->setCurrentIndex(-1);
 	DescriptionSelect->setEnabled(false);
 	ClearDescriptionsHistoryButton->setEnabled(false);
