@@ -1,13 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,36 +22,50 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SUBSCRIPTION_WINDOW_H
-#define SUBSCRIPTION_WINDOW_H
-
-#include <QtGui/QComboBox>
-#include <QtGui/QDialog>
+#pragma once
 
 #include "contacts/contact.h"
 #include "os/generic/desktop-aware-object.h"
 #include "exports.h"
 
+#include <QtCore/QObject>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialog>
+#include <injeqt/injeqt.h>
+
+class BuddyManager;
+class ContactManager;
+class InjectedFactory;
+class PluginInjectedFactory;
+
 class KADUAPI SubscriptionWindow : public QDialog, DesktopAwareObject
 {
 	Q_OBJECT
 
-	Contact CurrentContact;
-
-private slots:
-	void accepted();
-	void allowed();
-	void rejected();
-
 public:
-	static void getSubscription(Contact contact, QObject* receiver, const char* slot);
+	static void getSubscription(PluginInjectedFactory *pluginInjectedFactory, Contact contact, QObject* receiver, const char* slot);
 
-	explicit SubscriptionWindow(Contact contact, QWidget* parent = 0);
+	explicit SubscriptionWindow(Contact contact, QWidget* parent = nullptr);
 	virtual ~SubscriptionWindow();
 
 signals:
 	void requestConsidered(Contact contact, bool accepted);
 
-};
+private:
+	QPointer<BuddyManager> m_buddyManager;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<InjectedFactory> m_injectedFactory;
 
-#endif // SUBSCRIPTION_WINDOW_H
+	Contact m_contact;
+
+private slots:
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_INIT void init();
+
+	void accepted();
+	void allowed();
+	void rejected();
+
+};
