@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,47 +21,66 @@
  */
 
 #include <QtCore/QLocale>
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QDialogButtonBox>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
-#include <QtGui/QStyle>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStyle>
+#include <QtWidgets/QVBoxLayout>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "os/generic/url-opener.h"
 
 #include "updates-dialog.h"
 
 UpdatesDialog::UpdatesDialog(const QString &newestVersion, QWidget *parent) :
-		QDialog(parent), DesktopAwareObject(this)
+		QDialog(parent), DesktopAwareObject(this),
+		m_newestVersion{newestVersion}
 {
 	setWindowRole("kadu-updates");
 	setWindowTitle(tr("New version is available. Please update"));
 
 	setAttribute(Qt::WA_DeleteOnClose);
 	setMinimumSize(QSize(450, 150));
+}
 
+UpdatesDialog::~UpdatesDialog()
+{
+}
+
+void UpdatesDialog::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void UpdatesDialog::setUrlOpener(UrlOpener *urlOpener)
+{
+	m_urlOpener = urlOpener;
+}
+
+void UpdatesDialog::init()
+{
 	QVBoxLayout *layout = new QVBoxLayout(this);
 
 	QLabel *messageLabel = new QLabel(this);
 	messageLabel->setWordWrap(true);
 
-#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+#if defined(Q_OS_UNIX)
 	messageLabel->setText(QString(tr("A new version <b>%1</b> of Kadu Instant Messenger is available for download. "
 							 "Please <a href='download'>download</a> an installer and upgrade or use "
-							 "your package management system to update Kadu.")).arg(newestVersion));
+							 "your package management system to update Kadu.")).arg(m_newestVersion));
 #else
 	messageLabel->setText(QString(tr("A new version <b>%1</b> of Kadu Instant Messenger is available for download. "
-							 "Please <a href='download'>download</a> an installer and upgrade.")).arg(newestVersion));
+							 "Please <a href='download'>download</a> an installer and upgrade.")).arg(m_newestVersion));
 #endif
 
 	connect(messageLabel, SIGNAL(linkActivated(QString)), this, SLOT(downloadClicked()));
 
-	CheckForUpdates = new QCheckBox(tr("Check for updates when Kadu is opened"));
-	CheckForUpdates->setChecked(config_file.readBoolEntry("General", "CheckUpdates", true));
+	m_checkForUpdates = new QCheckBox(tr("Check for updates when Kadu is opened"));
+	m_checkForUpdates->setChecked(m_configuration->deprecatedApi()->readBoolEntry("General", "CheckUpdates", true));
 
 	QDialogButtonBox *buttons = new QDialogButtonBox(Qt::Horizontal, this);
 
@@ -73,27 +92,23 @@ UpdatesDialog::UpdatesDialog(const QString &newestVersion, QWidget *parent) :
 
 	layout->addWidget(messageLabel);
 	layout->addSpacing(5);
-	layout->addWidget(CheckForUpdates);
-	layout->setAlignment(CheckForUpdates, Qt::AlignRight);
+	layout->addWidget(m_checkForUpdates);
+	layout->setAlignment(m_checkForUpdates, Qt::AlignRight);
 	layout->addStretch(100);
 	layout->addWidget(buttons);
 }
 
-UpdatesDialog::~UpdatesDialog()
-{
-}
-
 void UpdatesDialog::downloadClicked()
 {
-	if (config_file.readEntry("General", "Language") == "pl")
-		UrlOpener::openUrl("http://www.kadu.im/w/Pobierz");
+	if (m_configuration->deprecatedApi()->readEntry("General", "Language") == "pl")
+		m_urlOpener->openUrl("http://www.kadu.im/w/Pobierz");
 	else
-		UrlOpener::openUrl("http://www.kadu.im/w/English:Download");
+		m_urlOpener->openUrl("http://www.kadu.im/w/English:Download");
 }
 
 void UpdatesDialog::accepted()
 {
-	config_file.writeEntry("General", "CheckUpdates", CheckForUpdates->isChecked());
+	m_configuration->deprecatedApi()->writeEntry("General", "CheckUpdates", m_checkForUpdates->isChecked());
 
 	close();
 }
