@@ -1,12 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,31 +20,43 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef UPDATES_DIALOG_H
-#define UPDATES_DIALOG_H
-
-#include <QtGui/QDialog>
+#pragma once
 
 #include "os/generic/desktop-aware-object.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QDialog>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+class UrlOpener;
+
 class QCheckBox;
 
 class UpdatesDialog : public QDialog, DesktopAwareObject
 {
 	Q_OBJECT
 
-	QCheckBox *CheckForUpdates;
-
-private slots:
-	void accepted();
-	void downloadClicked();
+public:
+	explicit UpdatesDialog(const QString &newestVersion, QWidget *parent = nullptr);
+	virtual ~UpdatesDialog();
 
 protected:
 	virtual void keyPressEvent(QKeyEvent *e);
 
-public:
-	explicit UpdatesDialog(const QString &newestVersion, QWidget *parent = 0);
-	virtual ~UpdatesDialog();
-};
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<UrlOpener> m_urlOpener;
 
-#endif // UPDATES_DIALOG_H
+	QString m_newestVersion;
+	QCheckBox *m_checkForUpdates;
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setUrlOpener(UrlOpener *urlOpener);
+	INJEQT_INIT void init();
+
+	void accepted();
+	void downloadClicked();
+
+};
