@@ -1,12 +1,12 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,32 +23,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QGridLayout>
-#include <QtGui/QGroupBox>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QListView>
-#include <QtGui/QMessageBox>
-#include <QtGui/QPushButton>
-#include <QtGui/QStackedWidget>
-#include <QtGui/QVBoxLayout>
+#include "your-accounts.h"
 
 #include "accounts/account-manager.h"
 #include "accounts/model/accounts-model.h"
+#include "configuration/configuration-manager.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
+#include "core/myself.h"
 #include "gui/widgets/account-add-widget.h"
 #include "gui/widgets/account-create-widget.h"
 #include "gui/widgets/account-edit-widget.h"
 #include "gui/widgets/modal-configuration-widget.h"
 #include "gui/widgets/protocols-combo-box.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "model/action-filter-proxy-model.h"
 #include "model/action-list-model.h"
@@ -59,16 +48,65 @@
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
-
 #include "activate.h"
 
-#include "your-accounts.h"
-
-YourAccounts *YourAccounts::Instance = 0;
+#include <QtGui/QKeyEvent>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QListView>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStackedWidget>
+#include <QtWidgets/QVBoxLayout>
 
 YourAccounts::YourAccounts(QWidget *parent) :
 		QWidget(parent), DesktopAwareObject(this), CurrentWidget(0), IsCurrentWidgetEditAccount(false),
 		ForceWidgetChange(false), LastProtocol(0), CanRegisterFilter(new CanRegisterProtocolFilter())
+{
+}
+
+YourAccounts::~YourAccounts()
+{
+}
+
+void YourAccounts::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void YourAccounts::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void YourAccounts::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void YourAccounts::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void YourAccounts::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void YourAccounts::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void YourAccounts::init()
 {
 	setWindowRole("kadu-your-accounts");
 
@@ -78,27 +116,7 @@ YourAccounts::YourAccounts(QWidget *parent) :
 	createGui();
 	AccountsView->selectionModel()->select(AccountsView->model()->index(0, 0), QItemSelectionModel::ClearAndSelect);
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("General", "YourAccountsWindowGeometry"), QRect(0, 50, 700, 500), this);
-}
-
-YourAccounts::~YourAccounts()
-{
-	Instance = 0;
-}
-
-YourAccounts * YourAccounts::instance()
-{
-	if (!Instance)
-		Instance = new YourAccounts();
-
-	return Instance;
-}
-
-void YourAccounts::show()
-{
-	QWidget::show();
-
-	_activateWindow(this);
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "General", "YourAccountsWindowGeometry"), QRect(0, 50, 700, 500), this);
 }
 
 void YourAccounts::createGui()
@@ -111,13 +129,13 @@ void YourAccounts::createGui()
 	AccountsView = new QListView(this);
 	AccountsView->setMinimumWidth(150);
 	contentLayout->addWidget(AccountsView);
-	MyAccountsModel = new AccountsModel(AccountsView);
+	MyAccountsModel = m_injectedFactory->makeInjected<AccountsModel>(m_accountManager, AccountsView);
 
 	QAction *separator = new QAction(this);
 	separator->setSeparator(true);
 
-	AddExistingAccountAction = new QAction(KaduIcon("contact-new").icon(), tr("Add existing account"), this);
-	CreateNewAccountAction = new QAction(KaduIcon("system-users").icon(), tr("Create new account"), this);
+	AddExistingAccountAction = new QAction(m_iconsManager->iconByPath(KaduIcon("contact-new")), tr("Add existing account"), this);
+	CreateNewAccountAction = new QAction(m_iconsManager->iconByPath(KaduIcon("system-users")), tr("Create new account"), this);
 
 	ActionListModel *actionsModel = new ActionListModel(this);
 	actionsModel->appendAction(separator);
@@ -206,7 +224,7 @@ void YourAccounts::createAccountWidget()
 	QFormLayout *selectNetworkLayout = new QFormLayout(selectNetworkGroupbox);
 
 	QLabel *imNetworkLabel = new QLabel(tr("IM Network") + ':', CreateAddAccountContainer);
-	Protocols = new ProtocolsComboBox(CreateAddAccountContainer);
+	Protocols = m_injectedFactory->makeInjected<ProtocolsComboBox>(CreateAddAccountContainer);
 	Protocols->addFilter(CanRegisterFilter);
 	selectNetworkLayout->addRow(imNetworkLabel, Protocols);
 
@@ -349,7 +367,7 @@ bool YourAccounts::canChangeWidget()
 
 	if (!IsCurrentWidgetEditAccount)
 	{
-		MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Unsaved changes"),
+		MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Unsaved changes"),
 					tr("You have unsaved changes in current account.<br />Do you want to return to edit or discard changes?"));
 		dialog->addButton(QMessageBox::Yes, tr("Return to edit"));
 		dialog->addButton(QMessageBox::Ignore, tr("Discard changes"));
@@ -373,7 +391,7 @@ bool YourAccounts::canChangeWidget()
 
 	if (StateChangedDataValid == CurrentWidget->stateNotifier()->state())
 	{
-		MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Unsaved changes"),
+		MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Unsaved changes"),
 					tr("You have unsaved changes in current account.<br />Do you want to save them?"));
 		dialog->addButton(QMessageBox::Save, tr("Save changes"));
 		dialog->addButton(QMessageBox::Ignore, tr("Discard"));
@@ -398,7 +416,7 @@ bool YourAccounts::canChangeWidget()
 
 	if (StateChangedDataInvalid == CurrentWidget->stateNotifier()->state())
 	{
-		MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Invalid changes"),
+		MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Invalid changes"),
 					tr("You have invalid changes in current account, which cannot be saved.<br />Do you want to stay in edit or discard changes?"));
 		dialog->addButton(QMessageBox::Yes, tr("Stay in edit"));
 		dialog->addButton(QMessageBox::Ignore, tr("Discard changes"));
@@ -428,10 +446,10 @@ void YourAccounts::accountCreated(Account account)
 	if (!account)
 		return;
 
-	AccountManager::instance()->addItem(account);
-	account.accountContact().setOwnerBuddy(Core::instance()->myself());
+	m_accountManager->addItem(account);
+	account.accountContact().setOwnerBuddy(m_myself->buddy());
 
-	ConfigurationManager::instance()->flush();
+	m_configurationManager->flush();
 	selectAccount(account);
 }
 
