@@ -20,50 +20,51 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
+#include "icons-manager.h"
 
 #include "accounts/account-manager.h"
 #include "configuration/configuration.h"
 #include "configuration/deprecated-configuration-api.h"
-#include "core/application.h"
+#include "core/core.h"
+#include "core/core.h"
 #include "icons/kadu-icon.h"
 #include "misc/misc.h"
 #include "protocols/protocol.h"
 #include "themes/icon-theme-manager.h"
 #include "debug.h"
 
-#include "icons-manager.h"
+#include <QtCore/QFileInfo>
 
-IconsManager * IconsManager::Instance = 0;
-
-IconsManager * IconsManager::instance()
+IconsManager::IconsManager(QObject *parent) :
+		QObject{parent}
 {
-	if (Instance == 0)
-		Instance = new IconsManager();
-	return Instance;
 }
 
-IconsManager::IconsManager()
+IconsManager::~IconsManager()
 {
-	kdebugf();
+}
 
-	ThemeManager = new IconThemeManager(this);
-	ThemeManager->loadThemes();
-	ThemeManager->setCurrentTheme(Application::instance()->configuration()->deprecatedApi()->readEntry("Look", "IconTheme"));
+void IconsManager::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void IconsManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void IconsManager::setIconThemeManager(IconThemeManager *iconThemeManager)
+{
+	m_iconThemeManager = iconThemeManager;
+}
+
+void IconsManager::init()
+{
 	configurationUpdated();
 
-	Application::instance()->configuration()->deprecatedApi()->writeEntry("Look", "IconTheme", ThemeManager->currentTheme().name());
-
 	// TODO: localized protocol
 	localProtocolPath = "gadu-gadu";
-
-	kdebugf2();
-}
-
-IconThemeManager * IconsManager::themeManager() const
-{
-	return ThemeManager;
 }
 
 QString IconsManager::iconPath(const KaduIcon &icon, IconsManager::AllowEmpty allowEmpty) const
@@ -72,7 +73,7 @@ QString IconsManager::iconPath(const KaduIcon &icon, IconsManager::AllowEmpty al
 	QString size = icon.size();
 
 	QFileInfo fileInfo(path);
-	QString themePath = icon.themePath().isEmpty() ? ThemeManager->currentTheme().path() : icon.themePath();
+	QString themePath = icon.themePath().isEmpty() ? m_iconThemeManager->currentTheme().path() : icon.themePath();
 	QString name = fileInfo.fileName();
 	QString realPath = fileInfo.path();
 
@@ -92,11 +93,11 @@ QString IconsManager::iconPath(const KaduIcon &icon, IconsManager::AllowEmpty al
 	if (fileInfo.isFile() && fileInfo.isReadable())
 		return fileInfo.canonicalFilePath();
 
-	if (realPath == QLatin1String("protocols/common"))
+	if (realPath == QStringLiteral("protocols/common"))
 	{
 		QString protocolPath;
-		if (AccountManager::instance()->defaultAccount().protocolHandler())
-			protocolPath = AccountManager::instance()->defaultAccount().protocolHandler()->statusPixmapPath();
+		if (m_accountManager->defaultAccount().protocolHandler())
+			protocolPath = m_accountManager->defaultAccount().protocolHandler()->statusPixmapPath();
 		else
 			protocolPath = localProtocolPath;
 
@@ -113,14 +114,14 @@ QString IconsManager::iconPath(const KaduIcon &icon, IconsManager::AllowEmpty al
 
 QIcon IconsManager::buildPngIcon(const QString &themePath, const QString &path)
 {
-	static QLatin1String sizes [] = {
-		QLatin1String("16x16"),
-		QLatin1String("22x22"),
-		QLatin1String("32x32"),
-		QLatin1String("64x64"),
-		QLatin1String("96x96"),
-		QLatin1String("128x128"),
-		QLatin1String("256x256")
+	static QString sizes [] = {
+		QStringLiteral("16x16"),
+		QStringLiteral("22x22"),
+		QStringLiteral("32x32"),
+		QStringLiteral("64x64"),
+		QStringLiteral("96x96"),
+		QStringLiteral("128x128"),
+		QStringLiteral("256x256")
 	};
 	static int sizes_count = 7;
 
@@ -200,8 +201,8 @@ QIcon IconsManager::iconByPath(const QString &themePath, const QString &path, Al
 				if (path.contains(commonRegexp))
 				{
 					QString protocolpath;
-					if (AccountManager::instance()->defaultAccount().protocolHandler())
-						protocolpath = AccountManager::instance()->defaultAccount().protocolHandler()->statusPixmapPath();
+					if (m_accountManager->defaultAccount().protocolHandler())
+						protocolpath = m_accountManager->defaultAccount().protocolHandler()->statusPixmapPath();
 					else
 						protocolpath = localProtocolPath;
 					return iconByPath(themePath, QString("protocols/%1/%2").arg(protocolpath, commonRegexp.cap(1)));
@@ -222,6 +223,11 @@ QIcon IconsManager::iconByPath(const QString &themePath, const QString &path, Al
 	return IconCache.value(themePath + path);
 }
 
+QIcon IconsManager::iconByPath(const KaduIcon &icon)
+{
+	return iconByPath(icon.themePath(), icon.path());
+}
+
 void IconsManager::clearCache()
 {
 	IconCache.clear();
@@ -229,12 +235,12 @@ void IconsManager::clearCache()
 
 void IconsManager::configurationUpdated()
 {
-	bool themeWasChanged = Application::instance()->configuration()->deprecatedApi()->readEntry("Look", "IconTheme") != ThemeManager->currentTheme().name();
+	bool themeWasChanged = m_configuration->deprecatedApi()->readEntry("Look", "IconTheme") != m_iconThemeManager->currentTheme().name();
 	if (themeWasChanged)
 	{
 		clearCache();
-		ThemeManager->setCurrentTheme(Application::instance()->configuration()->deprecatedApi()->readEntry("Look", "IconTheme"));
-		Application::instance()->configuration()->deprecatedApi()->writeEntry("Look", "IconTheme", ThemeManager->currentTheme().name());
+		m_iconThemeManager->setCurrentTheme(m_configuration->deprecatedApi()->readEntry("Look", "IconTheme"));
+		m_configuration->deprecatedApi()->writeEntry("Look", "IconTheme", m_iconThemeManager->currentTheme().name());
 
 		emit themeChanged();
 	}
