@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,22 +20,8 @@
 
 #include <QtGui/QIcon>
 
+#include "core/core.h"
 #include "icons/icons-manager.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 
 #include "kadu-icon.h"
-
-QString KaduIcon::fullPath() const
-{
-	return IconsManager::instance()->iconPath(*this);
-}
-
-QString KaduIcon::webKitPath() const
-{
-	return KaduPaths::webKitPath(fullPath());
-}
-
-QIcon KaduIcon::icon() const
-{
-	return IconsManager::instance()->iconByPath(themePath(), path());
-}
