@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,32 +18,32 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "identity-manager.h"
-
 #include "identities-aware-object.h"
 
+#include "identity-manager.h"
+
 KADU_AWARE_CLASS(IdentitiesAwareObject)
 
 void IdentitiesAwareObject::notifyIdentityAdded(Identity identity)
 {
-	foreach (IdentitiesAwareObject *object, Objects)
+	for (IdentitiesAwareObject *object : Objects)
 		object->identityAdded(identity);
 }
 
 void IdentitiesAwareObject::notifyIdentityRemoved(Identity identity)
 {
-	foreach (IdentitiesAwareObject *object, Objects)
+	for (IdentitiesAwareObject *object : Objects)
 		object->identityRemoved(identity);
 }
 
-void IdentitiesAwareObject::triggerAllIdentitiesAdded()
+void IdentitiesAwareObject::triggerAllIdentitiesAdded(IdentityManager *identityManager)
 {
-	foreach (const Identity &identity, IdentityManager::instance()->items())
+	for (const Identity &identity : identityManager->items())
 		identityAdded(identity);
 }
 
-void IdentitiesAwareObject::triggerAllIdentitiesRemoved()
+void IdentitiesAwareObject::triggerAllIdentitiesRemoved(IdentityManager *identityManager)
 {
-	foreach (const Identity &identity, IdentityManager::instance()->items())
+	for (const Identity &identity : identityManager->items())
 		identityRemoved(identity);
 }
