@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,20 +24,12 @@
 #include "configuration/configuration-manager.h"
 #include "core/core.h"
 #include "identities/identities-aware-object.h"
+#include "identities/identity-storage.h"
 
 #include "identity-manager.h"
 
-IdentityManager * IdentityManager::Instance = 0;
-
-IdentityManager * IdentityManager::instance()
-{
-	if (0 == Instance)
-		Instance = new IdentityManager();
-
-	return Instance;
-}
-
-IdentityManager::IdentityManager()
+IdentityManager::IdentityManager(QObject *parent) :
+		SimpleManager<Identity>{parent}
 {
 }
 
@@ -45,6 +37,26 @@ IdentityManager::~IdentityManager()
 {
 }
 
+void IdentityManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void IdentityManager::setIdentityStorage(IdentityStorage *identityStorage)
+{
+	m_identityStorage = identityStorage;
+}
+
+void IdentityManager::init()
+{
+	m_configurationManager->registerStorableObject(this);
+}
+
+void IdentityManager::done()
+{
+	m_configurationManager->unregisterStorableObject(this);
+}
+
 Identity IdentityManager::byName(const QString &name, bool create)
 {
 	QMutexLocker locker(&mutex());
@@ -61,7 +73,7 @@ Identity IdentityManager::byName(const QString &name, bool create)
 	if (!create)
 		return Identity::null;
 
-	Identity newIdentity = Identity::create();
+	auto newIdentity = m_identityStorage->create();
 	newIdentity.setName(name);
 	addItem(newIdentity);
 
@@ -119,19 +131,19 @@ void IdentityManager::addDefaultIdentities()
 {
 	QMutexLocker locker(&mutex());
 
-	Identity friendsIdentity = Identity::create();
+	auto friendsIdentity = m_identityStorage->create();
 	friendsIdentity.data()->setState(StateNew);
 	friendsIdentity.setPermanent(true);
 	friendsIdentity.setName(tr("Friends"));
 	addItem(friendsIdentity);
 
-	Identity workIdentity = Identity::create();
+	auto workIdentity = m_identityStorage->create();
 	workIdentity.data()->setState(StateNew);
 	workIdentity.setPermanent(true);
 	workIdentity.setName(tr("Work"));
 	addItem(workIdentity);
 
-	Identity schoolIdentity = Identity::create();
+	auto schoolIdentity = m_identityStorage->create();
 	schoolIdentity.data()->setState(StateNew);
 	schoolIdentity.setPermanent(true);
 	schoolIdentity.setName(tr("School"));
@@ -148,4 +160,9 @@ void IdentityManager::load()
 		addDefaultIdentities();
 }
 
+Identity IdentityManager::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+{
+	return m_identityStorage->loadStubFromStorage(storagePoint);
+}
+
 #include "moc_identity-manager.cpp"
