@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,46 +20,33 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IDENTITY_MANAGER_H
-#define IDENTITY_MANAGER_H
-
-#include <QtCore/QList>
-#include <QtCore/QObject>
-#include <QtCore/QUuid>
+#pragma once
 
 #include "identities/identity.h"
 #include "storage/simple-manager.h"
-
 #include "exports.h"
 
+#include <QtCore/QList>
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtCore/QUuid>
+#include <injeqt/injeqt.h>
+
 class Account;
+class ConfigurationManager;
+class IdentityStorage;
 class Status;
 
-class KADUAPI IdentityManager : public QObject, public SimpleManager<Identity>
+class KADUAPI IdentityManager : public SimpleManager<Identity>
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(IdentityManager)
-
-	static IdentityManager *Instance;
-
-	IdentityManager();
-	virtual ~IdentityManager();
-
-	void addDefaultIdentities();
-
-protected:
-	virtual void itemAboutToBeAdded(Identity item);
-	virtual void itemAdded(Identity item);
-	virtual void itemAboutToBeRemoved(Identity item);
-	virtual void itemRemoved(Identity item);
-
-	virtual void load();
 
 public:
-	static IdentityManager * instance();
+	Q_INVOKABLE explicit IdentityManager(QObject *parent = nullptr);
+	virtual ~IdentityManager();
 
-	virtual QString storageNodeName() { return QLatin1String("Identities"); }
-	virtual QString storageNodeItemName() { return QLatin1String("Identity"); }
+	virtual QString storageNodeName() { return QStringLiteral("Identities"); }
+	virtual QString storageNodeItemName() { return QStringLiteral("Identity"); }
 
 	Identity byName(const QString &name, bool create = true);
 	Identity identityForAcccount(Account account);
@@ -72,6 +59,25 @@ signals:
 	void identityAboutToBeRemoved(Identity);
 	void identityRemoved(Identity);
 
-};
+protected:
+	virtual void itemAboutToBeAdded(Identity item);
+	virtual void itemAdded(Identity item);
+	virtual void itemAboutToBeRemoved(Identity item);
+	virtual void itemRemoved(Identity item);
 
-#endif // IDENTITY_MANAGER_H
+	virtual void load();
+	virtual Identity loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint);
+
+private:
+	QPointer<ConfigurationManager> m_configurationManager;
+	QPointer<IdentityStorage> m_identityStorage;
+
+	void addDefaultIdentities();
+
+private slots:
+	INJEQT_SET void setConfigurationManager(ConfigurationManager *configurationManager);
+	INJEQT_SET void setIdentityStorage(IdentityStorage *identityStorage);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
+};
