@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,39 +22,21 @@
  */
 
 #include "accounts/account-manager.h"
-#include "configuration/main-configuration-holder.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/injected-factory.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity-manager.h"
+#include "identities/identity-status-container.h"
 #include "misc/misc.h"
 #include "protocols/protocol.h"
 
-#include "status/status-type-manager.h"
 #include "status/status-type.h"
 
 #include "identity-shared.h"
 
-IdentityShared * IdentityShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+IdentityShared::IdentityShared(const QUuid &uuid, QObject *parent) :
+		Shared(uuid, parent), Permanent(false)
 {
-	IdentityShared *identityShared = loadFromStorage(storagePoint);
-	identityShared->loadStub();
-
-	return identityShared;
-}
-
-IdentityShared * IdentityShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	IdentityShared *identityShared = new IdentityShared();
-	identityShared->setStorage(storagePoint);
-
-	return identityShared;
-}
-
-IdentityShared::IdentityShared(const QUuid &uuid) :
-		StorableStatusContainer(this), Shared(uuid), Permanent(false)
-{
-	setState(StateNotLoaded);
 }
 
 IdentityShared::~IdentityShared()
@@ -62,14 +44,30 @@ IdentityShared::~IdentityShared()
 	ref.ref();
 }
 
+void IdentityShared::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void IdentityShared::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void IdentityShared::init()
+{
+	m_identityStatusContainer = m_injectedFactory->makeNotOwned<IdentityStatusContainer>(this);
+	setState(StateNotLoaded);
+}
+
 StorableObject * IdentityShared::storageParent()
 {
-	return IdentityManager::instance();
+	return m_identityManager;
 }
 
 QString IdentityShared::storageNodeName()
 {
-	return QLatin1String("Identity");
+	return QStringLiteral("Identity");
 }
 
 void IdentityShared::load()
@@ -108,6 +106,13 @@ void IdentityShared::aboutToBeRemoved()
 	Accounts.clear();
 }
 
+QList<Account> IdentityShared::accounts()
+{
+	ensureLoaded();
+
+	return Accounts;
+}
+
 void IdentityShared::addAccount(const Account &account)
 {
 	if (!account)
@@ -116,11 +121,7 @@ void IdentityShared::addAccount(const Account &account)
 	ensureLoaded();
 
 	Accounts.append(account);
-	connect(account.statusContainer(), SIGNAL(statusUpdated(StatusContainer *)), this, SIGNAL(statusUpdated(StatusContainer *)));
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
-		account.statusContainer()->setStatus(LastSetStatus, SourceStatusChanger);
-
-	emit statusUpdated(this);
+	m_identityStatusContainer->addAccount(account);
 }
 
 void IdentityShared::removeAccount(const Account &account)
@@ -131,10 +132,7 @@ void IdentityShared::removeAccount(const Account &account)
 	ensureLoaded();
 
 	if (Accounts.removeAll(account) > 0)
-	{
-		disconnect(account.statusContainer(), 0, this, 0);
-		emit statusUpdated(this);
-	}
+		m_identityStatusContainer->removeAccount(account);
 }
 
 bool IdentityShared::hasAccount(const Account &account)
@@ -162,56 +160,9 @@ bool IdentityShared::isEmpty()
 	return Accounts.isEmpty();
 }
 
-void IdentityShared::setStatus(Status status, StatusChangeSource source)
+StatusContainer * IdentityShared::statusContainer() const
 {
-	ensureLoaded();
-
-	LastSetStatus = status;
-	foreach (const Account &account, Accounts)
-		if (account)
-			account.statusContainer()->setStatus(status, source);
-}
-
-Status IdentityShared::status()
-{
-	Account account = AccountManager::bestAccount(Accounts);
-	return account ? account.statusContainer()->status() : Status();
-}
-
-bool IdentityShared::isStatusSettingInProgress()
-{
-	Account account = AccountManager::bestAccount(Accounts);
-	return account ? account.statusContainer()->isStatusSettingInProgress() : false;
-}
-
-KaduIcon IdentityShared::statusIcon()
-{
-	return statusIcon(status());
-}
-
-KaduIcon IdentityShared::statusIcon(const Status &status)
-{
-	QSet<QString> protocols;
-	foreach (const Account &account, Accounts)
-		protocols.insert(account.protocolName());
-
-	if (protocols.count() > 1)
-		return StatusTypeManager::instance()->statusIcon("common", status);
-
-	Account account = AccountManager::bestAccount(Accounts);
-	return account ? account.statusContainer()->statusIcon(status) : KaduIcon();
-}
-
-QList<StatusType> IdentityShared::supportedStatusTypes()
-{
-	Account account = AccountManager::bestAccount(Accounts);
-	return account ? account.statusContainer()->supportedStatusTypes() : QList<StatusType>();
-}
-
-int IdentityShared::maxDescriptionLength()
-{
-	Account account = AccountManager::bestAccount(Accounts);
-	return account ? account.statusContainer()->maxDescriptionLength() : -1;
+	return m_identityStatusContainer.get();
 }
 
 #include "moc_identity-shared.cpp"
