@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
+#include "core/injected-factory.h"
 
 #include "identity.h"
 
@@ -29,21 +30,6 @@ KaduSharedBaseClassImpl(Identity)
 
 Identity Identity::null;
 
-Identity Identity::create()
-{
-	return new IdentityShared();
-}
-
-Identity Identity::loadStubFromStorage(const std::shared_ptr<StoragePoint> &accountStoragePoint)
-{
-	return IdentityShared::loadStubFromStorage(accountStoragePoint);
-}
-
-Identity Identity::loadFromStorage(const std::shared_ptr<StoragePoint> &accountStoragePoint)
-{
-	return IdentityShared::loadFromStorage(accountStoragePoint);
-}
-
 Identity::Identity()
 {
 }
@@ -102,5 +88,12 @@ bool Identity::isEmpty() const
 			: true;
 }
 
+StatusContainer * Identity::statusContainer() const
+{
+	return !isNull()
+			? data()->statusContainer()
+			: nullptr;
+}
+
 KaduSharedBase_PropertyBoolDef(Identity, Permanent, false)
 KaduSharedBase_PropertyDefCRW(Identity, QString, name, Name, QString())
