@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,33 +19,42 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "identity-model.h"
+
 #include "identities/identity-manager.h"
 #include "model/roles.h"
 #include "protocols/protocol.h"
 
-#include "identity-model.h"
-
 IdentityModel::IdentityModel(QObject *parent) :
 		QAbstractListModel(parent)
 {
-	connect(IdentityManager::instance(), SIGNAL(identityAboutToBeAdded(Identity)),
-			this, SLOT(identityAboutToBeAdded(Identity)), Qt::DirectConnection);
-	connect(IdentityManager::instance(), SIGNAL(identityAdded(Identity)),
-			this, SLOT(identityAdded(Identity)), Qt::DirectConnection);
-	connect(IdentityManager::instance(), SIGNAL(identityAboutToBeRemoved(Identity)),
-			this, SLOT(identityAboutToBeRemoved(Identity)), Qt::DirectConnection);
-	connect(IdentityManager::instance(), SIGNAL(identityRemoved(Identity)),
-			this, SLOT(identityRemoved(Identity)), Qt::DirectConnection);
 }
 
 IdentityModel::~IdentityModel()
 {
-	disconnect(IdentityManager::instance(), 0, this, 0);
+	disconnect(m_identityManager, 0, this, 0);
+}
+
+void IdentityModel::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void IdentityModel::init()
+{
+	connect(m_identityManager, SIGNAL(identityAboutToBeAdded(Identity)),
+			this, SLOT(identityAboutToBeAdded(Identity)), Qt::DirectConnection);
+	connect(m_identityManager, SIGNAL(identityAdded(Identity)),
+			this, SLOT(identityAdded(Identity)), Qt::DirectConnection);
+	connect(m_identityManager, SIGNAL(identityAboutToBeRemoved(Identity)),
+			this, SLOT(identityAboutToBeRemoved(Identity)), Qt::DirectConnection);
+	connect(m_identityManager, SIGNAL(identityRemoved(Identity)),
+			this, SLOT(identityRemoved(Identity)), Qt::DirectConnection);
 }
 
 int IdentityModel::rowCount(const QModelIndex &parent) const
 {
-	return parent.isValid() ? 0 : IdentityManager::instance()->count();
+	return parent.isValid() ? 0 : m_identityManager->count();
 }
 
 QVariant IdentityModel::data(const QModelIndex &index, int role) const
@@ -75,12 +84,12 @@ Identity IdentityModel::identity(const QModelIndex &index) const
 	if (index.row() < 0 || index.row() >= rowCount())
 		return Identity::null;
 
-	return IdentityManager::instance()->byIndex(index.row());
+	return m_identityManager->byIndex(index.row());
 }
 
 int IdentityModel::identityIndex(Identity identity) const
 {
-	return IdentityManager::instance()->indexOf(identity);
+	return m_identityManager->indexOf(identity);
 }
 
 QModelIndexList IdentityModel::indexListForValue(const QVariant &value) const
