@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,28 +19,24 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IDENTITY_MODEL_H
-#define IDENTITY_MODEL_H
-
-#include <QtCore/QAbstractListModel>
-#include <QtCore/QModelIndex>
+#pragma once
 
 #include "model/kadu-abstract-model.h"
 
+#include <QtCore/QAbstractListModel>
+#include <QtCore/QModelIndex>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class IdentityManager;
 class Identity;
 
 class IdentityModel : public QAbstractListModel, public KaduAbstractModel
 {
 	Q_OBJECT
 
-private slots:
-	void identityAboutToBeAdded(Identity identity);
-	void identityAdded(Identity identity);
-	void identityAboutToBeRemoved(Identity identity);
-	void identityRemoved(Identity identity);
-
 public:
-	explicit IdentityModel(QObject *parent = 0);
+	explicit IdentityModel(QObject *parent = nullptr);
 	virtual ~IdentityModel();
 
 	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
@@ -51,8 +47,16 @@ public:
 	int identityIndex(Identity identity) const;
 	virtual QModelIndexList indexListForValue(const QVariant &value) const;
 
+private:
+	QPointer<IdentityManager> m_identityManager;
+
+private slots:
+	INJEQT_SET void setIdentityManager(IdentityManager *identityManager);
+	INJEQT_INIT void init();
+
+	void identityAboutToBeAdded(Identity identity);
+	void identityAdded(Identity identity);
+	void identityAboutToBeRemoved(Identity identity);
+	void identityRemoved(Identity identity);
+
 };
-
-#include "identities/identity.h" // for MOC
-
-#endif // IDENTITY_MODEL_H
