@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,14 +18,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/chat-configuration-holder.h"
-#include "dom/dom-processor-service.h"
-#include "formatted-string/formatted-string-dom-visitor.h"
-#include "formatted-string/formatted-string.h"
-#include "message/message.h"
-
 #include "message-html-renderer-service.h"
 
+#include "dom/dom-processor-service.h"
+#include "html/normalized-html-string.h"
+#include "message/message.h"
+
 MessageHtmlRendererService::MessageHtmlRendererService(QObject *parent) :
 		QObject(parent)
 {
@@ -39,27 +35,12 @@ MessageHtmlRendererService::~MessageHtmlRendererService()
 
 void MessageHtmlRendererService::setDomProcessorService(DomProcessorService *domProcessorService)
 {
-	CurrentDomProcessorService = domProcessorService;
+	m_domProcessorService = domProcessorService;
 }
 
 QString MessageHtmlRendererService::renderMessage(const Message &message)
 {
-	FormattedStringDomVisitor formattedStringDomVisitor;
-	message.content()->accept(&formattedStringDomVisitor);
-
-	QDomDocument domDocument = formattedStringDomVisitor.result();
-
-	if (CurrentDomProcessorService)
-		CurrentDomProcessorService.data()->process(domDocument);
-
-	if (domDocument.documentElement().childNodes().isEmpty())
-		return QString();
-
-	QString result = domDocument.toString(-1).trimmed();
-	// remove <message></message>
-	Q_ASSERT(result.startsWith(QLatin1String("<message>")));
-	Q_ASSERT(result.endsWith(QLatin1String("</message>")));
-	return result.mid(static_cast<int>(qstrlen("<message>")), result.length() - static_cast<int>(qstrlen("<message></message>")));
+	return QString{R"(<span style="white-space: pre-wrap;">%1</span>)"}.arg(m_domProcessorService->process(message.content().string()));
 }
 
 #include "moc_message-html-renderer-service.cpp"
