@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004, 2006 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,15 +21,16 @@
 #include "message-render-info.h"
 
 #include "core/core.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "message/message-html-renderer-service.h"
 #include "misc/date-time.h"
 #include "parser/parser.h"
 
-static QString getMessage(const ParserData * const object)
+static QString getMessage(MessageHtmlRendererService *messageHtmlRendererService, const ParserData * const object)
 {
 	const MessageRenderInfo * const messageRenderInfo = dynamic_cast<const MessageRenderInfo * const>(object);
 	if (messageRenderInfo)
-		return Core::instance()->messageHtmlRendererService()->renderMessage(messageRenderInfo->message());
+		return messageHtmlRendererService->renderMessage(messageRenderInfo->message());
 	else
 		return QString();
 }
@@ -82,20 +78,20 @@ static QString getNickColor(const ParserData * const object)
 		return QString();
 }
 
-static QString getSentDate(const ParserData * const object)
+static QString getSentDate(bool niceDateFormat, const ParserData * const object)
 {
 	const MessageRenderInfo * const messageRenderInfo = dynamic_cast<const MessageRenderInfo * const>(object);
 	if (messageRenderInfo && messageRenderInfo->showServerTime())
-		return printDateTime(messageRenderInfo->message().sendDate());
+		return printDateTime(niceDateFormat, messageRenderInfo->message().sendDate());
 	else
 		return QString();
 }
 
-static QString getReceivedDate(const ParserData * const object)
+static QString getReceivedDate(bool niceDateFormat, const ParserData * const object)
 {
 	const MessageRenderInfo * const messageRenderInfo = dynamic_cast<const MessageRenderInfo * const>(object);
 	if (messageRenderInfo)
-		return printDateTime(messageRenderInfo->message().receiveDate());
+		return printDateTime(niceDateFormat, messageRenderInfo->message().receiveDate());
 	else
 		return QString();
 }
@@ -113,30 +109,30 @@ static QString getSeparator(const ParserData * const object)
 		return QString();
 }
 
-void MessageRenderInfo::registerParserTags()
+void MessageRenderInfo::registerParserTags(Parser *parser, ChatConfigurationHolder *chatConfigurationHolder, MessageHtmlRendererService *messageHtmlRendererService)
 {
-	Parser::registerObjectTag("message", getMessage);
-	Parser::registerObjectTag("messageId", getMessageId);
-	Parser::registerObjectTag("messageStatus", getMessageStatus);
-	Parser::registerObjectTag("backgroundColor", getBackgroundColor);
-	Parser::registerObjectTag("fontColor", getFontColor);
-	Parser::registerObjectTag("nickColor", getNickColor);
-	Parser::registerObjectTag("sentDate", getSentDate);
-	Parser::registerObjectTag("receivedDate", getReceivedDate);
-	Parser::registerObjectTag("separator", getSeparator);
+	parser->registerObjectTag("message", [messageHtmlRendererService](const ParserData * const object){ return getMessage(messageHtmlRendererService, object); });
+	parser->registerObjectTag("messageId", getMessageId);
+	parser->registerObjectTag("messageStatus", getMessageStatus);
+	parser->registerObjectTag("backgroundColor", getBackgroundColor);
+	parser->registerObjectTag("fontColor", getFontColor);
+	parser->registerObjectTag("nickColor", getNickColor);
+	parser->registerObjectTag("sentDate", [chatConfigurationHolder](const ParserData * const object){ return getSentDate(chatConfigurationHolder->niceDateFormat(), object); } );
+	parser->registerObjectTag("receivedDate", [chatConfigurationHolder](const ParserData * const object){ return getReceivedDate(chatConfigurationHolder->niceDateFormat(), object); });
+	parser->registerObjectTag("separator", getSeparator);
 }
 
-void MessageRenderInfo::unregisterParserTags()
+void MessageRenderInfo::unregisterParserTags(Parser *parser)
 {
-	Parser::unregisterObjectTag("message");
-	Parser::unregisterObjectTag("messageId");
-	Parser::unregisterObjectTag("messageStatus");
-	Parser::unregisterObjectTag("backgroundColor");
-	Parser::unregisterObjectTag("fontColor");
-	Parser::unregisterObjectTag("nickColor");
-	Parser::unregisterObjectTag("sentDate");
-	Parser::unregisterObjectTag("receivedDate");
-	Parser::unregisterObjectTag("separator");
+	parser->unregisterObjectTag("message");
+	parser->unregisterObjectTag("messageId");
+	parser->unregisterObjectTag("messageStatus");
+	parser->unregisterObjectTag("backgroundColor");
+	parser->unregisterObjectTag("fontColor");
+	parser->unregisterObjectTag("nickColor");
+	parser->unregisterObjectTag("sentDate");
+	parser->unregisterObjectTag("receivedDate");
+	parser->unregisterObjectTag("separator");
 }
 
 MessageRenderInfo::MessageRenderInfo(Message message, QString backgroundColor, QString fontColor, QString nickColor,
