@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +20,8 @@
 
 #include "chat/chat.h"
 #include "contacts/contact.h"
-#include "formatted-string/formatted-string.h"
+#include "core/injected-factory.h"
+#include "html/normalized-html-string.h"
 
 #include "message.h"
 
@@ -32,21 +29,6 @@ KaduSharedBaseClassImpl(Message)
 
 Message Message::null;
 
-Message Message::create()
-{
-	return new MessageShared();
-}
-
-Message Message::loadStubFromStorage(const std::shared_ptr<StoragePoint> &messageStoragePoint)
-{
-	return MessageShared::loadStubFromStorage(messageStoragePoint);
-}
-
-Message Message::loadFromStorage(const std::shared_ptr<StoragePoint> &messageStoragePoint)
-{
-	return MessageShared::loadFromStorage(messageStoragePoint);
-}
-
 Message::Message()
 {
 }
@@ -74,16 +56,7 @@ Message::~Message()
 
 KaduSharedBase_PropertyDefCRW(Message, Chat, messageChat, MessageChat, Chat::null)
 KaduSharedBase_PropertyDefCRW(Message, Contact, messageSender, MessageSender, Contact::null)
-
-void Message::setContent(std::unique_ptr<FormattedString> &&content) const
-{
-	if (!isNull())
-		data()->setContent(std::move(content));
-}
-
-KaduSharedBase_PropertyReadDef(Message, FormattedString *, content, Content, 0)
-KaduSharedBase_PropertyReadDef(Message, QString, plainTextContent, PlainTextContent, QString())
-KaduSharedBase_PropertyReadDef(Message, QString, htmlContent, HtmlContent, QString())
+KaduSharedBase_PropertyDefCRW(Message, NormalizedHtmlString, content, Content, NormalizedHtmlString())
 KaduSharedBase_PropertyDefCRW(Message, QDateTime, receiveDate, ReceiveDate, QDateTime())
 KaduSharedBase_PropertyDefCRW(Message, QDateTime, sendDate, SendDate, QDateTime())
 KaduSharedBase_PropertyDef(Message, MessageStatus, status, Status, MessageStatusUnknown)
