@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -35,15 +32,13 @@
 class Chat;
 class Contact;
 class MessageShared;
+class NormalizedHtmlString;
 
 class KADUAPI Message : public SharedBase<MessageShared>
 {
 	KaduSharedBaseClass(Message)
 
 public:
-	static Message create();
-	static Message loadStubFromStorage(const std::shared_ptr<StoragePoint> &messageStoragePoint);
-	static Message loadFromStorage(const std::shared_ptr<StoragePoint> &messageStoragePoint);
 	static Message null;
 
 	Message();
@@ -54,10 +49,7 @@ public:
 
 	KaduSharedBase_PropertyCRW(Chat, messageChat, MessageChat)
 	KaduSharedBase_PropertyCRW(Contact, messageSender, MessageSender)
-	void setContent(std::unique_ptr<FormattedString> &&content) const;
-	KaduSharedBase_PropertyRead(FormattedString *, content, Content)
-	KaduSharedBase_PropertyRead(QString, plainTextContent, PlainTextContent)
-	KaduSharedBase_PropertyRead(QString, htmlContent, HtmlContent)
+	KaduSharedBase_PropertyCRW(NormalizedHtmlString, content, Content)
 	KaduSharedBase_PropertyCRW(QDateTime, receiveDate, ReceiveDate)
 	KaduSharedBase_PropertyCRW(QDateTime, sendDate, SendDate)
 	KaduSharedBase_Property(MessageStatus, status, Status)
