@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2014 Michał Ziąbkowski (mziab@o2.pl)
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 
 #include "chat/chat.h"
 #include "formatted-string/formatted-string.h"
+#include "html/normalized-html-string.h"
 
 bool SortedMessages::earlier(const Message &left, const Message &right)
 {
@@ -63,7 +64,7 @@ bool SortedMessages::same(const Message &left, const Message &right)
 	if (left.messageSender() != right.messageSender())
 		return false;
 
-	if (*left.content() != *right.content())
+	if (left.content() != right.content())
 		return false;
 
 	return true;
