@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,37 +21,69 @@
 #include "unread-message-repository.h"
 
 #include "buddies/buddy-manager.h"
-#include "chat/chat.h"
 #include "chat/chat-details-buddy.h"
+#include "chat/chat.h"
+#include "configuration/configuration-manager.h"
+#include "message/message-storage.h"
 #include "message/message.h"
 #include "message/sorted-messages.h"
 
 UnreadMessageRepository::UnreadMessageRepository(QObject *parent) :
-		QObject{parent}
+		StorableObject{parent}
 {
 	setState(StateNotLoaded);
-	ConfigurationManager::instance()->registerStorableObject(this);
 }
 
 UnreadMessageRepository::~UnreadMessageRepository()
 {
-	ConfigurationManager::instance()->unregisterStorableObject(this);
+}
+
+void UnreadMessageRepository::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void UnreadMessageRepository::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void UnreadMessageRepository::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void UnreadMessageRepository::setMessageStorage(MessageStorage *messageStorage)
+{
+	m_messageStorage = messageStorage;
+}
+
+void UnreadMessageRepository::init()
+{
+	m_configurationManager->registerStorableObject(this);
+
+	ensureLoaded();
+}
+
+void UnreadMessageRepository::done()
+{
+	m_configurationManager->unregisterStorableObject(this);
 }
 
 bool UnreadMessageRepository::importFromPendingMessages()
 {
-	auto pendingMessagesNode = xml_config_file->getNode("PendingMessages", XmlConfigFile::ModeFind);
+	auto pendingMessagesNode = m_configuration->api()->getNode("PendingMessages", ConfigurationApi::ModeFind);
 	if (pendingMessagesNode.isNull())
 		return false;
 
-	auto messageElements = xml_config_file->getNodes(pendingMessagesNode, "Message");
+	auto messageElements = m_configuration->api()->getNodes(pendingMessagesNode, "Message");
 	for (const auto &messageElement : messageElements)
 	{
 		auto storagePoint = std::make_shared<StoragePoint>(storage()->storage(), messageElement);
 		auto uuid = QUuid{storagePoint->point().attribute("uuid")};
 		if (!uuid.isNull())
 		{
-			auto message = Message::loadStubFromStorage(storagePoint);
+			auto message = m_messageStorage->loadStubFromStorage(storagePoint);
 			addUnreadMessage(message);
 
 			// reset storage for message as it will be stored in other place
@@ -89,7 +121,7 @@ void UnreadMessageRepository::load()
 		auto uuid = QUuid{storagePoint->point().attribute("uuid")};
 		if (!uuid.isNull())
 		{
-			auto item = Message::loadStubFromStorage(storagePoint);
+			auto item = m_messageStorage->loadStubFromStorage(storagePoint);
 			addUnreadMessage(item);
 		}
 	}
@@ -109,7 +141,7 @@ void UnreadMessageRepository::addUnreadMessage(const Message &message)
 {
 	// just ensure that owner buddy is managed - we need it to be shown on contact list
 	// todo: rethink this one
-	BuddyManager::instance()->byContact(message.messageSender(), ActionCreateAndAdd);
+	m_buddyManager->byContact(message.messageSender(), ActionCreateAndAdd);
 
 	m_unreadMessages.append(message);
 
