@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -51,7 +51,7 @@ class KADUAPI ChangeNotifier : public QObject
 	bool Changed;
 
 public:
-	explicit ChangeNotifier(QObject *parent = 0);
+	explicit ChangeNotifier(QObject *parent = nullptr);
 	virtual ~ChangeNotifier();
 
 	/**
