@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
  *
@@ -194,19 +191,19 @@ static QString parseLongKaduUptime(Talkable talkable)
 	return getKaduUptime(true);
 }
 
-void DateTimeParserTags::registerParserTags()
+void DateTimeParserTags::registerParserTags(Parser *parser)
 {
 	// TODO: do it pretty, possibly in Core
 	started = QDateTime::currentDateTime();
 
-	Parser::registerTag("time", parseTime);
-	Parser::registerTag("time-long", parseLongTime);
-	Parser::registerTag("date", parseDate);
-	Parser::registerTag("date-long", parseLongDate);
-	Parser::registerTag("start", parseStartTime);
-	Parser::registerTag("start-long", parseLongStartTime);
-	Parser::registerTag("uptime", parseUptime);
-	Parser::registerTag("uptime-long", parseLongUptime);
-	Parser::registerTag("kuptime", parseKaduUptime);
-	Parser::registerTag("kuptime-long", parseLongKaduUptime);
+	parser->registerTag("time", parseTime);
+	parser->registerTag("time-long", parseLongTime);
+	parser->registerTag("date", parseDate);
+	parser->registerTag("date-long", parseLongDate);
+	parser->registerTag("start", parseStartTime);
+	parser->registerTag("start-long", parseLongStartTime);
+	parser->registerTag("uptime", parseUptime);
+	parser->registerTag("uptime-long", parseLongUptime);
+	parser->registerTag("kuptime", parseKaduUptime);
+	parser->registerTag("kuptime-long", parseLongKaduUptime);
 }
