@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
  *
@@ -24,9 +22,11 @@
 #ifndef DATE_TIME_PARSER_TAGS_H
 #define DATE_TIME_PARSER_TAGS_H
 
+class Parser;
+
 namespace DateTimeParserTags
 {
-	void registerParserTags();
+	void registerParserTags(Parser *parser);
 
 }
 
