@@ -3,8 +3,8 @@
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@
  */
 
 #include <QtCore/QDateTime>
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 #ifdef Q_OS_WIN
 #include <sys/timeb.h>
@@ -31,12 +31,9 @@
 #endif
 #include <time.h>
 
-#include "configuration/chat-configuration-holder.h"
-#include "configuration/configuration-file.h"
-
 #include "date-time.h"
 
-QString printDateTime(const QDateTime &datetime)
+QString printDateTime(bool niceDateFormat, const QDateTime &datetime)
 {
 	QString ret;
 	QDateTime current_date;
@@ -50,7 +47,7 @@ QString printDateTime(const QDateTime &datetime)
 
 	if (delta != 0)
 	{
-		if (ChatConfigurationHolder::instance()->niceDateFormat())
+		if (niceDateFormat)
 		{
 			if (delta == 1) // 1 day ago
 				ret.prepend(QCoreApplication::translate("@default", "Yesterday at "));
