@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -55,7 +55,7 @@ public:
 		if (contains(m_nodes, payload))
 			return m_nodes.at(payload).get();
 
-		auto node = make_unique<NodeType>(payload);
+		auto node = std::make_unique<NodeType>(payload);
 		auto result = node.get();
 		m_nodes.insert(std::make_pair(payload, std::move(node)));
 		return result;
