@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -33,9 +31,8 @@ QString ellipsis(const QString &text, quint16 length)
 	if (text.isEmpty() || length == 0)
 		return QString();
 
-	QString trimmed = text.left(length);
-
-	if (trimmed.length() > 1 && trimmed.length() < text.length())
+	auto trimmed = text.left(length);
+	if (!trimmed.isEmpty() && trimmed.length() < text.length())
 		return trimmed + "...";
 
 	return trimmed;
