@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,31 +19,45 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "syntax-list.h"
+
+#include "misc/paths-provider.h"
+
 #include <QtCore/QDir>
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
 #include <QtCore/QTextStream>
 
-#include "misc/kadu-paths.h"
+SyntaxList::SyntaxList(const QString &category, QObject *parent) :
+		QObject{parent},
+		m_category(category)
+{
+}
 
-#include "syntax-list.h"
+SyntaxList::~SyntaxList()
+{
+}
 
-SyntaxList::SyntaxList(const QString &category)
-	: category(category)
+void SyntaxList::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void SyntaxList::init()
 {
 	reload();
 }
 
-QString SyntaxList::readSyntax(const QString &category, const QString &name, const QString &defaultSyntax)
+QString SyntaxList::readSyntax(PathsProvider *pathsProvider, const QString &category, const QString &name, const QString &defaultSyntax)
 {
 	QString path;
 	QFile syntaxFile;
-	path = KaduPaths::instance()->dataPath() + QLatin1String("syntax/") + category + '/' + name + QLatin1String(".syntax");
+	path = pathsProvider->dataPath() + QStringLiteral("syntax/") + category + '/' + name + QStringLiteral(".syntax");
 
 	syntaxFile.setFileName(path);
 	if (!syntaxFile.open(QIODevice::ReadOnly))
 	{
-		path = KaduPaths::instance()->profilePath() + QLatin1String("syntax/") + category + '/' + name + QLatin1String(".syntax");
+		path = pathsProvider->profilePath() + QStringLiteral("syntax/") + category + '/' + name + QStringLiteral(".syntax");
 
 		syntaxFile.setFileName(path);
 		if (!syntaxFile.open(QIODevice::ReadOnly))
@@ -75,7 +86,7 @@ void SyntaxList::reload()
 	SyntaxInfo info;
 
 	info.global = false;
-	path = KaduPaths::instance()->profilePath() + QLatin1String("syntax/") + category + '/';
+	path = m_pathsProvider->profilePath() + QStringLiteral("syntax/") + m_category + '/';
 	dir.setPath(path);
 
 	dir.setNameFilters(QStringList("*.syntax"));
@@ -89,7 +100,7 @@ void SyntaxList::reload()
 	}
 
 	info.global = true;
-	path = KaduPaths::instance()->dataPath() + QLatin1String("syntax/") + category + '/';
+	path = m_pathsProvider->dataPath() + QStringLiteral("syntax/") + m_category + '/';
 	dir.setPath(path);
 
 	files = dir.entryList();
@@ -112,13 +123,13 @@ void SyntaxList::reload()
 
 bool SyntaxList::updateSyntax(const QString &name, const QString &syntax)
 {
-	QString path = KaduPaths::instance()->profilePath() + QLatin1String("syntax/");
+	QString path = m_pathsProvider->profilePath() + QStringLiteral("syntax/");
 	QDir dir(path);
 	if (!dir.exists())
 		if (!dir.mkdir(path))
 			return false;
 
-	path = KaduPaths::instance()->profilePath() + QLatin1String("syntax/") + category + '/';
+	path = m_pathsProvider->profilePath() + QStringLiteral("syntax/") + m_category + '/';
 	dir.setPath(path);
 	if (!dir.exists())
 		if (!dir.mkdir(path))
@@ -151,9 +162,9 @@ QString SyntaxList::readSyntax(const QString &name)
 	SyntaxInfo info = *(find(name));
 	QString path;
 	if (info.global)
-		path = KaduPaths::instance()->dataPath() + QLatin1String("syntax/") + category + '/' + name + QLatin1String(".syntax");
+		path = m_pathsProvider->dataPath() + QStringLiteral("syntax/") + m_category + '/' + name + QStringLiteral(".syntax");
 	else
-		path = KaduPaths::instance()->profilePath() + QLatin1String("syntax/") + category + '/' + name + QLatin1String(".syntax");
+		path = m_pathsProvider->profilePath() + QStringLiteral("syntax/") + m_category + '/' + name + QStringLiteral(".syntax");
 
 	QFile syntaxFile;
 	syntaxFile.setFileName(path);
@@ -178,7 +189,7 @@ bool SyntaxList::deleteSyntax(const QString &name)
 	if (info.global)
 		return false;
 
-	QString path = KaduPaths::instance()->profilePath() + QLatin1String("syntax/") + category + '/' + name + QLatin1String(".syntax");
+	QString path = m_pathsProvider->profilePath() + QStringLiteral("syntax/") + m_category + '/' + name + QStringLiteral(".syntax");
 	QFile file;
 	file.setFileName(path);
 
