@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -55,7 +52,7 @@ public:
 	 *
 	 * Creates new instance of KaduMergedProxyModel.
 	 */
-	explicit KaduMergedProxyModel(QObject *parent = 0);
+	explicit KaduMergedProxyModel(QObject *parent = nullptr);
 	virtual ~KaduMergedProxyModel();
 
 	/**
