@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +23,7 @@
 #include <QtCore/QAbstractTableModel>
 
 class MultilogonService;
-class MultilogonSession;
+struct MultilogonSession;
 
 class MultilogonModel : public QAbstractTableModel
 {
@@ -34,10 +32,10 @@ class MultilogonModel : public QAbstractTableModel
 	MultilogonService *Service;
 
 private slots:
-	void multilogonSessionAboutToBeConnected(MultilogonSession *session);
-	void multilogonSessionConnected(MultilogonSession *session);
-	void multilogonSessionAboutToBeDisconnected(MultilogonSession *session);
-	void multilogonSessionDisconnected(MultilogonSession *session);
+	void multilogonSessionAboutToBeConnected(MultilogonSession session);
+	void multilogonSessionConnected(MultilogonSession session);
+	void multilogonSessionAboutToBeDisconnected(MultilogonSession session);
+	void multilogonSessionDisconnected(MultilogonSession session);
 
 public:
 	explicit MultilogonModel(MultilogonService *service, QObject *parent);
