@@ -1,13 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,9 +24,10 @@
 
 #include "network-manager-qt.h"
 
-NetworkManagerQt::NetworkManagerQt()
+NetworkManagerQt::NetworkManagerQt(QObject *parent) :
+		NetworkManager{parent}
 {
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
 	// Kadu bug #2591
 	if (QSysInfo::WindowsVersion < QSysInfo::WV_VISTA)
 	{
