@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,12 +18,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef NETWORK_MANAGER_H
-#define NETWORK_MANAGER_H
-
-#include <QtCore/QObject>
+#pragma once
 
 #include "exports.h"
+#include "injeqt-type-roles.h"
+
+#include <QtCore/QObject>
+#include <injeqt/injeqt.h>
 
 /**
  * @addtogroup Network
@@ -53,19 +49,11 @@
 class KADUAPI NetworkManager : public QObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(NetworkManager)
-
-	static NetworkManager *Instance;
-
-protected slots:
-	void onlineStateChanged(bool isOnline);
-
-protected:
-	NetworkManager();
-	virtual ~NetworkManager();
+	INJEQT_TYPE_ROLE(SERVICE)
 
 public:
-	static NetworkManager * instance();
+	explicit NetworkManager(QObject *parent = nullptr);
+	virtual ~NetworkManager();
 
 	/**
 	 * @author Rafał 'Vogel' Malinowski
@@ -106,10 +94,11 @@ signals:
 	 */
 	void offline();
 
+protected slots:
+	void onlineStateChanged(bool isOnline);
+
 };
 
 /**
  * @}
  */
-
-#endif // NETWORK_MANAGER_H
