@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,30 +18,39 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "network-proxy-model.h"
+
 #include "model/roles.h"
 #include "network/proxy/network-proxy-manager.h"
 #include "network/proxy/network-proxy.h"
 
-#include "network-proxy-model.h"
-
 NetworkProxyModel::NetworkProxyModel(QObject *parent) :
 		QAbstractListModel(parent)
 {
-	connect(NetworkProxyManager::instance(), SIGNAL(networkProxyUpdated(NetworkProxy)),
-			this, SLOT(networkProxyUpdated(NetworkProxy)), Qt::DirectConnection);
-	connect(NetworkProxyManager::instance(), SIGNAL(networkProxyAboutToBeAdded(NetworkProxy)),
-			this, SLOT(networkProxyAboutToBeAdded(NetworkProxy)), Qt::DirectConnection);
-	connect(NetworkProxyManager::instance(), SIGNAL(networkProxyAdded(NetworkProxy)),
-			this, SLOT(networkProxyAdded(NetworkProxy)), Qt::DirectConnection);
-	connect(NetworkProxyManager::instance(), SIGNAL(networkProxyAboutToBeRemoved(NetworkProxy)),
-			this, SLOT(networkProxyAboutToBeRemoved(NetworkProxy)), Qt::DirectConnection);
-	connect(NetworkProxyManager::instance(), SIGNAL(networkProxyRemoved(NetworkProxy)),
-			this, SLOT(networkProxyRemoved(NetworkProxy)), Qt::DirectConnection);
 }
 
 NetworkProxyModel::~NetworkProxyModel()
 {
-	disconnect(NetworkProxyManager::instance(), 0, this, 0);
+	disconnect(m_networkProxyManager, 0, this, 0);
+}
+
+void NetworkProxyModel::setNetworkProxyManager(NetworkProxyManager *networkProxyManager)
+{
+	m_networkProxyManager = networkProxyManager;
+}
+
+void NetworkProxyModel::init()
+{
+	connect(m_networkProxyManager, SIGNAL(networkProxyUpdated(NetworkProxy)),
+			this, SLOT(networkProxyUpdated(NetworkProxy)), Qt::DirectConnection);
+	connect(m_networkProxyManager, SIGNAL(networkProxyAboutToBeAdded(NetworkProxy)),
+			this, SLOT(networkProxyAboutToBeAdded(NetworkProxy)), Qt::DirectConnection);
+	connect(m_networkProxyManager, SIGNAL(networkProxyAdded(NetworkProxy)),
+			this, SLOT(networkProxyAdded(NetworkProxy)), Qt::DirectConnection);
+	connect(m_networkProxyManager, SIGNAL(networkProxyAboutToBeRemoved(NetworkProxy)),
+			this, SLOT(networkProxyAboutToBeRemoved(NetworkProxy)), Qt::DirectConnection);
+	connect(m_networkProxyManager, SIGNAL(networkProxyRemoved(NetworkProxy)),
+			this, SLOT(networkProxyRemoved(NetworkProxy)), Qt::DirectConnection);
 }
 
 int NetworkProxyModel::columnCount(const QModelIndex &parent) const
@@ -51,7 +60,7 @@ int NetworkProxyModel::columnCount(const QModelIndex &parent) const
 
 int NetworkProxyModel::rowCount(const QModelIndex &parent) const
 {
-	return parent.isValid() ? 0 : NetworkProxyManager::instance()->count();
+	return parent.isValid() ? 0 : m_networkProxyManager->count();
 }
 
 QVariant NetworkProxyModel::data(const QModelIndex &index, int role) const
@@ -84,12 +93,12 @@ NetworkProxy NetworkProxyModel::networkProxy(const QModelIndex &index) const
 	if (index.row() < 0 || index.row() >= rowCount())
 		return NetworkProxy::null;
 
-	return NetworkProxyManager::instance()->byIndex(index.row());
+	return m_networkProxyManager->byIndex(index.row());
 }
 
 int NetworkProxyModel::networkProxyIndex(NetworkProxy networkProxy) const
 {
-	return NetworkProxyManager::instance()->indexOf(networkProxy);
+	return m_networkProxyManager->indexOf(networkProxy);
 }
 
 QModelIndexList NetworkProxyModel::indexListForValue(const QVariant &value) const
