@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,31 +20,50 @@
 
 #include <QtXml/QDomElement>
 
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "network/proxy/network-proxy-storage.h"
 #include "storage/storage-point.h"
 
 #include "network-proxy-manager.h"
 
-NetworkProxyManager *NetworkProxyManager::Instance = 0;
-
-NetworkProxyManager * NetworkProxyManager::instance()
+NetworkProxyManager::NetworkProxyManager(QObject *parent) :
+		SimpleManager<NetworkProxy>{parent}
 {
-	if (!Instance)
-		Instance = new NetworkProxyManager();
-
-	return Instance;
-}
-
-NetworkProxyManager::NetworkProxyManager()
-{
-	configurationUpdated();
 }
 
 NetworkProxyManager::~NetworkProxyManager()
 {
 }
 
+void NetworkProxyManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void NetworkProxyManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void NetworkProxyManager::setNetworkProxyStorage(NetworkProxyStorage *networkProxyStorage)
+{
+	m_networkProxyStorage = networkProxyStorage;
+}
+
+void NetworkProxyManager::init()
+{
+	m_configurationManager->registerStorableObject(this);
+	configurationUpdated();
+}
+
+void NetworkProxyManager::done()
+{
+	m_configurationManager->unregisterStorableObject(this);
+}
+
 void NetworkProxyManager::load()
 {
 	QMutexLocker locker(&mutex());
@@ -59,15 +78,20 @@ void NetworkProxyManager::store()
 	SimpleManager<NetworkProxy>::store();
 }
 
+NetworkProxy NetworkProxyManager::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
+{
+	return m_networkProxyStorage->loadStubFromStorage(storagePoint);
+}
+
 void NetworkProxyManager::configurationUpdated()
 {
-	DefaultProxy = byUuid(config_file.readEntry("Network", "DefaultProxy"));
+	DefaultProxy = byUuid(m_configuration->deprecatedApi()->readEntry("Network", "DefaultProxy"));
 }
 
 void NetworkProxyManager::setDefaultProxy(const NetworkProxy &proxy)
 {
 	DefaultProxy = proxy;
-	config_file.writeEntry("Network", "DefaultProxy", DefaultProxy.uuid().toString());
+	m_configuration->deprecatedApi()->writeEntry("Network", "DefaultProxy", DefaultProxy.uuid().toString());
 }
 
 const NetworkProxy & NetworkProxyManager::defaultProxy()
@@ -90,7 +114,7 @@ NetworkProxy NetworkProxyManager::byConfiguration(const QString &address, int po
 	if (ActionReturnNull == action)
 		return NetworkProxy::null;
 
-	NetworkProxy networkProxy = NetworkProxy::create();
+	auto networkProxy = m_networkProxyStorage->create();
 	networkProxy.setAddress(address);
 	networkProxy.setPort(port);
 	networkProxy.setUser(user);
