@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,52 +18,34 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef NETWORK_PROXY_MANAGER_H
-#define NETWORK_PROXY_MANAGER_H
-
-#include <QtCore/QList>
-#include <QtCore/QObject>
-#include <QtCore/QString>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 #include "network/proxy/network-proxy.h"
 #include "storage/simple-manager.h"
-
 #include "exports.h"
 
+#include <QtCore/QList>
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtCore/QString>
+#include <injeqt/injeqt.h>
+
+class ConfigurationManager;
+class Configuration;
+class NetworkProxyStorage;
 class NetworkProxy;
 
-class KADUAPI NetworkProxyManager : public QObject, public SimpleManager<NetworkProxy>, ConfigurationAwareObject
+class KADUAPI NetworkProxyManager : public SimpleManager<NetworkProxy>, ConfigurationAwareObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(NetworkProxyManager)
-
-	static NetworkProxyManager *Instance;
-
-	NetworkProxy DefaultProxy;
-
-	NetworkProxyManager();
-	virtual ~NetworkProxyManager();
-
-private slots:
-	void networkProxyDataUpdated();
-
-protected:
-	virtual void load();
-	virtual void store();
-
-	virtual void itemAboutToBeAdded(NetworkProxy item);
-	virtual void itemAdded(NetworkProxy item);
-	virtual void itemAboutToBeRemoved(NetworkProxy item);
-	virtual void itemRemoved(NetworkProxy item);
-
-	virtual void configurationUpdated();
 
 public:
-	static NetworkProxyManager * instance();
+	Q_INVOKABLE explicit NetworkProxyManager(QObject *parent = nullptr);
+	virtual ~NetworkProxyManager();
 
-	virtual QString storageNodeName() { return QLatin1String("Proxys"); }
-	virtual QString storageNodeItemName() { return QLatin1String("Proxy"); }
+	virtual QString storageNodeName() { return QStringLiteral("Proxys"); }
+	virtual QString storageNodeItemName() { return QStringLiteral("Proxy"); }
 
 	void setDefaultProxy(const NetworkProxy &proxy);
 	const NetworkProxy &defaultProxy();
@@ -79,6 +61,32 @@ signals:
 
 	void networkProxyUpdated(NetworkProxy networkProxy);
 
-};
+protected:
+	virtual void load();
+	virtual void store();
+	virtual NetworkProxy loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint);
 
-#endif // NETWORK_PROXY_MANAGER_H
+	virtual void itemAboutToBeAdded(NetworkProxy item);
+	virtual void itemAdded(NetworkProxy item);
+	virtual void itemAboutToBeRemoved(NetworkProxy item);
+	virtual void itemRemoved(NetworkProxy item);
+
+	virtual void configurationUpdated();
+
+private:
+	QPointer<ConfigurationManager> m_configurationManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<NetworkProxyStorage> m_networkProxyStorage;
+
+	NetworkProxy DefaultProxy;
+
+private slots:
+	INJEQT_SET void setConfigurationManager(ConfigurationManager *configurationManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setNetworkProxyStorage(NetworkProxyStorage *networkProxyStorage);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
+	void networkProxyDataUpdated();
+
+};
