@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,27 +19,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "core/injected-factory.h"
 #include "misc/change-notifier.h"
 #include "network/proxy/network-proxy-manager.h"
 
 #include "network-proxy-shared.h"
 
-NetworkProxyShared * NetworkProxyShared::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	NetworkProxyShared *result = loadFromStorage(storagePoint);
-	result->loadStub();
-
-	return result;
-}
-
-NetworkProxyShared * NetworkProxyShared::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	NetworkProxyShared *result = new NetworkProxyShared();
-	result->setStorage(storagePoint);
-
-	return result;
-}
-
 NetworkProxyShared::NetworkProxyShared(const QUuid &uuid) :
 		Shared(uuid), Port(0)
 {
@@ -51,14 +36,19 @@ NetworkProxyShared::~NetworkProxyShared()
 	ref.ref();
 }
 
+void NetworkProxyShared::setNetworkProxyManager(NetworkProxyManager *networkProxyManager)
+{
+	m_networkProxyManager = networkProxyManager;
+}
+
 StorableObject * NetworkProxyShared::storageParent()
 {
-	return NetworkProxyManager::instance();
+	return m_networkProxyManager;
 }
 
 QString NetworkProxyShared::storageNodeName()
 {
-	return QLatin1String("Proxy");
+	return QStringLiteral("Proxy");
 }
 
 void NetworkProxyShared::load()
