@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,6 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "core/injected-factory.h"
 #include "network/proxy/network-proxy-manager.h"
 #include "network/proxy/network-proxy-shared.h"
 #include "storage/storage-point.h"
@@ -29,21 +30,6 @@ KaduSharedBaseClassImpl(NetworkProxy)
 
 NetworkProxy NetworkProxy::null;
 
-NetworkProxy NetworkProxy::create()
-{
-	return new NetworkProxyShared();
-}
-
-NetworkProxy NetworkProxy::loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	return NetworkProxyShared::loadStubFromStorage(storagePoint);
-}
-
-NetworkProxy NetworkProxy::loadFromStorage(const std::shared_ptr<StoragePoint> &storagePoint)
-{
-	return NetworkProxyShared::loadFromStorage(storagePoint);
-}
-
 NetworkProxy::NetworkProxy()
 {
 }
