@@ -1,6 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,14 +31,11 @@ class KADUAPI NetworkProxy : public SharedBase<NetworkProxyShared>
 	KaduSharedBaseClass(NetworkProxy)
 
 public:
-	static NetworkProxy create();
-	static NetworkProxy loadStubFromStorage(const QSharedPointer<StoragePoint> &storage);
-	static NetworkProxy loadFromStorage(const QSharedPointer<StoragePoint> &storage);
 	static NetworkProxy null;
 
 	NetworkProxy();
 	NetworkProxy(NetworkProxyShared *data);
-	NetworkProxy(QObject *data);
+	explicit NetworkProxy(QObject *data);
 	NetworkProxy(const NetworkProxy &copy);
 
 	virtual ~NetworkProxy();
