@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,15 +19,36 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "url-opener.h"
+
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
+
 #include <QtCore/QProcess>
 #include <QtCore/QUrl>
-#include <QtGui/QApplication>
 #include <QtGui/QDesktopServices>
+#include <QtWidgets/QApplication>
 
-#include "configuration/configuration-file.h"
-#include "gui/windows/message-dialog.h"
+UrlOpener::UrlOpener(QObject *parent) :
+		QObject{parent}
+{
+}
 
-#include "url-opener.h"
+UrlOpener::~UrlOpener()
+{
+}
+
+void UrlOpener::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void UrlOpener::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
 
 bool UrlOpener::openUrl(const QByteArray &urlForDesktopServices, const QByteArray &urlForApplication, const QString &application)
 {
@@ -52,21 +73,22 @@ bool UrlOpener::openUrl(const QByteArray &urlForDesktopServices, const QByteArra
 void UrlOpener::openUrl(const QByteArray &url)
 {
 	QString browser;
-	bool useDefaultWebBrowser = config_file.readBoolEntry("Chat", "UseDefaultWebBrowser", true);
+	bool useDefaultWebBrowser = m_configuration->deprecatedApi()->readBoolEntry("Chat", "UseDefaultWebBrowser", true);
 	if (!useDefaultWebBrowser)
-		browser = config_file.readEntry("Chat", "WebBrowser");
+		browser = m_configuration->deprecatedApi()->readEntry("Chat", "WebBrowser");
 
 	if (!openUrl(url, url, browser))
-		MessageDialog::show(KaduIcon("dialog-error"), QCoreApplication::translate("@default", QT_TR_NOOP("Kadu")),
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-error")), QCoreApplication::translate("@default", QT_TR_NOOP("Kadu")),
 				QCoreApplication::translate("@default", QT_TR_NOOP("Could not spawn Web browser process. Check if the Web browser is functional")));
 }
 
 void UrlOpener::openEmail(const QByteArray &email)
 {
 	QString client;
-	bool useDefaultEMailClient = config_file.readBoolEntry("Chat", "UseDefaultEMailClient", true);
+
+	bool useDefaultEMailClient = m_configuration->deprecatedApi()->readBoolEntry("Chat", "UseDefaultEMailClient", true);
 	if (!useDefaultEMailClient)
-		client = config_file.readEntry("Chat", "MailClient");
+		client = m_configuration->deprecatedApi()->readEntry("Chat", "MailClient");
 
 	QByteArray urlForDesktopServices;
 	QByteArray urlForApplication;
@@ -83,6 +105,8 @@ void UrlOpener::openEmail(const QByteArray &email)
 	}
 
 	if (!openUrl(urlForDesktopServices, urlForApplication, client))
-		MessageDialog::show(KaduIcon("dialog-error"), QCoreApplication::translate("@default", QT_TR_NOOP("Kadu")),
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-error")), QCoreApplication::translate("@default", QT_TR_NOOP("Kadu")),
 				QCoreApplication::translate("@default", QT_TR_NOOP("Could not spawn Mail client process. Check if the Mail client is functional")));
 }
+
+#include "moc_url-opener.cpp"
