@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -42,13 +42,10 @@
  */
 
 #include <QtCore/QVariant>
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QWidget>
-
-#ifdef Q_OS_MAC
-#include <QtGui/QMainWindow>
-#endif
+#include <QtGui/QWindow>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtWidgets/QWidget>
 
 #include "misc/misc.h"
 #include "misc/variant-wrapper.h"
@@ -90,7 +87,11 @@ bool WindowGeometryManager::eventFilter(QObject *watched, QEvent *event)
 		QWidget *parentWidget = qobject_cast<QWidget *>(parent());
 		Q_ASSERT(parentWidget);
 
-		if (event->type() == QEvent::Move || event->type() == QEvent::Resize)
+		if (event->type() == QEvent::QEvent::Show)
+		{
+			restoreGeometry();
+		}
+		else if (event->type() == QEvent::Move || event->type() == QEvent::Resize)
 		{
 			if (parentWidget->isWindow())
 			{
@@ -106,7 +107,7 @@ bool WindowGeometryManager::eventFilter(QObject *watched, QEvent *event)
 				restoreGeometry();
 		}
 
-		return false;
+		return QObject::eventFilter(watched, event);
 	}
 
 	return QObject::eventFilter(watched, event);
@@ -117,14 +118,8 @@ void WindowGeometryManager::saveGeometry()
 	QWidget *parentWidget = qobject_cast<QWidget *>(parent());
 	Q_ASSERT(parentWidget);
 
-#ifdef Q_OS_MAC
-	/* Dorr: workaround for Qt window geometry bug when unified toolbars enabled */
-	/* TODO: Check if this is still needed. If not, drop all 4 calls in this file. */
-	/* TODO: Check if we can benefit from the OS X workaround as used in QWidget::saveGeometry()
-	 *       implementation. If so, use it here. */
-	if (QMainWindow *mainWindow = qobject_cast<QMainWindow *>(parentWidget))
-		mainWindow->setUnifiedTitleAndToolBarOnMac(false);
-#endif
+	if (!parentWidget->isVisible())
+		return;
 
 	bool isMaximized = parentWidget->windowState() & Qt::WindowMaximized;
 	QStringList configuration;
@@ -136,12 +131,6 @@ void WindowGeometryManager::saveGeometry()
 	configuration.insert(FullscreenIndex, QString::number(int(bool(parentWidget->windowState() & Qt::WindowFullScreen))));
 
 	MyVariantWrapper->set(configuration.join(":"));
-
-#ifdef Q_OS_MAC
-	/* Dorr: workaround for Qt window geometry bug when unified toolbars enabled */
-	if (QMainWindow *mainWindow = qobject_cast<QMainWindow *>(parentWidget))
-		mainWindow->setUnifiedTitleAndToolBarOnMac(true);
-#endif
 }
 
 void WindowGeometryManager::restoreGeometry()
@@ -149,11 +138,10 @@ void WindowGeometryManager::restoreGeometry()
 	QWidget *parentWidget = qobject_cast<QWidget *>(parent());
 	Q_ASSERT(parentWidget);
 
-#ifdef Q_OS_MAC
-	/* Dorr: workaround for Qt window geometry bug when unified toolbars enabled */
-	if (QMainWindow *mainWindow = qobject_cast<QMainWindow *>(parentWidget))
-		mainWindow->setUnifiedTitleAndToolBarOnMac(false);
-#endif
+	if (!parentWidget->window()->isVisible())
+	{
+		return;
+	}
 
 	QString configurationString = MyVariantWrapper->get().toString();
 	QStringList configuration = configurationString.split(':');
@@ -183,24 +171,22 @@ void WindowGeometryManager::restoreGeometry()
 		const quint16 minorVersion = 0;
 
 		NormalGeometry = stringToRect(configuration.at(NormalGeometryIndex));
+		auto storedGeometry = stringToRect(configuration.at(NormalGeometryIndex));
 
 		stream << magicNumber
 				<< majorVersion
 				<< minorVersion
 				<< stringToRect(configuration.at(FrameGeometryIndex))
-				<< NormalGeometry
+				<< storedGeometry
 				<< qint32(configuration.at(ScreenIndex).toInt())
 				<< quint8(bool(configuration.at(MaximizedIndex).toInt()))
 				<< quint8(bool(configuration.at(FullscreenIndex).toInt()));
 
 		parentWidget->restoreGeometry(array);
-	}
-
-#ifdef Q_OS_MAC
-	/* Dorr: workaround for Qt window geometry bug when unified toolbars enabled */
-	if (QMainWindow *mainWindow = qobject_cast<QMainWindow *>(parentWidget))
-		mainWindow->setUnifiedTitleAndToolBarOnMac(true);
+#ifndef Q_OS_WIN
+		parentWidget->move(storedGeometry.topLeft());
 #endif
+	}
 }
 
 #include "moc_window-geometry-manager.cpp"
