@@ -1,15 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2009 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,32 +22,34 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QFile>
-#include <QtCore/QProcess>
-#include <QtCore/QStack>
-#include <QtCore/QVariant>
-#include <QtGui/QApplication>
-#include <QtGui/QTextDocument>
-#include <QtNetwork/QHostAddress>
+#include "parser.h"
 
 #include "accounts/account-manager.h"
 #include "buddies/group.h"
 #include "chat/model/chat-data-extractor.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "misc/misc.h"
+#include "misc/paths-provider.h"
 #include "parser/parser-token.h"
 #include "status/status-container-manager.h"
 #include "status/status-container.h"
 #include "status/status-type-data.h"
 #include "status/status-type-manager.h"
 #include "status/status-type.h"
-
-#include "icons/icons-manager.h"
+#include "talkable/talkable-converter.h"
 #include "debug.h"
 
-#include "parser.h"
+#include <QtCore/QFileInfo>
+#include <QtCore/QProcess>
+#include <QtCore/QStack>
+#include <QtCore/QVariant>
+#include <QtGui/QTextDocument>
+#include <QtNetwork/QHostAddress>
+#include <QtWidgets/QApplication>
 
 #define SEARCH_CHARS "%[{\\$@#}]"
 #define EXEC_SEARCH_CHARS "`\'"
@@ -62,14 +60,14 @@
 
 Q_GLOBAL_STATIC(QSet<QChar>, searchChars)
 
-static void prepareSearchChars(bool forceExecSeachChars = false)
+static void prepareSearchChars(Configuration *configuration, bool forceExecSeachChars = false)
 {
 	QSet<QChar> &chars = *searchChars();
 	if (chars.isEmpty())
 		foreach (QChar c, QString(SEARCH_CHARS))
 			chars.insert(c);
 
-	bool allowExec = forceExecSeachChars || config_file.readBoolEntry("General", "AllowExecutingFromParser", false);
+	bool allowExec = forceExecSeachChars || configuration->deprecatedApi()->readBoolEntry("General", "AllowExecutingFromParser", false);
 	foreach (QChar c, QString(EXEC_SEARCH_CHARS))
 		if (allowExec)
 			chars.insert(c);
@@ -77,13 +75,48 @@ static void prepareSearchChars(bool forceExecSeachChars = false)
 			chars.remove(c);
 }
 
-QMap<QString, QString> Parser::GlobalVariables;
-QMap<QString, Parser::TalkableTagCallback> Parser::RegisteredTalkableTags;
-QMap<QString, Parser::ObjectTagCallback> Parser::RegisteredObjectTags;
+Parser::Parser(QObject *parent) :
+		QObject{parent}
+{
+}
+
+Parser::~Parser()
+{
+}
+
+void Parser::setChatDataExtractor(ChatDataExtractor *chatDataExtractor)
+{
+	m_chatDataExtractor = chatDataExtractor;
+}
+
+void Parser::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void Parser::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void Parser::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void Parser::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void Parser::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
 
 QString Parser::escape(const QString &string)
 {
-	prepareSearchChars(true);
+	prepareSearchChars(m_configuration, true);
 
 	QString escaped;
 	escaped.reserve(string.size() * 2);
@@ -102,19 +135,19 @@ bool Parser::registerTag(const QString &name, TalkableTagCallback func)
 {
 	kdebugf();
 
-	if (RegisteredTalkableTags.contains(name))
+	if (m_registeredTalkableTags.contains(name))
 	{
 		kdebugmf(KDEBUG_ERROR | KDEBUG_FUNCTION_END, "tag %s already registered!\n", qPrintable(name));
 		return false;
 	}
 
-	if (RegisteredObjectTags.contains(name))
+	if (m_registeredObjectTags.contains(name))
 	{
 		kdebugmf(KDEBUG_ERROR | KDEBUG_FUNCTION_END, "tag %s already registered (as object tag)!\n", qPrintable(name));
 		return false;
 	}
 
-	RegisteredTalkableTags.insert(name, func);
+	m_registeredTalkableTags.insert(name, func);
 
 	kdebugf2();
 	return true;
@@ -124,13 +157,13 @@ bool Parser::unregisterTag(const QString &name)
 {
 	kdebugf();
 
-	if (!RegisteredTalkableTags.contains(name))
+	if (!m_registeredTalkableTags.contains(name))
 	{
 		kdebugmf(KDEBUG_ERROR | KDEBUG_FUNCTION_END, "Talkable tag %s not registered!\n", qPrintable(name));
 		return false;
 	}
 
-	RegisteredTalkableTags.remove(name);
+	m_registeredTalkableTags.remove(name);
 
 	kdebugf2();
 	return true;
@@ -140,19 +173,19 @@ bool Parser::registerObjectTag(const QString &name, ObjectTagCallback func)
 {
 	kdebugf();
 
-	if (RegisteredObjectTags.contains(name))
+	if (m_registeredObjectTags.contains(name))
 	{
 		kdebugmf(KDEBUG_ERROR | KDEBUG_FUNCTION_END, "tag %s already registered!\n", qPrintable(name));
 		return false;
 	}
 
-	if (RegisteredTalkableTags.contains(name))
+	if (m_registeredTalkableTags.contains(name))
 	{
 		kdebugmf(KDEBUG_ERROR | KDEBUG_FUNCTION_END, "tag %s already registered (as Talkable tag)!\n", qPrintable(name));
 		return false;
 	}
 
-	RegisteredObjectTags.insert(name, func);
+	m_registeredObjectTags.insert(name, func);
 
 	kdebugf2();
 	return true;
@@ -162,13 +195,13 @@ bool Parser::unregisterObjectTag(const QString &name)
 {
 	kdebugf();
 
-	if (!RegisteredObjectTags.contains(name))
+	if (!m_registeredObjectTags.contains(name))
 	{
 		kdebugmf(KDEBUG_ERROR | KDEBUG_FUNCTION_END, "object tag %s not registered!\n", qPrintable(name));
 		return false;
 	}
 
-	RegisteredObjectTags.remove(name);
+	m_registeredObjectTags.remove(name);
 
 	kdebugf2();
 	return true;
@@ -225,9 +258,9 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 	ParserToken pe;
 	pe.setType(PT_STRING);
 
-	Chat chat = talkable.toChat();
-	Buddy buddy = talkable.toBuddy();
-	Contact contact = talkable.toContact();
+	Chat chat = m_talkableConverter->toChat(talkable);
+	Buddy buddy = m_talkableConverter->toBuddy(talkable);
+	Contact contact = m_talkableConverter->toContact(talkable);
 
 	switch (s.at(idx).toAscii())
 	{
@@ -249,13 +282,13 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 					pe.setContent(QCoreApplication::translate("@default", "Blocking"));
 				else
 				{
-					const StatusTypeData & typeData = StatusTypeManager::instance()->statusTypeData(contact.currentStatus().type());
+					const StatusTypeData & typeData = m_statusTypeManager->statusTypeData(contact.currentStatus().type());
 					pe.setContent(typeData.displayName());
 				}
 			}
 			else if (chat && chat.chatAccount().statusContainer())
 			{
-				const StatusTypeData & typeData = StatusTypeManager::instance()->statusTypeData(chat.chatAccount().statusContainer()->status().type());
+				const StatusTypeData & typeData = m_statusTypeManager->statusTypeData(chat.chatAccount().statusContainer()->status().type());
 				pe.setContent(typeData.displayName());
 			}
 
@@ -267,9 +300,9 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 			{
 				StatusContainer *container = contact.contactAccount().statusContainer();
 				if (container)
-					pe.setContent(container->statusIcon(contact.currentStatus().type()).path());
+					pe.setContent(container->statusIcon(Status{contact.currentStatus().type()}).path());
 				else
-					pe.setContent(StatusContainerManager::instance()->statusIcon(contact.currentStatus().type()).path());
+					pe.setContent(m_statusContainerManager->statusIcon(Status{contact.currentStatus().type()}).path());
 			}
 			else if (chat)
 			{
@@ -277,7 +310,7 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 				if (container)
 					pe.setContent(container->statusIcon().path());
 				else
-					pe.setContent(StatusContainerManager::instance()->statusIcon(Status()).path());
+					pe.setContent(m_statusContainerManager->statusIcon(Status()).path());
 			}
 
 			break;
@@ -292,10 +325,10 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 
 				pe.setContent(description);
 
-				if (config_file.readBoolEntry("Look", "ShowMultilineDesc"))
+				if (m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowMultilineDesc"))
 				{
 					QString content = pe.decodedContent();
-					content.replace('\n', QLatin1String("<br/>"));
+					content.replace('\n', QStringLiteral("<br/>"));
 					content.replace(QRegExp("\\s\\s"), QString(" &nbsp;"));
 					pe.setContent(content);
 				}
@@ -304,24 +337,12 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 			break;
 		case 'i':
 			++idx;
-
-			if (contact)
-				pe.setContent(contact.address().toString());
-
 			break;
 		case 'v':
 			++idx;
-
-			if (contact)
-				pe.setContent(contact.dnsName());
-
 			break;
 		case 'p':
 			++idx;
-
-			if (contact && contact.port())
-				pe.setContent(QString::number(contact.port()));
-
 			break;
 		case 'u':
 			++idx;
@@ -334,16 +355,12 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 			break;
 		case 'h':
 			++idx;
-
-			if (contact && !contact.currentStatus().isDisconnected())
-				pe.setContent(contact.protocolVersion());
-
 			break;
 		case 'n':
 		{
 			++idx;
 
-			QString nickName = chat ? ChatDataExtractor::data(chat, Qt::DisplayRole).toString() : buddy.nickName();
+			QString nickName = chat ? m_chatDataExtractor->data(chat, Qt::DisplayRole).toString() : buddy.nickName();
 			if (escape == ParserEscape::HtmlEscape)
 				nickName = Qt::escape(nickName);
 
@@ -355,7 +372,7 @@ ParserToken Parser::parsePercentSyntax(const QString &s, int &idx, const Talkabl
 		{
 			++idx;
 
-			QString display = chat ? ChatDataExtractor::data(chat, Qt::DisplayRole).toString() : buddy.display();
+			QString display = chat ? m_chatDataExtractor->data(chat, Qt::DisplayRole).toString() : buddy.display();
 			if (escape == ParserEscape::HtmlEscape)
 				display = Qt::escape(display);
 
@@ -492,9 +509,9 @@ QString Parser::joinParserTokens(const ContainerClass &parseStack)
 
 QString Parser::parse(const QString &s, Talkable talkable, const ParserData * const parserData, ParserEscape escape = ParserEscape::HtmlEscape)
 {
-	kdebugmf(KDEBUG_DUMP, "%s htmlEscape=%i\n", qPrintable(s), escape);
+	kdebugmf(KDEBUG_DUMP, "%s htmlEscape=%i\n", qPrintable(s), static_cast<int>(escape));
 
-	prepareSearchChars();
+	prepareSearchChars(m_configuration);
 
 	QStack<ParserToken> parseStack;
 	int idx = 0, len = s.length();
@@ -668,11 +685,16 @@ QString Parser::parse(const QString &s, Talkable talkable, const ParserData * co
 							filePath = joinParserTokens(tokens.mid(0, firstSpaceTokenIdx)) +
 									tokens.at(firstSpaceTokenIdx).rawContent().left(spacePos);
 
-						if (filePath.startsWith(QLatin1String("file://")))
+#ifdef Q_OS_WIN
+						if (filePath.startsWith(QStringLiteral("file:///")))
+							filePath = filePath.mid(static_cast<int>(qstrlen("file:///")));
+#else
+						if (filePath.startsWith(QStringLiteral("file:///")))
 							filePath = filePath.mid(static_cast<int>(qstrlen("file://")));
+#endif
 
 						bool checkFileExists = (pe2.type() == PT_CHECK_FILE_EXISTS);
-						if (QFile::exists(filePath) == checkFileExists)
+						if (QFileInfo::exists(filePath) == checkFileExists)
 						{
 							pe.setType(PT_STRING);
 
@@ -723,10 +745,10 @@ QString Parser::parse(const QString &s, Talkable talkable, const ParserData * co
 						if (content.contains(':'))
 						{
 							QStringList parts = content.split(':');
-							pe.setContent(KaduIcon(parts.at(0), parts.at(1)).webKitPath());
+							pe.setContent(PathsProvider::webKitPath(m_iconsManager->iconPath(KaduIcon(parts.at(0), parts.at(1)))));
 						}
 						else
-							pe.setContent(KaduIcon(content).webKitPath());
+							pe.setContent(PathsProvider::webKitPath(m_iconsManager->iconPath(KaduIcon(content))));
 
 						parseStack.push(pe);
 
@@ -739,10 +761,10 @@ QString Parser::parse(const QString &s, Talkable talkable, const ParserData * co
 
 						pe.setType(PT_STRING);
 
-						if (RegisteredTalkableTags.contains(content))
-							pe.setContent(RegisteredTalkableTags[content](talkable));
-						else if (parserData && RegisteredObjectTags.contains(content))
-							pe.setContent(RegisteredObjectTags[content](parserData));
+						if (m_registeredTalkableTags.contains(content))
+							pe.setContent(m_registeredTalkableTags[content](talkable));
+						else if (parserData && m_registeredObjectTags.contains(content))
+							pe.setContent(m_registeredObjectTags[content](parserData));
 						else
 						{
 							kdebugm(KDEBUG_WARNING, "tag %s not registered\n", qPrintable(pe.decodedContent()));
@@ -912,3 +934,5 @@ QString Parser::parse(const QString &s, Talkable talkable, const ParserData * co
 
 	return ret;
 }
+
+#include "moc_parser.cpp"
