@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,9 +21,18 @@
 
 #include "misc/memory.h"
 
-ActivePlugin::ActivePlugin(const QString &pluginName, bool firstLoad) :
-		m_pluginTranslationsLoader{make_unique<PluginTranslationsLoader>(pluginName)},
-		m_pluginLoader{make_unique<PluginLoader>(pluginName)},
-		m_pluginRootComponentHandler{make_unique<PluginRootComponentHandler>(pluginName, firstLoad, m_pluginLoader->instance())}
+ActivePlugin::ActivePlugin(const QString &pluginDirPath, const QString &pluginTranslationDir, const QString &language, const QString &pluginName, PluginInjectorProvider *pluginInjectorProvider) :
+		m_pluginTranslationsLoader{std::make_unique<PluginTranslationsLoader>(pluginTranslationDir, language, pluginName)},
+		m_pluginLoader{std::make_unique<PluginLoader>(pluginDirPath, pluginName, pluginInjectorProvider)}
 {
 }
+
+injeqt::injector & ActivePlugin::injector() const
+{
+	return m_pluginLoader->injector();
+}
+
+void ActivePlugin::start()
+{
+	return m_pluginLoader->start();
+}
