@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  *
@@ -21,10 +21,11 @@
 
 #include "plugin-activation-error-handler.h"
 
+#include "core/injected-factory.h"
 #include "plugin/activation/plugin-activation-service.h"
 #include "plugin/gui/plugin-error-dialog.h"
-#include "plugin/state/plugin-state.h"
 #include "plugin/state/plugin-state-service.h"
+#include "plugin/state/plugin-state.h"
 
 #include <QtCore/QTimer>
 
@@ -37,6 +38,11 @@ PluginActivationErrorHandler::~PluginActivationErrorHandler()
 {
 }
 
+void PluginActivationErrorHandler::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
 void PluginActivationErrorHandler::setPluginActivationService(PluginActivationService *pluginActivationService)
 {
 	m_pluginActivationService = pluginActivationService;
@@ -56,7 +62,7 @@ void PluginActivationErrorHandler::handleActivationError(const QString &pluginNa
 	auto offerLoadInFutureChoice = PluginState::Enabled == state;
 
 	// TODO: set parent to MainConfigurationWindow is it exists
-	auto errorDialog = new PluginErrorDialog{pluginName, errorMessage, offerLoadInFutureChoice, 0};
+	auto errorDialog = m_injectedFactory->makeInjected<PluginErrorDialog>(pluginName, errorMessage, offerLoadInFutureChoice, nullptr);
 	if (offerLoadInFutureChoice)
 		connect(errorDialog, SIGNAL(accepted(QString,bool)), this, SLOT(setStateEnabledIfInactive(QString,bool)));
 
