@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +24,9 @@
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
+class InjectedFactory;
 class PluginStateService;
 class PluginActivationService;
 
@@ -60,12 +58,9 @@ class KADUAPI PluginActivationErrorHandler : public QObject
 	Q_DISABLE_COPY(PluginActivationErrorHandler)
 
 public:
-	explicit PluginActivationErrorHandler(QObject *parent = nullptr);
+	Q_INVOKABLE explicit PluginActivationErrorHandler(QObject *parent = nullptr);
 	virtual ~PluginActivationErrorHandler();
 
-	void setPluginActivationService(PluginActivationService *pluginActivationService);
-	void setPluginStateService(PluginStateService *pluginStateService);
-
 	/**
 	 * @author Bartosz 'beevvy' Brachaczek
 	 * @short Shows activation error to the user.
@@ -79,10 +74,15 @@ public:
 	void handleActivationError(const QString &pluginName, const QString &errorMessage);
 
 private:
+	QPointer<InjectedFactory> m_injectedFactory;
 	QPointer<PluginActivationService> m_pluginActivationService;
 	QPointer<PluginStateService> m_pluginStateService;
 
 private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setPluginActivationService(PluginActivationService *pluginActivationService);
+	INJEQT_SET void setPluginStateService(PluginStateService *pluginStateService);
+
 	/**
 	 * @author Bartosz 'beevvy' Brachaczek
 	 * @short Sets state enablement of plugin if it is inactive.
