@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +19,18 @@
 
 #include "plugin-activation-service.h"
 
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "misc/algorithm.h"
 #include "misc/memory.h"
+#include "misc/paths-provider.h"
 #include "plugin/activation/active-plugin.h"
 #include "plugin/activation/plugin-activation-error-exception.h"
 #include "plugin/activation/plugin-activation-error-handler.h"
 #include "plugin/plugin-dependency-handler.h"
-#include "plugin/state/plugin-state.h"
+#include "plugin/plugin-injector-provider.h"
 #include "plugin/state/plugin-state-service.h"
+#include "plugin/state/plugin-state.h"
 
 PluginActivationService::PluginActivationService(QObject *parent) :
 		QObject{parent}
@@ -37,6 +41,16 @@ PluginActivationService::~PluginActivationService()
 {
 }
 
+void PluginActivationService::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void PluginActivationService::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
 void PluginActivationService::setPluginActivationErrorHandler(PluginActivationErrorHandler *pluginActivationErrorHandler)
 {
 	m_pluginActivationErrorHandler = pluginActivationErrorHandler;
@@ -47,6 +61,11 @@ void PluginActivationService::setPluginDependencyHandler(PluginDependencyHandler
 	m_pluginDependencyHandler = pluginDependencyHandler;
 }
 
+void PluginActivationService::setPluginInjectorProvider(PluginInjectorProvider *pluginInjectorProvider)
+{
+	m_pluginInjectorProvider = pluginInjectorProvider;
+}
+
 void PluginActivationService::setPluginStateService(PluginStateService *pluginStateService)
 {
 	m_pluginStateService = pluginStateService;
@@ -73,7 +92,7 @@ QVector<QString> PluginActivationService::activatePluginWithDependencies(const Q
 
 		for (auto plugin : withDependencies)
 		{
-			activatePlugin(plugin, PluginState::New == m_pluginStateService->pluginState(plugin));
+			activatePlugin(plugin);
 			result.append(plugin);
 		}
 	}
@@ -111,10 +130,18 @@ QVector<QString> PluginActivationService::deactivatePluginWithDependents(const Q
 	return result;
 }
 
-void PluginActivationService::activatePlugin(const QString &pluginName, bool firstTime)
+void PluginActivationService::activatePlugin(const QString &pluginName)
 {
 	if (!contains(m_activePlugins, pluginName))
-		m_activePlugins.insert(std::make_pair(pluginName, make_unique<ActivePlugin>(pluginName, firstTime)));
+	{
+		m_activePlugins.insert(std::make_pair(pluginName, std::make_unique<ActivePlugin>(
+			m_pathsProvider->pluginsLibPath(),
+			m_pathsProvider->dataPath() + QStringLiteral("plugins/translations"),
+			m_configuration->deprecatedApi()->readEntry("General", "Language"),
+			pluginName,
+			m_pluginInjectorProvider)));
+		m_activePlugins[pluginName]->start();
+	}
 }
 
 void PluginActivationService::deactivatePlugin(const QString &pluginName)
@@ -134,3 +161,10 @@ QSet<QString> PluginActivationService::activePlugins() const
 		result.insert(activePlugin.first);
 	return result;
 }
+
+ActivePlugin * PluginActivationService::activePlugin(const QString& pluginName) const
+{
+	return isActive(pluginName)
+			? m_activePlugins.at(pluginName).get()
+			: nullptr;
+}
