@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,8 +22,8 @@
 #include "plugin/dependency-graph/plugin-dependency-graph.h"
 #include "plugin/metadata/plugin-metadata.h"
 
-#include <queue>
 #include <QtCore/QSet>
+#include <queue>
 
 PluginDependencyGraphBuilder::PluginDependencyGraphBuilder(QObject *parent) :
 		QObject{parent}
@@ -101,7 +101,7 @@ QSet<QString> PluginDependencyGraphBuilder::setWithDependents(QSet<QString> set,
 	set.insert(pluginName);
 	for (auto dependent : graph.findDependents(pluginName))
 		set.insert(dependent);
-	return std::move(set);
+	return set;
 }
 
 PluginDependencyGraph PluginDependencyGraphBuilder::applyFilters(const std::map<QString, PluginMetadata> &plugins, std::vector<PluginFilter> filters) const
@@ -134,7 +134,7 @@ PluginDependencyGraph PluginDependencyGraphBuilder::buildGraph(const std::map<QS
 			result.addDependency(plugin.first, dependency);
 	}
 
-	return std::move(result);
+	return result;
 }
 
 std::set<QString> PluginDependencyGraphBuilder::invalidPlugins(const PluginDependencyGraph &graph,
