@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,18 +17,38 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QCheckBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QStyle>
-
-#include "icons/kadu-icon.h"
-
 #include "plugin-error-dialog.h"
 
+#include "icons/icons-manager.h"
+#include "icons/kadu-icon.h"
+
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QStyle>
+
 PluginErrorDialog::PluginErrorDialog(QString pluginName, const QString &text, bool offerLoadInFutureChoice, QWidget *parent) :
-		QDialog(parent), DesktopAwareObject(this), m_pluginName{std::move(pluginName)}, LoadInFutureCheck(0)
+		// using C++ initializers breaks Qt's lupdate
+		QDialog(parent),
+		DesktopAwareObject(this),
+		m_pluginName(std::move(pluginName)),
+		m_text{text},
+		m_offerLoadInFutureChoice{offerLoadInFutureChoice},
+		LoadInFutureCheck(0)
+{
+}
+
+PluginErrorDialog::~PluginErrorDialog()
+{
+}
+
+void PluginErrorDialog::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void PluginErrorDialog::init()
 {
 	setWindowRole("kadu-plugin-error");
 	setWindowTitle(tr("Kadu"));
@@ -42,7 +61,7 @@ PluginErrorDialog::PluginErrorDialog(QString pluginName, const QString &text, bo
 	layout->setColumnStretch(1, 100);
 
 	int iconSize = style()->pixelMetric(QStyle::PM_MessageBoxIconSize, 0, this);
-	QPixmap iconPixmap = KaduIcon("dialog-error").icon().pixmap(iconSize, iconSize);
+	QPixmap iconPixmap = m_iconsManager->iconByPath(KaduIcon("dialog-error")).pixmap(iconSize, iconSize);
 	if (!iconPixmap.isNull())
 	{
 		QLabel *iconLabel = new QLabel(this);
@@ -50,11 +69,11 @@ PluginErrorDialog::PluginErrorDialog(QString pluginName, const QString &text, bo
 		layout->addWidget(iconLabel, 0, 0, Qt::AlignTop);
 	}
 
-	QLabel *textLabel = new QLabel(text, this);
+	QLabel *textLabel = new QLabel(m_text, this);
 	textLabel->setWordWrap(true);
 	layout->addWidget(textLabel, 0, 1);
 
-	if (offerLoadInFutureChoice)
+	if (m_offerLoadInFutureChoice)
 	{
 		LoadInFutureCheck = new QCheckBox(tr("Try to load this plugin on next Kadu run"), this);
 		LoadInFutureCheck->setChecked(true);
@@ -66,10 +85,6 @@ PluginErrorDialog::PluginErrorDialog(QString pluginName, const QString &text, bo
 	layout->addWidget(buttonBox, 2, 0, 1, 2, Qt::AlignCenter);
 }
 
-PluginErrorDialog::~PluginErrorDialog()
-{
-}
-
 void PluginErrorDialog::accept()
 {
 	QDialog::accept();
