@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This file is derived from part of the KDE project
@@ -84,7 +83,7 @@ class PluginListWidgetDelegateEventListener
         PluginListWidgetDelegateWidgets *Pool;
 
 public:
-        PluginListWidgetDelegateEventListener(PluginListWidgetDelegateWidgets *pool, QObject *parent = 0);
+        PluginListWidgetDelegateEventListener(PluginListWidgetDelegateWidgets *pool, QObject *parent = nullptr);
 
         virtual bool eventFilter(QObject *watched, QEvent *event);
 };
