@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This file is derived from part of the KDE project
@@ -28,10 +27,10 @@
 #include <QtCore/QEvent>
 #include <QtCore/QList>
 #include <QtCore/QPersistentModelIndex>
-#include <QtGui/QAbstractItemDelegate>
+#include <QtWidgets/QAbstractItemDelegate>
 
 
-#include <QtGui/QItemSelectionModel>
+#include <QtCore/QItemSelectionModel>
 
 class PluginListWidgetDelegate;
 class PluginListWidgetDelegateWidgets;
@@ -42,7 +41,7 @@ class PluginListWidgetDelegateWidgets;
 //         Q_OBJECT
 //
 // public:
-//         explicit PluginListWidgetDelegatePrivate(PluginListWidgetDelegate *q, QObject *parent = 0);
+//         explicit PluginListWidgetDelegatePrivate(PluginListWidgetDelegate *q, QObject *parent = nullptr);
 //         ~PluginListWidgetDelegatePrivate();
 
 //         void _k_slotRowsInserted(const QModelIndex &parent, int start, int end);
@@ -102,7 +101,7 @@ public:
          * @param itemView the item view the new delegate will monitor
          * @param parent the parent of this delegate
          */
-        explicit PluginListWidgetDelegate(QAbstractItemView *itemView, QObject *parent = 0);
+        explicit PluginListWidgetDelegate(QAbstractItemView *itemView, QObject *parent = nullptr);
 
         /**
          * Destroys an ItemDelegate.
