@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Marcel Zięba (marseel@gmail.com)
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This file is derived from part of the KDE project
@@ -31,6 +28,7 @@
 #include "gui/widgets/categorized-list-view-painter.h"
 #include "gui/widgets/categorized-list-view.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "model/categorized-sort-filter-proxy-model.h"
 #include "plugin/gui/plugin-list/plugin-list-view-delegate.h"
@@ -41,28 +39,37 @@
 #include "plugin/model/plugin-proxy-model.h"
 #include "plugin/plugin-dependency-handler.h"
 
-#include <QtGui/QApplication>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QCheckBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
 #include <QtGui/QPainter>
-#include <QtGui/QPushButton>
-#include <QtGui/QStyleOptionViewItemV4>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QBoxLayout>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStyleOptionViewItemV4>
 
 #define MARGIN 5
 
 PluginListWidgetItemDelegate::PluginListWidgetItemDelegate(PluginListWidget *pluginSelector, QObject *parent) :
-		PluginListWidgetDelegate{pluginSelector->m_listView, parent}, m_checkBox{make_unique<QCheckBox>()},
-		m_pushButton{make_unique<QPushButton>()}, m_pluginSelector{pluginSelector}
+		PluginListWidgetDelegate{pluginSelector->m_listView, parent}, m_checkBox{std::make_unique<QCheckBox>()},
+		m_pushButton{std::make_unique<QPushButton>()}, m_pluginSelector{pluginSelector}
 {
-	m_pushButton->setIcon(KaduIcon("preferences-other").icon()); // only for getting size matters
 }
 
 PluginListWidgetItemDelegate::~PluginListWidgetItemDelegate()
 {
 }
 
+void PluginListWidgetItemDelegate::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void PluginListWidgetItemDelegate::init()
+{
+	m_pushButton->setIcon(m_iconsManager->iconByPath(KaduIcon("preferences-other"))); // only for getting size matters
+}
+
 void PluginListWidgetItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
 	if (!index.isValid())
@@ -70,9 +77,7 @@ void PluginListWidgetItemDelegate::paint(QPainter *painter, const QStyleOptionVi
 
 	auto xOffset = m_checkBox->sizeHint().width();
 
-#ifdef Q_OS_WIN32
 	xOffset += QApplication::style()->pixelMetric(QStyle::PM_CheckBoxLabelSpacing);
-#endif
 
 	painter->save();
 
@@ -131,7 +136,7 @@ QList<QWidget *> PluginListWidgetItemDelegate::createItemWidgets() const
 	connect(enabledCheckBox, SIGNAL(clicked(bool)), this, SLOT(slotStateChanged(bool)));
 
 	auto aboutPushButton = new QPushButton;
-	aboutPushButton->setIcon(KaduIcon("help-contents").icon());
+	aboutPushButton->setIcon(m_iconsManager->iconByPath(KaduIcon("help-contents")));
 	connect(aboutPushButton, SIGNAL(clicked(bool)), this, SLOT(slotAboutClicked()));
 
 	setBlockedEventTypes(enabledCheckBox, QList<QEvent::Type>() << QEvent::MouseButtonPress
@@ -189,7 +194,7 @@ void PluginListWidgetItemDelegate::slotAboutClicked()
 	info += tr("Dependencies: %1").arg(pluginMetadata.dependencies().join(", ")) + "\n";
 	info += tr("Provides: %1").arg(pluginMetadata.provides());
 
-	MessageDialog::show(KaduIcon("dialog-information"), tr("Plugin information"), info, QMessageBox::Ok, itemView());
+	MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-information")), tr("Plugin information"), info, QMessageBox::Ok, itemView());
 }
 
 QFont PluginListWidgetItemDelegate::titleFont(const QFont &baseFont) const
