@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This file is derived from part of the KDE project
@@ -26,13 +25,16 @@
 
 #include "plugin/gui/plugin-list/plugin-list-view-delegate.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 #include <memory>
 
+class IconsManager;
+class PluginListWidget;
+
 class QCheckBox;
 class QPushButton;
 
-class PluginListWidget;
-
 class PluginListWidgetItemDelegate : public PluginListWidgetDelegate
 {
 	Q_OBJECT
@@ -49,6 +51,8 @@ protected:
 	virtual void updateItemWidgets(const QList<QWidget *> widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex &index) const override;
 
 private:
+	QPointer<IconsManager> m_iconsManager;
+
 	std::unique_ptr<QCheckBox> m_checkBox;
 	std::unique_ptr<QPushButton> m_pushButton;
 	PluginListWidget *m_pluginSelector;
@@ -57,6 +61,9 @@ private:
 	QFont subtitleFont(const QFont &baseFont) const;
 
 private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_INIT void init();
+
 	void slotStateChanged(bool state);
 	void slotAboutClicked();
 
