@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This file is derived from part of the KDE project
@@ -25,6 +23,7 @@
 
 #include "plugin-list-widget.h"
 
+#include "core/injected-factory.h"
 #include "gui/widgets/categorized-list-view-painter.h"
 #include "gui/widgets/categorized-list-view.h"
 #include "gui/widgets/configuration/config-section.h"
@@ -33,27 +32,66 @@
 #include "gui/windows/main-configuration-window.h"
 #include "gui/windows/string-list-dialog.h"
 #include "misc/change-notifier-lock.h"
-#include "plugin/model/plugin-model.h"
-#include "plugin/model/plugin-proxy-model.h"
 #include "plugin/activation/plugin-activation-service.h"
 #include "plugin/gui/plugin-list/plugin-list-view-delegate.h"
 #include "plugin/gui/plugin-list/plugin-list-widget-item-delegate.h"
+#include "plugin/model/plugin-model.h"
+#include "plugin/model/plugin-proxy-model.h"
 #include "plugin/plugin-conflict-resolver.h"
 #include "plugin/plugin-dependency-handler.h"
-#include "plugin/state/plugin-state.h"
 #include "plugin/state/plugin-state-manager.h"
 #include "plugin/state/plugin-state-service.h"
+#include "plugin/state/plugin-state.h"
 
-#include <QtGui/QBoxLayout>
+#include <QtWidgets/QBoxLayout>
 
 PluginListWidget::PluginListWidget(MainConfigurationWindow *window) :
 		QWidget{window}, m_listView{0}, m_processingChange{false}
+{
+	connect(window, SIGNAL(configurationWindowApplied()), this, SLOT(configurationApplied()));
+}
+
+PluginListWidget::~PluginListWidget()
+{
+}
+
+void PluginListWidget::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void PluginListWidget::setPluginActivationService(PluginActivationService *pluginActivationService)
+{
+	m_pluginActivationService = pluginActivationService;
+}
+
+void PluginListWidget::setPluginConflictResolver(PluginConflictResolver *pluginConflictResolver)
+{
+	m_pluginConflictResolver = pluginConflictResolver;
+}
+
+void PluginListWidget::setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler)
+{
+	m_pluginDependencyHandler = pluginDependencyHandler;
+}
+
+void PluginListWidget::setPluginStateManager(PluginStateManager *pluginStateManager)
+{
+	m_pluginStateManager = pluginStateManager;
+}
+
+void PluginListWidget::setPluginStateService(PluginStateService *pluginStateService)
+{
+	m_pluginStateService = pluginStateService;
+}
+
+void PluginListWidget::init()
 {
 	auto layout = new QVBoxLayout;
 	layout->setMargin(0);
 	setLayout(layout);
 
-	auto filterEdit = new FilterWidget{this};
+	auto filterEdit = m_injectedFactory->makeInjected<FilterWidget>(this);
 	filterEdit->setAutoVisibility(false);
 
 	m_listView = new CategorizedListView{this};
@@ -70,13 +108,21 @@ PluginListWidget::PluginListWidget(MainConfigurationWindow *window) :
 	m_model = new PluginModel{this};
 	connect(m_model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(modelDataChanged(QModelIndex,QModelIndex)));
 
+	auto pluginEntries = QVector<PluginMetadata>{};
+	for (auto pluginMetadata : m_pluginDependencyHandler)
+		pluginEntries.append(pluginMetadata);
+
+	m_model->setActivePlugins(m_pluginActivationService->activePlugins());
+	m_model->setPluginEntries(pluginEntries);
+
 	m_proxyModel = new PluginProxyModel{this};
 	m_proxyModel->setCategorizedModel(true);
 	m_proxyModel->setSourceModel(m_model);
+	m_proxyModel->sort(0);
 	m_listView->setModel(m_proxyModel);
 	m_listView->setAlternatingRowColors(true);
 
-	auto delegate = new PluginListWidgetItemDelegate{this, this};
+	auto delegate = m_injectedFactory->makeInjected<PluginListWidgetItemDelegate>(this, this);
 	m_listView->setItemDelegate(delegate);
 
 	m_listView->setMouseTracking(true);
@@ -89,53 +135,10 @@ PluginListWidget::PluginListWidget(MainConfigurationWindow *window) :
 	layout->addWidget(filterEdit);
 	layout->addWidget(m_listView);
 
+	auto window = static_cast<MainConfigurationWindow *>(parent());
 	auto pluginsSection = window->widget()->configSection("Plugins");
 	if (pluginsSection)
 		pluginsSection->addFullPageWidget("Plugins", this);
-
-	connect(window, SIGNAL(configurationWindowApplied()), this, SLOT(configurationApplied()));
-}
-
-PluginListWidget::~PluginListWidget()
-{
-}
-
-void PluginListWidget::setPluginActivationService(PluginActivationService *pluginActivationService)
-{
-	m_pluginActivationService = pluginActivationService;
-
-	if (m_pluginActivationService)
-		m_model->setActivePlugins(m_pluginActivationService->activePlugins());
-}
-
-void PluginListWidget::setPluginConflictResolver(PluginConflictResolver *pluginConflictResolver)
-{
-	m_pluginConflictResolver = pluginConflictResolver;
-}
-
-void PluginListWidget::setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler)
-{
-	m_pluginDependencyHandler = pluginDependencyHandler;
-
-	if (!m_pluginDependencyHandler)
-		return;
-
-	auto pluginEntries = QVector<PluginMetadata>{};
-	for (auto pluginMetadata : m_pluginDependencyHandler)
-		pluginEntries.append(pluginMetadata);
-	m_model->setPluginEntries(pluginEntries);
-
-	m_proxyModel->sort(0);
-}
-
-void PluginListWidget::setPluginStateManager(PluginStateManager *pluginStateManager)
-{
-	m_pluginStateManager = pluginStateManager;
-}
-
-void PluginListWidget::setPluginStateService(PluginStateService *pluginStateService)
-{
-	m_pluginStateService = pluginStateService;
 }
 
 int PluginListWidget::dependantLayoutValue(int value, int width, int totalWidth) const
