@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This file is derived from part of the KDE project
@@ -26,12 +24,14 @@
 #pragma once
 
 #include <QtCore/QPointer>
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 class QLineEdit;
 class QModelIndex;
 
 class CategorizedListView;
+class InjectedFactory;
 class MainConfigurationWindow;
 class PluginActivationService;
 class PluginConflictResolver;
@@ -57,12 +57,6 @@ public:
 	explicit PluginListWidget(MainConfigurationWindow *mainWindow);
 	virtual ~PluginListWidget();
 
-	void setPluginActivationService(PluginActivationService *pluginActivationService);
-	void setPluginConflictResolver(PluginConflictResolver *pluginConflictResolver);
-	void setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler);
-	void setPluginStateManager(PluginStateManager *pluginStateManager);
-	void setPluginStateService(PluginStateService *pluginStateService);
-
 	void applyChanges();
 
 	int dependantLayoutValue(int value, int width, int totalWidth) const;
@@ -72,6 +66,7 @@ private:
 	friend class PluginModel;
 	friend class PluginProxyModel;
 
+	QPointer<InjectedFactory> m_injectedFactory;
 	QPointer<PluginActivationService> m_pluginActivationService;
 	QPointer<PluginConflictResolver> m_pluginConflictResolver;
 	QPointer<PluginDependencyHandler> m_pluginDependencyHandler;
@@ -93,6 +88,14 @@ private:
 	QString vectorToString(const QVector<QString> &plugins);
 
 private slots:
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setPluginActivationService(PluginActivationService *pluginActivationService);
+	INJEQT_SET void setPluginConflictResolver(PluginConflictResolver *pluginConflictResolver);
+	INJEQT_SET void setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler);
+	INJEQT_SET void setPluginStateManager(PluginStateManager *pluginStateManager);
+	INJEQT_SET void setPluginStateService(PluginStateService *pluginStateService);
+	INJEQT_INIT void init();
+
 	void configurationApplied();
 	void modelDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
 
