@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -58,11 +58,8 @@ PluginDependencyHandler::Iterator PluginDependencyHandler::end()
 	return {m_allPluginMetadata.end(), converter};
 }
 
-void PluginDependencyHandler::initialize()
+void PluginDependencyHandler::init()
 {
-	if (!m_pluginDependencyGraphBuilder || !m_pluginMetadataProvider)
-		return;
-
 	auto metadata = m_pluginMetadataProvider->provide();
 	m_pluginDependencyDAG = m_pluginDependencyGraphBuilder->buildValidGraph(metadata);
 	auto pluginsInDAG = m_pluginDependencyDAG.plugins(); // expensive method
