@@ -1,19 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004, 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Roman Krzystyniak (Ron_K@tlen.pl)
- * Copyright 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2004, 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2010 Radosław Szymczyszyn (lavrin@gmail.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -35,15 +23,16 @@
 #include "misc/algorithm.h"
 #include "plugin/activation/plugin-activation-service.h"
 #include "plugin/plugin-dependency-handler.h"
-#include "plugin/state/plugin-state.h"
 #include "plugin/state/plugin-state-service.h"
-#include "plugin/state/plugin-state-storage.h"
 #include "plugin/state/plugin-state-storage-09.h"
+#include "plugin/state/plugin-state-storage.h"
+#include "plugin/state/plugin-state.h"
 #include "debug.h"
 
 PluginManager::PluginManager(QObject *parent) :
 		QObject{parent}
 {
+	m_runningUnity = QString::compare(qgetenv("XDG_CURRENT_DESKTOP"), "unity", Qt::CaseInsensitive) == 0;
 }
 
 PluginManager::~PluginManager()
@@ -100,6 +89,14 @@ bool PluginManager::shouldActivate(const PluginMetadata &pluginMetadata) const n
 	if (!m_pluginStateService)
 		return false;
 
+	if (m_runningUnity)
+	{
+		if (pluginMetadata.name().contains("indicator_docking"))
+			return true;
+		if (pluginMetadata.name().contains("docking"))
+			return false;
+	}
+
 	switch (m_pluginStateService->pluginState(pluginMetadata.name()))
 	{
 		case PluginState::Enabled:
@@ -127,12 +124,11 @@ void PluginManager::activateReplacementPlugins()
 		if (replacementPlugin.isEmpty())
 			continue;
 
-		if (PluginState::New == m_pluginStateService->pluginState(replacementPlugin))
-			if (m_pluginActivationService->activatePluginWithDependencies(replacementPlugin).contains(replacementPlugin))
-			{
-				m_pluginStateService->setPluginState(pluginToReplace, PluginState::Disabled);
-				m_pluginStateService->setPluginState(replacementPlugin, PluginState::Enabled);
-			}
+		if (m_pluginActivationService->activatePluginWithDependencies(replacementPlugin).contains(replacementPlugin))
+		{
+			m_pluginStateService->setPluginState(pluginToReplace, PluginState::Disabled);
+			m_pluginStateService->setPluginState(replacementPlugin, PluginState::Enabled);
+		}
 	}
 }
 
