@@ -1,18 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2004, 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Roman Krzystyniak (Ron_K@tlen.pl)
- * Copyright 2003, 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2010 Radosław Szymczyszyn (lavrin@gmail.com)
- * Copyright 2007, 2008, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -34,9 +23,10 @@
 #include "plugin/metadata/plugin-metadata.h"
 #include "exports.h"
 
-#include <functional>
 #include <QtCore/QPointer>
 #include <QtCore/QVector>
+#include <injeqt/injeqt.h>
+#include <functional>
 
 class PluginActivationService;
 class PluginDependencyHandler;
@@ -79,13 +69,9 @@ class KADUAPI PluginManager : public QObject
 	Q_DISABLE_COPY(PluginManager)
 
 public:
-	explicit PluginManager(QObject *parent = nullptr);
+	Q_INVOKABLE explicit PluginManager(QObject *parent = nullptr);
 	virtual ~PluginManager();
 
-	void setPluginActivationService(PluginActivationService *pluginActivationService);
-	void setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler);
-	void setPluginStateService(PluginStateService *pluginStateService);
-
 	/**
 	 * @short Activate all protocols plugins that are enabled.
 	 *
@@ -120,6 +106,7 @@ private:
 	QPointer<PluginActivationService> m_pluginActivationService;
 	QPointer<PluginDependencyHandler> m_pluginDependencyHandler;
 	QPointer<PluginStateService> m_pluginStateService;
+	bool m_runningUnity;
 
 	QVector<QString> pluginsToActivate(std::function<bool(const PluginMetadata &)> filter = [](const PluginMetadata &){ return true; }) const;
 
@@ -137,6 +124,11 @@ private:
 	bool shouldActivate(const PluginMetadata &pluginMetadata) const noexcept;
 	QString findReplacementPlugin(const QString &pluginToReplace) const noexcept;
 
+private slots:
+	INJEQT_SET void setPluginActivationService(PluginActivationService *pluginActivationService);
+	INJEQT_SET void setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler);
+	INJEQT_SET void setPluginStateService(PluginStateService *pluginStateService);
+
 };
 
 /**
