@@ -37,6 +37,16 @@ PluginStateManager::~PluginStateManager()
 {
 }
 
+void PluginStateManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void PluginStateManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
 void PluginStateManager::setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler)
 {
 	m_pluginDependencyHandler = pluginDependencyHandler;
@@ -60,7 +70,7 @@ void PluginStateManager::loadPluginStates()
 	if (!m_pluginDependencyHandler || !m_pluginStateService || !m_storagePointFactory)
 		return;
 
-	auto storagePoint = m_storagePointFactory->createStoragePoint(QLatin1String{"Plugins"});
+	auto storagePoint = m_storagePointFactory->createStoragePoint(QStringLiteral("Plugins"));
 	if (!storagePoint)
 		return;
 
@@ -76,13 +86,13 @@ QMap<QString, PluginState> PluginStateManager::loadPluginStates(StoragePoint *st
 {
 	return importedFrom09
 			? PluginStateStorage{}.load(*storagePoint)
-			: PluginStateStorage09{}.load(m_pluginDependencyHandler->pluginNames());
+			: PluginStateStorage09{}.load(m_configuration, m_pluginDependencyHandler->pluginNames());
 }
 
 void PluginStateManager::storePluginStatesAndFlush()
 {
 	storePluginStates();
-	ConfigurationManager::instance()->flush();
+	m_configurationManager->flush();
 }
 
 void PluginStateManager::storePluginStates()
@@ -90,7 +100,7 @@ void PluginStateManager::storePluginStates()
 	if (!m_pluginStateService || !m_storagePointFactory)
 		return;
 
-	auto storagePoint = m_storagePointFactory->createStoragePoint(QLatin1String{"Plugins"});
+	auto storagePoint = m_storagePointFactory->createStoragePoint(QStringLiteral("Plugins"));
 	if (!storagePoint)
 		return;
 
