@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,7 +19,8 @@
 
 #include "plugin-state-storage-09.h"
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "misc/algorithm.h"
 #include "plugin/state/plugin-state.h"
 
@@ -32,16 +33,16 @@
  * This method loads old configuration from depreceated configuration entries: General/EverLaoded,
  * General/LoadedModules and General/UnloadedModules.
  */
-QMap<QString, PluginState> PluginStateStorage09::load(const ::std::set<QString> &installedPluginNames) const
+QMap<QString, PluginState> PluginStateStorage09::load(Configuration *configuration, const ::std::set<QString> &installedPluginNames) const
 {
 	auto result = QMap<QString, PluginState>{};
 
-	auto everLoaded = config_file.readEntry("General", "EverLoaded").split(',', QString::SkipEmptyParts).toSet();
-	auto loaded = config_file.readEntry("General", "LoadedModules");
+	auto everLoaded = configuration->deprecatedApi()->readEntry("General", "EverLoaded").split(',', QString::SkipEmptyParts).toSet();
+	auto loaded = configuration->deprecatedApi()->readEntry("General", "LoadedModules");
 
 	auto loadedPlugins = loaded.split(',', QString::SkipEmptyParts).toSet();
 	everLoaded += loadedPlugins;
-	auto unloaded_str = config_file.readEntry("General", "UnloadedModules");
+	auto unloaded_str = configuration->deprecatedApi()->readEntry("General", "UnloadedModules");
 	auto unloadedPlugins = unloaded_str.split(',', QString::SkipEmptyParts).toSet();
 
 	auto allPlugins = everLoaded + unloadedPlugins; // just in case...
@@ -53,8 +54,7 @@ QMap<QString, PluginState> PluginStateStorage09::load(const ::std::set<QString>
 	if (loadedPlugins.contains("encryption"))
 	{
 		loadedPlugins.remove("encryption");
-		loadedPlugins.insert("encryption_ng");
-		loadedPlugins.insert("encryption_ng_simlite");
+		loadedPlugins.remove("encryption_otr");
 	}
 	if (loadedPlugins.contains("osd_hints"))
 	{
