@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,7 +19,8 @@
 
 #include "plugin-state-storage.h"
 
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "plugin/state/plugin-state.h"
 #include "storage/storage-point.h"
 
@@ -29,11 +30,11 @@
 QMap<QString, PluginState> PluginStateStorage::load(StoragePoint &storagePoint) const
 {
 	auto result = QMap<QString, PluginState>();
-	auto elements = storagePoint.storage()->getNodes(storagePoint.point(), QLatin1String("Plugin"));
+	auto elements = storagePoint.storage()->getNodes(storagePoint.point(), QStringLiteral("Plugin"));
 	for (const auto &element : elements)
 	{
 		auto name = element.attribute("name");
-		auto state = stringToPluginState(storagePoint.storage()->getTextNode(element, QLatin1String("State")));
+		auto state = stringToPluginState(storagePoint.storage()->getTextNode(element, QStringLiteral("State")));
 		result.insert(name, state);
 	}
 
@@ -49,8 +50,8 @@ void PluginStateStorage::store(StoragePoint &storagePoint, const QMap<QString, P
 		auto stateString = pluginStateToString(pluginStates.value(name));
 		if (!stateString.isEmpty())
 		{
-			auto node = storagePoint.storage()->getNamedNode(storagePoint.point(), QLatin1String{"Plugin"}, name, XmlConfigFile::ModeAppend);
-			storagePoint.storage()->appendTextNode(node, QLatin1String{"State"}, stateString);
+			auto node = storagePoint.storage()->getNamedNode(storagePoint.point(), QStringLiteral("Plugin"), name, ConfigurationApi::ModeAppend);
+			storagePoint.storage()->appendTextNode(node, QStringLiteral("State"), stateString);
 		}
 	}
 }
