@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,9 +26,9 @@ QString pluginStateToString(PluginState pluginState)
 	switch (pluginState)
 	{
 		case PluginState::Enabled:
-			return QLatin1String{"Loaded"};
+			return QStringLiteral("Loaded");
 		case PluginState::Disabled:
-			return QLatin1String{"NotLoaded"};
+			return QStringLiteral("NotLoaded");
 		default:
 			return {};
 	}
@@ -41,9 +36,9 @@ QString pluginStateToString(PluginState pluginState)
 
 PluginState stringToPluginState(const QString &string)
 {
-	if (string == QLatin1String{"Loaded"})
+	if (string == QStringLiteral("Loaded"))
 		return PluginState::Enabled;
-	else if (string == QLatin1String{"NotLoaded"})
+	else if (string == QStringLiteral("NotLoaded"))
 		return PluginState::Disabled;
 	else
 		return PluginState::New;
