@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,26 +20,28 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "protocols-model.h"
+
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
+#include "core/core.h"
 #include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "model/roles.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocols-manager.h"
 
-#include "protocols-model.h"
-
-ProtocolsModel::ProtocolsModel(QObject *parent) :
-		QAbstractListModel(parent)
+ProtocolsModel::ProtocolsModel(ProtocolsManager *protocolsManager, QObject *parent) :
+		QAbstractListModel{parent},
+		m_protocolsManager{protocolsManager}
 {
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryAboutToBeRegistered(ProtocolFactory *)),
+	connect(m_protocolsManager, SIGNAL(protocolFactoryAboutToBeRegistered(ProtocolFactory *)),
 		this, SLOT(protocolFactoryAboutToBeRegistered(ProtocolFactory *)));
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryRegistered(ProtocolFactory *)),
+	connect(m_protocolsManager, SIGNAL(protocolFactoryRegistered(ProtocolFactory *)),
 		this, SLOT(protocolFactoryRegistered(ProtocolFactory *)));
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryAboutToBeUnregistered(ProtocolFactory *)),
+	connect(m_protocolsManager, SIGNAL(protocolFactoryAboutToBeUnregistered(ProtocolFactory *)),
 		this, SLOT(protocolFactoryAboutToBeUnregistered(ProtocolFactory *)));
-	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryUnregistered(ProtocolFactory *)),
+	connect(m_protocolsManager, SIGNAL(protocolFactoryUnregistered(ProtocolFactory *)),
 		this, SLOT(protocolFactoryUnregistered(ProtocolFactory *)));
 }
 
@@ -47,44 +49,49 @@ ProtocolsModel::~ProtocolsModel()
 {
 }
 
+void ProtocolsModel::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
 int ProtocolsModel::rowCount(const QModelIndex &parent) const
 {
-	return parent.isValid() ? 0 : ProtocolsManager::instance()->protocolFactories().count();
+	return parent.isValid() ? 0 : m_protocolsManager->protocolFactories().count();
 }
 
 QVariant ProtocolsModel::data(const QModelIndex &index, int role) const
 {
-	ProtocolFactory *pf = protocolFactory(index);
+	auto pf = protocolFactory(index);
 	if (0 == pf)
-		return QVariant();
+		return QVariant{};
 
 	switch (role)
 	{
 		case Qt::DisplayRole:
 			return pf->displayName();
 		case Qt::DecorationRole:
-			return pf->icon().icon();
+			return m_iconsManager->iconByPath(pf->icon());
 		case ProtocolRole:
 			return QVariant::fromValue<ProtocolFactory *>(pf);
 		default:
-			return QVariant();
+			return QVariant{};
 	}
 }
 
 ProtocolFactory * ProtocolsModel::protocolFactory(const QModelIndex &index) const
 {
 	if (!index.isValid())
-		return 0;
+		return nullptr;
 
 	if (index.row() >= rowCount())
-		return 0;
+		return nullptr;
 
-	return ProtocolsManager::instance()->byIndex(index.row());
+	return m_protocolsManager->byIndex(index.row());
 }
 
 int ProtocolsModel::protocolFactoryIndex(ProtocolFactory *protocolFactory) const
 {
-	return ProtocolsManager::instance()->indexOf(protocolFactory);
+	return m_protocolsManager->indexOf(protocolFactory);
 }
 
 QModelIndexList ProtocolsModel::indexListForValue(const QVariant &value) const
@@ -102,7 +109,7 @@ void ProtocolsModel::protocolFactoryAboutToBeRegistered(ProtocolFactory *protoco
 {
 	Q_UNUSED(protocolFactory)
 
-	int count = rowCount();
+	auto count = rowCount();
 	beginInsertRows(QModelIndex(), count, count);
 }
 
@@ -115,7 +122,7 @@ void ProtocolsModel::protocolFactoryRegistered(ProtocolFactory *protocolFactory)
 
 void ProtocolsModel::protocolFactoryAboutToBeUnregistered(ProtocolFactory *protocolFactory)
 {
-	int index = protocolFactoryIndex(protocolFactory);
+	auto index = protocolFactoryIndex(protocolFactory);
 	beginRemoveRows(QModelIndex(), index, index);
 }
 
