@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,28 +19,25 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PROTOCOLS_MODEL
-#define PROTOCOLS_MODEL
-
-#include <QtCore/QAbstractListModel>
-#include <QtCore/QModelIndex>
+#pragma once
 
 #include "model/kadu-abstract-model.h"
 
+#include <QtCore/QAbstractListModel>
+#include <QtCore/QModelIndex>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class IconsManager;
 class ProtocolFactory;
+class ProtocolsManager;
 
 class ProtocolsModel : public QAbstractListModel, public KaduAbstractModel
 {
 	Q_OBJECT
 
-private slots:
-	void protocolFactoryAboutToBeRegistered(ProtocolFactory *protocolFactory);
-	void protocolFactoryRegistered(ProtocolFactory *protocolFactory);
-	void protocolFactoryAboutToBeUnregistered(ProtocolFactory *protocolFactory);
-	void protocolFactoryUnregistered(ProtocolFactory *protocolFactory);
-
 public:
-	explicit ProtocolsModel(QObject *parent = 0);
+	explicit ProtocolsModel(ProtocolsManager *protocolsManager, QObject *parent = nullptr);
 	virtual ~ProtocolsModel();
 
 	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
@@ -51,6 +48,16 @@ public:
 	int protocolFactoryIndex(ProtocolFactory *protocolFactory) const;
 	virtual QModelIndexList indexListForValue(const QVariant &value) const;
 
-};
+private:
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<ProtocolsManager> m_protocolsManager;
 
-#endif // PROTOCOLS_MODEL
+private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+
+	void protocolFactoryAboutToBeRegistered(ProtocolFactory *protocolFactory);
+	void protocolFactoryRegistered(ProtocolFactory *protocolFactory);
+	void protocolFactoryAboutToBeUnregistered(ProtocolFactory *protocolFactory);
+	void protocolFactoryUnregistered(ProtocolFactory *protocolFactory);
+
+};
