@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -37,6 +37,19 @@
  */
 ProtocolStateMachine::ProtocolStateMachine(Protocol *protocol) :
 		QStateMachine(protocol), CurrentProtocol(protocol)
+{
+}
+
+ProtocolStateMachine::~ProtocolStateMachine()
+{
+}
+
+void ProtocolStateMachine::setNetworkManager(NetworkManager *networkManager)
+{
+	m_networkManager = networkManager;
+}
+
+void ProtocolStateMachine::init()
 {
 	TryToGoOnlineTimer.setInterval(5000);
 	TryToGoOnlineTimer.setSingleShot(true);
@@ -53,6 +66,7 @@ ProtocolStateMachine::ProtocolStateMachine(Protocol *protocol) :
 	LoggingInMaybeOnlineState = new QState(this);
 	LoggedInState = new QState(this);
 	PasswordRequiredState = new QState(this);
+	WaitForSslErrorResult = new QState(this);
 
 	connect(LoggingOutState, SIGNAL(entered()), this, SLOT(printConfiguration()));
 	connect(LoggedOutOnlineState, SIGNAL(entered()), this, SLOT(printConfiguration()));
@@ -63,6 +77,7 @@ ProtocolStateMachine::ProtocolStateMachine(Protocol *protocol) :
 	connect(LoggingInMaybeOnlineState, SIGNAL(entered()), this, SLOT(printConfiguration()));
 	connect(LoggedInState, SIGNAL(entered()), this, SLOT(printConfiguration()));
 	connect(PasswordRequiredState, SIGNAL(entered()), this, SLOT(printConfiguration()));
+	connect(WaitForSslErrorResult, SIGNAL(entered()), this, SLOT(printConfiguration()));
 
 	connect(LoggingOutState, SIGNAL(entered()), this, SIGNAL(loggingOutStateEntered()));
 	connect(LoggedOutOnlineState, SIGNAL(entered()), this, SIGNAL(loggedOutOnlineStateEntered()));
@@ -71,7 +86,7 @@ ProtocolStateMachine::ProtocolStateMachine(Protocol *protocol) :
 	connect(LoggingInState, SIGNAL(entered()), this, SIGNAL(loggingInStateEntered()));
 	connect(LoggingInMaybeOnlineState, SIGNAL(entered()), this, SIGNAL(loggingInStateEntered()));
 	connect(LoggedInState, SIGNAL(entered()), this, SIGNAL(loggedInStateEntered()));
-	connect(LoggedInState, SIGNAL(entered()), NetworkManager::instance(), SLOT(forceOnline()));
+	connect(LoggedInState, SIGNAL(entered()), m_networkManager, SLOT(forceOnline()));
 	connect(PasswordRequiredState, SIGNAL(entered()), this, SIGNAL(passwordRequiredStateEntered()));
 
 	connect(WantToLogInState, SIGNAL(entered()), &TryToGoOnlineTimer, SLOT(start()));
@@ -80,53 +95,62 @@ ProtocolStateMachine::ProtocolStateMachine(Protocol *protocol) :
 	connect(LoggingInDelayState, SIGNAL(entered()), &DelayTimer, SLOT(start()));
 	connect(LoggingInDelayState, SIGNAL(exited()), &DelayTimer, SLOT(stop()));
 
-	LoggingOutState->addTransition(NetworkManager::instance(), SIGNAL(offline()), LoggedOutOfflineState);
+	LoggingOutState->addTransition(m_networkManager, SIGNAL(offline()), LoggedOutOfflineState);
 	LoggingOutState->addTransition(CurrentProtocol, SIGNAL(stateMachineLoggedOut()), LoggedOutOnlineState);
 
 	LoggedOutOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachineChangeStatus()), LoggingInState);
-	LoggedOutOnlineState->addTransition(NetworkManager::instance(), SIGNAL(offline()), LoggedOutOfflineState);
+	LoggedOutOnlineState->addTransition(m_networkManager, SIGNAL(offline()), LoggedOutOfflineState);
 
 	LoggedOutOfflineState->addTransition(CurrentProtocol, SIGNAL(stateMachineChangeStatus()), WantToLogInState);
-	LoggedOutOfflineState->addTransition(NetworkManager::instance(), SIGNAL(online()), LoggedOutOnlineState);
+	LoggedOutOfflineState->addTransition(m_networkManager, SIGNAL(online()), LoggedOutOnlineState);
 
-	WantToLogInState->addTransition(NetworkManager::instance(), SIGNAL(online()), LoggingInState);
+	WantToLogInState->addTransition(m_networkManager, SIGNAL(online()), LoggingInState);
 	WantToLogInState->addTransition(&TryToGoOnlineTimer, SIGNAL(timeout()), LoggingInMaybeOnlineState);
 	WantToLogInState->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggedOutOfflineState);
 
-	LoggingInState->addTransition(NetworkManager::instance(), SIGNAL(offline()), WantToLogInState);
+	LoggingInState->addTransition(m_networkManager, SIGNAL(offline()), WantToLogInState);
 	LoggingInState->addTransition(CurrentProtocol, SIGNAL(stateMachineLoggedIn()), LoggedInState);
 	LoggingInState->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggedOutOnlineState);
 	LoggingInState->addTransition(CurrentProtocol, SIGNAL(stateMachinePasswordRequired()), PasswordRequiredState);
 	LoggingInState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionError()), LoggingInDelayState);
 	LoggingInState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionClosed()), LoggedOutOnlineState);
+	LoggingInState->addTransition(CurrentProtocol, SIGNAL(stateMachineSslError()), WaitForSslErrorResult);
 
-	LoggingInDelayState->addTransition(NetworkManager::instance(), SIGNAL(offline()), WantToLogInState);
+	LoggingInDelayState->addTransition(m_networkManager, SIGNAL(offline()), WantToLogInState);
 	LoggingInDelayState->addTransition(&DelayTimer, SIGNAL(timeout()), LoggingInState);
 	LoggingInDelayState->addTransition(CurrentProtocol, SIGNAL(stateMachineLoggedIn()), LoggedInState);
 	LoggingInDelayState->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggedOutOnlineState);
 	LoggingInDelayState->addTransition(CurrentProtocol, SIGNAL(stateMachinePasswordRequired()), PasswordRequiredState);
 	LoggingInDelayState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionClosed()), LoggedOutOnlineState);
 
-	LoggingInMaybeOnlineState->addTransition(NetworkManager::instance(), SIGNAL(offline()), WantToLogInState);
+	LoggingInMaybeOnlineState->addTransition(m_networkManager, SIGNAL(offline()), WantToLogInState);
 	LoggingInMaybeOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachineLoggedIn()), LoggedInState);
 	LoggingInMaybeOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggedOutOnlineState);
 	LoggingInMaybeOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachinePasswordRequired()), PasswordRequiredState);
 	// in this case we assume that user still wants to log in even if connection failed badly
 	LoggingInMaybeOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionError()), WantToLogInState);
 	LoggingInMaybeOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionClosed()), WantToLogInState);
+	LoggingInMaybeOnlineState->addTransition(CurrentProtocol, SIGNAL(stateMachineSslError()), WantToLogInState);
 
-	LoggedInState->addTransition(NetworkManager::instance(), SIGNAL(offline()), WantToLogInState);
+	LoggedInState->addTransition(m_networkManager, SIGNAL(offline()), WantToLogInState);
 	LoggedInState->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggingOutState);
 	LoggedInState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionError()), LoggingInState);
 	LoggedInState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionClosed()), LoggedOutOnlineState);
+	LoggedInState->addTransition(CurrentProtocol, SIGNAL(stateMachineSslError()), LoggingInState);
 
-	PasswordRequiredState->addTransition(NetworkManager::instance(), SIGNAL(offline()), WantToLogInState);
+	PasswordRequiredState->addTransition(m_networkManager, SIGNAL(offline()), WantToLogInState);
 	PasswordRequiredState->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggedOutOnlineState);
 	PasswordRequiredState->addTransition(CurrentProtocol, SIGNAL(stateMachinePasswordAvailable()), LoggingInState);
 	PasswordRequiredState->addTransition(CurrentProtocol, SIGNAL(stateMachinePasswordNotAvailable()), LoggedOutOnlineState);
 	PasswordRequiredState->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionClosed()), LoggedOutOnlineState);
 
-	if (NetworkManager::instance()->isOnline())
+	WaitForSslErrorResult->addTransition(m_networkManager, SIGNAL(offline()), WantToLogInState);
+	WaitForSslErrorResult->addTransition(CurrentProtocol, SIGNAL(stateMachineLogout()), LoggedOutOnlineState);
+	WaitForSslErrorResult->addTransition(CurrentProtocol, SIGNAL(stateMachineSslErrorResolved()), LoggingInState);
+	WaitForSslErrorResult->addTransition(CurrentProtocol, SIGNAL(stateMachineSslErrorNotResolved()), LoggedOutOnlineState);
+	WaitForSslErrorResult->addTransition(CurrentProtocol, SIGNAL(stateMachineConnectionClosed()), LoggedOutOnlineState);
+
+	if (m_networkManager->isOnline())
 		setInitialState(LoggedOutOnlineState);
 	else
 		setInitialState(LoggedOutOfflineState);
@@ -134,10 +158,6 @@ ProtocolStateMachine::ProtocolStateMachine(Protocol *protocol) :
 	start();
 }
 
-ProtocolStateMachine::~ProtocolStateMachine()
-{
-}
-
 /**
  * @author Rafał 'Vogel' Malinowski
  * @short Helper method printing current machine configuration to debug output.
