@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,12 +18,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PROTOCOL_STATE_MACHINE_H
-#define PROTOCOL_STATE_MACHINE_H
+#pragma once
 
+#include <QtCore/QPointer>
 #include <QtCore/QStateMachine>
 #include <QtCore/QTimer>
+#include <injeqt/injeqt.h>
 
+class NetworkManager;
 class Protocol;
 
 /**
@@ -103,6 +104,7 @@ class Protocol;
  *       <li>protocol password required -> password required</li>
  *       <li>protocol connection error -> Logging in (delay)</li>
  *       <li>protocol connection closed -> logged out, online</li>
+ *       <li>protocol ssl error -> Wait for SSL result</li>
  *     </ul>
  *   </dd>
  *   <dt>Logging in delay</dt>
@@ -127,6 +129,7 @@ class Protocol;
  *       <li>protocol password required -> password required</li>
  *       <li>protocol connection closed -> want to log in</li>
  *       <li>protocol connection error -> want to log in</li>
+ *       <li>protocol ssl error -> want to log in</li>
  *     </ul>
  *   </dd>
  *   <dt>Logged in</dt>
@@ -137,7 +140,8 @@ class Protocol;
  *     <ul>
  *       <li>network goes offline -> want to log in</li>
  *       <li>protocol changes state to offline state -> logging out</li>
- *       <li>protocol connection error -> Logging in (another try)</li>
+ *       <li>protocol connection error -> Logging in</li>
+ *       <li>protocol ssl error -> Logging in</li>
  *       <li>protocol connection closed -> logged out, online</li>
  *     </ul>
  *   </dd>
@@ -153,6 +157,18 @@ class Protocol;
  *       <li>password not available -> logged out, online</li>
  *     </ul>
  *   </dd>
+ *   <td>Wait for SSL result</dt>
+ *   <dd>
+ *     This state is used when protocol SSL error occurs. Dialog should be displayed for user with possibility to
+ *     ignore that error:
+ *     <ul>
+ *       <li>network goes offline -> want to log in</li>
+ *       <li>protocol logged out -> logged out, online</li>
+ *       <li>protocol connection closed -> logged out, online</li>
+ *       <li>ssl error resolved -> logging in</li>
+ *       <li>ssl error not resolved -> logged out, online</li>
+ *     </ul>
+ *   </dd>
  * <dl>
  *
  * 11 transitions are defined:
@@ -185,6 +201,8 @@ class ProtocolStateMachine : public QStateMachine
 {
 	Q_OBJECT
 
+	QPointer<NetworkManager> m_networkManager;
+
 	Protocol *CurrentProtocol;
 
 	QTimer TryToGoOnlineTimer;
@@ -199,8 +217,12 @@ class ProtocolStateMachine : public QStateMachine
 	QState *LoggingInDelayState;
 	QState *LoggingInMaybeOnlineState;
 	QState *LoggedInState;
+	QState *WaitForSslErrorResult;
 
 private slots:
+	INJEQT_SET void setNetworkManager(NetworkManager *networkManager);
+	INJEQT_INIT void init();
+
 	void printConfiguration();
 
 public:
@@ -280,5 +302,3 @@ signals:
 /**
  * @}
  */
-
-#endif // PROTOCOL_STATE_MACHINE_H
