@@ -1,13 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2010, 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,19 +22,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PROTOCOL_H
-#define PROTOCOL_H
-
-#include <QtCore/QDateTime>
-#include <QtCore/QObject>
-#include <QtCore/QPointer>
-
-#include "exports.h"
+#pragma once
 
 #include "accounts/account.h"
 #include "chat/chat.h"
 #include "status/status-change-source.h"
 #include "status/status.h"
+#include "exports.h"
+
+#include <QtCore/QDateTime>
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 typedef quint32 UinType;
 
@@ -44,20 +41,24 @@ class QPixmap;
 
 class AccountShared;
 class AvatarService;
+class BuddyListSerializationService;
 class ChatImageService;
 class ChatService;
 class ChatStateService;
-class ContactListService;
+class ContactManager;
 class ContactPersonalInfoService;
 class ContactSet;
 class FileTransferService;
 class Message;
 class MultilogonService;
 class PersonalInfoService;
+class PluginInjectedFactory;
 class ProtocolFactory;
 class ProtocolStateMachine;
 class RosterService;
 class SearchService;
+class SessionService;
+class StatusTypeManager;
 class Status;
 class SubscriptionService;
 class KaduIcon;
@@ -65,62 +66,6 @@ class KaduIcon;
 class KADUAPI Protocol : public QObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(Protocol)
-
-	ProtocolFactory *Factory;
-	ProtocolStateMachine *Machine;
-
-	Account CurrentAccount;
-
-	// services
-	QPointer<ChatService> CurrentChatService;
-	QPointer<ChatStateService> CurrentChatStateService;
-	QPointer<RosterService> CurrentRosterService;
-
-	// real status, can be offline after connection error
-	Status CurrentStatus;
-	// status used by user to login, after connection error its value does not change
-	// it can only by changed by user or status changer
-	Status LoginStatus;
-
-	void setAllOffline();
-
-private slots:
-	// state machine slots
-	void prepareStateMachine();
-
-	void loggingInStateEntered();
-	void loggedInStateEntered();
-	void loggingOutStateEntered();
-	void loggedOutAnyStateEntered();
-	void wantToLogInStateEntered();
-	void passwordRequiredStateEntered();
-
-protected:
-	Status loginStatus() const;
-
-	virtual void login() = 0;
-	virtual void afterLoggedIn() {}
-	virtual void logout() = 0;
-	virtual void sendStatusToServer() = 0;
-
-	virtual void disconnectedCleanup();
-	void statusChanged(Status newStatus);
-
-	void doSetStatus(Status status);
-
-	// services
-	void setChatService(ChatService * const chatService);
-	void setChatStateService(ChatStateService * const chatStateService);
-	void setRosterService(RosterService * const rosterService);
-
-protected slots:
-	void loggedIn();
-	void loggedOut();
-	void passwordRequired();
-	void connectionError();
-	void connectionClosed();
-	void reconnect();
 
 public:
 	Protocol(Account account, ProtocolFactory *factory);
@@ -130,11 +75,11 @@ public:
 	Account account() const { return CurrentAccount; }
 
 	virtual AvatarService * avatarService() { return 0; }
+	virtual BuddyListSerializationService * buddyListSerializationService() { return nullptr; }
 	virtual ChatImageService * chatImageService() { return 0; }
 	virtual ChatService * chatService();
 	virtual ChatStateService * chatStateService();
 	virtual ContactPersonalInfoService * contactPersonalInfoService() { return 0; }
-	virtual ContactListService * contactListService() { return 0; }
 	virtual FileTransferService * fileTransferService() { return 0; }
 	virtual MultilogonService * multilogonService() { return 0; }
 	virtual PersonalInfoService * personalInfoService() { return 0; }
@@ -145,9 +90,9 @@ public:
 	virtual bool contactsListReadOnly() = 0;
 	virtual bool supportsPrivateStatus() { return false; }
 
-	bool isConnected();
-	bool isConnecting();
-	bool isDisconnecting();
+	bool isConnected() const;
+	bool isConnecting() const;
+	bool isDisconnecting() const;
 
 	// method called by user
 	void setStatus(Status status, StatusChangeSource source);
@@ -178,6 +123,7 @@ signals:
 	void disconnected(Account account);
 
 	void statusChanged(Account account, Status newStatus);
+	void remoteStatusChangeRequest(Account account, Status requestedStatus);
 	void contactStatusChanged(Contact contact, Status oldStatus);
 
 // TODO: REVIEW
@@ -198,6 +144,78 @@ signals:
 	void stateMachineConnectionError();
 	void stateMachineConnectionClosed();
 
-};
+	void stateMachineSslError();
+	void stateMachineSslErrorResolved();
+	void stateMachineSslErrorNotResolved();
 
-#endif // PROTOCOL_H
+protected:
+	ContactManager * contactManager() const;
+	PluginInjectedFactory * pluginInjectedFactory() const;
+	StatusTypeManager * statusTypeManager() const;
+
+	Status loginStatus() const;
+
+	virtual void login() = 0;
+	virtual void afterLoggedIn() {}
+	virtual void logout() = 0;
+	virtual void sendStatusToServer() = 0;
+
+	virtual void disconnectedCleanup();
+	void statusChanged(Status newStatus);
+
+	void doSetStatus(Status status);
+
+	// services
+	void setChatService(ChatService * const chatService);
+	void setChatStateService(ChatStateService * const chatStateService);
+	void setRosterService(RosterService * const rosterService);
+
+protected slots:
+	void loggedIn();
+	void loggedOut();
+	void passwordRequired();
+	void connectionError();
+	void connectionClosed();
+	void sslError();
+	void reconnect();
+
+private:
+	QPointer<ChatService> m_chatService;
+	QPointer<ChatStateService> m_chatStateService;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<RosterService> m_rosterService;
+	QPointer<SessionService> m_sessionService;
+	QPointer<StatusTypeManager> m_statusTypeManager;
+
+	ProtocolFactory *Factory;
+	ProtocolStateMachine *Machine;
+
+	Account CurrentAccount;
+
+	// real status, can be offline after connection error
+	Status CurrentStatus;
+	// status used by user to login, after connection error its value does not change
+	// it can only by changed by user or status changer
+	Status LoginStatus;
+
+	void setAllOffline();
+
+private slots:
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setSessionService(SessionService *sessionService);
+	INJEQT_SET void setStatusTypeManager(StatusTypeManager *statusTypeManager);
+	INJEQT_INIT void init();
+
+	// state machine slots
+	void prepareStateMachine();
+
+	void loggingInStateEntered();
+	void loggedInStateEntered();
+	void loggingOutStateEntered();
+	void loggedOutAnyStateEntered();
+	void wantToLogInStateEntered();
+	void passwordRequiredStateEntered();
+
+};
