@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,40 +20,22 @@
  */
 
 #include "accounts/account-manager.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "misc/misc.h"
-#include "protocols/connection-error-notification.h"
 #include "protocols/protocol-factory.h"
 
 #include "debug.h"
 
 #include "protocols-manager.h"
 
-ProtocolsManager * ProtocolsManager::Instance = 0;
-
-ProtocolsManager * ProtocolsManager::instance()
-{
-	if (0 == Instance)
-	{
-		Instance = new ProtocolsManager();
-		Instance->init();
-	}
-
-	return Instance;
-}
-
-ProtocolsManager::ProtocolsManager()
+ProtocolsManager::ProtocolsManager(QObject *parent) :
+		QObject{parent}
 {
 }
 
 ProtocolsManager::~ProtocolsManager()
 {
-	ConnectionErrorNotification::unregisterEvent();
-}
-
-void ProtocolsManager::init()
-{
-	ConnectionErrorNotification::registerEvent();
 }
 
 void ProtocolsManager::registerProtocolFactory(ProtocolFactory *factory)
