@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +20,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "services/message-filter-service.h"
+#include "message/message-filter-service.h"
 #include "services/message-transformer-service.h"
 #include "services/raw-message-transformer-service.h"
 
@@ -39,12 +37,12 @@ ChatService::~ChatService()
 
 void ChatService::setRawMessageTransformerService(RawMessageTransformerService *rawMessageTransformerService)
 {
-	CurrentRawMessageTransformerService = rawMessageTransformerService;
+	m_rawMessageTransformerService = rawMessageTransformerService;
 }
 
 RawMessageTransformerService * ChatService::rawMessageTransformerService() const
 {
-	return CurrentRawMessageTransformerService.data();
+	return m_rawMessageTransformerService.data();
 }
 
 #include "moc_chat-service.cpp"
