@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,25 +24,28 @@
 
 #include <QtCore/QObject>
 
+#include "account-service.h"
+
 #include "exports.h"
 
-class MultilogonSession;
+struct MultilogonSession;
 
-class KADUAPI MultilogonService : public QObject
+class KADUAPI MultilogonService : public AccountService
 {
 	Q_OBJECT
 
 public:
-	explicit MultilogonService(QObject *parent) : QObject(parent) {}
+	explicit MultilogonService(Account account, QObject *parent);
+	virtual ~MultilogonService();
 
-	virtual const QList<MultilogonSession *> & sessions() const = 0;
-	virtual void killSession(MultilogonSession *session) = 0;
+	virtual const QList<MultilogonSession> & sessions() const = 0;
+	virtual void killSession(MultilogonSession session) = 0;
 
 signals:
-	void multilogonSessionAboutToBeConnected(MultilogonSession *session);
-	void multilogonSessionConnected(MultilogonSession *session);
-	void multilogonSessionAboutToBeDisconnected(MultilogonSession *session);
-	void multilogonSessionDisconnected(MultilogonSession *session);
+	void multilogonSessionAboutToBeConnected(MultilogonSession session);
+	void multilogonSessionConnected(MultilogonSession session);
+	void multilogonSessionAboutToBeDisconnected(MultilogonSession session);
+	void multilogonSessionDisconnected(MultilogonSession session);
 
 };
 
