@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2008, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2005, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -37,7 +34,7 @@ class KADUAPI LongValidator : public QValidator
 	qlonglong Top;
 
 public:
-	LongValidator(qlonglong bottom, qlonglong top, QObject *parent = 0);
+	LongValidator(qlonglong bottom, qlonglong top, QObject *parent = nullptr);
 	virtual ~LongValidator();
 
 	virtual QValidator::State validate(QString &input, int &) const;
