@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@ class KADUAPI RawMessageTransformerService : public QObject, public Configurable
 	Q_OBJECT
 
 public:
-	explicit RawMessageTransformerService(QObject *parent = 0);
+	Q_INVOKABLE explicit RawMessageTransformerService(QObject *parent = nullptr);
 	virtual ~RawMessageTransformerService();
 
 };
