@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,28 +21,46 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "configuration/main-configuration-holder.h"
 #include "icons/kadu-icon.h"
 #include "protocols/protocol.h"
+#include "status/status-configuration-holder.h"
 
 #include "all-accounts-status-container.h"
 
 AllAccountsStatusContainer::AllAccountsStatusContainer(QObject *parent) :
 		StatusContainer(parent)
 {
-	triggerAllAccountsRegistered();
 }
 
 AllAccountsStatusContainer::~AllAccountsStatusContainer()
 {
-	triggerAllAccountsUnregistered();
+}
+
+void AllAccountsStatusContainer::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void AllAccountsStatusContainer::setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder)
+{
+	m_statusConfigurationHolder = statusConfigurationHolder;
+}
+
+void AllAccountsStatusContainer::init()
+{
+	triggerAllAccountsRegistered(m_accountManager);
+}
+
+void AllAccountsStatusContainer::done()
+{
+	triggerAllAccountsUnregistered(m_accountManager);
 }
 
 void AllAccountsStatusContainer::accountRegistered(Account account)
 {
 	Accounts.append(account);
 	connect(account.statusContainer(), SIGNAL(statusUpdated(StatusContainer *)), this, SIGNAL(statusUpdated(StatusContainer *)));
-	if (!MainConfigurationHolder::instance()->isSetStatusPerAccount() && !MainConfigurationHolder::instance()->isSetStatusPerIdentity())
+	if (!m_statusConfigurationHolder->isSetStatusPerAccount() && !m_statusConfigurationHolder->isSetStatusPerIdentity())
 		account.statusContainer()->setStatus(LastSetStatus, SourceStatusChanger);
 
 	emit statusUpdated(this);
