@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,13 +17,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ALL_ACCOUNTS_STATUS_CONTAINER_H
-#define ALL_ACCOUNTS_STATUS_CONTAINER_H
+#pragma once
 
 #include "accounts/accounts-aware-object.h"
 #include "status/status-container.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
 class Account;
+class StatusConfigurationHolder;
 
 /**
  * @addtogroup Status
@@ -42,10 +46,6 @@ class Account;
 class KADUAPI AllAccountsStatusContainer : public StatusContainer, public AccountsAwareObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(AllAccountsStatusContainer)
-
-	QList<Account> Accounts;
-	Status LastSetStatus;
 
 protected:
 	/**
@@ -69,7 +69,7 @@ protected:
 	virtual void accountUnregistered(Account account);
 
 public:
-	explicit AllAccountsStatusContainer(QObject *parent = 0);
+	Q_INVOKABLE explicit AllAccountsStatusContainer(QObject *parent = nullptr);
 	virtual ~AllAccountsStatusContainer();
 
 	/**
@@ -171,10 +171,21 @@ public:
 	 */
 	virtual void storeStatus(Status status);
 
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<StatusConfigurationHolder> m_statusConfigurationHolder;
+
+	QList<Account> Accounts;
+	Status LastSetStatus;
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
 };
 
 /**
  * @}
  */
-
-#endif // ALL_ACCOUNTS_STATUS_CONTAINER_H
