@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,37 +20,47 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/configuration-file.h"
-#include "configuration/configuration-manager.h"
-#include "core/core.h"
-#include "status/description-model.h"
-
 #include "description-manager.h"
 
-DescriptionManager * DescriptionManager::Instance = 0;
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "status/description-model.h"
 
-DescriptionManager * DescriptionManager::instance()
+DescriptionManager::DescriptionManager(QObject *parent) :
+		StorableStringList{parent}
 {
-	if (0 == Instance)
-		Instance = new DescriptionManager();
-	return Instance;
 }
 
-DescriptionManager::DescriptionManager()
+DescriptionManager::~DescriptionManager()
 {
-	ConfigurationManager::instance()->registerStorableObject(this);
+}
+
+void DescriptionManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void DescriptionManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void DescriptionManager::init()
+{
+	m_configurationManager->registerStorableObject(this);
 
 	configurationUpdated();
 
-	if (xml_config_file->getNode("Descriptions", XmlConfigFile::ModeFind).isNull())
+	if (m_configuration->api()->getNode("Descriptions", ConfigurationApi::ModeFind).isNull())
 		import();
 	else
 		setState(StateNotLoaded);
 }
 
-DescriptionManager::~DescriptionManager()
+void DescriptionManager::done()
 {
-	ConfigurationManager::instance()->unregisterStorableObject(this);
+	m_configurationManager->unregisterStorableObject(this);
 }
 
 StorableObject * DescriptionManager::storageParent()
@@ -60,12 +70,12 @@ StorableObject * DescriptionManager::storageParent()
 
 QString DescriptionManager::storageNodeName()
 {
-	return QLatin1String("Descriptions");
+	return QStringLiteral("Descriptions");
 }
 
 QString DescriptionManager::storageItemNodeName()
 {
-	return QLatin1String("Description");
+	return QStringLiteral("Description");
 }
 
 DescriptionModel * DescriptionManager::model()
@@ -78,7 +88,7 @@ DescriptionModel * DescriptionManager::model()
 void DescriptionManager::import()
 {
 	StringList.clear();
-	StringList.append(config_file.readEntry("General", "DefaultDescription").split("<-->", QString::SkipEmptyParts));
+	StringList.append(m_configuration->deprecatedApi()->readEntry("General", "DefaultDescription").split("<-->", QString::SkipEmptyParts));
 	StringList.removeDuplicates();
 
 	truncate();
@@ -99,7 +109,7 @@ void DescriptionManager::truncate()
 
 void DescriptionManager::configurationUpdated()
 {
-	MaxNumberOfDescriptions = config_file.readNumEntry("General", "NumberOfDescriptions");
+	MaxNumberOfDescriptions = m_configuration->deprecatedApi()->readNumEntry("General", "NumberOfDescriptions");
 	truncate();
 }
 
