@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,10 +21,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
+#include "status-actions.h"
 
 #include "accounts/account-manager.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "protocols/protocol.h"
@@ -36,10 +37,38 @@
 #include "status/status-type-manager.h"
 #include "status/status-type.h"
 
-#include "status-actions.h"
+#include <QtWidgets/QAction>
 
-StatusActions::StatusActions(StatusContainer *statusContainer, bool includePrefix, QObject *parent) :
-		QObject(parent), MyStatusContainer(statusContainer), IncludePrefix(includePrefix), ChangeDescription(0)
+StatusActions::StatusActions(StatusContainer *statusContainer, bool includePrefix, bool onlyStatuses, QObject *parent) :
+		QObject(parent), MyStatusContainer(statusContainer), IncludePrefix(includePrefix), OnlyStatuses{onlyStatuses}, ChangeDescription(0)
+{
+}
+
+StatusActions::~StatusActions()
+{
+}
+
+void StatusActions::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void StatusActions::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void StatusActions::setStatusSetter(StatusSetter *statusSetter)
+{
+	m_statusSetter = statusSetter;
+}
+
+void StatusActions::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void StatusActions::init()
 {
 	ChangeStatusActionGroup = new QActionGroup(this);
 	ChangeStatusActionGroup->setExclusive(true); // HACK
@@ -48,11 +77,7 @@ StatusActions::StatusActions(StatusContainer *statusContainer, bool includePrefi
 	statusUpdated();
 	connect(MyStatusContainer, SIGNAL(statusUpdated(StatusContainer *)), this, SLOT(statusUpdated(StatusContainer *)));
 
-	connect(IconsManager::instance(), SIGNAL(themeChanged()), this, SLOT(iconThemeChanged()));
-}
-
-StatusActions::~StatusActions()
-{
+	connect(m_iconsManager, SIGNAL(themeChanged()), this, SLOT(iconThemeChanged()));
 }
 
 void StatusActions::createActions()
@@ -60,30 +85,33 @@ void StatusActions::createActions()
 	createBasicActions();
 
 	MyStatusTypes = MyStatusContainer->supportedStatusTypes();
-	StatusTypeGroup currentGroup = StatusTypeGroupNone;
+	StatusTypeGroup currentGroup = StatusTypeGroup::None;
 	bool setDescriptionAdded = false;
 
 	foreach (StatusType statusType, MyStatusTypes)
 	{
-		if (StatusTypeNone == statusType)
+		if (StatusType::None == statusType)
 			continue;
 
-		const StatusTypeData & typeData = StatusTypeManager::instance()->statusTypeData(statusType);
+		const StatusTypeData & typeData = m_statusTypeManager->statusTypeData(statusType);
 
-		if (StatusTypeGroupNone == currentGroup)
+		if (StatusTypeGroup::None == currentGroup)
 			currentGroup = typeData.typeGroup();
 
-		if (!setDescriptionAdded && typeData.typeGroup() == StatusTypeGroupOffline)
+		if (!setDescriptionAdded && typeData.typeGroup() == StatusTypeGroup::Offline)
 		{
-			if (!Actions.isEmpty())
+			if (!OnlyStatuses && !Actions.isEmpty())
+			{
 				Actions.append(createSeparator());
-			Actions.append(ChangeDescription);
-			setDescriptionAdded = true;
+				Actions.append(ChangeDescription);
+				setDescriptionAdded = true;
+			}
 		}
 
 		if (typeData.typeGroup() != currentGroup)
 		{
-			Actions.append(createSeparator());
+			if (!OnlyStatuses)
+				Actions.append(createSeparator());
 			currentGroup = typeData.typeGroup();
 		}
 
@@ -110,8 +138,8 @@ QAction * StatusActions::createSeparator()
 
 QAction * StatusActions::createStatusAction(const StatusTypeData &typeData)
 {
-	KaduIcon icon = MyStatusContainer->statusIcon(typeData.type());
-	QAction *statusAction = ChangeStatusActionGroup->addAction(icon.icon(), IncludePrefix
+	KaduIcon icon = MyStatusContainer->statusIcon(Status{typeData.type()});
+	QAction *statusAction = ChangeStatusActionGroup->addAction(m_iconsManager->iconByPath(icon), IncludePrefix
 			? MyStatusContainer->statusNamePrefix() + typeData.displayName()
 			: typeData.displayName());
 	statusAction->setCheckable(true);
@@ -147,7 +175,7 @@ void StatusActions::statusUpdated(StatusContainer *container)
 
 	StatusType currentStatusType = container
 		? container->status().type()
-		: StatusSetter::instance()->manuallySetStatus(MyStatusContainer).type();
+		: m_statusSetter->manuallySetStatus(MyStatusContainer).type();
 
 	if (!MyStatusContainer->supportedStatusTypes().contains(currentStatusType))
 		currentStatusType = MyStatusContainer->status().type();
@@ -155,15 +183,15 @@ void StatusActions::statusUpdated(StatusContainer *container)
 	foreach (QAction *action, ChangeStatusActionGroup->actions())
 	{
 		StatusType statusType = action->data().value<StatusType>();
-		if (StatusTypeNone == statusType)
+		if (StatusType::None == statusType)
 			continue;
-		action->setIcon(MyStatusContainer->statusIcon(statusType).icon());
+		action->setIcon(m_iconsManager->iconByPath(MyStatusContainer->statusIcon(Status{statusType})));
 
 		if (!MyStatusContainer->isStatusSettingInProgress())
 		{
 			// For 'All xxx' status menu items - check only if all accounts have the same status
-			if (StatusContainerManager::instance() == MyStatusContainer)
-				action->setChecked(StatusContainerManager::instance()->allStatusOfType(statusType));
+			if (m_statusContainerManager == MyStatusContainer)
+				action->setChecked(m_statusContainerManager->allStatusOfType(statusType));
 			else
 				action->setChecked(currentStatusType == statusType);
 		}
@@ -177,10 +205,10 @@ void StatusActions::iconThemeChanged()
 	foreach (QAction *action, ChangeStatusActionGroup->actions())
 	{
 		StatusType statusType = action->data().value<StatusType>();
-		if (StatusTypeNone == statusType)
+		if (StatusType::None == statusType)
 			continue;
 
-		action->setIcon(MyStatusContainer->statusIcon(statusType).icon());
+		action->setIcon(m_iconsManager->iconByPath(MyStatusContainer->statusIcon(Status{statusType})));
 	}
 }
 
