@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,26 +21,52 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STATUS_ACTIONS_H
-#define STATUS_ACTIONS_H
+#pragma once
+
+#include "status/status-type.h"
+#include "exports.h"
 
 #include <QtCore/QList>
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
-#include "status/status-type.h"
+class IconsManager;
+class StatusContainerManager;
+class StatusContainer;
+class StatusSetter;
+class StatusTypeData;
+class StatusTypeManager;
 
 class QAction;
 class QActionGroup;
 
-class StatusContainer;
-class StatusTypeData;
-
-class StatusActions : public QObject
+class KADUAPI StatusActions : public QObject
 {
 	Q_OBJECT
 
+public:
+	explicit StatusActions(StatusContainer *statusContainer, bool includePrefix, bool onlyStatuses, QObject *parent = nullptr);
+	virtual ~StatusActions();
+
+	const QList<QAction *> & actions() const { return Actions; }
+	StatusContainer * statusContainer() const { return MyStatusContainer; }
+
+signals:
+	void statusActionsRecreated();
+
+	void statusActionTriggered(QAction *);
+	void changeDescriptionActionTriggered(bool);
+
+private:
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<StatusContainerManager> m_statusContainerManager;
+	QPointer<StatusSetter> m_statusSetter;
+	QPointer<StatusTypeManager> m_statusTypeManager;
+
 	StatusContainer *MyStatusContainer;
 	bool IncludePrefix;
+	bool OnlyStatuses;
 
 	QActionGroup *ChangeStatusActionGroup;
 	QAction *ChangeDescription;
@@ -55,21 +81,13 @@ class StatusActions : public QObject
 	void cleanUpActions();
 
 private slots:
-	void statusUpdated();
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setStatusContainerManager(StatusContainerManager *statusContainerManager);
+	INJEQT_SET void setStatusSetter(StatusSetter *statusSetter);
+	INJEQT_SET void setStatusTypeManager(StatusTypeManager *statusTypeManager);
+	INJEQT_INIT void init();
+
+	void statusUpdated(StatusContainer *container = 0);
 	void iconThemeChanged();
 
-public:
-	StatusActions(StatusContainer *statusContainer, bool includePrefix, QObject *parent);
-	virtual ~StatusActions();
-
-	const QList<QAction *> & actions() const { return Actions; }
-
-signals:
-	void statusActionsRecreated();
-
-	void statusActionTriggered(QAction *);
-	void changeDescriptionActionTriggered(bool);
-
 };
-
-#endif // STATUS_ACTIONS_H
