@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,17 +25,8 @@
 
 #include "status-changer-manager.h"
 
-StatusChangerManager * StatusChangerManager::Instance = 0;
-
-StatusChangerManager * StatusChangerManager::instance()
-{
-	if (0 == Instance)
-		Instance = new StatusChangerManager();
-
-	return Instance;
-}
-
-StatusChangerManager::StatusChangerManager()
+StatusChangerManager::StatusChangerManager(QObject *parent) :
+		QObject{parent}
 {
 }
 
@@ -43,6 +34,11 @@ StatusChangerManager::~StatusChangerManager()
 {
 }
 
+void StatusChangerManager::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
 void StatusChangerManager::registerStatusChanger(StatusChanger *statusChanger)
 {
 	kdebugf();
@@ -77,10 +73,11 @@ void StatusChangerManager::unregisterStatusChanger(StatusChanger *statusChanger)
 	kdebugf2();
 }
 
-void StatusChangerManager::setStatus(StatusContainer *statusContainer, Status status)
+void StatusChangerManager::setStatusManually(StatusContainer *statusContainer, Status status)
 {
 	if (statusContainer)
 	{
+		emit manualStatusAboutToBeChanged(statusContainer, status);
 		Statuses.insert(statusContainer, status);
 		statusChanged(statusContainer, SourceUser);
 	}
@@ -97,7 +94,7 @@ void StatusChangerManager::statusChanged(StatusContainer *container, StatusChang
 {
 	if (!container)
 	{
-		foreach (StatusContainer *statusContainer, StatusContainerManager::instance()->statusContainers())
+		foreach (StatusContainer *statusContainer, m_statusContainerManager->statusContainers())
 			if (statusContainer)
 				statusChanged(statusContainer, source);
 
