@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -35,14 +35,14 @@ void StatusContainerAwareObject::notifyStatusContainerUnregistered(StatusContain
 		object->statusContainerUnregistered(statusContainer);
 }
 
-void StatusContainerAwareObject::triggerAllStatusContainerRegistered()
+void StatusContainerAwareObject::triggerAllStatusContainerRegistered(StatusContainerManager *statusContainerManager)
 {
-	foreach (StatusContainer *statusContainer, StatusContainerManager::instance()->statusContainers())
+	foreach (StatusContainer *statusContainer, statusContainerManager->statusContainers())
 		statusContainerRegistered(statusContainer);
 }
 
-void StatusContainerAwareObject::triggerAllStatusContainerUnregistered()
+void StatusContainerAwareObject::triggerAllStatusContainerUnregistered(StatusContainerManager *statusContainerManager)
 {
-	foreach (StatusContainer *statusContainer, StatusContainerManager::instance()->statusContainers())
+	foreach (StatusContainer *statusContainer, statusContainerManager->statusContainers())
 		statusContainerUnregistered(statusContainer);
 }
