@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,97 +23,113 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "configuration/main-configuration-holder.h"
-#include "core/core.h"
 #include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "identities/identity-manager.h"
 #include "protocols/protocol.h"
 #include "status/all-accounts-status-container.h"
+#include "status/status-configuration-holder.h"
 #include "status/status-container-aware-object.h"
 #include "status/status-type-manager.h"
 #include "status/status-type.h"
 
 #include "status-container-manager.h"
 
-StatusContainerManager * StatusContainerManager::Instance = 0;
-
-StatusContainerManager * StatusContainerManager::instance()
+StatusContainerManager::StatusContainerManager(QObject *parent) :
+		StatusContainer(parent), DefaultStatusContainer(0)
 {
-	if (!Instance)
-		Instance = new StatusContainerManager();
-	return Instance;
-}
-
-StatusContainerManager::StatusContainerManager() :
-		StatusContainer(0), DefaultStatusContainer(0)
-{
-	AllAccountsContainer = new AllAccountsStatusContainer(this);
-
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
-		triggerAllIdentitiesAdded();
-	else if (MainConfigurationHolder::instance()->isSetStatusPerAccount())
-		triggerAllAccountsRegistered();
-	else
-		registerStatusContainer(AllAccountsContainer);
-
-	connect(MainConfigurationHolder::instance(), SIGNAL(setStatusModeChanged()), this, SLOT(setStatusModeChanged()));
-	connect(AccountManager::instance(), SIGNAL(accountUpdated(Account)), this, SLOT(updateIdentities()));
 }
 
 StatusContainerManager::~StatusContainerManager()
 {
-	disconnect(AccountManager::instance(), 0, this, 0);
-	disconnect(MainConfigurationHolder::instance(), 0, this, 0);
+}
 
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
-		triggerAllIdentitiesRemoved();
-	else if (MainConfigurationHolder::instance()->isSetStatusPerAccount())
-		triggerAllAccountsUnregistered();
+void StatusContainerManager::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void StatusContainerManager::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void StatusContainerManager::setStatusConfigurationHolder(StatusConfigurationHolder *statusConfigurationHolder)
+{
+	m_statusConfigurationHolder = statusConfigurationHolder;
+}
+
+void StatusContainerManager::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void StatusContainerManager::init()
+{
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity())
+		triggerAllIdentitiesAdded(m_identityManager);
+	else if (m_statusConfigurationHolder->isSetStatusPerAccount())
+		triggerAllAccountsRegistered(m_accountManager);
 	else
-		unregisterStatusContainer(AllAccountsContainer);
+		registerStatusContainer(m_allAccountsStatusContainer);
+
+	connect(m_statusConfigurationHolder, SIGNAL(setStatusModeChanged()), this, SLOT(setStatusModeChanged()));
+	connect(m_accountManager, SIGNAL(accountUpdated(Account)), this, SLOT(updateIdentities()));
+}
+
+void StatusContainerManager::done()
+{
+	if (m_statusConfigurationHolder)
+	{
+		if (m_statusConfigurationHolder->isSetStatusPerIdentity())
+			triggerAllIdentitiesRemoved(m_identityManager);
+		else if (m_statusConfigurationHolder->isSetStatusPerAccount())
+			triggerAllAccountsUnregistered(m_accountManager);
+		else
+			unregisterStatusContainer(m_allAccountsStatusContainer);
+	}
 }
 
 void StatusContainerManager::updateIdentities()
 {
-	if (!MainConfigurationHolder::instance()->isSetStatusPerIdentity())
+	if (!m_statusConfigurationHolder->isSetStatusPerIdentity())
 		return;
 
-	foreach (const Identity &identity, IdentityManager::instance()->items())
-		if (StatusContainers.contains(identity) && !identity.hasAnyAccountWithDetails())
-			unregisterStatusContainer(identity);
-		else if (!StatusContainers.contains(identity) && identity.hasAnyAccountWithDetails())
-			registerStatusContainer(identity);
+	foreach (const Identity &identity, m_identityManager->items())
+		if (StatusContainers.contains(identity.statusContainer()) && !identity.hasAnyAccountWithDetails())
+			unregisterStatusContainer(identity.statusContainer());
+		else if (!StatusContainers.contains(identity.statusContainer()) && identity.hasAnyAccountWithDetails())
+			registerStatusContainer(identity.statusContainer());
 }
 
 void StatusContainerManager::accountRegistered(Account account)
 {
-	if (MainConfigurationHolder::instance()->isSetStatusPerAccount() && !StatusContainers.contains(account.statusContainer()))
+	if (m_statusConfigurationHolder->isSetStatusPerAccount() && !StatusContainers.contains(account.statusContainer()))
 		registerStatusContainer(account.statusContainer());
 
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity() && !StatusContainers.contains(account.accountIdentity()))
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity() && !StatusContainers.contains(account.accountIdentity().statusContainer()))
 		updateIdentities();
 }
 
 void StatusContainerManager::accountUnregistered(Account account)
 {
-	if (MainConfigurationHolder::instance()->isSetStatusPerAccount() && StatusContainers.contains(account.statusContainer()))
+	if (m_statusConfigurationHolder->isSetStatusPerAccount() && StatusContainers.contains(account.statusContainer()))
 		unregisterStatusContainer(account.statusContainer());
 
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity())
 		updateIdentities();
 }
 
 void StatusContainerManager::identityAdded(Identity identity)
 {
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity() && !StatusContainers.contains(identity) && identity.hasAnyAccountWithDetails())
-		registerStatusContainer(identity);
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity() && !StatusContainers.contains(identity.statusContainer()) && identity.hasAnyAccountWithDetails())
+		registerStatusContainer(identity.statusContainer());
 }
 
 void StatusContainerManager::identityRemoved(Identity identity)
 {
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity() && StatusContainers.contains(identity))
-		unregisterStatusContainer(identity);
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity() && StatusContainers.contains(identity.statusContainer()))
+		unregisterStatusContainer(identity.statusContainer());
 }
 
 void StatusContainerManager::cleanStatusContainers()
@@ -124,7 +140,7 @@ void StatusContainerManager::cleanStatusContainers()
 
 void StatusContainerManager::addAllAccounts()
 {
-	foreach (Account account, AccountManager::instance()->items())
+	foreach (Account account, m_accountManager->items())
 		registerStatusContainer(account.statusContainer());
 }
 
@@ -133,6 +149,11 @@ void StatusContainerManager::addAllIdentities()
 	updateIdentities();
 }
 
+void StatusContainerManager::setAllAccountsStatusContainer(AllAccountsStatusContainer *allAccountsStatusContainer)
+{
+	m_allAccountsStatusContainer = allAccountsStatusContainer;
+}
+
 void StatusContainerManager::setDefaultStatusContainer(StatusContainer *defaultStatusContainer)
 {
 	if (defaultStatusContainer == DefaultStatusContainer)
@@ -155,12 +176,12 @@ void StatusContainerManager::setDefaultStatusContainer(StatusContainer *defaultS
 void StatusContainerManager::setStatusModeChanged()
 {
 	cleanStatusContainers();
-	if (MainConfigurationHolder::instance()->isSetStatusPerIdentity())
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity())
 		addAllIdentities();
-	else if (MainConfigurationHolder::instance()->isSetStatusPerAccount())
+	else if (m_statusConfigurationHolder->isSetStatusPerAccount())
 		addAllAccounts();
 	else
-		registerStatusContainer(AllAccountsContainer);
+		registerStatusContainer(m_allAccountsStatusContainer);
 }
 
 void StatusContainerManager::registerStatusContainer(StatusContainer *statusContainer)
@@ -196,7 +217,7 @@ void StatusContainerManager::unregisterStatusContainer(StatusContainer *statusCo
 
 bool StatusContainerManager::allStatusOfType(StatusType type)
 {
-	if (StatusTypeNone == type)
+	if (StatusType::None == type)
 		return false;
 
 	foreach (StatusContainer *container, StatusContainers)
@@ -238,9 +259,9 @@ KaduIcon StatusContainerManager::statusIcon()
 KaduIcon StatusContainerManager::statusIcon(const Status &status)
 {
 	if (!DefaultStatusContainer)
-		return StatusTypeManager::instance()->statusIcon("common", StatusTypeOffline);
+		return m_statusTypeManager->statusIcon("common", Status{StatusType::Offline});
 
-	return StatusTypeManager::instance()->statusIcon("common", status);
+	return m_statusTypeManager->statusIcon("common", status);
 }
 
 QList<StatusType> StatusContainerManager::supportedStatusTypes()
@@ -280,4 +301,13 @@ QList<StatusContainer *> StatusContainerManager::subStatusContainers()
 	return StatusContainers;
 }
 
+StatusContainer * StatusContainerManager::statusContainerForAccount(Account account) const
+{
+	if (m_statusConfigurationHolder->isSetStatusPerAccount())
+		return account.statusContainer();
+	if (m_statusConfigurationHolder->isSetStatusPerIdentity())
+		return account.accountIdentity().statusContainer();
+	return m_allAccountsStatusContainer;
+}
+
 #include "moc_status-container-manager.cpp"
