@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -58,7 +56,7 @@ class KADUAPI StatusContainer : public QObject
 	friend class Core;
 
 public:
-	explicit StatusContainer(QObject *parent = 0);
+	explicit StatusContainer(QObject *parent = nullptr);
 
 	virtual ~StatusContainer();
 
@@ -209,7 +207,7 @@ signals:
 	 * StatusContainer was changed that might have caused implicit status change (but did not
 	 * need to, so do not assume real status change after this signal).
 	 */
-	void statusUpdated();
+	void statusUpdated(StatusContainer *container);
 
 };
 
