@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2011, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,11 +17,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STATUS_SETTER_H
-#define STATUS_SETTER_H
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 #include "status/status-container-aware-object.h"
+#include "exports.h"
+
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+class StatusChangerManager;
+class StatusContainerManager;
+class StatusTypeManager;
+class Status;
 
 /**
  * @addtogroup Status
@@ -41,20 +49,64 @@
  *
  * StatusSetter also allows receiving originally statused (not modified) by manuallySetStatus method.
  */
-class StatusSetter : private StatusContainerAwareObject, private ConfigurationAwareObject
+class KADUAPI StatusSetter : public QObject, private StatusContainerAwareObject, private ConfigurationAwareObject
 {
-	Q_DISABLE_COPY(StatusSetter)
+	Q_OBJECT
 
+public:
+	Q_INVOKABLE explicit StatusSetter(QObject *parent = nullptr);
+	virtual ~StatusSetter();
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Sets status on given status container with modifications.
+	 * @param statusContainer StatusContainer to set status on.
+	 * @param status status to be modified and then set on statusContainer
+	 *
+	 * This methods stores given status as manually set status (to receive by manuallySetStatus) and then modifies
+	 * it using StatusChangersManager singleton. After all changes are done, new status is set on statusContainer
+	 * using StatusContainer::setStatus method.
+	 */
+	void setStatusManually(StatusContainer *statusContainer, Status status);
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Returns manually (unchanged) status from given StatusContainer.
+	 * @param statusContainer StatusContainer to get status from.
+	 *
+	 * This methods returns manually set status from given StatusContainer. This is the last status that was
+	 * set using StatusSetter::setStatus method.
+	 */
+	Status manuallySetStatus(StatusContainer *statusContainer);
+
+protected:
+	void configurationUpdated();
+
+	/**
+	 * @author Rafał 'Vogel' Malinowski
+	 * @short Called on registration of new container, sets default status.
+	 * @param statusContainer new status container
+	 *
+	 * If core is initialized this method calls setDefaultStatus to set initial status on given status container.
+	 * If core is not initialized, this method does nothing. On core initialization this method will be called
+	 * for each status container.
+	 */
+	void statusContainerRegistered(StatusContainer *statusContainer);
+	void statusContainerUnregistered(StatusContainer *statusContainer);
+
+private:
 	friend class Core;
 
-	bool CoreInitialized;
+	QPointer<Configuration> m_configuration;
+	QPointer<StatusChangerManager> m_statusChangerManager;
+	QPointer<StatusContainerManager> m_statusContainerManager;
+	QPointer<StatusTypeManager> m_statusTypeManager;
+
 	QString StartupStatus;
 	QString StartupDescription;
 	bool StartupLastDescription;
 	bool OfflineToInvisible;
 
-	static StatusSetter *Instance;
-
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Private method called by Core.
@@ -76,55 +128,12 @@ class StatusSetter : private StatusContainerAwareObject, private ConfigurationAw
 	 */
 	void setDefaultStatus(StatusContainer *statusContainer);
 
-	StatusSetter();
-	virtual ~StatusSetter();
-
-protected:
-	void configurationUpdated();
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Called on registration of new container, sets default status.
-	 * @param statusContainer new status container
-	 *
-	 * If core is initialized this method calls setDefaultStatus to set initial status on given status container.
-	 * If core is not initialized, this method does nothing. On core initialization this method will be called
-	 * for each status container.
-	 */
-	void statusContainerRegistered(StatusContainer *statusContainer);
-	void statusContainerUnregistered(StatusContainer *statusContainer);
-
-public:
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Returns StatusSetter singleton instance.
-	 * @return StatusSetter singleton instance
-	 *
-	 * Returns StatusSetter singleton instance.
-	 */
-	static StatusSetter * instance();
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Sets status on given status container with modifications.
-	 * @param statusContainer StatusContainer to set status on.
-	 * @param status status to be modified and then set on statusContainer
-	 *
-	 * This methods stores given status as manually set status (to receive by manuallySetStatus) and then modifies
-	 * it using StatusChangersManager singleton. After all changes are done, new status is set on statusContainer
-	 * using StatusContainer::setStatus method.
-	 */
-	void setStatus(StatusContainer *statusContainer, Status status);
-
-	/**
-	 * @author Rafał 'Vogel' Malinowski
-	 * @short Returns manually (unchanged) status from given StatusContainer.
-	 * @param statusContainer StatusContainer to get status from.
-	 *
-	 * This methods returns manually set status from given StatusContainer. This is the last status that was
-	 * set using StatusSetter::setStatus method.
-	 */
-	Status manuallySetStatus(StatusContainer *statusContainer);
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setStatusChangerManager(StatusChangerManager *statusChangerManager);
+	INJEQT_SET void setStatusContainerManager(StatusContainerManager *statusContainerManager);
+	INJEQT_SET void setStatusTypeManager(StatusTypeManager *statusTypeManager);
+	INJEQT_INIT void init();
 
 };
 
@@ -132,5 +141,3 @@ public:
  * @addtogroup Status
  * @}
  */
-
-#endif // STATUS_SETTER_H
