@@ -2,11 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -39,8 +36,7 @@ Status::Status(StatusType statusType, const QString &description) :
 }
 
 Status::Status(const Status& copyme) :
-		Type(copyme.Type), Group(copyme.Group), Description(copyme.Description),
-		DisplayName(copyme.DisplayName)
+		Type(copyme.Type), Description(copyme.Description)
 {
 }
 
@@ -51,15 +47,11 @@ Status::~Status()
 void Status::setType(StatusType type)
 {
 	Type = type;
-
-	const StatusTypeData & typeData = StatusTypeManager::instance()->statusTypeData(Type);
-	DisplayName = typeData.displayName();
-	Group = typeData.typeGroup();
 }
 
 bool Status::isDisconnected() const
 {
-	return StatusTypeGroupOffline == Group;
+	return StatusType::Offline == Type;
 }
 
 bool Status::operator < (const Status &compare) const
