@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,6 @@
 #include <QtCore/QObject>
 #include <QtCore/QUuid>
 
-#include "configuration/configuration-manager.h"
 #include "storage/manager-common.h"
 #include "storage/storable-object.h"
 
@@ -79,11 +78,11 @@ protected:
 	 * in @link ConfigurationManager @endlink singleton, so this class
 	 * will automatically store itself on each configuration flush request.
 	 */
-	Manager() :
+	explicit Manager(QObject *parent = nullptr) :
+			StorableObject{parent},
 			Mutex(QMutex::Recursive)
 	{
 		setState(StateNotLoaded);
-		ConfigurationManager::instance()->registerStorableObject(this);
 	}
 
 	/**
@@ -95,7 +94,6 @@ protected:
 	 */
 	virtual ~Manager()
 	{
-		ConfigurationManager::instance()->unregisterStorableObject(this);
 	}
 
 	QMutex & mutex()
@@ -252,14 +250,24 @@ protected:
 			QUuid uuid = storagePoint->point().attribute("uuid");
 			if (!uuid.isNull())
 			{
-				Item item = Item::loadStubFromStorage(storagePoint);
-				addItem(item);
+				Item item = loadStubFromStorage(storagePoint);
+				Items.insert(item.uuid(), item);
 			}
 		}
 
+		for (auto const &item : Items)
+		{
+			itemAboutToBeAdded(item);
+			itemAdded(item);
+			if (item.details())
+				registerItem(item);
+		}
+
 		loaded();
 	}
 
+	virtual Item loadStubFromStorage(const std::shared_ptr<StoragePoint> &storagePoint) = 0;
+
 	/**
 	 * @author Rafal 'Vogel' Malinowski
 	 * @short Stores all items to configuration file.
