@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,16 +19,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QtAlgorithms>
+#include "storable-object.h"
 
-#include "core/core.h"
 #include "storage/custom-properties.h"
 #include "storage/storage-point-factory.h"
 
-#include "storable-object.h"
+#include <QtCore/QtAlgorithms>
 
-StorableObject::StorableObject() :
-		State(StateNew)
+StorableObject::StorableObject(QObject *parent) :
+		QObject{parent},
+		State{StateNew}
 {
 	Properties = new CustomProperties();
 }
@@ -41,10 +38,20 @@ StorableObject::~StorableObject()
 	delete Properties;
 }
 
+void StorableObject::setStoragePointFactory(StoragePointFactory *storagePointFactory)
+{
+	m_storagePointFactory = storagePointFactory;
+}
+
+StoragePointFactory * StorableObject::storagePointFactory() const
+{
+	return m_storagePointFactory;
+}
+
 std::shared_ptr<StoragePoint> StorableObject::createStoragePoint()
 {
 	auto parent = storageParent();
-	return Core::instance()->storagePointFactory()->createStoragePoint(storageNodeName(), parent ? parent->storage().get() : nullptr);
+	return m_storagePointFactory->createStoragePoint(storageNodeName(), parent ? parent->storage().get() : nullptr);
 }
 
 void StorableObject::setStorage(const std::shared_ptr<StoragePoint> &storage)
@@ -132,3 +139,5 @@ CustomProperties * StorableObject::customProperties() const
 {
 	return Properties;
 }
+
+#include "moc_storable-object.cpp"
