@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,18 +19,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STORABLE_OBJECT_H
-#define STORABLE_OBJECT_H
+#pragma once
 
-#include <memory>
-
-#include <QtCore/QVariant>
-
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
 #include "storage/storage-point.h"
-
 #include "exports.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtCore/QVariant>
+#include <memory>
+#include <injeqt/injeqt.h>
+
 #define PROPERTY_DEC(type, fieldName) \
 	type fieldName;
 #define PROPERTY_DEF(type, getMethodName, setMethodName, fieldName) \
@@ -42,6 +39,7 @@
 	void setMethodName(type value) { ensureLoaded(); fieldName = value; }
 
 class CustomProperties;
+class StoragePointFactory;
 
 /**
  * @addtogroup Storage
@@ -79,7 +77,7 @@ class CustomProperties;
  * when storageNodeName is defined as:
  *
  * <pre>
- * return QLatin1String("Application");
+ * return QStringLiteral("Application");
  * </pre>
  *
  * will result in following XML structure:
@@ -103,8 +101,10 @@ class CustomProperties;
  * @link customProperties() @endlink getter. Storage mechanism for these values is described in
  * @link CustomProperties @endlink documentation.
  */
-class KADUAPI StorableObject
+class KADUAPI StorableObject : public QObject
 {
+	Q_OBJECT
+
 public:
 	/**
 	 * @enum StorableObjectState
@@ -134,11 +134,18 @@ public:
 	};
 
 private:
+	QPointer<StoragePointFactory> m_storagePointFactory;
+
 	std::shared_ptr<StoragePoint> Storage;
 	StorableObjectState State;
 	CustomProperties *Properties;
 
+private slots:
+	INJEQT_SET void setStoragePointFactory(StoragePointFactory *storagePointFactory);
+
 protected:
+	StoragePointFactory * storagePointFactory() const;
+
 	/**
 	 * @author Rafal 'Vogel' Malinowski
 	 * @short Creates default storage point for object.
@@ -199,7 +206,7 @@ public:
 	 * Constructs object with @link<StorableObject::StateNew state @endlink and null
 	 * (invalid) @link<StorableObject::storage storage point @endlink.
 	 */
-	StorableObject();
+	explicit StorableObject(QObject *parent = nullptr);
 	virtual ~StorableObject();
 
 	/**
@@ -432,5 +439,3 @@ template<class T>
 /**
  * @}
  */
-
-#endif // STORABLE_OBJECT_H
