@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,25 +19,22 @@
 
 #pragma once
 
-#include <memory>
+#include "exports.h"
+
 #include <QtCore/QObject>
+#include <injeqt/injeqt.h>
+#include <memory>
 
 class StoragePoint;
-class XmlConfigFile;
 
-class StoragePointFactory : public QObject
+class KADUAPI StoragePointFactory : public QObject
 {
 	Q_OBJECT
 
 public:
-	explicit StoragePointFactory(QObject *parent = 0);
+	explicit StoragePointFactory(QObject *parent = nullptr);
 	virtual ~StoragePointFactory();
 
-	void setConfigurationFile(XmlConfigFile *configurationFile);
-
-	std::unique_ptr<StoragePoint> createStoragePoint(const QString &nodeName, StoragePoint *parent = 0);
-
-private:
-	XmlConfigFile *m_configurationFile;
+	virtual std::unique_ptr<StoragePoint> createStoragePoint(const QString &nodeName, StoragePoint *parent = 0) = 0;
 
 };
