@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,14 +18,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "hide-offline-without-description-talkable-filter.h"
+
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy.h"
 #include "contacts/contact.h"
 
-#include "hide-offline-without-description-talkable-filter.h"
-
 HideOfflineWithoutDescriptionTalkableFilter::HideOfflineWithoutDescriptionTalkableFilter(QObject *parent) :
-		TalkableFilter(parent), Enabled(false)
+		TalkableFilter(parent), m_enabled(false)
 {
 }
 
@@ -33,12 +33,17 @@ HideOfflineWithoutDescriptionTalkableFilter::~HideOfflineWithoutDescriptionTalka
 {
 }
 
+void HideOfflineWithoutDescriptionTalkableFilter::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
 TalkableFilter::FilterResult HideOfflineWithoutDescriptionTalkableFilter::filterBuddy(const Buddy &buddy)
 {
-	if (!Enabled)
+	if (!m_enabled)
 		return Undecided;
 
-	const Contact &contact = BuddyPreferredManager::instance()->preferredContact(buddy, false);
+	auto const &contact = m_buddyPreferredManager->preferredContact(buddy, false);
 	if (!contact)
 		return Rejected;
 
@@ -47,10 +52,10 @@ TalkableFilter::FilterResult HideOfflineWithoutDescriptionTalkableFilter::filter
 
 TalkableFilter::FilterResult HideOfflineWithoutDescriptionTalkableFilter::filterContact(const Contact &contact)
 {
-	if (!Enabled)
+	if (!m_enabled)
 		return Undecided;
 
-	const Status &status = contact.currentStatus();
+	auto const &status = contact.currentStatus();
 	if (status.isDisconnected() && status.description().isEmpty())
 		return Rejected;
 	else
@@ -59,10 +64,10 @@ TalkableFilter::FilterResult HideOfflineWithoutDescriptionTalkableFilter::filter
 
 void HideOfflineWithoutDescriptionTalkableFilter::setEnabled(bool enabled)
 {
-	if (Enabled == enabled)
+	if (m_enabled == enabled)
 		return;
 
-	Enabled = enabled;
+	m_enabled = enabled;
 	emit filterChanged();
 }
 
