@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,20 +17,23 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef HIDE_OFFLINE_WITHOUT_DESCRIPTION_TALKABLE_FILTER_H
-#define HIDE_OFFLINE_WITHOUT_DESCRIPTION_TALKABLE_FILTER_H
-
-#include <QtCore/QMetaType>
+#pragma once
 
 #include "talkable/filter/talkable-filter.h"
 
+#include <QtCore/QMetaType>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class BuddyPreferredManager;
+
 /**
  * @addtogroup Talkable
  * @{
  */
 
 /**
- * @class HideOfflineTalkableFilter
+ * @class HideOfflineWithoutDescriptionTalkableFilter
  * @author Rafał 'Vogel' Malinowski
  * @short Filter that removes items that are not available and have no description.
  *
@@ -44,15 +47,13 @@ class HideOfflineWithoutDescriptionTalkableFilter : public TalkableFilter
 {
 	Q_OBJECT
 
-	bool Enabled;
-
 public:
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Create new instance of HideOfflineWithoutDescriptionTalkableFilter with given parent.
 	 * @param parent QObject parent of new object
 	 */
-	explicit HideOfflineWithoutDescriptionTalkableFilter(QObject *parent = 0);
+	explicit HideOfflineWithoutDescriptionTalkableFilter(QObject *parent = nullptr);
 	virtual ~HideOfflineWithoutDescriptionTalkableFilter();
 
 	virtual FilterResult filterBuddy(const Buddy &buddy);
@@ -65,6 +66,14 @@ public:
 	 */
 	void setEnabled(bool enabled);
 
+private:
+	QPointer<BuddyPreferredManager> m_buddyPreferredManager;
+
+	bool m_enabled;
+
+private slots:
+	INJEQT_SET void setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager);
+
 };
 
 /**
@@ -72,5 +81,3 @@ public:
  */
 
 Q_DECLARE_METATYPE(HideOfflineWithoutDescriptionTalkableFilter *)
-
-#endif // HIDE_OFFLINE_WITHOUT_DESCRIPTION_TALKABLE_FILTER_H
