@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -116,7 +113,7 @@ public:
 	 * @param mode mode controlling return value when given item matches name
 	 * @param parent QObject parent of new object
 	 */
-	explicit NameTalkableFilter(NameFilterMatchingMode mode, QObject *parent = 0);
+	explicit NameTalkableFilter(NameFilterMatchingMode mode, QObject *parent = nullptr);
 	virtual ~NameTalkableFilter();
 
 	virtual FilterResult filterChat(const Chat &chat);
