@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -77,7 +78,7 @@ public:
 	 * @short Create new instance of TalkableFilter with given parent.
 	 * @param parent QObject parent of new object
 	 */
-	explicit TalkableFilter(QObject *parent = 0);
+	explicit TalkableFilter(QObject *parent = nullptr);
 	virtual ~TalkableFilter();
 
 	/**
