@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -49,7 +45,7 @@ public:
 	 * @short Create new instance of UnreadMessagesTalkableFilter with given parent.
 	 * @param parent QObject parent of new object
 	 */
-	explicit UnreadMessagesTalkableFilter(QObject *parent = 0);
+	explicit UnreadMessagesTalkableFilter(QObject *parent = nullptr);
 	virtual ~UnreadMessagesTalkableFilter();
 
 	virtual FilterResult filterChat(const Chat &chat);
