@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,14 +17,20 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TALKABLE_MODEL_H
-#define TALKABLE_MODEL_H
+#pragma once
 
+#include "misc/memory.h"
 #include "model/kadu-merged-proxy-model.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class BuddyListModel;
 class BuddyManagerAdapter;
 class ChatListModel;
+class ChatManager;
+class InjectedFactory;
+class Myself;
 
 /**
  * @addtogroup Talkable
@@ -43,18 +49,13 @@ class TalkableModel : public KaduMergedProxyModel
 {
 	Q_OBJECT
 
-	ChatListModel *Chats;
-	BuddyListModel *Buddies;
-	BuddyManagerAdapter *BuddiesAdapter;
-	bool IncludeMyself;
-
 public:
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Create new instance of TalkableModel with given parent.
 	 * @param parent QObject parent of new object
 	 */
-	explicit TalkableModel(QObject *parent = 0);
+	explicit TalkableModel(QObject *parent = nullptr);
 	virtual ~TalkableModel();
 
 	/**
@@ -77,10 +78,24 @@ public:
 	 */
 	bool includeMyself() const;
 
+private:
+	QPointer<ChatManager> m_chatManager;
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<Myself> m_myself;
+
+	owned_qptr<ChatListModel> m_chats;
+	owned_qptr<BuddyListModel> m_buddies;
+	owned_qptr<BuddyManagerAdapter> m_buddiesAdapter;
+	bool m_includeMyself;
+
+private slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setMyself(Myself *myself);
+	INJEQT_INIT void init();
+
 };
 
 /**
  * @}
  */
-
-#endif // TALKABLE_MODEL_H
