@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
@@ -23,6 +23,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "talkable-proxy-model.h"
+
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy.h"
 #include "chat/chat.h"
@@ -33,10 +35,26 @@
 #include "status/status.h"
 #include "talkable/filter/talkable-filter.h"
 
-#include "talkable-proxy-model.h"
-
 TalkableProxyModel::TalkableProxyModel(QObject *parent) :
 		QSortFilterProxyModel(parent), SortByStatusAndUnreadMessages(true)
+{
+}
+
+TalkableProxyModel::~TalkableProxyModel()
+{
+}
+
+void TalkableProxyModel::setBuddyPreferredManager(BuddyPreferredManager *buddyPreferredManager)
+{
+	m_buddyPreferredManager = buddyPreferredManager;
+}
+
+void TalkableProxyModel::setChatDataExtractor(ChatDataExtractor *chatDataExtractor)
+{
+	m_chatDataExtractor = chatDataExtractor;
+}
+
+void TalkableProxyModel::init()
 {
 	setDynamicSortFilter(true);
 	sort(0);
@@ -46,10 +64,6 @@ TalkableProxyModel::TalkableProxyModel(QObject *parent) :
 		fprintf(stderr, "There's something wrong with native string compare function. Applying workaround (slower).\n");
 }
 
-TalkableProxyModel::~TalkableProxyModel()
-{
-}
-
 void TalkableProxyModel::setSortByStatusAndUnreadMessages(bool sortByStatusAndUnreadMessages)
 {
 	if (SortByStatusAndUnreadMessages == sortByStatusAndUnreadMessages)
@@ -75,8 +89,8 @@ bool TalkableProxyModel::lessThan(const Chat &left, const Chat &right) const
 	if (left.unreadMessagesCount() == 0 && right.unreadMessagesCount() > 0)
 		return false;
 
-	const QString &leftChatDisplay = ChatDataExtractor::data(left, Qt::DisplayRole).toString();
-	const QString &rightChatDisplay = ChatDataExtractor::data(right, Qt::DisplayRole).toString();
+	const QString &leftChatDisplay = m_chatDataExtractor->data(left, Qt::DisplayRole).toString();
+	const QString &rightChatDisplay = m_chatDataExtractor->data(right, Qt::DisplayRole).toString();
 
 	return lessThan(leftChatDisplay, rightChatDisplay);
 }
@@ -108,8 +122,8 @@ bool TalkableProxyModel::lessThan(const Buddy &left, const Buddy &right) const
 		if (left.isAnonymous() && !right.isAnonymous())
 			return false;
 
-		const Contact &leftContact = BuddyPreferredManager::instance()->preferredContact(left, false);
-		const Contact &rightContact = BuddyPreferredManager::instance()->preferredContact(right, false);
+		const Contact &leftContact = m_buddyPreferredManager->preferredContact(left, false);
+		const Contact &rightContact = m_buddyPreferredManager->preferredContact(right, false);
 
 		if (!leftContact.isBlocking() && rightContact.isBlocking())
 			return true;
