@@ -2,13 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,20 +20,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "icon-theme-manager.h"
+
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "misc/paths-provider.h"
+
 #include <QtCore/QFileInfo>
 #include <QtCore/QStringList>
 
-#include "misc/kadu-paths.h"
-
-#include "icon-theme-manager.h"
-
 QString IconThemeManager::defaultTheme()
 {
-	return QLatin1String("default");
+	return QStringLiteral("default");
 }
 
 IconThemeManager::IconThemeManager(QObject *parent) :
-		ThemeManager(parent)
+		ThemeManager{parent}
 {
 }
 
@@ -46,6 +43,23 @@ IconThemeManager::~IconThemeManager()
 {
 }
 
+void IconThemeManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void IconThemeManager::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void IconThemeManager::init()
+{
+	loadThemes();
+	setCurrentTheme(m_configuration->deprecatedApi()->readEntry("Look", "IconTheme"));
+	m_configuration->deprecatedApi()->writeEntry("Look", "IconTheme", currentTheme().name());
+}
+
 QString IconThemeManager::defaultThemeName() const
 {
 	return defaultTheme();
@@ -54,15 +68,15 @@ QString IconThemeManager::defaultThemeName() const
 QStringList IconThemeManager::defaultThemePaths() const
 {
 	// Allow local themes to override global ones.
-	QStringList result = getSubDirs(KaduPaths::instance()->profilePath() + QLatin1String("icons"));
-	result += getSubDirs(KaduPaths::instance()->dataPath() + QLatin1String("themes/icons"));
+	auto result = getSubDirs(m_pathsProvider->profilePath() + QStringLiteral("icons"));
+	result += getSubDirs(m_pathsProvider->dataPath() + QStringLiteral("themes/icons"));
 
 	return result;
 }
 
 bool IconThemeManager::isValidThemePath(const QString &themePath) const
 {
-	QString kaduIconFileName = themePath + "/kadu_icons/64x64/kadu.png";
+	auto kaduIconFileName = themePath + "/kadu_icons/64x64/kadu.png";
 	QFileInfo kaduIconFile(kaduIconFileName);
 
 	return kaduIconFile.exists();
