@@ -4,12 +4,10 @@
  * Copyright 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2008, 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2003, 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2008, 2009, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2006, 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2008, 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -33,8 +31,12 @@
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/injected-factory.h"
+#include "core/version-service.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/updates-dialog.h"
 #include "debug.h"
@@ -44,15 +46,48 @@
 Updates::Updates(QObject *parent) :
 		QObject(parent), UpdateChecked{false}
 {
-	kdebugf();
-	buildQuery();
-	triggerAllAccountsRegistered();
 }
 
 Updates::~Updates()
 {
 }
 
+void Updates::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void Updates::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void Updates::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void Updates::setInjectedFactory(InjectedFactory *injectedFactory)
+{
+	m_injectedFactory = injectedFactory;
+}
+
+void Updates::setMainWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void Updates::setVersionService(VersionService *versionService)
+{
+	m_versionService = versionService;
+}
+
+void Updates::init()
+{
+	buildQuery();
+	triggerAllAccountsRegistered(m_accountManager);
+}
+
 void Updates::accountRegistered(Account account)
 {
 	connect(account, SIGNAL(connected()), this, SLOT(run()));
@@ -65,9 +100,9 @@ void Updates::accountUnregistered(Account account)
 
 void Updates::buildQuery()
 {
-	Query = QString("/update-new.php?uuid=%1&version=%2").arg(ConfigurationManager::instance()->uuid().toString()).arg(Core::version());
+	Query = QString("/update-new.php?uuid=%1&version=%2").arg(m_configurationManager->uuid().toString()).arg(m_versionService->version());
 
-	if (config_file.readBoolEntry("General", "SendSysInfo"), true)
+	if (m_configuration->deprecatedApi()->readBoolEntry("General", "SendSysInfo"), true)
 	{
 		QString platform("&system=");
 #if defined(Q_OS_LINUX)
@@ -91,26 +126,7 @@ void Updates::buildQuery()
 		platform.append("OpenBSD");
 #elif defined(Q_OS_SOLARIS)
 		platform.append("Solaris");
-#elif defined(Q_OS_MAC)
-		switch (QSysInfo::MacintoshVersion)
-		{
-			case QSysInfo::MV_PANTHER:
-				platform.append("MacOSX-Panther");
-				break;
-			case QSysInfo::MV_TIGER:
-				platform.append("MacOSX-Tiger");
-				break;
-			case QSysInfo::MV_LEOPARD:
-				platform.append("MacOSX-Leopard");
-				break;
-			case QSysInfo::MV_SNOWLEOPARD:
-				platform.append("MacOSX-SnowLeopard");
-				break;
-			default:
-				platform.append("MacOSX-Unknown");
-				break;
-		}
-#elif defined(Q_OS_WIN32)
+#elif defined(Q_OS_WIN)
 		switch (QSysInfo::WindowsVersion)
 		{
 			case QSysInfo::WV_95:
@@ -166,12 +182,12 @@ void Updates::run()
 	connect(manager, SIGNAL(finished(QNetworkReply*)),
 			this, SLOT(gotUpdatesInfo(QNetworkReply*)));
 
-	manager->get(QNetworkRequest{QUrl{QLatin1String{"http://www.kadu.im"} + Query}});
+	manager->get(QNetworkRequest{QUrl{QStringLiteral("http://www.kadu.im") + Query}});
 }
 
 bool Updates::isNewerVersionThan(const QString &version)
 {
-	QStringList thisVersion = stripVersion(Core::version()).split('.');
+	QStringList thisVersion = stripVersion(m_versionService->version()).split('.');
 	QStringList queryVersion = stripVersion(version).split('.');
 
 	for (int i = 0, end = qMin(thisVersion.size(), queryVersion.size()); i < end; ++i)
@@ -210,7 +226,7 @@ void Updates::gotUpdatesInfo(QNetworkReply *reply)
 	reply->deleteLater();
 	deleteLater();
 
-	if (config_file.readBoolEntry("General", "CheckUpdates"))
+	if (m_configuration->deprecatedApi()->readBoolEntry("General", "CheckUpdates"))
 	{
 		auto newestVersion = QString::fromUtf8(reply->readAll());
 		if (newestVersion.size() > 31)
@@ -221,7 +237,7 @@ void Updates::gotUpdatesInfo(QNetworkReply *reply)
 
 		if (isNewerVersionThan(newestVersion))
 		{
-			UpdatesDialog *dialog = new UpdatesDialog(newestVersion, Core::instance()->kaduWindow());
+			auto dialog = m_injectedFactory->makeInjected<UpdatesDialog>(newestVersion, m_kaduWindowService->kaduWindow());
 			dialog->show();
 		}
 	}
