@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,22 +17,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "dom/ignore-links-dom-visitor.h"
-#include "url-handlers/mail-url-expander.h"
-
 #include "mail-url-dom-visitor-provider.h"
 
-MailUrlDomVisitorProvider::MailUrlDomVisitorProvider()
+#include "dom/ignore-links-dom-visitor.h"
+#include "misc/memory.h"
+#include "url-handlers/mail-url-expander.h"
+
+MailUrlDomVisitorProvider::MailUrlDomVisitorProvider() :
+	m_ignoreLinks{std::make_unique<MailUrlExpander>(QRegExp{"\\b[a-zA-Z0-9_\\.\\-]+@[a-zA-Z0-9\\-\\.]+\\.[a-zA-Z]{2,4}\\b"})}
 {
-	MailUrlExpander *expander = new MailUrlExpander(QRegExp("\\b[a-zA-Z0-9_\\.\\-]+@[a-zA-Z0-9\\-\\.]+\\.[a-zA-Z]{2,4}\\b"));
-	IgnoreLinks.reset(new IgnoreLinksDomVisitor(expander));
 }
 
 MailUrlDomVisitorProvider::~MailUrlDomVisitorProvider()
 {
 }
 
-DomVisitor * MailUrlDomVisitorProvider::provide() const
+const DomVisitor * MailUrlDomVisitorProvider::provide() const
 {
-	return IgnoreLinks.data();
+	return &m_ignoreLinks;
 }
