@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -37,13 +33,11 @@ class MailUrlHandler : public UrlHandler
 public:
 	MailUrlHandler();
 
-	bool isUrlValid(const QByteArray &url);
-
-	void convertUrlsToHtml(HtmlDocument &document, bool generateOnlyHrefAttr);
-
-	void openUrl(const QByteArray &url, bool disableMenu);
+	virtual bool isUrlValid(const QByteArray &url);
+	virtual void openUrl(UrlOpener *urlOpener, const QByteArray &url, bool disableMenu = false);
 
 	const QRegExp & mailRegExp() { return MailRegExp; }
+
 };
 
 #endif // MAIL_URL_HANDLER_H
