@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,25 +17,25 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "standard-url-dom-visitor-provider.h"
+
 #include "dom/ignore-links-dom-visitor.h"
+#include "misc/memory.h"
 #include "url-handlers/standard-url-expander-configurator.h"
 #include "url-handlers/standard-url-expander.h"
 
-#include "standard-url-dom-visitor-provider.h"
-
-StandardUrlDomVisitorProvider::StandardUrlDomVisitorProvider()
+StandardUrlDomVisitorProvider::StandardUrlDomVisitorProvider(Configuration *configuration) :
+	m_ignoreLinks{std::make_unique<StandardUrlExpander>(QRegExp{"\\b(http://|https://|www\\.|ftp://)([^\\s]*)"})},
+	m_configurator{configuration}
 {
-	StandardUrlExpander *expander = new StandardUrlExpander(QRegExp("\\b(http://|https://|www\\.|ftp://)([^\\s]*)"));
-	IgnoreLinks.reset(new IgnoreLinksDomVisitor(expander));
-	Configurator.reset(new StandardUrlExpanderConfigurator());
-	Configurator->setStandardUrlExpander(expander);
+	m_configurator.setStandardUrlExpander(static_cast<StandardUrlExpander *>(m_ignoreLinks.visitor()));
 }
 
 StandardUrlDomVisitorProvider::~StandardUrlDomVisitorProvider()
 {
 }
 
-DomVisitor * StandardUrlDomVisitorProvider::provide() const
+const DomVisitor * StandardUrlDomVisitorProvider::provide() const
 {
-	return IgnoreLinks.data();
+	return &m_ignoreLinks;
 }
