@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,12 +31,12 @@ StandardUrlExpander::~StandardUrlExpander()
 {
 }
 
-bool StandardUrlExpander::shouldFold(int length)
+bool StandardUrlExpander::shouldFold(int length) const
 {
 	return Configuration.foldLink() && (length > Configuration.foldLinkThreshold());
 }
 
-QString StandardUrlExpander::displayLink(const QString &link)
+QString StandardUrlExpander::displayLink(const QString &link) const
 {
 	int partLength = Configuration.foldLinkThreshold() / 2;
 
@@ -51,7 +51,7 @@ void StandardUrlExpander::setConfiguration(const StandardUrlExpanderConfiguratio
 	Configuration = configuration;
 }
 
-QList<QDomNode> StandardUrlExpander::matchToDomNodes(QDomDocument document, QRegExp regExp)
+QList<QDomNode> StandardUrlExpander::matchToDomNodes(QDomDocument document, QRegExp regExp) const
 {
 	QDomElement linkElement = document.createElement("a");
 
