@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Marcel Zięba (marseel@marseel-F3Sg.(none))
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2012 Marcel Zięba (marseel@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,29 +25,21 @@
 
 #include <QtCore/QRegExp>
 
-#include "configuration/configuration-aware-object.h"
-#include "configuration/configuration-holder.h"
 #include "url-handler.h"
 
-class StandardUrlHandler : public UrlHandler, public ConfigurationHolder
+class StandardUrlHandler : public UrlHandler
 {
 	QRegExp UrlRegExp;
-	int LinkFoldTreshold;
-	bool FoldLink;
-
-protected:
-	void configurationUpdated();
 
 public:
 	StandardUrlHandler();
+	virtual ~StandardUrlHandler();
 
-	bool isUrlValid(const QByteArray &url);
-
-	void convertUrlsToHtml(HtmlDocument &document, bool generateOnlyHrefAttr);
-
-	void openUrl(const QByteArray &url, bool disableMenu = false);
+	virtual bool isUrlValid(const QByteArray &url);
+	virtual void openUrl(UrlOpener *urlOpener, const QByteArray &url, bool disableMenu = false);
 
 	const QRegExp &urlRegExp() { return UrlRegExp; }
+
 };
 
 #endif // STANDARD_URL_HANDLER_H
