@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,6 +22,8 @@
 #ifndef URL_HANDLER_H
 #define URL_HANDLER_H
 
+class UrlOpener;
+
 class QByteArray;
 class QDomDocument;
 
@@ -32,7 +33,7 @@ public:
 	virtual ~UrlHandler() {}
 
 	virtual bool isUrlValid(const QByteArray &url) = 0;
-	virtual void openUrl(const QByteArray &url, bool disableMenu = false) = 0;
+	virtual void openUrl(UrlOpener *urlOpener, const QByteArray &url, bool disableMenu = false) = 0;
 
 };
 
