@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,46 +19,27 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QListWidget>
-#include <QtGui/QPushButton>
-#include <QtGui/QSpinBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QSpinBox>
 
+#include "core/core.h"
+#include "core/core.h"
+#include "configuration/gui/configuration-ui-handler-repository.h"
 #include "gui/widgets/configuration/config-group-box.h"
 #include "gui/widgets/configuration/configuration-widget.h"
-#include "misc/kadu-paths.h"
+#include "gui/windows/main-configuration-window.h"
+#include "misc/paths-provider.h"
 
 #include "antistring-configuration.h"
-#include "antistring.h"
 
 #include "antistring-configuration-ui-handler.h"
 
-AntistringConfigurationUiHandler * AntistringConfigurationUiHandler::Instance = 0;
-
-void AntistringConfigurationUiHandler::registerUiHandler()
-{
-	if (!Instance)
-	{
-		Instance = new AntistringConfigurationUiHandler();
-		MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/antistring.ui"));
-		MainConfigurationWindow::registerUiHandler(Instance);
-	}
-}
-
-void AntistringConfigurationUiHandler::unregisterUiHandler()
-{
-	if (Instance)
-	{
-		MainConfigurationWindow::unregisterUiHandler(Instance);
-		MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/antistring.ui"));
-		delete Instance;
-		Instance = 0;
-	}
-}
-
-AntistringConfigurationUiHandler::AntistringConfigurationUiHandler() :
+AntistringConfigurationUiHandler::AntistringConfigurationUiHandler(QObject *parent) :
+		QObject{parent},
 		ConditionListWidget{}, ConditionWidget{}, FactorWidget{}
 {
 }
@@ -68,6 +48,11 @@ AntistringConfigurationUiHandler::~AntistringConfigurationUiHandler()
 {
 }
 
+void AntistringConfigurationUiHandler::setAntistringConfiguration(AntistringConfiguration *antistringConfiguration)
+{
+	m_antistringConfiguration = antistringConfiguration;
+}
+
 void AntistringConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
 {
 	ConfigGroupBox *groupBox = mainConfigurationWindow->widget()->configGroupBox("Chat", "Antistring", "Conditions");
@@ -110,11 +95,19 @@ void AntistringConfigurationUiHandler::mainConfigurationWindowCreated(MainConfig
 	connect(mainConfigurationWindow, SIGNAL(configurationWindowApplied()), this, SLOT(applyConfiguration()));
 }
 
+void AntistringConfigurationUiHandler::mainConfigurationWindowDestroyed()
+{
+}
+
+void AntistringConfigurationUiHandler::mainConfigurationWindowApplied()
+{
+}
+
 void AntistringConfigurationUiHandler::updateConditionList()
 {
 	ConditionListWidget->clear();
 
-	foreach (const ConditionPair &condition, Antistring::instance()->configuration().conditions())
+	foreach (const ConditionPair &condition, m_antistringConfiguration->conditions())
 		ConditionListWidget->addItem(QString("(%1) %2").arg(condition.second).arg(condition.first));
 }
 
@@ -127,7 +120,7 @@ void AntistringConfigurationUiHandler::addCondition()
 		return;
 
 	ConditionListWidget->addItem(QString("(%1) %2").arg(factor).arg(condition));
-	Antistring::instance()->configuration().conditions().append(qMakePair(condition, factor));
+	m_antistringConfiguration->conditions().append(qMakePair(condition, factor));
 
 	FactorWidget->setValue(0);
 	ConditionWidget->clear();
@@ -144,11 +137,11 @@ void AntistringConfigurationUiHandler::changeCondition()
 	if (condition.isEmpty())
 		return;
 
-	if (index < 0 || index >= Antistring::instance()->configuration().conditions().count())
+	if (index < 0 || index >= m_antistringConfiguration->conditions().count())
 		return;
 
 	item->setText(QString("(%1) %2").arg(factor).arg(condition));
-	Antistring::instance()->configuration().conditions()[index] = qMakePair(condition, factor);
+	m_antistringConfiguration->conditions()[index] = qMakePair(condition, factor);
 
 	FactorWidget->setValue(0);
 	ConditionWidget->clear();
@@ -158,17 +151,17 @@ void AntistringConfigurationUiHandler::deleteCondition()
 {
 	int index = ConditionListWidget->currentIndex().row();
 
-	if (index < 0 || index >= Antistring::instance()->configuration().conditions().count())
+	if (index < 0 || index >= m_antistringConfiguration->conditions().count())
 		return;
 
-	Antistring::instance()->configuration().conditions().removeAt(index);
+	m_antistringConfiguration->conditions().removeAt(index);
 
 	updateConditionList();
 }
 
 void AntistringConfigurationUiHandler::applyConfiguration()
 {
-	Antistring::instance()->configuration().storeConditions();
+	m_antistringConfiguration->storeConditions();
 }
 
 void AntistringConfigurationUiHandler::wordSelected(QListWidgetItem *item)
@@ -176,14 +169,14 @@ void AntistringConfigurationUiHandler::wordSelected(QListWidgetItem *item)
 	Q_UNUSED(item)
 
 	int index = ConditionListWidget->currentIndex().row();
-	if (index < 0 || index >= Antistring::instance()->configuration().conditions().count())
+	if (index < 0 || index >= m_antistringConfiguration->conditions().count())
 	{
 		FactorWidget->setValue(0);
 		ConditionWidget->clear();
 		return;
 	}
 
-	ConditionPair condition = Antistring::instance()->configuration().conditions().at(index);
+	ConditionPair condition = m_antistringConfiguration->conditions().at(index);
 
 	FactorWidget->setValue(condition.second);
 	ConditionWidget->setText(condition.first);
