@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,33 +17,45 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ANTISTRING_CONFIGURATION_UI_HANDLER_H
-#define ANTISTRING_CONFIGURATION_UI_HANDLER_H
+#pragma once
 
-#include "gui/windows/main-configuration-window.h"
+#include "configuration/gui/configuration-ui-handler.h"
+
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class AntistringConfiguration;
 
 class QLineEdit;
 class QListWidget;
 class QListWidgetItem;
 class QSpinBox;
 
-class AntistringConfigurationUiHandler : public ConfigurationUiHandler
+class AntistringConfigurationUiHandler : public QObject, public ConfigurationUiHandler
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(AntistringConfigurationUiHandler)
 
-	static AntistringConfigurationUiHandler *Instance;
+public:
+	Q_INVOKABLE AntistringConfigurationUiHandler(QObject *parent = nullptr);
+	virtual ~AntistringConfigurationUiHandler();
 
 	QListWidget *ConditionListWidget;
 	QLineEdit *ConditionWidget;
 	QSpinBox *FactorWidget;
 
-	AntistringConfigurationUiHandler();
-	virtual ~AntistringConfigurationUiHandler();
-
 	void updateConditionList();
 
+protected:
+	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow) override;
+	virtual void mainConfigurationWindowDestroyed() override;
+	virtual void mainConfigurationWindowApplied() override;
+
+private:
+	QPointer<AntistringConfiguration> m_antistringConfiguration;
+
 private slots:
+	INJEQT_SET void setAntistringConfiguration(AntistringConfiguration *antistringConfiguration);
+
 	void addCondition();
 	void changeCondition();
 	void deleteCondition();
@@ -55,15 +64,4 @@ private slots:
 
 	void wordSelected(QListWidgetItem *item);
 
-public:
-	static void registerUiHandler();
-	static void unregisterUiHandler();
-
-	static AntistringConfigurationUiHandler * instance() { return Instance; }
-
-public slots:
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
-
 };
-
-#endif // ANTISTRING_CONFIGURATION_UI_HANDLER_H
