@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,29 +18,48 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "antistring-configuration.h"
+
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/core.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "misc/paths-provider.h"
+#include "debug.h"
+
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
 
-#include "configuration/configuration-file.h"
-#include "misc/kadu-paths.h"
-#include "debug.h"
-
-#include "antistring-configuration.h"
-
-AntistringConfiguration::AntistringConfiguration()
+AntistringConfiguration::AntistringConfiguration(QObject *parent) :
+		QObject{parent}
 {
-	createDefaultConfiguration();
-	configurationUpdated();
 }
 
 AntistringConfiguration::~AntistringConfiguration()
 {
 }
 
+void AntistringConfiguration::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void AntistringConfiguration::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void AntistringConfiguration::init()
+{
+	createDefaultConfiguration();
+	configurationUpdated();
+}
+
 void AntistringConfiguration::createDefaultConfiguration()
 {
-	config_file.addVariable("PowerKadu", "log file", KaduPaths::instance()->profilePath() + QLatin1String("antistring.log"));
-	config_file.addVariable("PowerKadu", "admonish_tresc_config",
+	m_configuration->deprecatedApi()->addVariable("PowerKadu", "log file", m_pathsProvider->profilePath() + QStringLiteral("antistring.log"));
+	m_configuration->deprecatedApi()->addVariable("PowerKadu", "admonish_tresc_config",
 			"http://www.olsztyn.mm.pl/~silentman/lancuszki.htm");
 }
 
@@ -49,11 +67,11 @@ void AntistringConfiguration::configurationUpdated()
 {
 	readConditions();
 
-	Enabled = config_file.readBoolEntry("PowerKadu", "enable_antistring");
-	MessageStop = config_file.readBoolEntry("PowerKadu", "message stop");
-	LogMessage = config_file.readBoolEntry("PowerKadu", "log message");
-	ReturnMessage = config_file.readEntry("PowerKadu", "admonish_tresc_config");
-	LogFile = config_file.readEntry("PowerKadu", "log file", KaduPaths::instance()->profilePath() + QLatin1String("antistring.log"));
+	Enabled = m_configuration->deprecatedApi()->readBoolEntry("PowerKadu", "enable_antistring");
+	MessageStop = m_configuration->deprecatedApi()->readBoolEntry("PowerKadu", "message stop");
+	LogMessage = m_configuration->deprecatedApi()->readBoolEntry("PowerKadu", "log message");
+	ReturnMessage = normalizeHtml(HtmlString{m_configuration->deprecatedApi()->readEntry("PowerKadu", "admonish_tresc_config")});
+	LogFile = m_configuration->deprecatedApi()->readEntry("PowerKadu", "log file", m_pathsProvider->profilePath() + QStringLiteral("antistring.log"));
 }
 
 void AntistringConfiguration::addCondition(const QString &conditionString)
@@ -71,7 +89,7 @@ void AntistringConfiguration::addCondition(const QString &conditionString)
 
 void AntistringConfiguration::readDefaultConditions()
 {
-	QFile defaultListFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/data/antistring/ant_conditions.conf"));
+	QFile defaultListFile(m_pathsProvider->dataPath() + QStringLiteral("plugins/data/antistring/ant_conditions.conf"));
 	if (!defaultListFile.open(QFile::ReadOnly))
 	{
 		kdebug("Can't open file: %s\n", qPrintable(defaultListFile.fileName()));
@@ -90,7 +108,7 @@ void AntistringConfiguration::readConditions()
 {
 	Conditions.clear();
 
-	QString conditionsString = config_file.readEntry("PowerKadu", "antistring conditions");
+	QString conditionsString = m_configuration->deprecatedApi()->readEntry("PowerKadu", "antistring conditions");
 	QStringList conditionsList = conditionsString.split("\t\t");
 
 	if (conditionsList.empty())
@@ -110,5 +128,7 @@ void AntistringConfiguration::storeConditions()
 	foreach (const ConditionPair &condition, Conditions)
 		conditionsList.append(QString::number(condition.second) + '\t' + condition.first);
 
-	config_file.writeEntry("PowerKadu", "antistring conditions", conditionsList.join("\t\t"));
+	m_configuration->deprecatedApi()->writeEntry("PowerKadu", "antistring conditions", conditionsList.join("\t\t"));
 }
+
+#include "moc_antistring-configuration.cpp"
