@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,35 +17,28 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ANTISTRING_CONFIGURATION_H
-#define ANTISTRING_CONFIGURATION_H
-
-#include <QtCore/QList>
-#include <QtCore/QPair>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
+#include "html/normalized-html-string.h"
+
+#include <QtCore/QList>
+#include <QtCore/QObject>
+#include <QtCore/QPair>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 typedef QPair<QString, int> ConditionPair;
 
-class AntistringConfiguration : public ConfigurationAwareObject
+class Configuration;
+class PathsProvider;
+
+class AntistringConfiguration : public QObject, ConfigurationAwareObject
 {
-	QList<ConditionPair> Conditions;
-
-	bool Enabled;
-	bool MessageStop;
-	bool LogMessage;
-	QString ReturnMessage;
-	QString LogFile;
-
-	void createDefaultConfiguration();
-	void addCondition(const QString &conditionString);
-	void readDefaultConditions();
-
-protected:
-	virtual void configurationUpdated();
+	Q_OBJECT
 
 public:
-	AntistringConfiguration();
+	Q_INVOKABLE explicit AntistringConfiguration(QObject *parent = nullptr);
 	virtual ~AntistringConfiguration();
 
 	void readConditions();
@@ -58,9 +49,31 @@ public:
 	bool enabled() const { return Enabled; }
 	bool messageStop() const { return MessageStop; }
 	bool logMessage() const { return LogMessage; }
-	const QString & returnMessage() const { return ReturnMessage; }
+	const NormalizedHtmlString & returnMessage() const { return ReturnMessage; }
 	const QString & logFile() const { return LogFile; }
 
-};
+protected:
+	virtual void configurationUpdated();
 
-#endif // ANTISTRING_CONFIGURATION_H
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<PathsProvider> m_pathsProvider;
+
+	QList<ConditionPair> Conditions;
+
+	bool Enabled;
+	bool MessageStop;
+	bool LogMessage;
+	NormalizedHtmlString ReturnMessage;
+	QString LogFile;
+
+	void createDefaultConfiguration();
+	void addCondition(const QString &conditionString);
+	void readDefaultConditions();
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+	INJEQT_INIT void init();
+
+};
