@@ -42,14 +42,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>Antistring</name>
-    <message>
-        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
-</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>AntistringConfigurationUiHandler</name>
     <message>
@@ -78,7 +70,15 @@
     </message>
 </context>
 <context>
-    <name>AntistringNotification</name>
+    <name>AntistringMessageFilter</name>
+    <message>
+        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
+</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>AntistringNotificationService</name>
     <message>
         <source>Antistring</source>
         <translation type="unfinished"/>
