@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -42,15 +44,6 @@
         <translation>Antistring notifications</translation>
     </message>
 </context>
-<context>
-    <name>Antistring</name>
-    <message>
-        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
-</source>
-        <translation>     DATA AND TIME      ::   ID   ::    MESSAGE
-</translation>
-    </message>
-</context>
 <context>
     <name>AntistringConfigurationUiHandler</name>
     <message>
@@ -79,14 +72,23 @@
     </message>
 </context>
 <context>
-    <name>AntistringNotification</name>
+    <name>AntistringMessageFilter</name>
+    <message>
+        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
+</source>
+        <translation type="unfinished">     DATA AND TIME      ::   ID   ::    MESSAGE
+</translation>
+    </message>
+</context>
+<context>
+    <name>AntistringNotificationService</name>
     <message>
         <source>Antistring</source>
-        <translation>Antistring</translation>
+        <translation type="unfinished">Antistring</translation>
     </message>
     <message>
         <source>Your interlocutor send you love letter</source>
-        <translation>Your interlocutor send you love letter</translation>
+        <translation type="unfinished">Your interlocutor send you love letter</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
