@@ -42,15 +42,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>Antistring</name>
-    <message>
-        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
-</source>
-        <translation>     FECHA Y HORA      ::   ID   ::    MENSAJE
-</translation>
-    </message>
-</context>
 <context>
     <name>AntistringConfigurationUiHandler</name>
     <message>
@@ -79,14 +70,22 @@
     </message>
 </context>
 <context>
-    <name>AntistringNotification</name>
+    <name>AntistringMessageFilter</name>
+    <message>
+        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
+</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>AntistringNotificationService</name>
     <message>
         <source>Antistring</source>
-        <translation>Antistring</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Your interlocutor send you love letter</source>
-        <translation>Tu interlocutor te envio una carta de amor</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
