@@ -42,14 +42,6 @@
         <translation>Notifiche antistring</translation>
     </message>
 </context>
-<context>
-    <name>Antistring</name>
-    <message>
-        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
-</source>
-        <translation>DATA E TEMPO :: ID :: MESSAGGIO</translation>
-    </message>
-</context>
 <context>
     <name>AntistringConfigurationUiHandler</name>
     <message>
@@ -78,14 +70,22 @@
     </message>
 </context>
 <context>
-    <name>AntistringNotification</name>
+    <name>AntistringMessageFilter</name>
+    <message>
+        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
+</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>AntistringNotificationService</name>
     <message>
         <source>Antistring</source>
-        <translation>Antistring</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Your interlocutor send you love letter</source>
-        <translation>Il tuo interlocutore ti invia una lettera d&apos;amore</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
