@@ -42,15 +42,6 @@
         <translation>Powiadomienia antyłańcuszka</translation>
     </message>
 </context>
-<context>
-    <name>Antistring</name>
-    <message>
-        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
-</source>
-        <translation>     DATA I CZAS      ::   ID   ::    WIADOMOŚĆ
-</translation>
-    </message>
-</context>
 <context>
     <name>AntistringConfigurationUiHandler</name>
     <message>
@@ -79,7 +70,16 @@
     </message>
 </context>
 <context>
-    <name>AntistringNotification</name>
+    <name>AntistringMessageFilter</name>
+    <message>
+        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
+</source>
+        <translation>     DATA I CZAS      ::   ID   ::    WIADOMOŚĆ
+</translation>
+    </message>
+</context>
+<context>
+    <name>AntistringNotificationService</name>
     <message>
         <source>Antistring</source>
         <translation>Antyłańcuszek</translation>
