@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -7,7 +9,10 @@
     </message>
     <message numerus="yes">
         <source>%n second(s)</source>
-        <translation><numerusform>%n second</numerusform><numerusform>%n seconds</numerusform></translation>
+        <translation>
+            <numerusform>%n second</numerusform>
+            <numerusform>%n seconds</numerusform>
+        </translation>
     </message>
     <message>
         <source>Buddies list</source>
@@ -27,10 +32,10 @@
     </message>
 </context>
 <context>
-    <name>AutoHide</name>
+    <name>AutoHideConfigurationUiHandler</name>
     <message>
         <source>Don&apos;t hide</source>
-        <translation>Don&apos;t hide</translation>
+        <translation type="unfinished">Don&apos;t hide</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
