@@ -27,7 +27,7 @@
     </message>
 </context>
 <context>
-    <name>AutoHide</name>
+    <name>AutoHideConfigurationUiHandler</name>
     <message>
         <source>Don&apos;t hide</source>
         <translation>No ocultar</translation>
