@@ -27,10 +27,10 @@
     </message>
 </context>
 <context>
-    <name>AutoHide</name>
+    <name>AutoHideConfigurationUiHandler</name>
     <message>
         <source>Don&apos;t hide</source>
-        <translation>Não esconder</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
