@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2009, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,28 +18,41 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "status/status-type-data.h"
+#include "status/status-type-manager.h"
 #include "status/status.h"
 
 #include "autoaway.h"
 
 #include "autoaway-status-changer.h"
 
-AutoAwayStatusChanger::AutoAwayStatusChanger(AutoAway *autoawayController, QObject *parent) :
-		StatusChanger(900, parent), AutoawayController(autoawayController)
+AutoawayStatusChanger::AutoawayStatusChanger(QObject *parent) :
+		StatusChanger{900, parent}
 {
 }
 
-AutoAwayStatusChanger::~AutoAwayStatusChanger()
+AutoawayStatusChanger::~AutoawayStatusChanger()
 {
 }
 
-void AutoAwayStatusChanger::changeStatus(StatusContainer *container, Status &status)
+void AutoawayStatusChanger::setAutoaway(Autoaway *autoaway)
+{
+	m_autoaway = autoaway;
+}
+
+void AutoawayStatusChanger::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void AutoawayStatusChanger::changeStatus(StatusContainer *container, Status &status)
 {
 	Q_UNUSED(container)
 
-	ChangeStatusTo changeStatusTo = AutoawayController->changeStatusTo();
-	ChangeDescriptionTo changeDescriptionTo = AutoawayController->changeDescriptionTo();
-	QString descriptionAddon = AutoawayController->descriptionAddon();
+	auto changeStatusTo = m_autoaway->changeStatusTo();
+	auto changeDescriptionTo = m_autoaway->changeDescriptionTo();
+	auto descriptionAddon = m_autoaway->descriptionAddon();
+	auto group = m_statusTypeManager->statusTypeData(status.type()).typeGroup();
 
 	if (changeStatusTo == NoChangeStatus)
 		return;
@@ -51,7 +60,7 @@ void AutoAwayStatusChanger::changeStatus(StatusContainer *container, Status &sta
 	if (status.isDisconnected())
 		return;
 
-	QString description = status.description();
+	auto description = status.description();
 	switch (changeDescriptionTo)
 	{
 		case NoChangeDescription:
@@ -72,40 +81,40 @@ void AutoAwayStatusChanger::changeStatus(StatusContainer *container, Status &sta
 
 	if (changeStatusTo == ChangeStatusToOffline)
 	{
-		status.setType(StatusTypeOffline);
+		status.setType(StatusType::Offline);
 		status.setDescription(description);
 		return;
 	}
 
-	if (status.group() == StatusTypeGroupInvisible)
+	if (group == StatusTypeGroup::Invisible)
 		return;
 
 	if (changeStatusTo == ChangeStatusToInvisible)
 	{
-		status.setType(StatusTypeInvisible);
+		status.setType(StatusType::Invisible);
 		status.setDescription(description);
 		return;
 	}
 
-	if (status.group() == StatusTypeGroupAway)
+	if (group == StatusTypeGroup::Away)
 		return;
 
 	if (changeStatusTo == ChangeStatusToAway)
 	{
-		status.setType(StatusTypeAway);
+		status.setType(StatusType::Away);
 		status.setDescription(description);
 		return;
 	}
 
 	if (changeStatusTo == ChangeStatusToExtendedAway)
 	{
-		status.setType(StatusTypeNotAvailable);
+		status.setType(StatusType::NotAvailable);
 		status.setDescription(description);
 		return;
 	}
 }
 
-void AutoAwayStatusChanger::update()
+void AutoawayStatusChanger::update()
 {
 	emit statusChanged(0); // for all status containers
 }
