@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2009, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,18 +18,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef AUTOAWAY_STATUS_CHANGER_H
-#define AUTOAWAY_STATUS_CHANGER_H
+#pragma once
 
 #include "status/status-changer.h"
 
-class AutoAway;
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
-class AutoAwayStatusChanger : public StatusChanger
+class Autoaway;
+class StatusTypeManager;
+
+class AutoawayStatusChanger : public StatusChanger
 {
 	Q_OBJECT
 
-	friend class AutoAway;
+	friend class Autoaway;
 
 public:
 	enum ChangeStatusTo {
@@ -50,17 +50,19 @@ public:
 		ChangeDescriptionAppend
 	};
 
-private:
-	AutoAway *AutoawayController;
-
-public:
-	explicit AutoAwayStatusChanger(AutoAway *autoawayController, QObject *parent = 0);
-	virtual ~AutoAwayStatusChanger();
+	Q_INVOKABLE explicit AutoawayStatusChanger(QObject *parent = nullptr);
+	virtual ~AutoawayStatusChanger();
 
 	virtual void changeStatus(StatusContainer *container, Status &status);
 
 	void update();
 
-};
+private:
+	QPointer<Autoaway> m_autoaway;
+	QPointer<StatusTypeManager> m_statusTypeManager;
 
-#endif // AUTOAWAY_STATUS_CHANGER_H
+private slots:
+	INJEQT_SET void setAutoaway(Autoaway *autoaway);
+	INJEQT_SET void setStatusTypeManager(StatusTypeManager *statusTypeManager);
+
+};
