@@ -91,10 +91,10 @@
     </message>
 </context>
 <context>
-    <name>AutoAway</name>
+    <name>AutoawayConfigurationUiHandler</name>
     <message>
         <source>Don&apos;t refresh</source>
-        <translation>Nicht erneuern</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
