@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -35,7 +37,10 @@
     </message>
     <message numerus="yes">
         <source>%n second(s)</source>
-        <translation><numerusform>%n second</numerusform><numerusform>%n seconds</numerusform></translation>
+        <translation>
+            <numerusform>%n second</numerusform>
+            <numerusform>%n seconds</numerusform>
+        </translation>
     </message>
     <message>
         <source>Do Not Change</source>
@@ -59,7 +64,10 @@
     </message>
     <message numerus="yes">
         <source>%n minute(s)</source>
-        <translation><numerusform>%n minute(s)</numerusform><numerusform>%n minute(s)</numerusform></translation>
+        <translation>
+            <numerusform>%n minute(s)</numerusform>
+            <numerusform>%n minute(s)</numerusform>
+        </translation>
     </message>
     <message>
         <source>Switch to &apos;auto extended away&apos;</source>
@@ -91,10 +99,10 @@
     </message>
 </context>
 <context>
-    <name>AutoAway</name>
+    <name>AutoawayConfigurationUiHandler</name>
     <message>
         <source>Don&apos;t refresh</source>
-        <translation>Don&apos;t refresh</translation>
+        <translation type="unfinished">Don&apos;t refresh</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
