@@ -91,7 +91,7 @@
     </message>
 </context>
 <context>
-    <name>AutoAway</name>
+    <name>AutoawayConfigurationUiHandler</name>
     <message>
         <source>Don&apos;t refresh</source>
         <translation>Yenileme</translation>
