@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,29 +18,35 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QLineEdit>
-
-#include "gui/widgets/configuration/configuration-widget.h"
-#include "misc/kadu-paths.h"
-
 #include "autoresponder-configuration-ui-handler.h"
 
-AutoresponderConfigurationUiHolder::AutoresponderConfigurationUiHolder(QObject *parent) :
-		ConfigurationUiHandler(parent)
+#include "gui/widgets/configuration/configuration-widget.h"
+#include "gui/windows/main-configuration-window.h"
+
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QLineEdit>
+
+AutoresponderConfigurationUiHandler::AutoresponderConfigurationUiHandler(QObject *parent) :
+		QObject{parent}
 {
-	MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/autoresponder.ui"));
 }
 
-AutoresponderConfigurationUiHolder::~AutoresponderConfigurationUiHolder()
+AutoresponderConfigurationUiHandler::~AutoresponderConfigurationUiHandler()
 {
-	MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/autoresponder.ui"));
 }
 
-void AutoresponderConfigurationUiHolder::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
+void AutoresponderConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
 {
-	QLineEdit *autoRespondTextLineEdit = qobject_cast<QLineEdit *>(mainConfigurationWindow->widget()->widgetById("autoresponder/autoRespondText"));
+	auto autoRespondTextLineEdit = qobject_cast<QLineEdit *>(mainConfigurationWindow->widget()->widgetById("autoresponder/autoRespondText"));
 	autoRespondTextLineEdit->setToolTip(QCoreApplication::translate("@default", MainConfigurationWindow::SyntaxText));
 }
 
+void AutoresponderConfigurationUiHandler::mainConfigurationWindowDestroyed()
+{
+}
+
+void AutoresponderConfigurationUiHandler::mainConfigurationWindowApplied()
+{
+}
+
 #include "moc_autoresponder-configuration-ui-handler.cpp"
