@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,14 +18,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef AUTORESPONDER_CONFIGURATOR_H
-#define AUTORESPONDER_CONFIGURATOR_H
-
-#include <QtCore/QPointer>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 
-class AutoResponder;
+#include "injeqt-type-roles.h"
+
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class AutoresponderMessageFilter;
+class Configuration;
 
 /**
  * @addtogroup Autoresponder
@@ -39,33 +38,37 @@ class AutoResponder;
 
 /**
  * @class AutoresponderConfigurator
- * @short Standard configuration setter for AutoResponder.
+ * @short Standard configuration setter for AutoresponderMessageFilter.
  * @author Rafał 'Vogel' Malinowski
  *
  * This class listens to changed in global configuration. After change is detected it updated configuration of given
- * AutoResponder with newly created AutoresponderConfiguration instance.
+ * AutoresponderMessageFilter with newly created AutoresponderConfiguration instance.
  */
-class AutoresponderConfigurator : private ConfigurationAwareObject
+class AutoresponderConfigurator : private QObject, ConfigurationAwareObject
 {
-	QPointer<AutoResponder> ConfigurableAutoresponder;
+	Q_OBJECT
+	INJEQT_TYPE_ROLE(SERVICE)
 
-	void createDefaultConfiguration();
+public:
+	Q_INVOKABLE explicit AutoresponderConfigurator(QObject *parent = nullptr);
+	virtual ~AutoresponderConfigurator();
 
 protected:
 	virtual void configurationUpdated();
 
-public:
-	/**
-	 * @short Sets AutoResponder to configure.
-	 * @author Rafał 'Vogel' Malinowski
-	 * @param autoresponder autoresponder to configured
-	 */
-	void setAutoresponder(AutoResponder *autoresponder);
+private:
+	QPointer<AutoresponderMessageFilter> m_autoresponderMessageFilter;
+	QPointer<Configuration> m_configuration;
+
+	void createDefaultConfiguration();
+
+private slots:
+	INJEQT_SET void setAutoresponderMessageFilter(AutoresponderMessageFilter *autoresponderMessageFilter);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_INIT void init();
 
 };
 
 /**
  * @}
  */
-
-#endif // AUTORESPONDER_CONFIGURATOR_H
