@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -42,13 +44,6 @@
         <translation>Choose Status</translation>
     </message>
 </context>
-<context>
-    <name>AutoResponder</name>
-    <message>
-        <source>KADU AUTORESPONDER:</source>
-        <translation>KADU AUTORESPONDER:</translation>
-    </message>
-</context>
 <context>
     <name>AutoresponderConfigurator</name>
     <message>
@@ -56,4 +51,11 @@
         <translation>I am busy.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>AutoresponderMessageFilter</name>
+    <message>
+        <source>KADU AUTORESPONDER:</source>
+        <translation type="unfinished">KADU AUTORESPONDER:</translation>
+    </message>
+</context>
+</TS>
