@@ -42,13 +42,6 @@
         <translation>Choisir l&apos;état</translation>
     </message>
 </context>
-<context>
-    <name>AutoResponder</name>
-    <message>
-        <source>KADU AUTORESPONDER:</source>
-        <translation>RÉPONDEUR AUTOMATIQUE KADU :</translation>
-    </message>
-</context>
 <context>
     <name>AutoresponderConfigurator</name>
     <message>
@@ -56,4 +49,11 @@
         <translation>Je suis occupé.</translation>
     </message>
 </context>
+<context>
+    <name>AutoresponderMessageFilter</name>
+    <message>
+        <source>KADU AUTORESPONDER:</source>
+        <translation>RÉPONDEUR AUTOMATIQUE KADU :</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
