@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,30 +19,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
+#include <QtWidgets/QAction>
 
+#include "gui/actions/actions.h"
 #include "gui/menu/menu-inventory.h"
 #include "gui/windows/kadu-window.h"
+#include "plugin/plugin-injected-factory.h"
 
-#include "autostatus.h"
+#include "autostatus-service.h"
 
 #include "autostatus-actions.h"
 
-AutostatusActions * AutostatusActions::Instance = 0;
-
-void AutostatusActions::createInstance()
-{
-	if (!Instance)
-		Instance = new AutostatusActions();
-}
-
-void AutostatusActions::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-AutostatusActions::AutostatusActions() :
+AutostatusActions::AutostatusActions(QObject *parent) :
+		QObject{parent},
 		AutostatusActionDescription{}
 {
 }
@@ -52,15 +40,45 @@ AutostatusActions::~AutostatusActions()
 {
 }
 
+void AutostatusActions::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void AutostatusActions::setAutostatusService(AutostatusService *autostatusService)
+{
+	m_autostatusService = autostatusService;
+}
+
+void AutostatusActions::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void AutostatusActions::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void AutostatusActions::init()
+{
+	registerActions();
+}
+
+void AutostatusActions::done()
+{
+	unregisterActions();
+}
+
 void AutostatusActions::registerActions()
 {
-	AutostatusActionDescription = new ActionDescription(this,
+	AutostatusActionDescription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeMainMenu, "autostatusAction",
 		this, SLOT(autostatusActionActivated(QAction *, bool)),
 		KaduIcon(), tr("&Autostatus"), true
 	);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("main")
 		->addAction(AutostatusActionDescription, KaduMenu::SectionMiscTools, 2)
 		->update();
@@ -68,7 +86,7 @@ void AutostatusActions::registerActions()
 
 void AutostatusActions::unregisterActions()
 {
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("main")
 		->removeAction(AutostatusActionDescription)
 		->update();
@@ -81,7 +99,7 @@ void AutostatusActions::autostatusActionActivated(QAction *action, bool toggled)
 {
 	Q_UNUSED(action)
 
-	Autostatus::instance()->toggle(toggled);
+	m_autostatusService->toggle(toggled);
 }
 
 #include "moc_autostatus-actions.cpp"
