@@ -17,39 +17,49 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef AUTOSTATUS_ACTIONS_H
-#define AUTOSTATUS_ACTIONS_H
+#pragma once
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
-class QAction;
+class AutostatusService;
 
 class ActionDescription;
+class Actions;
+class PluginInjectedFactory;
+class MenuInventory;
+
+class QAction;
 
 class AutostatusActions : public QObject
 {
 	Q_OBJECT
 
-	static AutostatusActions *Instance;
-
-	ActionDescription *AutostatusActionDescription;
-
-	AutostatusActions();
-	virtual ~AutostatusActions();
-
-private slots:
-	//! This slot is called when new Autostatus it starts
-	void autostatusActionActivated(QAction *, bool);
-
 public:
-	static void createInstance();
-	static void destroyInstance();
-
-	static AutostatusActions * instance() { return Instance; }
+	Q_INVOKABLE explicit AutostatusActions(QObject *parent = nullptr);
+	virtual ~AutostatusActions();
 
 	void registerActions();
 	void unregisterActions();
 
-};
+private:
+	QPointer<Actions> m_actions;
+	QPointer<AutostatusService> m_autostatusService;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<MenuInventory> m_menuInventory;
 
-#endif // AUTOSTATUS_ACTIONS_H
+	ActionDescription *AutostatusActionDescription;
+
+private slots:
+	INJEQT_SET void setActions(Actions *actions);
+	INJEQT_SET void setAutostatusService(AutostatusService *autostatusService);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setMenuInventory(MenuInventory *menuInventory);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
+	//! This slot is called when new Autostatus it starts
+	void autostatusActionActivated(QAction *, bool);
+
+};
