@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -63,13 +63,13 @@ void AutostatusStatusChanger::changeStatus(StatusContainer *container, Status &s
 	switch (StatusIndex)
 	{
 		case 0:
-			status.setType(StatusTypeOnline);
+			status.setType(StatusType::Online);
 			break;
 		case 1:
-			status.setType(StatusTypeAway);
+			status.setType(StatusType::Away);
 			break;
 		case 2:
-			status.setType(StatusTypeInvisible);
+			status.setType(StatusType::Invisible);
 			break;
 	}
 
