@@ -1,12 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,17 +17,20 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef AUTOSTATUS_STATUS_CHANGER_H
-#define AUTOSTATUS_STATUS_CHANGER_H
+#pragma once
 
 #include "status/status-changer.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class AutostatusStatusChanger : public StatusChanger
 {
 	Q_OBJECT
 
 	bool Enabled;
 
+	// TODO: we have enums in C++
 	// 0 - online
 	// 1 - budy
 	// 2 - invisible
@@ -41,7 +38,7 @@ class AutostatusStatusChanger : public StatusChanger
 	QString Description;
 
 public:
-	explicit AutostatusStatusChanger(QObject *parent = 0);
+	Q_INVOKABLE explicit AutostatusStatusChanger(QObject *parent = nullptr);
 	virtual ~AutostatusStatusChanger();
 
 	void setEnabled(bool enabled);
@@ -50,5 +47,3 @@ public:
 	virtual void changeStatus(StatusContainer *container, Status &status);
 
 };
-
-#endif // AUTOSTATUS_STATUS_CHANGER_H
