@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +18,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "cenzor-configuration.h"
+
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "misc/paths-provider.h"
+
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
 
-#include "configuration/configuration-file.h"
-#include "misc/kadu-paths.h"
-
-#include "cenzor-configuration.h"
-
 QStringList CenzorConfiguration::toStringList(const QList<QRegExp> &list)
 {
 	QStringList result;
@@ -43,15 +45,30 @@ QList<QRegExp> CenzorConfiguration::toRegExpList(const QStringList &list)
 	return result;
 }
 
-CenzorConfiguration::CenzorConfiguration()
+CenzorConfiguration::CenzorConfiguration(QObject *parent) :
+		QObject{parent}
 {
-	configurationUpdated();
 }
 
 CenzorConfiguration::~CenzorConfiguration()
 {
 }
 
+void CenzorConfiguration::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void CenzorConfiguration::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void CenzorConfiguration::init()
+{
+	configurationUpdated();
+}
+
 void CenzorConfiguration::setExclusionList(const QList<QRegExp> &exclusionList)
 {
 	ExclusionList = exclusionList;
@@ -64,7 +81,7 @@ void CenzorConfiguration::setSwearList(const QList<QRegExp> &swearList)
 
 QList<QRegExp> CenzorConfiguration::loadRegExpList(const QString &itemName, const QString &fileName)
 {
-	QList<QRegExp> result = toRegExpList(config_file.readEntry("PowerKadu", itemName).split('\t', QString::SkipEmptyParts));
+	QList<QRegExp> result = toRegExpList(m_configuration->deprecatedApi()->readEntry("PowerKadu", itemName).split('\t', QString::SkipEmptyParts));
 
 	if (!result.empty())
 		return result;
@@ -84,14 +101,16 @@ QList<QRegExp> CenzorConfiguration::loadRegExpList(const QString &itemName, cons
 
 void CenzorConfiguration::configurationUpdated()
 {
-	Enabled = config_file.readBoolEntry("PowerKadu", "enable_cenzor");
-	Admonition = config_file.readEntry("PowerKadu", "admonition_content_cenzor", "Cenzor: Watch your mouth!! <nonono>");
-	SwearList = loadRegExpList("cenzor swearwords", KaduPaths::instance()->dataPath() + QLatin1String("plugins/data/cenzor/cenzor_words.conf"));
-	ExclusionList = loadRegExpList("cenzor exclusions", KaduPaths::instance()->dataPath() + QLatin1String("plugins/data/cenzor/cenzor_words_ok.conf"));
+	Enabled = m_configuration->deprecatedApi()->readBoolEntry("PowerKadu", "enable_cenzor");
+	Admonition = normalizeHtml(HtmlString{m_configuration->deprecatedApi()->readEntry("PowerKadu", "admonition_content_cenzor", "Cenzor: Watch your mouth!! <nonono>")});
+	SwearList = loadRegExpList("cenzor swearwords", m_pathsProvider->dataPath() + QStringLiteral("plugins/data/cenzor/cenzor_words.conf"));
+	ExclusionList = loadRegExpList("cenzor exclusions", m_pathsProvider->dataPath() + QStringLiteral("plugins/data/cenzor/cenzor_words_ok.conf"));
 }
 
 void CenzorConfiguration::saveConfiguration()
 {
-	config_file.writeEntry("PowerKadu", "cenzor swearwords", toStringList(SwearList).join("\t"));
-	config_file.writeEntry("PowerKadu", "cenzor exclusions", toStringList(ExclusionList).join("\t"));
+	m_configuration->deprecatedApi()->writeEntry("PowerKadu", "cenzor swearwords", toStringList(SwearList).join("\t"));
+	m_configuration->deprecatedApi()->writeEntry("PowerKadu", "cenzor exclusions", toStringList(ExclusionList).join("\t"));
 }
+
+#include "moc_cenzor-configuration.cpp"
