@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +22,7 @@
 #define LIST_EDIT_WIDGET_H
 
 #include <QtCore/QModelIndex>
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class QLineEdit;
 class QListWidget;
@@ -45,7 +43,7 @@ private slots:
 	void deleteItem();
 
 public:
-	explicit ListEditWidget(QWidget *parent = 0);
+	explicit ListEditWidget(QWidget *parent = nullptr);
 	virtual ~ListEditWidget();
 
 	void setList(const QStringList &list);
