@@ -35,18 +35,18 @@
     </message>
 </context>
 <context>
-    <name>CenzorNotification</name>
+    <name>CenzorNotificationService</name>
+    <message>
+        <source>Cenzor</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Message was cenzored</source>
-        <translation>Nachricht wurde zensiert</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Your interlocutor used obscene word and became admonished</source>
-        <translation>Dein Gegenüber schimpft und wurde auf sein Fehlverhalten hingewiesen</translation>
-    </message>
-    <message>
-        <source>Cenzor</source>
-        <translation>Zensor</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
