@@ -35,7 +35,11 @@
     </message>
 </context>
 <context>
-    <name>CenzorNotification</name>
+    <name>CenzorNotificationService</name>
+    <message>
+        <source>Cenzor</source>
+        <translation>Censor</translation>
+    </message>
     <message>
         <source>Message was cenzored</source>
         <translation>El mensaje fue censurado</translation>
@@ -44,10 +48,6 @@
         <source>Your interlocutor used obscene word and became admonished</source>
         <translation>Su interlocultor usó palabra obscena y fue amonestado</translation>
     </message>
-    <message>
-        <source>Cenzor</source>
-        <translation>Censor</translation>
-    </message>
 </context>
 <context>
     <name>ListEditWidget</name>
