@@ -35,19 +35,19 @@
     </message>
 </context>
 <context>
-    <name>CenzorNotification</name>
+    <name>CenzorNotificationService</name>
+    <message>
+        <source>Cenzor</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Message was cenzored</source>
-        <translation>Mensagem foi censurada</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Your interlocutor used obscene word and became admonished</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Cenzor</source>
-        <translation>Censura</translation>
-    </message>
 </context>
 <context>
     <name>ListEditWidget</name>
