@@ -35,7 +35,11 @@
     </message>
 </context>
 <context>
-    <name>CenzorNotification</name>
+    <name>CenzorNotificationService</name>
+    <message>
+        <source>Cenzor</source>
+        <translation>Sansür</translation>
+    </message>
     <message>
         <source>Message was cenzored</source>
         <translation>Mesaj sansürlendi</translation>
@@ -44,10 +48,6 @@
         <source>Your interlocutor used obscene word and became admonished</source>
         <translation>Konuştuğunuz kişi kötü söz söylediği için uyarıldı</translation>
     </message>
-    <message>
-        <source>Cenzor</source>
-        <translation>Sansü</translation>
-    </message>
 </context>
 <context>
     <name>ListEditWidget</name>
