@@ -35,7 +35,11 @@
     </message>
 </context>
 <context>
-    <name>CenzorNotification</name>
+    <name>CenzorNotificationService</name>
+    <message>
+        <source>Cenzor</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Message was cenzored</source>
         <translation type="unfinished"/>
@@ -44,10 +48,6 @@
         <source>Your interlocutor used obscene word and became admonished</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Cenzor</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>ListEditWidget</name>
