@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,18 +19,20 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "chat-notifier.h"
+
 #include "contacts/contact-set.h"
 #include "formatted-string/formatted-string-factory.h"
 #include "gui/widgets/chat-widget/chat-widget-repository.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
 #include "message/message-manager.h"
-#include "notify/notification/aggregate-notification.h"
-#include "notify/notification/chat-notification.h"
-
-#include "chat-notifier.h"
+#include "notification/notification.h"
 
 ChatNotifier::ChatNotifier(QObject *parent) :
-		Notifier("ChatNotifier", QT_TRANSLATE_NOOP("@default", "Chat window notifications"), KaduIcon("protocols/common/message"), parent)
+		QObject{parent},
+		Notifier{"ChatNotifier", QT_TRANSLATE_NOOP("@default", "Chat window notifications"), KaduIcon("protocols/common/message")}
 {
 }
 
@@ -56,38 +56,32 @@ NotifierConfigurationWidget * ChatNotifier::createConfigurationWidget(QWidget* p
 	return 0;
 }
 
-void ChatNotifier::sendNotificationToChatWidget(Notification *notification, ChatWidget *chatWidget)
+void ChatNotifier::sendNotificationToChatWidget(const Notification &notification, ChatWidget *chatWidget)
 {
 	if (!m_formattedStringFactory)
 		return;
 
-	auto content = notification->text();
-	if (!notification->details().isEmpty())
-		content += "<br/> <small>" + notification->details().join("<br/>") + "</small>";
+	auto content = notification.details.string().isEmpty()
+		? notification.text
+		: normalizeHtml(HtmlString{"%1<br/> <small>%2</small>"}).arg(notification.text, notification.details);
 
-	chatWidget->appendSystemMessage(m_formattedStringFactory.data()->fromHtml(content));
+	chatWidget->appendSystemMessage(content);
 }
 
-void ChatNotifier::notify(Notification *notification)
+void ChatNotifier::notify(const Notification &notification)
 {
 	if (!m_chatWidgetRepository)
 		return;
 
-	auto aggregateNotification = qobject_cast<AggregateNotification *>(notification);
-	if (!aggregateNotification)
-		return;
-
-	auto latestNotification = aggregateNotification->notifications().last();
-
 	auto buddies = BuddySet();
-	auto chatNotification = qobject_cast<ChatNotification *>(latestNotification);
-	if (chatNotification)
-		buddies = chatNotification->chat().contacts().toBuddySet();
+	auto chat = notification.data["chat"].value<Chat>();
+	if (chat)
+		buddies = chat.contacts().toBuddySet();
 
 	for (auto chatWidget : m_chatWidgetRepository.data())
 		// warning: do not exchange intersect caller and argument, it will modify buddies variable if you do
 		if (buddies.isEmpty() || !chatWidget->chat().contacts().toBuddySet().intersect(buddies).isEmpty())
-			sendNotificationToChatWidget(latestNotification, chatWidget);
+			sendNotificationToChatWidget(notification, chatWidget);
 }
 
 #include "moc_chat-notifier.cpp"
