@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,33 +20,35 @@
 
 #pragma once
 
-#include <QtCore/QPointer>
+#include "notification/notifier.h"
 
-#include "notify/notifier.h"
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class ChatWidget;
 class ChatWidgetRepository;
 class FormattedStringFactory;
 
-class ChatNotifier : public Notifier
+class ChatNotifier : public QObject, public Notifier
 {
 	Q_OBJECT
 
 public:
-	explicit ChatNotifier(QObject *parent = 0);
+	Q_INVOKABLE explicit ChatNotifier(QObject *parent = nullptr);
 	virtual ~ChatNotifier();
 
-	void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
-	void setFormattedStringFactory(FormattedStringFactory *formattedStringFactory);
+	virtual NotifierConfigurationWidget * createConfigurationWidget(QWidget *parent = nullptr);
 
-	virtual NotifierConfigurationWidget * createConfigurationWidget(QWidget *parent = 0);
-
-	virtual void notify(Notification *notification);
+	virtual void notify(const Notification &notification);
 
 private:
 	QPointer<ChatWidgetRepository> m_chatWidgetRepository;
 	QPointer<FormattedStringFactory> m_formattedStringFactory;
 
-	void sendNotificationToChatWidget(Notification *notification, ChatWidget *chatWidget);
+	void sendNotificationToChatWidget(const Notification &notification, ChatWidget *chatWidget);
+
+private slots:
+	INJEQT_SET void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+	INJEQT_SET void setFormattedStringFactory(FormattedStringFactory *formattedStringFactory);
 
 };
