@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,33 +18,42 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QRadioButton>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QRadioButton>
 
 #include "accounts/account-manager.h"
 #include "gui/widgets/protocols-combo-box.h"
 #include "gui/windows/your-accounts.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "config-wizard-choose-network-page.h"
 
 ConfigWizardChooseNetworkPage::ConfigWizardChooseNetworkPage(QWidget *parent) :
 		ConfigWizardPage(parent), LastProtocol(0)
 {
-	setDescription(tr("<p>Please choose the network for the account that you would like to set up.</p><p>You can also create a new account in the wizard if you don't already have one</p>"));
-
-	createGui();
 }
 
 ConfigWizardChooseNetworkPage::~ConfigWizardChooseNetworkPage()
 {
 }
 
+void ConfigWizardChooseNetworkPage::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void ConfigWizardChooseNetworkPage::init()
+{
+	setDescription(tr("<p>Please choose the network for the account that you would like to set up.</p><p>You can also create a new account in the wizard if you don't already have one</p>"));
+	createGui();
+}
+
 void ConfigWizardChooseNetworkPage::createGui()
 {
 	formLayout()->addRow(new QLabel(tr("<h3>Account Setup</h3>"), this));
 
-	SelectProtocol = new ProtocolsComboBox(this);
+	SelectProtocol = m_pluginInjectedFactory->makeInjected<ProtocolsComboBox>(this);
 	connect(SelectProtocol, SIGNAL(currentIndexChanged(int)),
 			this, SLOT(protocolChanged()));
 
