@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,13 +18,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIG_WIZARD_CHOOSE_NETWORK_PAGE_H
-#define CONFIG_WIZARD_CHOOSE_NETWORK_PAGE_H
+#pragma once
 
 #include "gui/widgets/config-wizard-page.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class QRadioButton;
 
+class PluginInjectedFactory;
 class ProtocolFactory;
 class ProtocolsComboBox;
 
@@ -32,6 +35,16 @@ class ConfigWizardChooseNetworkPage : public ConfigWizardPage
 {
 	Q_OBJECT
 
+public:
+	explicit ConfigWizardChooseNetworkPage(QWidget *parent = nullptr);
+	virtual ~ConfigWizardChooseNetworkPage();
+
+public slots:
+	void protocolChanged();
+
+private:
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+
 	ProtocolFactory *LastProtocol;
 	ProtocolsComboBox *SelectProtocol;
 
@@ -41,13 +54,8 @@ class ConfigWizardChooseNetworkPage : public ConfigWizardPage
 
 	void createGui();
 
-public slots:
-	void protocolChanged();
-
-public:
-	explicit ConfigWizardChooseNetworkPage(QWidget *parent = 0);
-	virtual ~ConfigWizardChooseNetworkPage();
+private slots:
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_INIT void init();
 
 };
-
-#endif // CONFIG_WIZARD_CHOOSE_NETWORK_PAGE_H
