@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +18,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QCheckBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
+#include "config-wizard-completed-page.h"
 
 #include "accounts/account-manager.h"
-#include "gui/windows/your-accounts.h"
+#include "gui/windows/your-accounts-window-service.h"
 
-#include "config-wizard-completed-page.h"
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
 
 ConfigWizardCompletedPage::ConfigWizardCompletedPage(QWidget *parent) :
 		ConfigWizardPage(parent)
@@ -40,6 +39,16 @@ ConfigWizardCompletedPage::~ConfigWizardCompletedPage()
 {
 }
 
+void ConfigWizardCompletedPage::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void ConfigWizardCompletedPage::setYourAccountsWindowService(YourAccountsWindowService *yourAccountsWindowService)
+{
+	m_yourAccountsWindowService = yourAccountsWindowService;
+}
+
 void ConfigWizardCompletedPage::createGui()
 {
 	formLayout()->addRow(new QLabel(tr("<h3>Configuration Wizard Completed</h3>"), this));
@@ -51,13 +60,13 @@ void ConfigWizardCompletedPage::createGui()
 
 void ConfigWizardCompletedPage::initializePage()
 {
-	ConfigureAccouuntsCheckBox->setChecked(AccountManager::instance()->items().isEmpty());
+	ConfigureAccouuntsCheckBox->setChecked(m_accountManager->items().isEmpty());
 }
 
 void ConfigWizardCompletedPage::acceptPage()
 {
     if (ConfigureAccouuntsCheckBox->isChecked())
-		YourAccounts::instance()->show();
+		m_yourAccountsWindowService->show();
 }
 
 #include "moc_config-wizard-completed-page.cpp"
