@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,7 +21,7 @@
 #ifndef CONFIG_WIZARD_PAGE_H
 #define CONFIG_WIZARD_PAGE_H
 
-#include <QtGui/QWizardPage>
+#include <QtWidgets/QWizardPage>
 
 class QFormLayout;
 class QTextBrowser;
@@ -38,7 +39,7 @@ protected:
 	QFormLayout * formLayout() { return FormLayout; }
 
 public:
-	explicit ConfigWizardPage(QWidget *parent = 0);
+	explicit ConfigWizardPage(QWidget *parent = nullptr);
 	virtual ~ConfigWizardPage();
 
 	virtual void acceptPage();
