@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,21 +18,45 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QComboBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
 
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/myself.h"
 #include "languages-manager.h"
 
 #include "config-wizard-profile-page.h"
 
 ConfigWizardProfilePage::ConfigWizardProfilePage(QWidget *parent) :
 		ConfigWizardPage(parent)
+{
+}
+
+ConfigWizardProfilePage::~ConfigWizardProfilePage()
+{
+}
+
+void ConfigWizardProfilePage::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ConfigWizardProfilePage::setLanguagesManager(LanguagesManager *languagesManager)
+{
+	m_languagesManager = languagesManager;
+}
+
+void ConfigWizardProfilePage::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void ConfigWizardProfilePage::init()
 {
 	setDescription(tr("<h3>Welcome to Kadu Instant Messenger</h3>"
 		"<p>This wizard will help you to configure the basic settings of Kadu.</p>"
@@ -43,10 +65,6 @@ ConfigWizardProfilePage::ConfigWizardProfilePage(QWidget *parent) :
 	createGui();
 }
 
-ConfigWizardProfilePage::~ConfigWizardProfilePage()
-{
-}
-
 void ConfigWizardProfilePage::createGui()
 {
 	formLayout()->addRow(new QLabel(tr("<h3>Profile setup</h3>"), this));
@@ -68,27 +86,28 @@ void ConfigWizardProfilePage::createGui()
 
 void ConfigWizardProfilePage::setLanguages()
 {
-	for (QMap<QString, QString>::const_iterator it = LanguagesManager::languages().constBegin(), end = LanguagesManager::languages().constEnd(); it != end; ++it)
+	for (QMap<QString, QString>::const_iterator it = m_languagesManager->languages().constBegin(), end = m_languagesManager->languages().constEnd(); it != end; ++it)
 		LanguagesCombo->addItem(it.value(), it.key());
 }
 
 void ConfigWizardProfilePage::initializePage()
 {
-	int languageIndex = LanguagesCombo->findData(config_file.readEntry("General", "Language"));
+	int languageIndex = LanguagesCombo->findData(m_configuration->deprecatedApi()->readEntry("General", "Language"));
 	if (-1 == languageIndex)
 		languageIndex = LanguagesCombo->findData("en");
 	if (-1 != languageIndex)
 		LanguagesCombo->setCurrentIndex(languageIndex);
 
-	NickNameEdit->setText(config_file.readEntry("General", "Nick", "Me"));
+	NickNameEdit->setText(m_configuration->deprecatedApi()->readEntry("General", "Nick", "Me"));
 }
 
 void ConfigWizardProfilePage::acceptPage()
 {
-	config_file.writeEntry("General", "Language", LanguagesCombo->itemData(LanguagesCombo->currentIndex()).toString());
-	config_file.writeEntry("General", "Nick", NickNameEdit->text());
+	m_configuration->deprecatedApi()->writeEntry("General", "Language", LanguagesCombo->itemData(LanguagesCombo->currentIndex()).toString());
+	m_configuration->deprecatedApi()->writeEntry("General", "Nick", NickNameEdit->text());
 
-	Core::instance()->myself().setDisplay(NickNameEdit->text());
+	// TODO: check if needed
+	m_myself->buddy().setDisplay(NickNameEdit->text());
 }
 
 #include "moc_config-wizard-profile-page.cpp"
