@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,30 +18,25 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIG_WIZARD_SET_UP_ACCOUNT_PAGE_H
-#define CONFIG_WIZARD_SET_UP_ACCOUNT_PAGE_H
-
-#include <QtCore/QPointer>
+#pragma once
 
 #include "accounts/account.h"
 #include "gui/widgets/config-wizard-page.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
+class ConfigurationManager;
 class ModalConfigurationWidget;
+class Myself;
 
 class ConfigWizardSetUpAccountPage : public ConfigWizardPage
 {
 	Q_OBJECT
 
-	QPointer<ModalConfigurationWidget> AccountWidget;
-	bool AccountSuccessfullyCreated;
-
-	void createGui();
-
-private slots:
-	void accountCreated(Account account);
-
 public:
-	explicit ConfigWizardSetUpAccountPage(QWidget *parent = 0);
+	explicit ConfigWizardSetUpAccountPage(QWidget *parent = nullptr);
 	virtual ~ConfigWizardSetUpAccountPage();
 
 	virtual bool isComplete() const;
@@ -51,6 +45,20 @@ public:
 	virtual void cleanupPage();
 	virtual bool validatePage();
 
-};
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<ConfigurationManager> m_configurationManager;
+	QPointer<ModalConfigurationWidget> AccountWidget;
+	QPointer<Myself> m_myself;
+	bool AccountSuccessfullyCreated;
 
-#endif // CONFIG_WIZARD_SET_UP_ACCOUNT_PAGE_H
+	void createGui();
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setConfigurationManager(ConfigurationManager *configurationManager);
+	INJEQT_SET void setMyself(Myself *myself);
+
+	void accountCreated(Account account);
+
+};
