@@ -1,16 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2004, 2005 Roman Krzystyniak (Ron_K@tlen.pl)
- * Copyright 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,6 +20,7 @@
 
 #include <QtCore/QVariant>
 
+#include "plugin/plugin-injected-factory.h"
 #include "debug.h"
 
 #include "gui/widgets/config-wizard-choose-network-page.h"
@@ -47,6 +39,26 @@
 
 ConfigWizardWindow::ConfigWizardWindow(QWidget *parent) :
 		QWizard(parent)
+{
+}
+
+ConfigWizardWindow::~ConfigWizardWindow()
+{
+	kdebugf();
+	kdebugf2();
+}
+
+void ConfigWizardWindow::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void ConfigWizardWindow::setProtocolsManager(ProtocolsManager *protocolsManager)
+{
+	m_protocolsManager = protocolsManager;
+}
+
+void ConfigWizardWindow::init()
 {
 	kdebugf();
 
@@ -54,26 +66,18 @@ ConfigWizardWindow::ConfigWizardWindow(QWidget *parent) :
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(tr("Kadu Wizard"));
 
-#ifdef Q_OS_MAC
-	/* MacOSX has it's own QWizard style which requires much more space
-	 * than the other ones so we're forcing the ClassicStyle to unify
-	 * the window sizes and look. Mac users will love us for that.
-	 */
-	setWizardStyle(QWizard::ClassicStyle);
-#else
-	#ifdef Q_OS_WIN32
+	#ifdef Q_OS_WIN
 		// NOTE: Workaround for bug #1912.
 		// TODO: Remove this as soon as QTBUG-10478 is fixed in
 		// a release we bundle in the Windows build.
 		setWizardStyle(QWizard::ModernStyle);
 	#endif
 	setMinimumSize(500, 500);
-#endif
 
-	setPage(ProfilePage, new ConfigWizardProfilePage(this));
-	setPage(ChooseNetworkPage, new ConfigWizardChooseNetworkPage(this));
-	setPage(SetUpAccountPage, new ConfigWizardSetUpAccountPage(this));
-	setPage(CompletedPage, new ConfigWizardCompletedPage(this));
+	setPage(ProfilePage, m_pluginInjectedFactory->makeInjected<ConfigWizardProfilePage>(this));
+	setPage(ChooseNetworkPage, m_pluginInjectedFactory->makeInjected<ConfigWizardChooseNetworkPage>(this));
+	setPage(SetUpAccountPage, m_pluginInjectedFactory->makeInjected<ConfigWizardSetUpAccountPage>(this));
+	setPage(CompletedPage, m_pluginInjectedFactory->makeInjected<ConfigWizardCompletedPage>(this));
 
 	connect(this, SIGNAL(accepted()), this, SLOT(acceptedSlot()));
 	connect(this, SIGNAL(rejected()), this, SLOT(rejectedSlot()));
@@ -81,12 +85,6 @@ ConfigWizardWindow::ConfigWizardWindow(QWidget *parent) :
 	kdebugf2();
 }
 
-ConfigWizardWindow::~ConfigWizardWindow()
-{
-	kdebugf();
-	kdebugf2();
-}
-
 void ConfigWizardWindow::setPage(int id, ConfigWizardPage *page)
 {
 	ConfigWizardPages.append(page);
@@ -96,7 +94,7 @@ void ConfigWizardWindow::setPage(int id, ConfigWizardPage *page)
 
 bool ConfigWizardWindow::goToChooseNetwork() const
 {
-	return ProtocolsManager::instance()->count() > 0;
+	return m_protocolsManager->count() > 0;
 }
 
 bool ConfigWizardWindow::goToAccountSetUp() const
