@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2004 Roman Krzystyniak (Ron_K@tlen.pl)
- * Copyright 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2005, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,12 +18,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIG_WIZARD_WINDOW_H
-#define CONFIG_WIZARD_WINDOW_H
+#pragma once
 
-#include <QtGui/QWizard>
+#include <QtCore/QPointer>
+#include <QtWidgets/QWizard>
+#include <injeqt/injeqt.h>
 
 class ConfigWizardPage;
+class PluginInjectedFactory;
+class ProtocolsManager;
 
 /**
  * @defgroup config_wizard Config wizard
@@ -38,6 +36,9 @@ class ConfigWizardWindow : public QWizard
 {
 	Q_OBJECT
 
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<ProtocolsManager> m_protocolsManager;
+
 	QList<ConfigWizardPage *> ConfigWizardPages;
 
 	void setPage(int id, ConfigWizardPage *page);
@@ -45,6 +46,10 @@ class ConfigWizardWindow : public QWizard
 	bool goToAccountSetUp() const;
 
 private slots:
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setProtocolsManager(ProtocolsManager *protocolsManager);
+	INJEQT_INIT void init();
+
 	void acceptedSlot();
 	void rejectedSlot();
 
@@ -60,11 +65,9 @@ public:
 		CompletedPage
 	};
 
-	explicit ConfigWizardWindow(QWidget *parent = 0);
+	explicit ConfigWizardWindow(QWidget *parent = nullptr);
 	virtual ~ConfigWizardWindow();
 
 };
 
 /** @} */
-
-#endif // CONFIG_WIZARD_WINDOW_H
