@@ -6,6 +6,13 @@
         <translation>Um die Spracheinstellungen zu aktivieren, muss Kadu neu gestartet werden.</translation>
     </message>
 </context>
+<context>
+    <name>ConfigWizardActions</name>
+    <message>
+        <source>Start Configuration Wizard</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ConfigWizardChooseNetworkPage</name>
     <message>
@@ -48,13 +55,6 @@
         <translation>&lt;p&gt;Bestätige die Einstellungen, um Kadu zu verwenden.&lt;/p&gt;</translation>
     </message>
 </context>
-<context>
-    <name>ConfigWizardConfigurationUiHandler</name>
-    <message>
-        <source>Start Configuration Wizard</source>
-        <translation>Einrichtungsassistenten starten</translation>
-    </message>
-</context>
 <context>
     <name>ConfigWizardProfilePage</name>
     <message>
