@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -6,6 +8,13 @@
         <translation>Kadu needs to be restarted before changes to the language settings will take effect.</translation>
     </message>
 </context>
+<context>
+    <name>ConfigWizardActions</name>
+    <message>
+        <source>Start Configuration Wizard</source>
+        <translation type="unfinished">Start Configuration Wizard</translation>
+    </message>
+</context>
 <context>
     <name>ConfigWizardChooseNetworkPage</name>
     <message>
@@ -48,13 +57,6 @@
         <translation>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</translation>
     </message>
 </context>
-<context>
-    <name>ConfigWizardConfigurationUiHandler</name>
-    <message>
-        <source>Start Configuration Wizard</source>
-        <translation>Start Configuration Wizard</translation>
-    </message>
-</context>
 <context>
     <name>ConfigWizardProfilePage</name>
     <message>
@@ -92,4 +94,4 @@
         <translation>Kadu Wizard</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
