@@ -6,6 +6,13 @@
         <translation>Kadu doit être redémarré avant que la modification de langue prenne effet.</translation>
     </message>
 </context>
+<context>
+    <name>ConfigWizardActions</name>
+    <message>
+        <source>Start Configuration Wizard</source>
+        <translation>Lancer l&apos;assistant de configuration</translation>
+    </message>
+</context>
 <context>
     <name>ConfigWizardChooseNetworkPage</name>
     <message>
@@ -48,13 +55,6 @@
         <translation>&lt;p&gt;Confirmez les paramètres de l&apos;assistant pour commencer à utiliser Kadu.&lt;/p&gt;</translation>
     </message>
 </context>
-<context>
-    <name>ConfigWizardConfigurationUiHandler</name>
-    <message>
-        <source>Start Configuration Wizard</source>
-        <translation>Lancer l&apos;assistant de configuration</translation>
-    </message>
-</context>
 <context>
     <name>ConfigWizardProfilePage</name>
     <message>
