@@ -6,6 +6,13 @@
         <translation>Kadu precisa ser reiniciado para que as configurações de idioma façam efeito.</translation>
     </message>
 </context>
+<context>
+    <name>ConfigWizardActions</name>
+    <message>
+        <source>Start Configuration Wizard</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ConfigWizardChooseNetworkPage</name>
     <message>
@@ -48,13 +55,6 @@
         <translation>Confirme as configurações para começar a user o Kadu</translation>
     </message>
 </context>
-<context>
-    <name>ConfigWizardConfigurationUiHandler</name>
-    <message>
-        <source>Start Configuration Wizard</source>
-        <translation>Iniciar Ajudante de configuração</translation>
-    </message>
-</context>
 <context>
     <name>ConfigWizardProfilePage</name>
     <message>
