@@ -6,6 +6,13 @@
         <translation>Dil ayarlarındaki değişikliklerin etkili olabilmesi için Kadu&apos;yu yeniden başlatmalısınız.</translation>
     </message>
 </context>
+<context>
+    <name>ConfigWizardActions</name>
+    <message>
+        <source>Start Configuration Wizard</source>
+        <translation>Ayarlama Sihirbazını Başlat</translation>
+    </message>
+</context>
 <context>
     <name>ConfigWizardChooseNetworkPage</name>
     <message>
@@ -48,13 +55,6 @@
         <translation>&lt;p&gt;Kadu&apos;yu kullanmaya başlamak için sihirbaz ayarlarını onaylayın.&lt;/p&gt;</translation>
     </message>
 </context>
-<context>
-    <name>ConfigWizardConfigurationUiHandler</name>
-    <message>
-        <source>Start Configuration Wizard</source>
-        <translation>Ayarlama Sihirbazını Başlat</translation>
-    </message>
-</context>
 <context>
     <name>ConfigWizardProfilePage</name>
     <message>
