@@ -6,6 +6,13 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>ConfigWizardActions</name>
+    <message>
+        <source>Start Configuration Wizard</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ConfigWizardChooseNetworkPage</name>
     <message>
@@ -48,13 +55,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>ConfigWizardConfigurationUiHandler</name>
-    <message>
-        <source>Start Configuration Wizard</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>ConfigWizardProfilePage</name>
     <message>
