@@ -20,21 +20,22 @@
 #include "docking-menu-handler.h"
 
 #include "docking-menu-action-repository.h"
+#include "status-notifier-item.h"
 
-#include "core/core.h"
 #include "gui/widgets/status-menu.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "icons/icons-manager.h"
-#include "notification/notification-service.h"
+#include "notification/silent-mode-service.h"
+#include "plugin/plugin-injected-factory.h"
 #include "status/status-container-manager.h"
 #include "activate.h"
 
 #include <QtWidgets/QApplication>
 #include <QtWidgets/QMenu>
 
-DockingMenuHandler::DockingMenuHandler(QMenu *menu, QObject *parent) :
+DockingMenuHandler::DockingMenuHandler(QObject *parent) :
 		QObject{parent},
-		m_menu{menu},
 #if defined(Q_OS_UNIX)
 		m_showKaduAction{nullptr},
 		m_hideKaduAction{nullptr},
@@ -44,6 +45,68 @@ DockingMenuHandler::DockingMenuHandler(QMenu *menu, QObject *parent) :
 		m_needsUpdate{true},
 		m_mainWindowLastVisible{true}
 {
+}
+
+DockingMenuHandler::~DockingMenuHandler()
+{
+}
+
+void DockingMenuHandler::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void DockingMenuHandler::setDockingMenuActionRepository(DockingMenuActionRepository *dockingMenuActionRepository)
+{
+	m_dockingMenuActionRepository = dockingMenuActionRepository;
+}
+
+void DockingMenuHandler::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void DockingMenuHandler::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void DockingMenuHandler::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void DockingMenuHandler::setSilentModeService(SilentModeService *silentModeService)
+{
+	m_silentModeService = silentModeService;
+}
+
+void DockingMenuHandler::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void DockingMenuHandler::setStatusNotifierItem(StatusNotifierItem *statusNotifierItem)
+{
+	m_menu = statusNotifierItem->contextMenu();
+}
+
+void DockingMenuHandler::init()
+{
+	connect(m_iconsManager, SIGNAL(themeChanged()), this, SLOT(update()));
+	connect(m_dockingMenuActionRepository, SIGNAL(actionAdded(QAction*)), this, SLOT(update()));
+	connect(m_dockingMenuActionRepository, SIGNAL(actionRemoved(QAction*)), this, SLOT(update()));
+
+	for (auto statusContainer : m_statusContainerManager->statusContainers())
+		connect(statusContainer, SIGNAL(statusUpdated(StatusContainer*)), this, SLOT(update()));
+	
+	connect(m_statusContainerManager, SIGNAL(statusContainerRegistered(StatusContainer*)),
+	        this, SLOT(statusContainerRegistered(StatusContainer*)));
+	connect(m_statusContainerManager, SIGNAL(statusContainerUnregistered(StatusContainer*)),
+	        this, SLOT(statusContainerUnregistered(StatusContainer*)));
+
+	connect(m_silentModeService, &SilentModeService::silentModeToggled, this, &DockingMenuHandler::update);
+
 	m_menu->setSeparatorsCollapsible(true);
 	connect(m_menu, SIGNAL(aboutToShow()), this, SLOT(aboutToShow()));
 	
@@ -55,48 +118,14 @@ DockingMenuHandler::DockingMenuHandler(QMenu *menu, QObject *parent) :
 	connect(m_hideKaduAction, SIGNAL(triggered()), this, SLOT(hideKaduWindow()));
 #endif
 
-	m_silentModeAction = new QAction{KaduIcon{"kadu_icons/enable-notifications"}.icon(), tr("Silent mode"), this};
+	m_silentModeAction = new QAction{m_iconsManager->iconByPath(KaduIcon{"kadu_icons/enable-notifications"}), tr("Silent mode"), this};
 	m_silentModeAction->setCheckable(true);
 	connect(m_silentModeAction, SIGNAL(triggered(bool)), this, SLOT(silentModeToggled(bool)));
 
-	m_closeKaduAction = new QAction{KaduIcon{"application-exit"}.icon(), tr("&Exit Kadu"), this};
+	m_closeKaduAction = new QAction{m_iconsManager->iconByPath(KaduIcon{"application-exit"}), tr("&Exit Kadu"), this};
 	connect(m_closeKaduAction, SIGNAL(triggered()), qApp, SLOT(quit()));
 }
 
-DockingMenuHandler::~DockingMenuHandler()
-{
-}
-
-void DockingMenuHandler::setDockingMenuActionRepository(DockingMenuActionRepository *dockingMenuActionRepository)
-{
-	m_dockingMenuActionRepository = dockingMenuActionRepository;
-	connect(m_dockingMenuActionRepository, SIGNAL(actionAdded(QAction*)), this, SLOT(update()));
-	connect(m_dockingMenuActionRepository, SIGNAL(actionRemoved(QAction*)), this, SLOT(update()));
-}
-
-void DockingMenuHandler::setIconsManager(IconsManager *iconsManager)
-{
-	connect(iconsManager, SIGNAL(themeChanged()), this, SLOT(update()));
-}
-
-void DockingMenuHandler::setNotificationService(NotificationService *notificationService)
-{
-	m_notificationService = notificationService;
-	connect(m_notificationService, SIGNAL(silentModeToggled(bool)), this, SLOT(update()));
-}
-
-void DockingMenuHandler::setStatusContainerManager(StatusContainerManager *statusContainerManager)
-{
-	m_statusContainerManager = statusContainerManager;
-	for (auto statusContainer : m_statusContainerManager->statusContainers())
-		connect(statusContainer, SIGNAL(statusUpdated(StatusContainer*)), this, SLOT(update()));
-	
-	connect(m_statusContainerManager, SIGNAL(statusContainerRegistered(StatusContainer*)),
-	        this, SLOT(statusContainerRegistered(StatusContainer*)));
-	connect(m_statusContainerManager, SIGNAL(statusContainerUnregistered(StatusContainer*)),
-	        this, SLOT(statusContainerUnregistered(StatusContainer*)));
-}
-
 void DockingMenuHandler::statusContainerRegistered(StatusContainer *statusContainer)
 {
 	connect(statusContainer, SIGNAL(statusUpdated(StatusContainer*)), this, SLOT(update()));
@@ -126,11 +155,11 @@ void DockingMenuHandler::doUpdate()
 	addStatusContainerMenus();
 	addActionRepositoryMenus();
 	m_menu->addSeparator();
-	m_silentModeAction->setChecked(m_notificationService->silentMode());
+	m_silentModeAction->setChecked(m_silentModeService->isSilent());
 	m_menu->addAction(m_silentModeAction);
 	m_menu->addSeparator();
 #if defined(Q_OS_UNIX)
-	m_mainWindowLastVisible = Core::instance()->kaduWindow()->window()->isVisible();
+	m_mainWindowLastVisible = m_kaduWindowService->kaduWindow()->window()->isVisible();
 	m_menu->addAction(m_mainWindowLastVisible ? m_hideKaduAction : m_showKaduAction);
 #endif
 	m_menu->addAction(m_closeKaduAction);
@@ -150,10 +179,10 @@ void DockingMenuHandler::addStatusContainerMenus()
 			addStatusContainerMenu(statusContainer);
 		m_menu->addSeparator();
 	}
-	
+
 	if (showAllAccountsMenu)
 	{
-		auto allAccountsMenu = new StatusMenu{StatusContainerManager::instance(), multipleMenus, m_menu};
+		auto allAccountsMenu = m_pluginInjectedFactory->makeInjected<StatusMenu>(m_statusContainerManager, multipleMenus, m_menu);
 		connect(allAccountsMenu, SIGNAL(menuRecreated()), this, SLOT(update()));
 	}
 }
@@ -161,7 +190,7 @@ void DockingMenuHandler::addStatusContainerMenus()
 void DockingMenuHandler::addStatusContainerMenu(StatusContainer *statusContainer)
 {
 	auto menu = new QMenu{statusContainer->statusContainerName(), m_menu};
-	menu->setIcon(statusContainer->statusIcon().icon());
+	menu->setIcon(m_iconsManager->iconByPath(statusContainer->statusIcon()));
 	new StatusMenu{statusContainer, false, menu};
 	m_menu->addMenu(menu);
 }
@@ -178,17 +207,17 @@ void DockingMenuHandler::addActionRepositoryMenus()
 
 void DockingMenuHandler::showKaduWindow()
 {
-	_activateWindow(Core::instance()->kaduWindow());
+	_activateWindow(m_configuration, m_kaduWindowService->kaduWindow());
 }
 
 void DockingMenuHandler::hideKaduWindow()
 {
-	Core::instance()->kaduWindow()->window()->hide();
+	m_kaduWindowService->kaduWindow()->window()->hide();
 }
 
 void DockingMenuHandler::silentModeToggled(bool enabled)
 {
-	m_notificationService->setSilentMode(enabled);
+	m_silentModeService->setSilent(enabled);
 }
 
 #include "moc_docking-menu-handler.cpp"
