@@ -27,92 +27,107 @@
 #include "docking.h"
 
 #include "docking-configuration-provider.h"
-#include "docking-menu-action-repository.h"
 #include "docking-menu-handler.h"
-#include "docking-tooltip-handler.h"
 #include "status-notifier-item.h"
 #include "status-notifier-item-attention-mode.h"
 #include "status-notifier-item-configuration.h"
 
-#include "core/application.h"
-#include "core/core.h"
+#include "core/session-service.h"
 #include "gui/status-icon.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "message/message.h"
 #include "message/unread-message-repository.h"
+#include "plugin/plugin-injected-factory.h"
 #include "provider/default-provider.h"
 #include "status/status-container-manager.h"
 #include "activate.h"
 #include "attention-service.h"
 
-Docking * Docking::m_instance = nullptr;
-
-void Docking::createInstance()
+Docking::Docking(QObject *parent) :
+		QObject{parent}
 {
-	if (!m_instance)
-		m_instance = new Docking();
-}
-
-void Docking::destroyInstance()
-{
-	delete m_instance;
-	m_instance = nullptr;
-}
-
-Docking * Docking::instance()
-{
-	return m_instance;
-}
-
-Docking::Docking()
-{
-	m_dockingMenuActionRepository = make_owned<DockingMenuActionRepository>(this);
-
-	auto statusIcon = make_owned<StatusIcon>(StatusContainerManager::instance(), this);
-	connect(statusIcon.get(), SIGNAL(iconUpdated(KaduIcon)), this, SLOT(configurationUpdated()));
-
-	connect(Core::instance()->attentionService(), SIGNAL(needAttentionChanged(bool)),
-	        this, SLOT(needAttentionChanged(bool)));
-
-	connect(Core::instance(), SIGNAL(searchingForTrayPosition(QPoint&)), this, SLOT(searchingForTrayPosition(QPoint&)));
-
-	m_statusNotifierItem = make_owned<StatusNotifierItem>(this);
-	connect(m_statusNotifierItem.get(), SIGNAL(activateRequested()), this, SLOT(activateRequested()));
-	connect(m_statusNotifierItem.get(), SIGNAL(messageClicked()), this, SIGNAL(messageClicked()));
-
-	m_dockingConfigurationProvider = make_owned<DockingConfigurationProvider>(this);
-
-	auto dockingMenuHandler = make_owned<DockingMenuHandler>(m_statusNotifierItem->contextMenu(), this);
-	dockingMenuHandler->setDockingMenuActionRepository(m_dockingMenuActionRepository.get());
-	dockingMenuHandler->setIconsManager(IconsManager::instance());
-	dockingMenuHandler->setNotificationService(Core::instance()->notificationService());
-	dockingMenuHandler->setStatusContainerManager(StatusContainerManager::instance());
-
-	auto dockingTooltipHandler = make_owned<DockingTooltipHandler>(m_statusNotifierItem.get(), this);
-	dockingTooltipHandler->setDockingConfigurationProvider(m_dockingConfigurationProvider.get());
-	dockingTooltipHandler->setStatusContainerManager(StatusContainerManager::instance());
-
-	connect(m_dockingConfigurationProvider.get(), SIGNAL(updated()), this, SLOT(configurationUpdated()));
-	configurationUpdated();
-
-	if (m_dockingConfigurationProvider->configuration().RunDocked)
-		Core::instance()->setShowMainWindowOnStart(false);
-	Core::instance()->kaduWindow()->setDocked(true);
 }
 
 Docking::~Docking()
 {
-	if (!Core::instance()->isClosing())
-		Core::instance()->kaduWindow()->window()->show();
-	Core::instance()->kaduWindow()->setDocked(false);
+	if (!m_sessionService->isClosing())
+		m_kaduWindowService->kaduWindow()->window()->show();
+	m_kaduWindowService->kaduWindow()->setDocked(false);
 }
 
-DockingMenuActionRepository * Docking::dockingMenuActionRepository() const
+void Docking::setAttentionService(AttentionService *attentionService)
 {
-	return m_dockingMenuActionRepository.get();
+	connect(attentionService, SIGNAL(needAttentionChanged(bool)), this, SLOT(needAttentionChanged(bool)));
+}
+
+void Docking::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void Docking::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void Docking::setDockingConfigurationProvider(DockingConfigurationProvider *dockingConfigurationProvider)
+{
+	m_dockingConfigurationProvider = dockingConfigurationProvider;
+}
+
+void Docking::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void Docking::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void Docking::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void Docking::setSessionService(SessionService *sessionService)
+{
+	m_sessionService = sessionService;
+}
+
+void Docking::setStatusContainerManager(StatusContainerManager *statusContainerManager)
+{
+	m_statusContainerManager = statusContainerManager;
+}
+
+void Docking::setStatusNotifierItem(StatusNotifierItem *statusNotifierItem)
+{
+	m_statusNotifierItem = statusNotifierItem;
+}
+
+void Docking::setUnreadMessageRepository(UnreadMessageRepository *unreadMessageRepository)
+{
+	m_unreadMessageRepository = unreadMessageRepository;
+}
+
+void Docking::init()
+{
+	auto statusIcon = m_pluginInjectedFactory->makeOwned<StatusIcon>(m_statusContainerManager, this);
+	connect(statusIcon.get(), SIGNAL(iconUpdated(KaduIcon)), this, SLOT(configurationUpdated()));
+
+	connect(m_statusNotifierItem, SIGNAL(activateRequested()), this, SLOT(activateRequested()));
+	connect(m_statusNotifierItem, SIGNAL(messageClicked()), this, SIGNAL(messageClicked()));
+
+	connect(m_dockingConfigurationProvider, SIGNAL(updated()), this, SLOT(configurationUpdated()));
+	configurationUpdated();
+
+	if (m_dockingConfigurationProvider->configuration().RunDocked)
+		m_kaduWindowService->setShowMainWindowOnStart(false);
+	m_kaduWindowService->kaduWindow()->setDocked(true);
 }
 
 void Docking::needAttentionChanged(bool needAttention)
@@ -122,8 +137,8 @@ void Docking::needAttentionChanged(bool needAttention)
 
 void Docking::openUnreadMessages()
 {
-	auto message = Core::instance()->unreadMessageRepository()->unreadMessage();
-	Core::instance()->chatWidgetManager()->openChat(message.messageChat(), OpenChatActivation::Activate);
+	auto message = m_unreadMessageRepository->unreadMessage();
+	m_chatWidgetManager->openChat(message.messageChat(), OpenChatActivation::Activate);
 }
 
 void Docking::showMessage(QString title, QString message, QSystemTrayIcon::MessageIcon icon, int msecs)
@@ -133,13 +148,13 @@ void Docking::showMessage(QString title, QString message, QSystemTrayIcon::Messa
 
 void Docking::activateRequested()
 {
-	if (Core::instance()->unreadMessageRepository()->hasUnreadMessages())
+	if (m_unreadMessageRepository->hasUnreadMessages())
 	{
 		openUnreadMessages();
 		return;
 	}
 
-	auto kaduWindow = Core::instance()->kaduWindow()->window();
+	auto kaduWindow = m_kaduWindowService->kaduWindow()->window();
 	if (kaduWindow->isMinimized() || !kaduWindow->isVisible()
 #ifndef Q_OS_WIN
 			// NOTE: It won't work as expected on Windows since when you click on tray icon,
@@ -148,23 +163,18 @@ void Docking::activateRequested()
 			|| !_isActiveWindow(kaduWindow)
 #endif
 			)
-		_activateWindow(kaduWindow);
+		_activateWindow(m_configuration, kaduWindow);
 	else
 		kaduWindow->hide();
 }
 
-void Docking::searchingForTrayPosition(QPoint &point)
-{
-	point = m_statusNotifierItem->trayPosition();
-}
-
 void Docking::configurationUpdated()
 {
 	auto configuration = StatusNotifierItemConfiguration{};
 	configuration.AttentionMode = m_dockingConfigurationProvider->configuration().NewMessageIcon;
 	configuration.AttentionIcon = KaduIcon{"protocols/common/message"};
-	configuration.AttentionMovie = KaduIcon{"protocols/common/message_anim", "16x16"}.fullPath();
-	configuration.Icon = StatusContainerManager::instance()->statusIcon();
+	configuration.AttentionMovie = m_iconsManager->iconPath(KaduIcon{"protocols/common/message_anim", "16x16"});
+	configuration.Icon = m_statusContainerManager->statusIcon();
 	m_statusNotifierItem->setConfiguration(configuration);
 }
 
