@@ -39,7 +39,7 @@
     </message>
 </context>
 <context>
-    <name>DockingManager</name>
+    <name>DockingMenuHandler</name>
     <message>
         <source>&amp;Restore</source>
         <translation>&amp;Obnovit</translation>
@@ -48,29 +48,13 @@
         <source>&amp;Minimize</source>
         <translation>&amp;Zmenšit</translation>
     </message>
-    <message>
-        <source>&amp;Exit Kadu</source>
-        <translation>&amp;Ukončit Kadu</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Stav</translation>
-    </message>
-    <message>
-        <source>Description</source>
-        <translation>Popis</translation>
-    </message>
-    <message>
-        <source>Statuses</source>
-        <translation>Stavy</translation>
-    </message>
-    <message>
-        <source>Descriptions</source>
-        <translation>Popisy</translation>
-    </message>
     <message>
         <source>Silent mode</source>
         <translation>Tichý režim</translation>
     </message>
+    <message>
+        <source>&amp;Exit Kadu</source>
+        <translation>&amp;Ukončit Kadu</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
