@@ -39,7 +39,7 @@
     </message>
 </context>
 <context>
-    <name>DockingManager</name>
+    <name>DockingMenuHandler</name>
     <message>
         <source>&amp;Restore</source>
         <translation>&amp;Restaurer</translation>
@@ -48,29 +48,13 @@
         <source>&amp;Minimize</source>
         <translation>&amp;Réduire</translation>
     </message>
-    <message>
-        <source>&amp;Exit Kadu</source>
-        <translation>&amp;Quitter Kadu</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>État</translation>
-    </message>
-    <message>
-        <source>Description</source>
-        <translation>Description</translation>
-    </message>
-    <message>
-        <source>Statuses</source>
-        <translation>États</translation>
-    </message>
-    <message>
-        <source>Descriptions</source>
-        <translation>Descriptions</translation>
-    </message>
     <message>
         <source>Silent mode</source>
         <translation>Mode silencieux</translation>
     </message>
+    <message>
+        <source>&amp;Exit Kadu</source>
+        <translation>&amp;Quitter Kadu</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
