@@ -39,7 +39,7 @@
     </message>
 </context>
 <context>
-    <name>DockingManager</name>
+    <name>DockingMenuHandler</name>
     <message>
         <source>&amp;Restore</source>
         <translation>P&amp;rzywróć</translation>
@@ -48,29 +48,13 @@
         <source>&amp;Minimize</source>
         <translation>&amp;Minimalizuj</translation>
     </message>
-    <message>
-        <source>&amp;Exit Kadu</source>
-        <translation>&amp;Zakończ Kadu</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Status</translation>
-    </message>
-    <message>
-        <source>Description</source>
-        <translation>Opis</translation>
-    </message>
-    <message>
-        <source>Statuses</source>
-        <translation>Statusy</translation>
-    </message>
-    <message>
-        <source>Descriptions</source>
-        <translation>Opisy</translation>
-    </message>
     <message>
         <source>Silent mode</source>
         <translation>Tryb cichy</translation>
     </message>
+    <message>
+        <source>&amp;Exit Kadu</source>
+        <translation>&amp;Zakończ Kadu</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
