@@ -39,7 +39,7 @@
     </message>
 </context>
 <context>
-    <name>DockingManager</name>
+    <name>DockingMenuHandler</name>
     <message>
         <source>&amp;Restore</source>
         <translation>&amp;Önceki Boyut</translation>
@@ -48,29 +48,13 @@
         <source>&amp;Minimize</source>
         <translation>&amp;Simge Durumuna</translation>
     </message>
-    <message>
-        <source>&amp;Exit Kadu</source>
-        <translation>Kadu&apos;dan &amp;Çık</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Durum</translation>
-    </message>
-    <message>
-        <source>Description</source>
-        <translation>Tanımlama</translation>
-    </message>
-    <message>
-        <source>Statuses</source>
-        <translation>Durumlar</translation>
-    </message>
-    <message>
-        <source>Descriptions</source>
-        <translation>Tanımlamalar</translation>
-    </message>
     <message>
         <source>Silent mode</source>
         <translation>Sessiz mod</translation>
     </message>
+    <message>
+        <source>&amp;Exit Kadu</source>
+        <translation>Kadu&apos;dan &amp;Çık</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
