@@ -39,7 +39,7 @@
     </message>
 </context>
 <context>
-    <name>DockingManager</name>
+    <name>DockingMenuHandler</name>
     <message>
         <source>&amp;Restore</source>
         <translation type="unfinished"/>
@@ -48,29 +48,13 @@
         <source>&amp;Minimize</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>&amp;Exit Kadu</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Description</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Statuses</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Descriptions</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Silent mode</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>&amp;Exit Kadu</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
