@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,13 +17,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EMOTICON_CLIPBOARD_HTML_TRANSFORMER_H
-#define EMOTICON_CLIPBOARD_HTML_TRANSFORMER_H
-
-#include <QtCore/QRegExp>
+#pragma once
 
 #include "gui/services/clipboard-html-transformer.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QRegExp>
+
 /**
  * @addtogroup Emoticons
  * @{
@@ -39,12 +34,14 @@
  * @short Transformer for replacing emoticon images with emoticon text triggers in HTML code that is pasted into clipboard.
  * @author Rafał 'Vogel' Malinowski
  */
-class EmoticonClipboardHtmlTransformer : public ClipboardHtmlTransformer
+class EmoticonClipboardHtmlTransformer : public QObject, public ClipboardHtmlTransformer
 {
+	Q_OBJECT
+
 	QRegExp EmoticonRegularExpression;
 
 public:
-	EmoticonClipboardHtmlTransformer();
+	Q_INVOKABLE EmoticonClipboardHtmlTransformer(QObject *parent = nullptr);
 	virtual ~EmoticonClipboardHtmlTransformer();
 
 	virtual QString transform(const QString &clipboardHtml);
@@ -54,5 +51,3 @@ public:
 /**
  * @}
  */
-
-#endif // EMOTICON_CLIPBOARD_HTML_TRANSFORMER_H
