@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QFileDialog>
 #include <QtGui/QPainter>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QFileDialog>
 
 #include "compression/archive-extractor.h"
 #include "gui/widgets/configuration/config-check-box.h"
@@ -29,8 +29,10 @@
 #include "gui/widgets/configuration/config-path-list-edit.h"
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/widgets/path-list-edit.h"
+#include "gui/windows/main-configuration-window.h"
 #include "gui/windows/message-dialog.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "theme/emoticon-theme.h"
 #include "theme/gadu-emoticon-theme-loader.h"
@@ -38,7 +40,7 @@
 #include "emoticons-configuration-ui-handler.h"
 
 EmoticonsConfigurationUiHandler::EmoticonsConfigurationUiHandler(QObject *parent) :
-		ConfigurationUiHandler(parent), ThemeManager(new EmoticonThemeManager())
+		QObject(parent)
 {
 }
 
@@ -46,6 +48,26 @@ EmoticonsConfigurationUiHandler::~EmoticonsConfigurationUiHandler()
 {
 }
 
+void EmoticonsConfigurationUiHandler::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void EmoticonsConfigurationUiHandler::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void EmoticonsConfigurationUiHandler::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void EmoticonsConfigurationUiHandler::init()
+{
+	ThemeManager.reset(m_pluginInjectedFactory->makeInjected<EmoticonThemeManager>());
+}
+
 void EmoticonsConfigurationUiHandler::updateEmoticonThemes()
 {
 	if (!ThemesList)
@@ -98,6 +120,14 @@ void EmoticonsConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigu
 	updateEmoticonThemes();
 }
 
+void EmoticonsConfigurationUiHandler::mainConfigurationWindowDestroyed()
+{
+}
+
+void EmoticonsConfigurationUiHandler::mainConfigurationWindowApplied()
+{
+}
+
 void EmoticonsConfigurationUiHandler::installEmoticonTheme()
 {
 	QString fileName = QFileDialog::getOpenFileName(Widget.data(), tr("Open icon theme archive"), QDir::home().path(), tr("Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)"));
@@ -105,7 +135,7 @@ void EmoticonsConfigurationUiHandler::installEmoticonTheme()
 	if (fileName.isEmpty())
 		return;
 
-	const QString &profilePath = KaduPaths::instance()->profilePath();
+	const QString &profilePath = m_pathsProvider->profilePath();
 	ArchiveExtractor extractor;
 	bool success = extractor.extract(fileName, profilePath + "emoticons");
 
@@ -115,7 +145,7 @@ void EmoticonsConfigurationUiHandler::installEmoticonTheme()
 	}
 	else
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Installation failed"), tr(extractor.message().toLocal8Bit().data()), QMessageBox::Ok, Widget.data());
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Installation failed"), tr(extractor.message().toLocal8Bit().data()), QMessageBox::Ok, Widget.data());
 	}
 }
 
