@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -15,57 +15,57 @@
     </message>
     <message>
         <source>Emoticons</source>
-        <translation type="unfinished"/>
+        <translation>Émoticônes</translation>
     </message>
     <message>
         <source>Enable emoticons</source>
-        <translation type="unfinished"/>
+        <translation>Activer émoticônes</translation>
     </message>
     <message>
         <source>Animate emoticons</source>
-        <translation type="unfinished"/>
+        <translation>Émoticônes animés</translation>
     </message>
     <message>
         <source>Icon theme</source>
-        <translation type="unfinished"/>
+        <translation>Thème d&apos;icônes</translation>
     </message>
     <message>
         <source>Choose emoticons theme</source>
-        <translation type="unfinished"/>
+        <translation>Choisir thème émoticônes</translation>
     </message>
     <message>
         <source>Install new emoticons...</source>
-        <translation type="unfinished"/>
+        <translation>Installer de nouvelles émoticônes...</translation>
     </message>
 </context>
 <context>
     <name>EmoticonsConfigurationUiHandler</name>
     <message>
         <source>Open icon theme archive</source>
-        <translation type="unfinished"/>
+        <translation>Ouvrir thème d&apos;émoticône depuis une archive</translation>
     </message>
     <message>
         <source>Installation failed</source>
-        <translation type="unfinished"/>
+        <translation>Installation échoué</translation>
     </message>
     <message>
         <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
-        <translation type="unfinished"/>
+        <translation>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
     </message>
 </context>
 <context>
     <name>InsertEmoticonAction</name>
     <message>
         <source>Insert Emoticon</source>
-        <translation type="unfinished"/>
+        <translation>Insérer Émoticône</translation>
     </message>
     <message>
         <source>Insert emoticon</source>
-        <translation type="unfinished"/>
+        <translation>Insérer émoticône</translation>
     </message>
     <message>
         <source>Insert emoticon - enable in configuration</source>
-        <translation type="unfinished"/>
+        <translation>Insérer émoticône - activer dans configuration</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
