@@ -1,71 +1,71 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>default</source>
-        <translation type="unfinished"/>
+        <translation>padrão</translation>
     </message>
     <message>
         <source>Look</source>
-        <translation type="unfinished"/>
+        <translation>Aparência</translation>
     </message>
     <message>
         <source>Icons</source>
-        <translation type="unfinished"/>
+        <translation>Ícones</translation>
     </message>
     <message>
         <source>Emoticons</source>
-        <translation type="unfinished"/>
+        <translation>Emoticons</translation>
     </message>
     <message>
         <source>Enable emoticons</source>
-        <translation type="unfinished"/>
+        <translation>Habilitar emoticons</translation>
     </message>
     <message>
         <source>Animate emoticons</source>
-        <translation type="unfinished"/>
+        <translation>Emoticons animados</translation>
     </message>
     <message>
         <source>Icon theme</source>
-        <translation type="unfinished"/>
+        <translation>Tema de ícone</translation>
     </message>
     <message>
         <source>Choose emoticons theme</source>
-        <translation type="unfinished"/>
+        <translation>Selecione o tema de emoticons</translation>
     </message>
     <message>
         <source>Install new emoticons...</source>
-        <translation type="unfinished"/>
+        <translation>Instalar novos emoticons...</translation>
     </message>
 </context>
 <context>
     <name>EmoticonsConfigurationUiHandler</name>
     <message>
         <source>Open icon theme archive</source>
-        <translation type="unfinished"/>
+        <translation>Abrir arquivo de tema de ícone</translation>
     </message>
     <message>
         <source>Installation failed</source>
-        <translation type="unfinished"/>
+        <translation>Instalação falhou</translation>
     </message>
     <message>
         <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
-        <translation type="unfinished"/>
+        <translation>Arquivo (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
     </message>
 </context>
 <context>
     <name>InsertEmoticonAction</name>
     <message>
         <source>Insert Emoticon</source>
-        <translation type="unfinished"/>
+        <translation>Inserir emoticon</translation>
     </message>
     <message>
         <source>Insert emoticon</source>
-        <translation type="unfinished"/>
+        <translation>Inserir emoticon</translation>
     </message>
     <message>
         <source>Insert emoticon - enable in configuration</source>
-        <translation type="unfinished"/>
+        <translation>Inserir emoticon - habilitar em configuração</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
