@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -54,7 +51,7 @@ private slots:
 	void updateState();
 
 public:
-	explicit OtrAccountConfigurationWidget(const Account &account, QWidget *parent = 0);
+	explicit OtrAccountConfigurationWidget(const Account &account, QWidget *parent = nullptr);
 	virtual ~OtrAccountConfigurationWidget();
 
 	void setPolicyService(OtrPolicyService *policyService);
