@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,26 +17,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_BUDDY_CONFIGURATION_WIDGET_FACTORY_H
-#define OTR_BUDDY_CONFIGURATION_WIDGET_FACTORY_H
-
-#include <QtCore/QPointer>
+#pragma once
 
 #include "gui/widgets/buddy-configuration-widget-factory.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
 class OtrPolicyService;
 
-class OtrBuddyConfigurationWidgetFactory : public BuddyConfigurationWidgetFactory
+class OtrBuddyConfigurationWidgetFactory : public QObject, public BuddyConfigurationWidgetFactory
 {
-	QPointer<OtrPolicyService> PolicyService;
+	Q_OBJECT
 
 public:
+	Q_INVOKABLE OtrBuddyConfigurationWidgetFactory() {}
 	virtual ~OtrBuddyConfigurationWidgetFactory();
 
-	void setPolicyService(OtrPolicyService *policyService);
-
 	virtual BuddyConfigurationWidget * createWidget(const Buddy &buddy, QWidget *parent);
 
-};
+private slots:
+	INJEQT_SET void setPolicyService(OtrPolicyService *policyService);
 
-#endif // OTR_BUDDY_CONFIGURATION_WIDGET_FACTORY_H
+private:
+	QPointer<OtrPolicyService> PolicyService;
+
+};
