@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,14 +17,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_CHAT_TOP_BAR_WIDGET_FACTORY_H
-#define OTR_CHAT_TOP_BAR_WIDGET_FACTORY_H
-
-#include <QtCore/QObject>
-#include <QtCore/QPointer>
+#pragma once
 
 #include "gui/widgets/chat-top-bar-widget-factory.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class ChatTypeManager;
+class PluginInjectedFactory;
 class OtrChatTopBarWidget;
 class OtrPeerIdentityVerificationWindowRepository;
 class OtrSessionService;
@@ -37,24 +36,27 @@ class OtrChatTopBarWidgetFactory : public QObject, public ChatTopBarWidgetFactor
 {
 	Q_OBJECT
 
+public:
+	Q_INVOKABLE OtrChatTopBarWidgetFactory();
+	virtual ~OtrChatTopBarWidgetFactory();
+
+	virtual QWidget * createWidget(const Chat &chat, QWidget *parent);
+
+private:
+	QPointer<ChatTypeManager> m_chatTypeManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
 	QPointer<OtrPeerIdentityVerificationWindowRepository> PeerIdentityVerificationWindowRepository;
 	QPointer<OtrSessionService> SessionService;
 	QPointer<OtrTrustLevelService> TrustLevelService;
 	QList<OtrChatTopBarWidget *> Widgets;
 
 private slots:
+	INJEQT_SET void setChatTypeManager(ChatTypeManager *chatTypeManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setPeerIdentityVerificationWindowRepository(OtrPeerIdentityVerificationWindowRepository *peerIdentityVerificationWindowRepository);
+	INJEQT_SET void setSessionService(OtrSessionService *sessionService);
+	INJEQT_SET void setTrustLevelService(OtrTrustLevelService *trustLevelService);
+
 	void widgetDestroyed(QObject *widget);
 
-public:
-	explicit OtrChatTopBarWidgetFactory(QObject *parent = 0);
-	virtual ~OtrChatTopBarWidgetFactory();
-
-	void setPeerIdentityVerificationWindowRepository(OtrPeerIdentityVerificationWindowRepository *peerIdentityVerificationWindowRepository);
-	void setSessionService(OtrSessionService *sessionService);
-	void setTrustLevelService(OtrTrustLevelService *trustLevelService);
-
-	virtual QWidget * createWidget(const Chat &chat, QWidget *parent);
-
 };
-
-#endif // OTR_CHAT_TOP_BAR_WIDGET_FACTORY_H
