@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,10 +17,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QMenu>
-#include <QtGui/QPushButton>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QPushButton>
 
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 
 #include "otr-policy.h"
@@ -34,14 +32,22 @@ OtrChatTopBarWidget::OtrChatTopBarWidget(const Contact &contact, QWidget *parent
 		QWidget(parent), MyContact(contact)
 {
 	setFocusPolicy(Qt::NoFocus);
-
-	createGui();
 }
 
 OtrChatTopBarWidget::~OtrChatTopBarWidget()
 {
 }
 
+void OtrChatTopBarWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void OtrChatTopBarWidget::init()
+{
+	createGui();
+}
+
 void OtrChatTopBarWidget::createGui()
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
@@ -92,12 +98,12 @@ void OtrChatTopBarWidget::trustLevelUpdated()
 
 	if (isPrivate)
 	{
-		OtrStatusButton->setIcon(KaduIcon("security-high").icon());
+		OtrStatusButton->setIcon(m_iconsManager->iconByPath(KaduIcon("security-high")));
 		StartAction->setText(tr("Refresh Private Conversation"));
 	}
 	else
 	{
-		OtrStatusButton->setIcon(KaduIcon("security-low").icon());
+		OtrStatusButton->setIcon(m_iconsManager->iconByPath(KaduIcon("security-low")));
 		StartAction->setText(tr("Start Private Conversation"));
 	}
 
