@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,18 +20,21 @@
 #ifndef OTR_CHAT_TOP_BAR_WIDGET_H
 #define OTR_CHAT_TOP_BAR_WIDGET_H
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 #include "contacts/contact.h"
 
 #include "otr-trust-level-service.h"
 
+class IconsManager;
+
 class QPushButton;
 
 class OtrChatTopBarWidget : public QWidget
 {
 	Q_OBJECT
 
+	QPointer<IconsManager> m_iconsManager;
 	QPointer<OtrTrustLevelService> TrustLevelService;
 
 	Contact MyContact;
@@ -48,13 +48,16 @@ class OtrChatTopBarWidget : public QWidget
 	QString trustStatusString(OtrTrustLevelService::TrustLevel level) const;
 
 private slots:
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_INIT void init();
+
 	void startSession();
 	void endSession();
 	void verifyPeerIdentity();
 	void trustLevelUpdated();
 
 public:
-	explicit OtrChatTopBarWidget(const Contact &contact, QWidget *parent = 0);
+	explicit OtrChatTopBarWidget(const Contact &contact, QWidget *parent = nullptr);
 	virtual ~OtrChatTopBarWidget();
 
 	void setTrustLevelService(OtrTrustLevelService *trustLevelService);
