@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,9 +17,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QLabel>
-#include <QtGui/QProgressBar>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QProgressBar>
+#include <QtWidgets/QVBoxLayout>
 
 #include "gui/windows/otr-peer-identity-verification-window.h"
 #include "otr-peer-identity-verification-service.h"
@@ -111,3 +111,5 @@ bool OtrPeerIdentityVerificationProgressPage::validatePage()
 
 	return State.isFinished();
 }
+
+#include "moc_otr-peer-identity-verification-progress-page.cpp"
