@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +20,7 @@
 #ifndef OTR_PEER_IDENTITY_VERIFICATION_RESPOND_SHARED_SECRET_PAGE_H
 #define OTR_PEER_IDENTITY_VERIFICATION_RESPOND_SHARED_SECRET_PAGE_H
 
-#include <QtGui/QWizardPage>
+#include <QtWidgets/QWizardPage>
 
 #include "contacts/contact.h"
 
@@ -40,7 +37,7 @@ class OtrPeerIdentityVerificationRespondSharedSecretPage : public QWizardPage
 	void createGui();
 
 public:
-	explicit OtrPeerIdentityVerificationRespondSharedSecretPage(const Contact &contact, QWidget *parent = 0);
+	explicit OtrPeerIdentityVerificationRespondSharedSecretPage(const Contact &contact, QWidget *parent = nullptr);
 	virtual ~OtrPeerIdentityVerificationRespondSharedSecretPage();
 
 	void setPeerIdentityVerificationService(OtrPeerIdentityVerificationService *peerIdentityVerificationService);
