@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +17,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QLabel>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QVBoxLayout>
 
 #include "gui/windows/otr-peer-identity-verification-window.h"
 #include "otr-peer-identity-verification-state.h"
@@ -83,3 +80,5 @@ QString OtrPeerIdentityVerificationResultPage::stateToString(const OtrPeerIdenti
 		return tr("Verification of %1 succeeded.").arg(MyContact.display(true));
 	return tr("Unknown.");
 }
+
+#include "moc_otr-peer-identity-verification-result-page.cpp"
