@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,8 +31,7 @@
 
 #include "otr-peer-identity-verification-window-factory.h"
 
-OtrPeerIdentityVerificationWindowFactory::OtrPeerIdentityVerificationWindowFactory(QObject *parent) :
-		QObject(parent)
+OtrPeerIdentityVerificationWindowFactory::OtrPeerIdentityVerificationWindowFactory()
 {
 }
 
@@ -97,3 +96,5 @@ OtrPeerIdentityVerificationWindow * OtrPeerIdentityVerificationWindowFactory::wi
 
 	return result;
 }
+
+#include "moc_otr-peer-identity-verification-window-factory.cpp"
