@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,8 +22,7 @@
 
 #include "otr-peer-identity-verification-window-repository.h"
 
-OtrPeerIdentityVerificationWindowRepository::OtrPeerIdentityVerificationWindowRepository(QObject *parent) :
-		QObject(parent)
+OtrPeerIdentityVerificationWindowRepository::OtrPeerIdentityVerificationWindowRepository()
 {
 }
 
@@ -86,3 +85,5 @@ void OtrPeerIdentityVerificationWindowRepository::showVerificationWindow(const C
 		window->raise();
 	}
 }
+
+#include "moc_otr-peer-identity-verification-window-repository.cpp"
