@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,13 +17,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_PEER_IDENTITY_VERIFICATION_WINDOW_REPOSITORY_H
-#define OTR_PEER_IDENTITY_VERIFICATION_WINDOW_REPOSITORY_H
-
-#include <QtCore/QObject>
+#pragma once
 
 #include "contacts/contact.h"
 
+#include <QtCore/QObject>
+#include <injeqt/injeqt.h>
+
 class OtrPeerIdentityVerificationWindow;
 class OtrPeerIdentityVerificationWindowFactory;
 
@@ -42,11 +38,9 @@ private slots:
 	void windowDestroyed(const Contact &contact);
 
 public:
-	explicit OtrPeerIdentityVerificationWindowRepository(QObject *parent = 0);
+	Q_INVOKABLE OtrPeerIdentityVerificationWindowRepository();
 	virtual ~OtrPeerIdentityVerificationWindowRepository();
 
-	void setPeerIdentityVerificationWindowFactory(OtrPeerIdentityVerificationWindowFactory *peerIdentityVerificationWindowFactory);
-
 	OtrPeerIdentityVerificationWindow * windowForContact(const Contact &contact);
 
 public slots:
@@ -54,6 +48,7 @@ public slots:
 	void showRespondSharedSecretVerificationWindow(const Contact &contact);
 	void showVerificationWindow(const Contact &contact);
 
-};
+private slots:
+	INJEQT_SET void setPeerIdentityVerificationWindowFactory(OtrPeerIdentityVerificationWindowFactory *peerIdentityVerificationWindowFactory);
 
-#endif // OTR_PEER_IDENTITY_VERIFICATION_WINDOW_REPOSITORY_H
+};
