@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +20,7 @@
 #ifndef OTR_PEER_IDENTITY_VERIFICATION_WINDOW_H
 #define OTR_PEER_IDENTITY_VERIFICATION_WINDOW_H
 
-#include <QtGui/QWizard>
+#include <QtWidgets/QWizard>
 
 #include "contacts/contact.h"
 
@@ -45,7 +43,7 @@ public:
 		ResultPage
 	};
 
-	explicit OtrPeerIdentityVerificationWindow(const Contact &contact, QWidget *parent = 0);
+	explicit OtrPeerIdentityVerificationWindow(const Contact &contact, QWidget *parent = nullptr);
 	virtual ~OtrPeerIdentityVerificationWindow();
 
 	void showRespondQuestionAndAnswer(const QString &question);
