@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -34,7 +34,7 @@ class OtrAppOpsService : public QObject
 	OtrlMessageAppOps AppOps;
 
 public:
-	explicit OtrAppOpsService();
+	Q_INVOKABLE OtrAppOpsService();
 	virtual ~OtrAppOpsService();
 
 	const OtrlMessageAppOps * appOps() const;
