@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +22,8 @@ extern "C" {
 }
 
 #include "accounts/account-manager.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact-set.h"
@@ -35,7 +33,7 @@ extern "C" {
 #include "otr-context-converter.h"
 
 OtrContextConverter::OtrContextConverter(QObject *parent) :
-		QObject(parent)
+		QObject{parent}
 {
 }
 
@@ -43,38 +41,58 @@ OtrContextConverter::~OtrContextConverter()
 {
 }
 
+void OtrContextConverter::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void OtrContextConverter::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void OtrContextConverter::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void OtrContextConverter::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
 void OtrContextConverter::setUserStateService(OtrUserStateService *userStateService)
 {
-	UserStateService = userStateService;
+	m_userStateService = userStateService;
 }
 
 Chat OtrContextConverter::connectionContextToChat(ConnContext *context) const
 {
-	Contact contact = connectionContextToContact(context);
-	return ChatTypeContact::findChat(contact, ActionCreateAndAdd);
+	auto contact = connectionContextToContact(context);
+	return ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd);
 }
 
 Contact OtrContextConverter::connectionContextToContact(ConnContext *context) const
 {
-	Account account = AccountManager::instance()->byId(QString::fromUtf8(context->protocol), QString::fromUtf8(context->accountname));
-	return ContactManager::instance()->byId(account, QString::fromUtf8(context->username), ActionReturnNull);
+	auto account = m_accountManager->byId(QString::fromUtf8(context->protocol), QString::fromUtf8(context->accountname));
+	return m_contactManager->byId(account, QString::fromUtf8(context->username), ActionReturnNull);
 }
 
 ConnContext * OtrContextConverter::chatToContextConverter(const Chat &chat, NotFoundAction notFoundAction) const
 {
-	if (!UserStateService || !chat)
-		return 0;
-
-	return contactToContextConverter(chat.contacts().toContact(), notFoundAction);
-	
+	return chat
+			? contactToContextConverter(chat.contacts().toContact(), notFoundAction)
+			: nullptr;
 }
 
 ConnContext * OtrContextConverter::contactToContextConverter(const Contact &contact, NotFoundAction notFoundAction) const
 {
-	if (!UserStateService || !contact)
+	if (!contact)
 		return 0;
 
-	return otrl_context_find(UserStateService.data()->userState(), qPrintable(contact.id()), qPrintable(contact.contactAccount().id()),
+	return otrl_context_find(m_userStateService->userState(), qPrintable(contact.id()), qPrintable(contact.contactAccount().id()),
 							 qPrintable(contact.contactAccount().protocolName()), OTRL_INSTAG_BEST, notFoundAction == ActionCreateAndAdd,
 							 0, 0, 0);
 }
+
+#include "moc_otr-context-converter.cpp"
