@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,19 +17,23 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_CONTEXT_CONVERTER_H
-#define OTR_CONTEXT_CONVERTER_H
+#pragma once
 
 extern "C" {
 #	include <libotr/context.h>
 }
 
-#include <QtCore/QObject>
-#include <QtCore/QPointer>
-
 #include "storage/manager-common.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
+class ChatManager;
+class ChatStorage;
 class Chat;
+class ContactManager;
 class Contact;
 
 class OtrUserStateService;
@@ -41,20 +42,28 @@ class OtrContextConverter : public QObject
 {
 	Q_OBJECT
 
-	QPointer<OtrUserStateService> UserStateService;
-
 public:
-	explicit OtrContextConverter(QObject *parent = 0);
+	Q_INVOKABLE explicit OtrContextConverter(QObject *parent = nullptr);
 	virtual ~OtrContextConverter();
 
-	void setUserStateService(OtrUserStateService *userStateService);
-
 	Chat connectionContextToChat(ConnContext *context) const;
 	Contact connectionContextToContact(ConnContext *context) const;
 
 	ConnContext * chatToContextConverter(const Chat &chat, NotFoundAction notFoundAction = ActionReturnNull) const;
 	ConnContext * contactToContextConverter(const Contact &contact, NotFoundAction notFoundAction = ActionReturnNull) const;
 
-};
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<OtrUserStateService> m_userStateService;
 
-#endif // OTR_CONTEXT_CONVERTER_H
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
+
+};
