@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,7 +17,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QThread>
+#include <QtCore/QThread>
 
 extern "C" {
 #   include <libotr/privkey.h>
@@ -108,3 +107,5 @@ void OtrCreatePrivateKeyJob::workerFinished(bool ok)
 
 	emit finished(MyAccount, 0 == err);
 }
+
+#include "moc_otr-create-private-key-job.cpp"
