@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -45,7 +41,7 @@ private slots:
 	void workerFinished(bool ok);
 
 public:
-	explicit OtrCreatePrivateKeyJob(QObject *parent = 0);
+	explicit OtrCreatePrivateKeyJob(QObject *parent = nullptr);
 	virtual ~OtrCreatePrivateKeyJob();
 
 	void setUserStateService(OtrUserStateService *userStateService);
