@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +29,7 @@ class OtrCreatePrivateKeyWorker : public QObject
 	void *KeyPointer;
 
 public:
-	explicit OtrCreatePrivateKeyWorker(void *keyPointer, QObject *parent = 0);
+	explicit OtrCreatePrivateKeyWorker(void *keyPointer, QObject *parent = nullptr);
 	virtual ~OtrCreatePrivateKeyWorker();
 
 public slots:
