@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +23,8 @@ extern "C" {
 
 #include "accounts/account.h"
 #include "contacts/contact.h"
-#include "misc/kadu-paths.h"
+#include "core/core.h"
+#include "misc/paths-provider.h"
 
 #include "otr-context-converter.h"
 #include "otr-op-data.h"
@@ -40,8 +40,7 @@ void OtrFingerprintService::wrapperOtrWriteFingerprints(void *data)
 		opData->fingerprintService()->writeFingerprints();
 }
 
-OtrFingerprintService::OtrFingerprintService(QObject *parent) :
-		QObject(parent)
+OtrFingerprintService::OtrFingerprintService()
 {
 }
 
@@ -124,7 +123,7 @@ QString OtrFingerprintService::extractAccountFingerprint(const Account &account)
 		return QString();
 
 	fingerprint[OTRL_PRIVKEY_FPRINT_HUMAN_LEN - 1] = 0;
-	return QString(fingerprint);
+	return QString::fromLatin1(fingerprint);
 }
 
 QString OtrFingerprintService::extractContactFingerprint(const Contact &contact) const
@@ -140,5 +139,7 @@ QString OtrFingerprintService::extractContactFingerprint(const Contact &contact)
 	otrl_privkey_hash_to_human(fingerprint, context->active_fingerprint->fingerprint);
 
 	fingerprint[OTRL_PRIVKEY_FPRINT_HUMAN_LEN - 1] = 0;
-	return QString(fingerprint);
+	return QString::fromLatin1(fingerprint);
 }
+
+#include "moc_otr-fingerprint-service.cpp"
