@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,11 +17,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_FINGERPRINT_SERVICE_H
-#define OTR_FINGERPRINT_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class Account;
 class Contact;
@@ -36,10 +33,6 @@ class OtrFingerprintService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<OtrContextConverter> ContextConverter;
-	QPointer<OtrPathService> PathService;
-	QPointer<OtrUserStateService> UserStateService;
-
 public:
 	static void wrapperOtrWriteFingerprints(void *data);
 
@@ -49,13 +42,9 @@ public:
 		TrustVerified
 	};
 
-	explicit OtrFingerprintService(QObject *parent = 0);
+	Q_INVOKABLE OtrFingerprintService();
 	virtual ~OtrFingerprintService();
 
-	void setContextConverter(OtrContextConverter *contextConverter);
-	void setPathService(OtrPathService *pathService);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 	void readFingerprints() const;
 	void writeFingerprints() const;
 
@@ -68,6 +57,16 @@ public:
 signals:
 	void fingerprintsUpdated() const;
 
-};
+private slots:
+	INJEQT_SET void setContextConverter(OtrContextConverter *contextConverter);
+	INJEQT_SET void setPathService(OtrPathService *pathService);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
 
-#endif // OTR_FINGERPRINT_SERVICE_H
+private:
+	QPointer<OtrContextConverter> ContextConverter;
+	QPointer<OtrPathService> PathService;
+	QPointer<OtrUserStateService> UserStateService;
+
+	QString fingerprintsStoreFileName() const;
+
+};
