@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,7 +18,8 @@
  */
 
 #include "accounts/account.h"
-#include "misc/kadu-paths.h"
+#include "core/core.h"
+#include "misc/paths-provider.h"
 
 #include "otr-op-data.h"
 #include "otr-path-service.h"
@@ -36,8 +37,7 @@ void OtrInstanceTagService::wrapperOtrCreateInstanceTag(void *data, const char *
 		opData->instanceTagService()->createInstanceTag(opData->contact().contactAccount());
 }
 
-OtrInstanceTagService::OtrInstanceTagService(QObject *parent) :
-		QObject(parent)
+OtrInstanceTagService::OtrInstanceTagService()
 {
 }
 
@@ -83,3 +83,5 @@ void OtrInstanceTagService::createInstanceTag(const Account &account)
 						 account.id().toUtf8().data(), account.protocolName().toUtf8().data());
 	writeInstanceTags();
 }
+
+#include "moc_otr-instance-tag-service.cpp"
