@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,11 +17,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_INSTANCE_TAG_SERVICE_H
-#define OTR_INSTANCE_TAG_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 extern "C" {
 #	include <libotr/proto.h>
@@ -40,22 +36,24 @@ class OtrInstanceTagService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<OtrPathService> PathService;
-	QPointer<OtrUserStateService> UserStateService;
-
 public:
 	static void wrapperOtrCreateInstanceTag(void *data, const char *accountName, const char *protocol);
 
-	explicit OtrInstanceTagService(QObject *parent = 0);
+	Q_INVOKABLE OtrInstanceTagService();
 	virtual ~OtrInstanceTagService();
 
-	void setPathService(OtrPathService *pathService);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 	void readInstanceTags();
 	void writeInstanceTags();
 	void createInstanceTag(const Account &account);
 
-};
+private slots:
+	INJEQT_SET void setPathService(OtrPathService *pathService);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
 
-#endif // OTR_INSTANCE_TAG_SERVICE_H
+private:
+	QPointer<OtrPathService> PathService;
+	QPointer<OtrUserStateService> UserStateService;
+
+	QString instanceTagsFileName() const;
+
+};
