@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@ int OtrIsLoggedInService::wrapperOtrIsLoggedIn(void *data, const char *accountNa
 }
 
 OtrIsLoggedInService::OtrIsLoggedInService(QObject *parent) :
-		QObject(parent)
+		QObject{parent}
 {
 }
 
@@ -47,15 +47,12 @@ OtrIsLoggedInService::~OtrIsLoggedInService()
 
 void OtrIsLoggedInService::setContactManager(ContactManager *contactManager)
 {
-	CurrentContactManager = contactManager;
+	m_contactManager = contactManager;
 }
 
 OtrIsLoggedInService::IsLoggedInStatus OtrIsLoggedInService::isLoggedIn(const Account &account, const QString &contactId)
 {
-	if (!CurrentContactManager)
-		return NotSure;
-
-	Contact contact = CurrentContactManager.data()->byId(account, contactId, ActionReturnNull);
+	auto contact = m_contactManager->byId(account, contactId, ActionReturnNull);
 
 	if (!contact)
 		return NotSure;
@@ -65,3 +62,5 @@ OtrIsLoggedInService::IsLoggedInStatus OtrIsLoggedInService::isLoggedIn(const Ac
 	else
 		return LoggedIn;
 }
+
+#include "moc_otr-is-logged-in-service.cpp"
