@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +17,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_IS_LOGGED_IN_SERVICE_H
-#define OTR_IS_LOGGED_IN_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
@@ -34,8 +29,6 @@ class OtrIsLoggedInService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<ContactManager> CurrentContactManager;
-
 public:
 	enum IsLoggedInStatus
 	{
@@ -46,13 +39,15 @@ public:
 
 	static int wrapperOtrIsLoggedIn(void *data, const char *accountName, const char *protocol, const char *recipient);
 
-	explicit OtrIsLoggedInService(QObject *parent = 0);
+	Q_INVOKABLE explicit OtrIsLoggedInService(QObject *parent = nullptr);
 	virtual ~OtrIsLoggedInService();
 
-	void setContactManager(ContactManager *contactManager);
-
 	IsLoggedInStatus isLoggedIn(const Account &account, const QString &contactId);
 
-};
+private:
+	QPointer<ContactManager> m_contactManager;
 
-#endif // OTR_IS_LOGGED_IN_SERVICE_H
+private slots:
+	void setContactManager(ContactManager *contactManager);
+
+};
