@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,15 +17,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "chat/type/chat-type-contact.h"
-#include "core/core.h"
-#include "gui/widgets/chat-widget/chat-widget-manager.h"
-#include "gui/widgets/chat-widget/chat-widget-repository.h"
-#include "gui/widgets/chat-widget/chat-widget.h"
+#include "otr-message-event-service.h"
 
 #include "otr-op-data.h"
 
-#include "otr-message-event-service.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
+#include "chat/type/chat-type-contact.h"
+#include "gui/widgets/chat-widget/chat-widget-repository.h"
+#include "gui/widgets/chat-widget/chat-widget.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
 
 void OtrMessageEventService::wrapperOtrHandleMessageEvent(void *data, OtrlMessageEvent event, ConnContext *context, const char *message, gcry_error_t error)
 {
@@ -36,8 +38,7 @@ void OtrMessageEventService::wrapperOtrHandleMessageEvent(void *data, OtrlMessag
 		opData->messageEventService()->handleMessageEvent(opData->contact(), event, message, error);
 }
 
-OtrMessageEventService::OtrMessageEventService(QObject *parent) :
-		QObject(parent)
+OtrMessageEventService::OtrMessageEventService()
 {
 }
 
@@ -45,9 +46,19 @@ OtrMessageEventService::~OtrMessageEventService()
 {
 }
 
-void OtrMessageEventService::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+void OtrMessageEventService::setChatManager(ChatManager *chatManager)
 {
-	CurrentChatWidgetManager = chatWidgetManager;
+	m_chatManager = chatManager;
+}
+
+void OtrMessageEventService::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void OtrMessageEventService::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
+{
+	m_chatWidgetRepository = chatWidgetRepository;
 }
 
 void OtrMessageEventService::handleMessageEvent(const Contact &contact, OtrlMessageEvent event, const QString &message, gcry_error_t errorCode) const
@@ -57,10 +68,10 @@ void OtrMessageEventService::handleMessageEvent(const Contact &contact, OtrlMess
 	if (errorMessage.isEmpty())
 		return;
 
-	auto chat = ChatTypeContact::findChat(contact, ActionCreateAndAdd);
-	auto chatWidget = Core::instance()->chatWidgetRepository()->widgetForChat(chat);
+	auto chat = ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd);
+	auto chatWidget = m_chatWidgetRepository->widgetForChat(chat);
 	if (chatWidget)
-		chatWidget->appendSystemMessage(errorMessage);
+		chatWidget->appendSystemMessage(normalizeHtml(plainToHtml(errorMessage)));
 }
 
 QString OtrMessageEventService::messageString(OtrlMessageEvent event, const QString &message, gcry_error_t errorCode, const QString &peerDisplay) const
@@ -110,3 +121,5 @@ QString OtrMessageEventService::gpgErrorString(gcry_error_t errorCode) const
 			return gcry_strerror(errorCode);
 	}
 }
+
+#include "moc_otr-message-event-service.cpp"
