@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,39 +17,45 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_MESSAGE_EVENT_SERVICE_H
-#define OTR_MESSAGE_EVENT_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 extern "C" {
 #	include <libotr/proto.h>
 #	include <libotr/message.h>
 }
 
-class ChatWidgetManager;
+class ChatManager;
+class ChatStorage;
+class ChatWidgetRepository;
 class Contact;
 
 class OtrMessageEventService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<ChatWidgetManager> CurrentChatWidgetManager;
+public:
+	static void wrapperOtrHandleMessageEvent(void *data, OtrlMessageEvent event, ConnContext *context, const char *message, gcry_error_t error);
+
+	Q_INVOKABLE OtrMessageEventService();
+	virtual ~OtrMessageEventService();
+
+	void handleMessageEvent(const Contact &contact, OtrlMessageEvent event, const QString &message, gcry_error_t errorCode) const;
+
+private:
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+	QPointer<ChatWidgetRepository> m_chatWidgetRepository;
 
 	QString messageString(OtrlMessageEvent event, const QString &message, gcry_error_t errorCode, const QString &peerDisplay) const;
 	QString gpgErrorString(gcry_error_t errorCode) const;
 
-public:
-	static void wrapperOtrHandleMessageEvent(void *data, OtrlMessageEvent event, ConnContext *context, const char *message, gcry_error_t error);
-
-	explicit OtrMessageEventService(QObject *parent = 0);
-	virtual ~OtrMessageEventService();
-
-	void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
-
-	void handleMessageEvent(const Contact &contact, OtrlMessageEvent event, const QString &message, gcry_error_t errorCode) const;
+private slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
 
 };
-
-#endif // OTR_MESSAGE_EVENT_SERVICE_H
