@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,6 +18,8 @@
  */
 
 #include "accounts/account.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/chat.h"
 #include "chat/type/chat-type-contact.h"
 #include "message/message-manager.h"
@@ -69,8 +71,7 @@ void OtrMessageService::wrapperOtrResentMessagePrefixFree(void *data, const char
 	free(const_cast<char *>(prefix));
 }
 
-OtrMessageService::OtrMessageService(QObject *parent) :
-		QObject(parent)
+OtrMessageService::OtrMessageService()
 {
 }
 
@@ -78,6 +79,16 @@ OtrMessageService::~OtrMessageService()
 {
 }
 
+void OtrMessageService::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void OtrMessageService::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
 void OtrMessageService::setMessageManager(MessageManager *messageManager)
 {
 	CurrentMessageManager = messageManager;
@@ -88,7 +99,7 @@ void OtrMessageService::injectMessage(const Contact &contact, const QByteArray &
 	if (!CurrentMessageManager)
 		return;
 
-	Chat chat = ChatTypeContact::findChat(contact, ActionCreateAndAdd);
+	Chat chat = ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd);
 	CurrentMessageManager.data()->sendRawMessage(chat, message);
 }
 
@@ -107,3 +118,5 @@ QString OtrMessageService::resentMessagePrefix() const
 {
 	return tr("[resent]");
 }
+
+#include "moc_otr-message-service.cpp"
