@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,17 +17,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_MESSAGE_SERVICE_H
-#define OTR_MESSAGE_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 extern "C" {
 #	include <libotr/proto.h>
 }
 
 class Account;
+class ChatManager;
+class ChatStorage;
 class Contact;
 class MessageManager;
 
@@ -39,23 +37,27 @@ class OtrMessageService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<MessageManager> CurrentMessageManager;
-
 public:
 	static void wrapperOtrInjectMessage(void *data, const char *accountName, const char *protocol, const char *recipient, const char *message);
 	static int wrapperOtrMaxMessageSize(void *data, ConnContext *context);
 	static const char * wrapperOtrResentMessagePrefix(void *data, ConnContext *context);
 	static void wrapperOtrResentMessagePrefixFree(void *data, const char *prefix);
 
-	explicit OtrMessageService(QObject *parent = 0);
+	Q_INVOKABLE OtrMessageService();
 	virtual ~OtrMessageService();
 
-	void setMessageManager(MessageManager *messageManager);
-
 	void injectMessage(const Contact &contact, const QByteArray &message) const;
 	int maxMessageSize(const Account &account) const;
 	QString resentMessagePrefix() const;
 
-};
+private:
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+	QPointer<MessageManager> CurrentMessageManager;
 
-#endif // OTR_MESSAGE_SERVICE_H
+private slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setMessageManager(MessageManager *messageManager);
+
+};
