@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,16 +17,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_NOTIFIER_H
-#define OTR_NOTIFIER_H
+#pragma once
+
+#include "notification/notification-event.h"
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class Account;
+class ChatManager;
+class ChatStorage;
 class ChatWidgetRepository;
 class Contact;
-class NotifyEvent;
+class NormalizedHtmlString;
+class NotificationService;
 
 class OtrNotifier : public QObject
 {
@@ -40,24 +41,30 @@ class OtrNotifier : public QObject
 	static QString CreatePrivateKeyStartedNotifyTopic;
 	static QString CreatePrivateKeyFinishedNotifyTopic;
 
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
 	QPointer<ChatWidgetRepository> MyChatWidgetRepository;
+	QPointer<NotificationService> m_notificationService;
 
-	QScopedPointer<NotifyEvent> OtrNotifyEvent;
-	QScopedPointer<NotifyEvent> CreatePrivateKeyStartedNotifyEvent;
-	QScopedPointer<NotifyEvent> CreatePrivateKeyFinishedNotifyEvent;
+	NotificationEvent OtrNotificationEvent;
+	NotificationEvent CreatePrivateKeyStartedNotificationEvent;
+	NotificationEvent CreatePrivateKeyFinishedNotificationEvent;
 
-	void notify(const QString &topic, const Account &account, const QString &message);
-	void notify(const Contact &contact, const QString &message);
+	void notify(const QString &topic, const Account &account, const NormalizedHtmlString &message);
+	void notify(const Contact &contact, const NormalizedHtmlString &message);
 
 public:
-	explicit OtrNotifier(QObject *parent = 0);
+	Q_INVOKABLE OtrNotifier();
 	virtual ~OtrNotifier();
 
-	void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
-
-	QList<NotifyEvent *> notifyEvents();
+	QList<NotificationEvent> notifyEvents();
 
 public slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+	INJEQT_SET void setNotificationService(NotificationService *notificationService);
+
 	void notifyTryingToStartSession(const Contact &contact);
 	void notifyTryingToRefreshSession(const Contact &contact);
 	void notifyPeerEndedSession(const Contact &contact);
@@ -68,5 +75,3 @@ public slots:
 	void notifyCreatePrivateKeyFinished(const Account &account, bool ok);
 
 };
-
-#endif // OTR_NOTIFIER_H
