@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,24 +19,28 @@
 
 #include "otr-path-service.h"
 
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 
 #include <QtCore/QDir>
 
 OtrPathService::OtrPathService(QObject *parent) :
 		QObject{parent}
 {
-	m_dir = KaduPaths::instance()->profilePath() + QString("/keys/");
-
-	QDir dir{m_dir};
-	if (!dir.exists())
-		dir.mkpath(".");
 }
 
 OtrPathService::~OtrPathService()
 {
 }
 
+void OtrPathService::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_dir = pathsProvider->profilePath() + QString("/keys/");
+
+	QDir dir{m_dir};
+	if (!dir.exists())
+		dir.mkpath(".");
+}
+
 QString OtrPathService::fingerprintsStoreFilePath() const
 {
 	return m_dir + QString{"otr_fingerprints"};
@@ -51,3 +55,5 @@ QString OtrPathService::privateKeysStoreFilePath() const
 {
 	return m_dir + QString{"otr_private"};
 }
+
+#include "moc_otr-path-service.cpp"
