@@ -20,13 +20,16 @@
 #pragma once
 
 #include <QtCore/QObject>
+#include <injeqt/injeqt.h>
+
+class PathsProvider;
 
 class OtrPathService : public QObject
 {
 	Q_OBJECT
 
 public:
-	Q_INVOKABLE explicit OtrPathService(QObject *parent = 0);
+	Q_INVOKABLE explicit OtrPathService(QObject *parent = nullptr);
 	virtual ~OtrPathService();
 
 	QString fingerprintsStoreFilePath() const;
@@ -36,4 +39,7 @@ public:
 private:
 	QString m_dir;
 
+private slots:
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+
 };
