@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -42,8 +38,7 @@ void OtrPeerIdentityVerificationService::wrapperHandleSmpEvent(void *data, OtrlS
 		opData->peerIdentityVerificationService()->handleSmpEvent(opData->contact(), smpEvent, progressPercent, QString::fromUtf8(question));
 }
 
-OtrPeerIdentityVerificationService::OtrPeerIdentityVerificationService(QObject *parent) :
-		QObject(parent)
+OtrPeerIdentityVerificationService::OtrPeerIdentityVerificationService()
 {
 }
 
@@ -167,3 +162,5 @@ void OtrPeerIdentityVerificationService::handleSmpEvent(const Contact &contact,
 
 	updateContactState(contact, OtrPeerIdentityVerificationState(state, progressPercent));
 }
+
+#include "moc_otr-peer-identity-verification-service.cpp"
