@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,12 +17,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_PEER_IDENTITY_VERIFICATION_SERVICE_H
-#define OTR_PEER_IDENTITY_VERIFICATION_SERVICE_H
+#pragma once
 
 #include <QtCore/QMap>
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 extern "C" {
 #	include <libotr/proto.h>
@@ -44,24 +41,12 @@ class OtrPeerIdentityVerificationService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<OtrAppOpsService> AppOpsService;
-	QPointer<OtrContextConverter> ContextConverter;
-	QPointer<OtrOpDataFactory> OpDataFactory;
-	QPointer<OtrUserStateService> UserStateService;
-
-	void handleSmpEvent(const Contact &contact, OtrlSMPEvent smpEvent, int progressPercent, const QString &question);
-
 public:
 	static void wrapperHandleSmpEvent(void *data, OtrlSMPEvent smpEvent, ConnContext *context, unsigned short progressPercent, char *question);
 
-	explicit OtrPeerIdentityVerificationService(QObject *parent = 0);
+	Q_INVOKABLE OtrPeerIdentityVerificationService();
 	virtual ~OtrPeerIdentityVerificationService();
 
-	void setAppOpsService(OtrAppOpsService *appOpsService);
-	void setContextConverter(OtrContextConverter *contextConverter);
-	void setOpDataFactory(OtrOpDataFactory *opDataFactory);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 public slots:
 	void updateContactState(const Contact &contact, const OtrPeerIdentityVerificationState &state);
 	void startQuestionAndAnswerVerification(const Contact &contact, const QString &question, const QString &answer);
@@ -74,6 +59,18 @@ signals:
 	void sharedSecretRequested(const Contact &contact);
 	void contactStateUpdated(const Contact &contact, const OtrPeerIdentityVerificationState &state);
 
-};
+private slots:
+	INJEQT_SET void setAppOpsService(OtrAppOpsService *appOpsService);
+	INJEQT_SET void setContextConverter(OtrContextConverter *contextConverter);
+	INJEQT_SET void setOpDataFactory(OtrOpDataFactory *opDataFactory);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
 
-#endif // OTR_PEER_IDENTITY_VERIFICATION_SERVICE_H
+private:
+	QPointer<OtrAppOpsService> AppOpsService;
+	QPointer<OtrContextConverter> ContextConverter;
+	QPointer<OtrOpDataFactory> OpDataFactory;
+	QPointer<OtrUserStateService> UserStateService;
+
+	void handleSmpEvent(const Contact &contact, OtrlSMPEvent smpEvent, int progressPercent, const QString &question);
+
+};
