@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -38,8 +36,7 @@ OtrlPolicy OtrPolicyService::wrapperOtrPolicy(void *data, ConnContext *context)
 		return OtrPolicy::PolicyManual.toOtrPolicy();
 }
 
-OtrPolicyService::OtrPolicyService(QObject *parent) :
-		QObject(parent)
+OtrPolicyService::OtrPolicyService()
 {
 }
 
@@ -79,3 +76,5 @@ OtrPolicy OtrPolicyService::contactPolicy(const Contact &contact) const
 	else
 		return fromBuddy;
 }
+
+#include "moc_otr-policy-service.cpp"
