@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +23,8 @@ extern "C" {
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "misc/kadu-paths.h"
+#include "core/core.h"
+#include "misc/paths-provider.h"
 
 #include "otr-create-private-key-job.h"
 #include "otr-op-data.h"
@@ -46,8 +46,7 @@ void OtrPrivateKeyService::wrapperOtrCreatePrivateKey(void *data, const char *ac
 	}
 }
 
-OtrPrivateKeyService::OtrPrivateKeyService(QObject *parent) :
-		QObject(parent)
+OtrPrivateKeyService::OtrPrivateKeyService()
 {
 }
 
@@ -98,3 +97,5 @@ void OtrPrivateKeyService::readPrivateKeys()
 	OtrlUserState userState = UserStateService->userState();
 	otrl_privkey_read(userState, PathService->privateKeysStoreFilePath().toUtf8().data());
 }
+
+#include "moc_otr-private-key-service.cpp"
