@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,12 +17,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_PRIVATE_KEY_SERVICE_H
-#define OTR_PRIVATE_KEY_SERVICE_H
+#pragma once
 
 #include <QtCore/QMap>
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class Account;
 
@@ -38,22 +34,12 @@ class OtrPrivateKeyService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<OtrPathService> PathService;
-	QPointer<OtrUserStateService> UserStateService;
-	QMap<Account, OtrCreatePrivateKeyJob *> CreateJobs;
-
-private slots:
-	void jobFinished(const Account &account, bool ok);
-
 public:
 	static void wrapperOtrCreatePrivateKey(void *data, const char *accountName, const char *protocol);
 
-	explicit OtrPrivateKeyService(QObject *parent = 0);
+	Q_INVOKABLE OtrPrivateKeyService();
 	virtual ~OtrPrivateKeyService();
 
-	void setPathService(OtrPathService *pathService);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 	void createPrivateKey(const Account &account);
 	void readPrivateKeys();
 
@@ -61,7 +47,17 @@ signals:
 	void createPrivateKeyStarted(const Account &account);
 	void createPrivateKeyFinished(const Account &account, bool ok);
 
+private slots:
+	INJEQT_SET void setPathService(OtrPathService *pathService);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
+
+	void jobFinished(const Account &account, bool ok);
+
+private:
+	QPointer<OtrPathService> PathService;
+	QPointer<OtrUserStateService> UserStateService;
+	QMap<Account, OtrCreatePrivateKeyJob *> CreateJobs;
+
+	QString privateStoreFileName() const;
+
 };
-
-
-#endif // OTR_PRIVATE_KEY_SERVICE_H
