@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,8 +23,12 @@ extern "C" {
 }
 
 #include "accounts/account.h"
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/chat.h"
 #include "chat/type/chat-type-contact.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
 #include "message/message-manager.h"
 
 #include "otr-app-ops-service.h"
@@ -66,8 +69,7 @@ void OtrSessionService::wrapperOtrStillSecure(void *data, ConnContext *context,
 		emit opData->sessionService()->stillSecure(opData->contact());
 }
 
-OtrSessionService::OtrSessionService(QObject *parent) :
-		QObject(parent)
+OtrSessionService::OtrSessionService()
 {
 }
 
@@ -80,6 +82,16 @@ void OtrSessionService::setAppOpsService(OtrAppOpsService *appOpsService)
 	AppOpsService = appOpsService;
 }
 
+void OtrSessionService::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void OtrSessionService::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
 void OtrSessionService::setMessageManager(MessageManager *messageManager)
 {
 	CurrentMessageManager = messageManager;
@@ -110,18 +122,17 @@ void OtrSessionService::startSession(const Contact &contact)
 	if (!CurrentMessageManager || !PolicyService || !TrustLevelService)
 		return;
 
-	OtrTrustLevelService::TrustLevel level = TrustLevelService->loadTrustLevelFromContact(contact);
-
-	Account account = contact.contactAccount();
-	OtrPolicy otrPolicy = PolicyService->accountPolicy(account);
-	QString message = QString::fromUtf8(otrl_proto_default_query_msg(qPrintable(account.id()), otrPolicy.toOtrPolicy()));
+	auto level = TrustLevelService->loadTrustLevelFromContact(contact);
+	auto account = contact.contactAccount();
+	auto otrPolicy = PolicyService->accountPolicy(account);
+	auto message = normalizeHtml(HtmlString{QString::fromUtf8(otrl_proto_default_query_msg(qPrintable(account.id()), otrPolicy.toOtrPolicy()))});
 
 	if (level == OtrTrustLevelService::TrustLevelNotPrivate)
 		emit tryingToStartSession(contact);
 	else
 		emit tryingToRefreshSession(contact);
 
-	CurrentMessageManager->sendMessage(ChatTypeContact::findChat(contact, ActionCreateAndAdd), message, true);
+	CurrentMessageManager->sendMessage(ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd), message, true);
 }
 
 void OtrSessionService::endSession(const Contact &contact)
@@ -138,3 +149,5 @@ void OtrSessionService::endSession(const Contact &contact)
 
 	emit goneInsecure(contact);
 }
+
+#include "moc_otr-session-service.cpp"
