@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,16 +17,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_SESSION_SERVICE_H
-#define OTR_SESSION_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 extern "C" {
 #	include <libotr/proto.h>
 }
 
+class ChatManager;
+class ChatStorage;
 class Contact;
 class MessageManager;
 
@@ -43,28 +42,14 @@ class OtrSessionService : public QObject
 {
 	Q_OBJECT
 
-	QPointer<MessageManager> CurrentMessageManager;
-	QPointer<OtrAppOpsService> AppOpsService;
-	QPointer<OtrOpDataFactory> OpDataFactory;
-	QPointer<OtrPolicyService> PolicyService;
-	QPointer<OtrTrustLevelService> TrustLevelService;
-	QPointer<OtrUserStateService> UserStateService;
-
 public:
 	static void wrapperOtrGoneSecure(void *data, ConnContext *context);
 	static void wrapperOtrGoneInsecure(void *data, ConnContext *context);
 	static void wrapperOtrStillSecure(void *data, ConnContext *context, int isReply);
 
-	explicit OtrSessionService(QObject *parent = 0);
+	Q_INVOKABLE OtrSessionService();
 	virtual ~OtrSessionService();
 
-	void setAppOpsService(OtrAppOpsService *appOpsService);
-	void setMessageManager(MessageManager *messageManager);
-	void setOpDataFactory(OtrOpDataFactory *opDataFactory);
-	void setPolicyService(OtrPolicyService *policyService);
-	void setTrustLevelService(OtrTrustLevelService *trustLevelService);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 public slots:
 	void startSession(const Contact &contact);
 	void endSession(const Contact &contact);
@@ -77,6 +62,24 @@ signals:
 	void goneInsecure(const Contact &contact) const;
 	void stillSecure(const Contact &contact) const;
 
-};
+private slots:
+	INJEQT_SET void setAppOpsService(OtrAppOpsService *appOpsService);
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setMessageManager(MessageManager *messageManager);
+	INJEQT_SET void setOpDataFactory(OtrOpDataFactory *opDataFactory);
+	INJEQT_SET void setPolicyService(OtrPolicyService *policyService);
+	INJEQT_SET void setTrustLevelService(OtrTrustLevelService *trustLevelService);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
 
-#endif // OTR_SESSION_SERVICE_H
+private:
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+	QPointer<MessageManager> CurrentMessageManager;
+	QPointer<OtrAppOpsService> AppOpsService;
+	QPointer<OtrOpDataFactory> OpDataFactory;
+	QPointer<OtrPolicyService> PolicyService;
+	QPointer<OtrTrustLevelService> TrustLevelService;
+	QPointer<OtrUserStateService> UserStateService;
+
+};
