@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -41,8 +40,8 @@ void OtrTimerService::wrapperOtrTimerControl(void *data, unsigned int interval)
 		opData->timerService()->timerControl(interval);
 }
 
-OtrTimerService::OtrTimerService(QObject *parent) :
-		QObject(parent), Timer(0)
+OtrTimerService::OtrTimerService() :
+		Timer(0)
 {
 }
 
@@ -99,3 +98,5 @@ void OtrTimerService::timerControl(unsigned int intervalInSeconds)
 	else
 		Timer->stop();
 }
+
+#include "moc_otr-timer-service.cpp"
