@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,11 +17,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_TIMER_SERVICE_H
-#define OTR_TIMER_SERVICE_H
+#pragma once
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class QTimer;
 
@@ -37,6 +33,21 @@ class OtrTimerService : public QObject
 {
 	Q_OBJECT
 
+private slots:
+	void otrTimerTimeout();
+
+public:
+	static void wrapperOtrTimerControl(void *data, unsigned int interval);
+
+	Q_INVOKABLE OtrTimerService();
+	virtual ~OtrTimerService();
+
+private slots:
+	INJEQT_SET void setAppOpsService(OtrAppOpsService *appOpsService);
+	INJEQT_SET void setOpDataFactory(OtrOpDataFactory *opDataFactory);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
+
+private:
 	QPointer<OtrAppOpsService> AppOpsService;
 	QPointer<OtrOpDataFactory> OpDataFactory;
 	QPointer<OtrUserStateService> UserStateService;
@@ -45,19 +56,4 @@ class OtrTimerService : public QObject
 
 	void timerControl(unsigned int intervalInSeconds);
 
-private slots:
-	void otrTimerTimeout();
-
-public:
-	static void wrapperOtrTimerControl(void *data, unsigned int interval);
-
-	explicit OtrTimerService(QObject *parent = 0);
-	virtual ~OtrTimerService();
-
-	void setAppOpsService(OtrAppOpsService *appOpsService);
-	void setOpDataFactory(OtrOpDataFactory *opDataFactory);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 };
-
-#endif // OTR_TIMER_SERVICE_H
