@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -33,8 +32,7 @@ void OtrTrustLevelService::wrapperOtrUpdateContextList(void *data)
 		opData->trustLevelService()->updateTrustLevels();
 }
 
-OtrTrustLevelService::OtrTrustLevelService(QObject *parent) :
-		QObject(parent)
+OtrTrustLevelService::OtrTrustLevelService()
 {
 }
 
@@ -101,3 +99,5 @@ void OtrTrustLevelService::updateTrustLevels()
 
 	emit trustLevelsUpdated();
 }
+
+#include "moc_otr-trust-level-service.cpp"
