@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +17,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OTR_TRUST_LEVEL_SERVICE_H
-#define OTR_TRUST_LEVEL_SERVICE_H
+#pragma once
 
 extern "C" {
 #	include <libotr/context.h>
@@ -30,6 +25,7 @@ extern "C" {
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class Contact;
 
@@ -54,12 +50,9 @@ public:
 		TrustLevelPrivate
 	};
 
-	explicit OtrTrustLevelService(QObject *parent = 0);
+	Q_INVOKABLE OtrTrustLevelService();
 	virtual ~OtrTrustLevelService();
 
-	void setContextConverter(OtrContextConverter *contextConverter);
-	void setUserStateService(OtrUserStateService *userStateService);
-
 	void storeTrustLevelToContact(const Contact &contact, TrustLevel level) const;
 	TrustLevel loadTrustLevelFromContact(const Contact &contact) const;
 
@@ -71,6 +64,8 @@ public slots:
 signals:
 	void trustLevelsUpdated();
 
-};
+private slots:
+	INJEQT_SET void setContextConverter(OtrContextConverter *contextConverter);
+	INJEQT_SET void setUserStateService(OtrUserStateService *userStateService);
 
-#endif // OTR_TRUST_LEVEL_SERVICE_H
+};
