@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,8 +19,7 @@
 
 #include "otr-user-state-service.h"
 
-OtrUserStateService::OtrUserStateService(QObject *parent) :
-		QObject(parent)
+OtrUserStateService::OtrUserStateService()
 {
 	UserState = otrl_userstate_create();
 }
@@ -37,3 +33,5 @@ OtrlUserState OtrUserStateService::userState() const
 {
 	return UserState;
 }
+
+#include "moc_otr-user-state-service.cpp"
