@@ -386,4 +386,11 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>OtrPluginObject</name>
+    <message>
+        <source>OTR encryption library could not be initialized</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 </TS>
\ No newline at end of file
