@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -386,4 +388,11 @@
         <translation>Verify Identity of %1</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>OtrPluginObject</name>
+    <message>
+        <source>OTR encryption library could not be initialized</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
