@@ -386,4 +386,11 @@
         <translation>Zweryfikuj tożsamość %1</translation>
     </message>
 </context>
+<context>
+    <name>OtrPluginObject</name>
+    <message>
+        <source>OTR encryption library could not be initialized</source>
+        <translation>Biblioteka szyfrująca OTR nie została znaleziona</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
