@@ -1,9 +1,9 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>Run command</source>
-        <translation type="unfinished"/>
+        <translation>Executar comando</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
