@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -7,35 +7,35 @@
     </message>
     <message>
         <source>File with description to synchronize</source>
-        <translation type="unfinished"/>
+        <translation>Arquivo com descrição para sincronizar</translation>
     </message>
     <message>
         <source>Enter here a file, which will contain descriptions to refresh by module.</source>
-        <translation type="unfinished"/>
+        <translation>Selecione um arquivo que irá conter as descrições para atualizar pelo módulo.</translation>
     </message>
     <message>
         <source>If you choose status without description, module will set it automatically to similar but with description</source>
-        <translation type="unfinished"/>
+        <translation>Se voce escolher um status sem descrição, o módulo irá automaticamente utilizar um similar, mas com descrição</translation>
     </message>
     <message>
         <source>Allow other descriptions</source>
-        <translation type="unfinished"/>
+        <translation>Permitir outras descrições</translation>
     </message>
     <message>
         <source>Allows you to set some custom description manualy, until file contents does not change</source>
-        <translation type="unfinished"/>
+        <translation>Permite que você defina algumas descrições personalizadas manualmente, enquanto o conteúdo do arquivo não muda</translation>
     </message>
     <message>
         <source>Behavior</source>
-        <translation type="unfinished"/>
+        <translation>Comportamento</translation>
     </message>
     <message>
         <source>Description</source>
-        <translation type="unfinished"/>
+        <translation>Descrição</translation>
     </message>
     <message>
         <source>Always add description to status</source>
-        <translation type="unfinished"/>
+        <translation>Sempre insira a descrição para o status</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
