@@ -1,41 +1,41 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>FileDesc</source>
-        <translation type="unfinished"/>
+        <translation>FileDesc</translation>
     </message>
     <message>
         <source>File with description to synchronize</source>
-        <translation type="unfinished"/>
+        <translation>Dosyayı tanımlama ile eşitle</translation>
     </message>
     <message>
         <source>Enter here a file, which will contain descriptions to refresh by module.</source>
-        <translation type="unfinished"/>
+        <translation>Buraya bir dosya girin, hangi modül yenilemek için tanımlamalarını içerecektir.</translation>
     </message>
     <message>
         <source>If you choose status without description, module will set it automatically to similar but with description</source>
-        <translation type="unfinished"/>
+        <translation>Eğer tanımlama olmadan durumunu seçerseniz, modül otomatik olarak benzerini ayarlayacaktır ama tanımlama ile</translation>
     </message>
     <message>
         <source>Allow other descriptions</source>
-        <translation type="unfinished"/>
+        <translation>Diğer tanımlamalara izin ver</translation>
     </message>
     <message>
         <source>Allows you to set some custom description manualy, until file contents does not change</source>
-        <translation type="unfinished"/>
+        <translation>Manuel olarak bazı özel tanımlama ayarlamanıza izin verir</translation>
     </message>
     <message>
         <source>Behavior</source>
-        <translation type="unfinished"/>
+        <translation>Davranış</translation>
     </message>
     <message>
         <source>Description</source>
-        <translation type="unfinished"/>
+        <translation>Tanımlama</translation>
     </message>
     <message>
         <source>Always add description to status</source>
-        <translation type="unfinished"/>
+        <translation>Her zaman tanımlamaları duruma ekle</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
