@@ -90,85 +90,6 @@
         <translation>Reacción a la respuesta correcta</translation>
     </message>
 </context>
-<context>
-    <name>Firewall</name>
-    <message>
-        <source>I want something</source>
-        <translation>Yo quiero algo</translation>
-    </message>
-    <message>
-        <source>flooding DoS attack with emoticons!</source>
-        <translation>¡ataque de inundación DoS con emoticonos!</translation>
-    </message>
-    <message>
-        <source>flooding DoS attack!</source>
-        <translation>¡ataque de inundación DoS!</translation>
-    </message>
-    <message>
-        <source>Chat with anonim silently dropped.
-</source>
-        <translation>Conversación con anónimo abandonada en silencio.
-</translation>
-    </message>
-    <message>
-        <source>OK, now say hello, and introduce yourself ;-)</source>
-        <translation>OK, ahora saluda, y presentate ;-)</translation>
-    </message>
-    <message>
-        <source>User wrote right answer!
-</source>
-        <translation>¡El usuario escribió la respuesta correcta!
-</translation>
-    </message>
-    <message>
-        <source>This message has been generated AUTOMATICALLY!
-
-I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
-        <translation>!Este mensaje ha sido generado AUTOMÁTICAMENTE!
-
-Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones. Encuentre a otra persona con quien hablar. Si REALMENTE quiere algo de mí, escriba &quot;Quiero algo&quot; (mayúscula no importa)</translation>
-    </message>
-    <message>
-        <source>Are you sure you want to send this message?</source>
-        <translation>¿Seguro que desea enviar este mensaje?</translation>
-    </message>
-    <message>
-        <source>&amp;Yes</source>
-        <translation>&amp;Sí</translation>
-    </message>
-    <message>
-        <source>Yes and allow until chat closed</source>
-        <translation>Si y permitir hasta que la conversación cierre</translation>
-    </message>
-    <message>
-        <source>&amp;No</source>
-        <translation>&amp;No</translation>
-    </message>
-    <message>
-        <source>%u writes</source>
-        <translation>%u escribe</translation>
-    </message>
-    <message>
-        <source>This message has been generated AUTOMATICALLY!
-
-I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
-        <translation>!Este mensaje ha sido generado AUTOMATICÁMENTE!
-
-Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones con las personas ocultándose. Si quiere hablar conmigo cambie el estado a En línea u Ocupado primero.</translation>
-    </message>
-    <message>
-        <source>Chat with invisible anonim ignored.
-</source>
-        <translation>Conversación con anónimo invisible ignorada.
-</translation>
-    </message>
-    <message>
-        <source>      DATA AND TIME      ::   ID      :: MESSAGE
-</source>
-        <translation>      FECHA Y HORA      ::   ID      :: MENSAJE
-</translation>
-    </message>
-</context>
 <context>
     <name>FirewallConfigurationUiHandler</name>
     <message>
@@ -205,7 +126,86 @@ Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones con
     </message>
 </context>
 <context>
-    <name>FirewallNotification</name>
+    <name>FirewallMessageFilter</name>
+    <message>
+        <source>flooding DoS attack with emoticons!</source>
+        <translation>¡ataque de inundación DoS con emoticonos!</translation>
+    </message>
+    <message>
+        <source>flooding DoS attack!</source>
+        <translation>¡ataque de inundación DoS!</translation>
+    </message>
+    <message>
+        <source>Chat with anonim silently dropped.
+</source>
+        <translation>Conversación con anónimo abandonada en silencio.
+</translation>
+    </message>
+    <message>
+        <source>This message has been generated AUTOMATICALLY!
+
+I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
+        <translation>!Este mensaje ha sido generado AUTOMATICÁMENTE!
+
+Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones con las personas ocultándose. Si quiere hablar conmigo cambie el estado a En línea u Ocupado primero.</translation>
+    </message>
+    <message>
+        <source>Chat with invisible anonim ignored.
+</source>
+        <translation>Conversación con anónimo invisible ignorada.
+</translation>
+    </message>
+    <message>
+        <source>User wrote right answer!
+</source>
+        <translation>¡El usuario escribió la respuesta correcta!
+</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to send this message?</source>
+        <translation>¿Seguro que desea enviar este mensaje?</translation>
+    </message>
+    <message>
+        <source>&amp;Yes</source>
+        <translation>&amp;Sí</translation>
+    </message>
+    <message>
+        <source>Yes and allow until chat closed</source>
+        <translation>Si y permitir hasta que la conversación cierre</translation>
+    </message>
+    <message>
+        <source>&amp;No</source>
+        <translation>&amp;No</translation>
+    </message>
+    <message>
+        <source>      DATA AND TIME      ::   ID      :: MESSAGE
+</source>
+        <translation>      FECHA Y HORA      ::   ID      :: MENSAJE
+</translation>
+    </message>
+    <message>
+        <source>OK, now say hello, and introduce yourself ;-)</source>
+        <translation>OK, ahora saluda, y presentate ;-)</translation>
+    </message>
+    <message>
+        <source>This message has been generated AUTOMATICALLY!
+
+I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
+        <translation>!Este mensaje ha sido generado AUTOMÁTICAMENTE!
+
+Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones. Encuentre a otra persona con quien hablar. Si REALMENTE quiere algo de mí, escriba &quot;Quiero algo&quot; (mayúscula no importa)</translation>
+    </message>
+    <message>
+        <source>I want something</source>
+        <translation>Yo quiero algo</translation>
+    </message>
+    <message>
+        <source>%u writes</source>
+        <translation>%u escribe</translation>
+    </message>
+</context>
+<context>
+    <name>FirewallNotificationService</name>
     <message>
         <source>Message was blocked</source>
         <translation>El mensaje fue bloqueado</translation>
