@@ -90,77 +90,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>Firewall</name>
-    <message>
-        <source>I want something</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>flooding DoS attack with emoticons!</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>flooding DoS attack!</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Chat with anonim silently dropped.
-</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>OK, now say hello, and introduce yourself ;-)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>User wrote right answer!
-</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This message has been generated AUTOMATICALLY!
-
-I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Are you sure you want to send this message?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&amp;Yes</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Yes and allow until chat closed</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&amp;No</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>%u writes</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This message has been generated AUTOMATICALLY!
-
-I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Chat with invisible anonim ignored.
-</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>      DATA AND TIME      ::   ID      :: MESSAGE
-</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>FirewallConfigurationUiHandler</name>
     <message>
@@ -197,7 +126,78 @@ I&apos;m a busy person and I don&apos;t have time for stupid chats with the pers
     </message>
 </context>
 <context>
-    <name>FirewallNotification</name>
+    <name>FirewallMessageFilter</name>
+    <message>
+        <source>flooding DoS attack with emoticons!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>flooding DoS attack!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Chat with anonim silently dropped.
+</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>This message has been generated AUTOMATICALLY!
+
+I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Chat with invisible anonim ignored.
+</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>User wrote right answer!
+</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to send this message?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Yes</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Yes and allow until chat closed</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;No</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>      DATA AND TIME      ::   ID      :: MESSAGE
+</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK, now say hello, and introduce yourself ;-)</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>This message has been generated AUTOMATICALLY!
+
+I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>I want something</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%u writes</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FirewallNotificationService</name>
     <message>
         <source>Message was blocked</source>
         <translation type="unfinished"/>
