@@ -1,13 +1,13 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>Notifications</source>
-        <translation type="unfinished"/>
+        <translation>Notificações</translation>
     </message>
     <message numerus="yes">
         <source>%n second(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n segundos</numerusform><numerusform>%n segundos</numerusform></translation>
     </message>
     <message>
         <source>Number of quoted characters</source>
@@ -15,27 +15,27 @@
     </message>
     <message>
         <source>System notifications</source>
-        <translation type="unfinished"/>
+        <translation>Notificações de sistema</translation>
     </message>
     <message>
         <source>Use custom expiration timeout</source>
-        <translation type="unfinished"/>
+        <translation>Utilizar prazo de expiração padrão</translation>
     </message>
     <message>
         <source>Expiration timeout</source>
-        <translation type="unfinished"/>
+        <translation>Prazo de expiração</translation>
     </message>
     <message>
         <source>Show message content</source>
-        <translation type="unfinished"/>
+        <translation>Mostrar conteúdo da mensagem</translation>
     </message>
     <message>
         <source>Never</source>
-        <translation type="unfinished"/>
+        <translation>Nunca</translation>
     </message>
     <message>
         <source>Options</source>
-        <translation type="unfinished"/>
+        <translation>Opções</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
