@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,21 +18,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/core.h"
 #include "gui/windows/open-chat-with/open-chat-with-runner-manager.h"
 #include "gui/windows/open-chat-with/open-chat-with-runner.h"
 #include "misc/misc.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "gadu-account-details.h"
 
-GaduAccountDetails::GaduAccountDetails(AccountShared *data) :
-		AccountDetails(data), AllowDcc(true), ReceiveImagesDuringInvisibility(true),
-		ChatImageSizeWarning(true), InitialRosterImport(true), TlsEncryption(false),
-		SendTypingNotification(true), ExternalPort(0), UserlistVersion(-1), ReceiveSpam(true)
+GaduAccountDetails::GaduAccountDetails(AccountShared *data, QObject *parent) :
+		AccountDetails(data, parent), ReceiveImagesDuringInvisibility(true),
+		ChatImageSizeWarning(true), InitialRosterImport(true),
+		SendTypingNotification(true), UserlistVersion(-1), ReceiveSpam(true)
 {
-	OpenChatRunner = new GaduOpenChatWithRunner(data);
-	OpenChatWithRunnerManager::instance()->registerRunner(OpenChatRunner);
 }
 
 GaduAccountDetails::~GaduAccountDetails()
@@ -48,6 +43,17 @@ GaduAccountDetails::~GaduAccountDetails()
 	OpenChatRunner = 0;
 }
 
+void GaduAccountDetails::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void GaduAccountDetails::init()
+{
+	OpenChatRunner = m_pluginInjectedFactory->makeInjected<GaduOpenChatWithRunner>(mainData());
+	OpenChatWithRunnerManager::instance()->registerRunner(OpenChatRunner);
+}
+
 void GaduAccountDetails::load()
 {
 	if (!isValidStorage())
@@ -55,14 +61,10 @@ void GaduAccountDetails::load()
 
 	AccountDetails::load();
 
-	AllowDcc = loadValue<bool>("AllowDcc", true);
 	ReceiveImagesDuringInvisibility = loadValue<bool>("ReceiveImagesDuringInvisibility", true);
 	ChatImageSizeWarning = loadValue<bool>("ChatImageSizeWarning", true);
 	InitialRosterImport = loadValue<bool>("InitialRosterImport", true);
-	TlsEncryption = loadValue<bool>("TlsEncryption", false);
 	SendTypingNotification = loadValue<bool>("SendTypingNotification", true);
-	ExternalIp = loadValue<QString>("ExternalIp");
-	ExternalPort = loadValue<unsigned int>("ExternalPort", 0);
 	UserlistVersion = loadValue<int>("UserlistVersion", -1);
 	ReceiveSpam = loadValue<bool>("ReceiveSpam", true);
 }
@@ -72,39 +74,17 @@ void GaduAccountDetails::store()
 	if (!isValidStorage())
 		return;
 
-	storeValue("AllowDcc", AllowDcc);
 	storeValue("ReceiveImagesDuringInvisibility", ReceiveImagesDuringInvisibility);
 	storeValue("ChatImageSizeWarning", ChatImageSizeWarning);
 	storeValue("InitialRosterImport", InitialRosterImport);
-	storeValue("TlsEncryption", TlsEncryption);
 	storeValue("SendTypingNotification", SendTypingNotification);
-	storeValue("ExternalIp", ExternalIp);
-	storeValue("ExternalPort", ExternalPort);
 	storeValue("UserlistVersion", UserlistVersion);
 	storeValue("ReceiveSpam", ReceiveSpam);
 }
 
-void GaduAccountDetails::import_0_6_5_LastStatus()
-{
-	if (!isValidStorage())
-		return;
-
-	QString name;
-
-	int typeIndex = config_file.readNumEntry("General", "LastStatusType", -1);
-	switch (typeIndex)
-	{
-		case 0: name = "Online"; break;
-		case 1: name = "Away"; break;
-		case 2: name = "Invisible"; break;
-		default: name = "Offline"; break;
-	}
-
-	storeValue("LastStatusName", name);
-	storeValue("LastStatusDescription", config_file.readEntry("General", "LastStatusDescription"));
-}
-
 UinType GaduAccountDetails::uin()
 {
 	return mainData()->id().toULong();
 }
+
+#include "moc_gadu-account-details.cpp"
