@@ -1,15 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Piotr Pełzowski (floss@pelzowski.eu)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QPushButton>
+#include <QtWidgets/QPushButton>
 
 #include "core/core.h"
 #include "icons/kadu-icon.h"
@@ -35,59 +28,63 @@
 #include "gui/widgets/gadu-add-account-widget.h"
 #include "gui/widgets/gadu-contact-personal-info-widget.h"
 #include "gui/widgets/gadu-edit-account-widget.h"
+#include "helpers/gadu-list-helper.h"
 #include "gadu-account-details.h"
-#include "gadu-contact-details.h"
 #include "gadu-id-validator.h"
 #include "gadu-protocol.h"
 #include "gadu-status-adapter.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "gadu-protocol-factory.h"
 
-GaduProtocolFactory *GaduProtocolFactory::Instance = 0;
-
-void GaduProtocolFactory::createInstance()
+GaduProtocolFactory::GaduProtocolFactory(QObject *parent) :
+		ProtocolFactory{}
 {
-	if (!Instance)
-		Instance = new GaduProtocolFactory();
-}
+	Q_UNUSED(parent);
 
-void GaduProtocolFactory::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-GaduProtocolFactory::GaduProtocolFactory()
-{
-	MyStatusAdapter = make_unique<GaduStatusAdapter>();
+	MyStatusAdapter = std::make_unique<GaduStatusAdapter>();
 
 	// already sorted
-	SupportedStatusTypes.append(StatusTypeFreeForChat);
-	SupportedStatusTypes.append(StatusTypeOnline);
-	SupportedStatusTypes.append(StatusTypeAway);
-	SupportedStatusTypes.append(StatusTypeDoNotDisturb);
-	SupportedStatusTypes.append(StatusTypeInvisible);
-	SupportedStatusTypes.append(StatusTypeOffline);
+	SupportedStatusTypes.append(StatusType::FreeForChat);
+	SupportedStatusTypes.append(StatusType::Online);
+	SupportedStatusTypes.append(StatusType::Away);
+	SupportedStatusTypes.append(StatusType::DoNotDisturb);
+	SupportedStatusTypes.append(StatusType::Invisible);
+	SupportedStatusTypes.append(StatusType::Offline);
+}
+
+GaduProtocolFactory::~GaduProtocolFactory()
+{
+}
+
+void GaduProtocolFactory::setGaduListHelper(GaduListHelper *gaduListHelper)
+{
+	m_gaduListHelper = gaduListHelper;
+}
+
+void GaduProtocolFactory::setGaduServersManager(GaduServersManager *gaduServersManager)
+{
+	m_gaduServersManager = gaduServersManager;
+}
+
+void GaduProtocolFactory::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
 }
 
 Protocol * GaduProtocolFactory::createProtocolHandler(Account account)
 {
-	return new GaduProtocol(account, this);
+	return m_pluginInjectedFactory->makeInjected<GaduProtocol>(m_gaduListHelper, m_gaduServersManager, account, this);
 }
 
 AccountDetails * GaduProtocolFactory::createAccountDetails(AccountShared *accountShared)
 {
-	return new GaduAccountDetails(accountShared);
-}
-
-ContactDetails * GaduProtocolFactory::createContactDetails(ContactShared *contactShared)
-{
-	return new GaduContactDetails(contactShared);
+	return m_pluginInjectedFactory->makeInjected<GaduAccountDetails>(accountShared);
 }
 
 AccountAddWidget * GaduProtocolFactory::newAddAccountWidget(bool showButtons, QWidget *parent)
 {
-	GaduAddAccountWidget *result = new GaduAddAccountWidget(showButtons, parent);
+	auto result = m_pluginInjectedFactory->makeInjected<GaduAddAccountWidget>(showButtons, parent);
 	connect(this, SIGNAL(destroyed()), result, SLOT(deleteLater()));
 	return result;
 }
@@ -99,7 +96,7 @@ AccountCreateWidget * GaduProtocolFactory::newCreateAccountWidget(bool, QWidget
 
 AccountEditWidget * GaduProtocolFactory::newEditAccountWidget(Account account, QWidget *parent)
 {
-	GaduEditAccountWidget *result = new GaduEditAccountWidget(Core::instance()->accountConfigurationWidgetFactoryRepository(), account, parent);
+	auto result = m_pluginInjectedFactory->makeInjected<GaduEditAccountWidget>(m_gaduServersManager, account, parent);
 	connect(this, SIGNAL(destroyed()), result, SLOT(deleteLater()));
 	return result;
 }
@@ -117,7 +114,7 @@ QString GaduProtocolFactory::idLabel()
 QValidator::State GaduProtocolFactory::validateId(QString id)
 {
 	int pos = 0;
-	return GaduIdValidator::instance()->validate(id, pos);
+	return createNotOwnedGaduIdValidator()->validate(id, pos);
 }
 
 bool GaduProtocolFactory::canRegister()
