@@ -1,13 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,37 +19,33 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GADU_PROTOCOL_FACTORY_H
-#define GADU_PROTOCOL_FACTORY_H
+#pragma once
 
 #include "protocols/protocol-factory.h"
 #include "status/status-adapter.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+#include <memory>
+
+class GaduListHelper;
+class GaduServersManager;
+class PluginInjectedFactory;
+
 class GaduProtocolFactory : public ProtocolFactory
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(GaduProtocolFactory)
-
-	static GaduProtocolFactory *Instance;
-	QList<StatusType> SupportedStatusTypes;
-
-	std::unique_ptr<StatusAdapter> MyStatusAdapter;
-
-	GaduProtocolFactory();
 
 public:
-	static void createInstance();
-	static void destroyInstance();
-
-	static GaduProtocolFactory * instance() { return Instance; }
+	Q_INVOKABLE explicit GaduProtocolFactory(QObject *parent = nullptr);
+	virtual ~GaduProtocolFactory();
 
 	virtual Protocol * createProtocolHandler(Account account);
 	virtual AccountDetails * createAccountDetails(AccountShared *accountShared);
-	virtual ContactDetails * createContactDetails(ContactShared *contactShared);
 	virtual AccountAddWidget * newAddAccountWidget(bool showButtons, QWidget *parent);
 	virtual AccountCreateWidget * newCreateAccountWidget(bool showButtons, QWidget *parent);
 	virtual AccountEditWidget * newEditAccountWidget(Account, QWidget *parent);
-	virtual QWidget * newContactPersonalInfoWidget(Contact contact, QWidget *parent = 0);
+	virtual QWidget * newContactPersonalInfoWidget(Contact contact, QWidget *parent = nullptr);
 	virtual QList<StatusType> supportedStatusTypes();
 	virtual StatusAdapter * statusAdapter() { return MyStatusAdapter.get(); }
 	virtual QString idLabel();
@@ -66,6 +57,18 @@ public:
 	virtual QString displayName() { return "Gadu-Gadu"; }
 	virtual KaduIcon icon();
 
-};
+private:
+	QPointer<GaduListHelper> m_gaduListHelper;
+	QPointer<GaduServersManager> m_gaduServersManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
 
-#endif // GADU_PROTOCOL_FACTORY_H
+	QList<StatusType> SupportedStatusTypes;
+
+	std::unique_ptr<StatusAdapter> MyStatusAdapter;
+
+private slots:
+	INJEQT_SET void setGaduListHelper(GaduListHelper *gaduListHelper);
+	INJEQT_SET void setGaduServersManager(GaduServersManager *gaduServersManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+
+};
