@@ -1,20 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2010, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009, 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004, 2005, 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Roman Krzystyniak (Ron_K@tlen.pl)
- * Copyright 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2004, 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2006, 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -47,17 +36,21 @@
 #include "buddies/buddy-manager.h"
 #include "chat/chat-manager.h"
 #include "chat/chat.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
-#include "core/core.h"
+#include "core/version-service.h"
 #include "formatted-string/composite-formatted-string.h"
 #include "gui/windows/message-dialog.h"
 #include "network/proxy/network-proxy-manager.h"
+#include "plugin/plugin-injected-factory.h"
 #include "qt/long-validator.h"
+#include "status/status-type-data.h"
 #include "status/status-type-manager.h"
 #include "status/status-type.h"
 #include "status/status.h"
 
+#include "core/core.h"
 #include "icons/icons-manager.h"
 #include "misc/misc.h"
 #include "debug.h"
@@ -66,71 +59,25 @@
 #include "server/protocol-gadu-connection.h"
 #include "socket-notifiers/gadu-protocol-socket-notifiers.h"
 
-#include "helpers/gadu-importer.h"
 #include "helpers/gadu-protocol-helper.h"
 #include "helpers/gadu-proxy-helper.h"
 #include "server/gadu-writable-session-token.h"
+#include "services/drive/gadu-drive-service.h"
+#include "services/gadu-imtoken-service.h"
+#include "services/gadu-notify-service.h"
 #include "services/gadu-roster-service.h"
+#include "services/user-data/gadu-user-data-service.h"
 #include "gadu-account-details.h"
-#include "gadu-contact-details.h"
 
 #include "gadu-protocol.h"
 
-GaduProtocol::GaduProtocol(Account account, ProtocolFactory *factory) :
-		Protocol(account, factory), CurrentFileTransferService(0),
-		ActiveServer(), GaduLoginParams(), GaduSession(0), SocketNotifiers(0), PingTimer(0)
+GaduProtocol::GaduProtocol(GaduListHelper *gaduListHelper, GaduServersManager *gaduServersManager, Account account, ProtocolFactory *factory) :
+		Protocol(account, factory),
+		m_gaduServersManager{gaduServersManager},
+		ActiveServer(), GaduLoginParams(), GaduSession(0), SocketNotifiers(0), PingTimer(0),
+		SecureConnection{false},
+		m_gaduListHelper{gaduListHelper}
 {
-	Connection = new ProtocolGaduConnection(this);
-	Connection->setConnectionProtocol(this);
-
-	CurrentAvatarService = new GaduAvatarService(account, this);
-
-	CurrentChatImageService = new GaduChatImageService(account, this);
-	CurrentChatImageService->setConnection(Connection);
-
-	CurrentChatService = new GaduChatService(account, this);
-	CurrentChatService->setConnection(Connection);
-	CurrentChatService->setFormattedStringFactory(Core::instance()->formattedStringFactory());
-	CurrentChatService->setGaduChatImageService(CurrentChatImageService);
-	CurrentChatService->setImageStorageService(Core::instance()->imageStorageService());
-	CurrentChatService->setRawMessageTransformerService(Core::instance()->rawMessageTransformerService());
-	CurrentChatImageService->setGaduChatService(CurrentChatService);
-
-	CurrentContactListService = new GaduContactListService(account, this);
-	CurrentContactListService->setConnection(Connection);
-	CurrentContactListService->setRosterNotifier(Core::instance()->rosterNotifier());
-
-	CurrentContactPersonalInfoService = new GaduContactPersonalInfoService(account, this);
-	CurrentContactPersonalInfoService->setConnection(Connection);
-
-	CurrentPersonalInfoService = new GaduPersonalInfoService(account, this);
-	CurrentPersonalInfoService->setConnection(Connection);
-
-	CurrentSearchService = new GaduSearchService(account, this);
-	CurrentSearchService->setConnection(Connection);
-
-	CurrentMultilogonService = new GaduMultilogonService(account, this);
-	CurrentMultilogonService->setConnection(Connection);
-
-	CurrentChatStateService = new GaduChatStateService(account, this);
-	CurrentChatStateService->setConnection(Connection);
-
-	connect(CurrentChatService, SIGNAL(messageReceived(Message)),
-	        CurrentChatStateService, SLOT(messageReceived(Message)));
-
-	GaduRosterService *rosterService = new GaduRosterService(account, this);
-	rosterService->setConnection(Connection);
-	rosterService->setProtocol(this);
-
-	setChatService(CurrentChatService);
-	setChatStateService(CurrentChatStateService);
-	setRosterService(rosterService);
-
-	configureServices();
-
-	connect(account, SIGNAL(updated()), this, SLOT(accountUpdated()));
-
-	kdebugf2();
 }
 
 GaduProtocol::~GaduProtocol()
@@ -142,6 +89,97 @@ GaduProtocol::~GaduProtocol()
 	kdebugf2();
 }
 
+void GaduProtocol::setAvatarManager(AvatarManager *avatarManager)
+{
+	m_avatarManager = avatarManager;
+}
+
+void GaduProtocol::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void GaduProtocol::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void GaduProtocol::setNetworkProxyManager(NetworkProxyManager *networkProxyManager)
+{
+	m_networkProxyManager = networkProxyManager;
+}
+
+void GaduProtocol::setVersionService(VersionService *versionService)
+{
+	m_versionService = versionService;
+}
+
+void GaduProtocol::init()
+{
+	Connection = new ProtocolGaduConnection(this);
+	Connection->setConnectionProtocol(this);
+
+	CurrentAvatarService = new GaduAvatarService(account(), this);
+
+	CurrentBuddyListSerializationService = new GaduBuddyListSerializationService{m_gaduListHelper, account(), this};
+
+	CurrentChatImageService = new GaduChatImageService(account(), this);
+	CurrentChatImageService->setConnection(Connection);
+
+	CurrentImTokenService = new GaduIMTokenService{this};
+
+	CurrentFileTransferService = pluginInjectedFactory()->makeInjected<GaduFileTransferService>(this);
+	CurrentFileTransferService->setGaduIMTokenService(CurrentImTokenService);
+
+	CurrentChatService = pluginInjectedFactory()->makeInjected<GaduChatService>(account(), this);
+	CurrentChatService->setConnection(Connection);
+	CurrentChatService->setGaduChatImageService(CurrentChatImageService);
+	CurrentChatService->setGaduFileTransferService(CurrentFileTransferService);
+	CurrentChatImageService->setGaduChatService(CurrentChatService);
+
+	CurrentContactPersonalInfoService = pluginInjectedFactory()->makeInjected<GaduContactPersonalInfoService>(account(), this);
+	CurrentContactPersonalInfoService->setConnection(Connection);
+
+	CurrentPersonalInfoService = pluginInjectedFactory()->makeInjected<GaduPersonalInfoService>(account(), this);
+	CurrentPersonalInfoService->setConnection(Connection);
+
+	CurrentSearchService = pluginInjectedFactory()->makeInjected<GaduSearchService>(account(), this);
+	CurrentSearchService->setConnection(Connection);
+
+	CurrentMultilogonService = new GaduMultilogonService(account(), this);
+	CurrentMultilogonService->setConnection(Connection);
+
+	CurrentChatStateService = pluginInjectedFactory()->makeInjected<GaduChatStateService>(account(), this);
+	CurrentChatStateService->setConnection(Connection);
+
+	connect(CurrentChatService, SIGNAL(messageReceived(Message)),
+	        CurrentChatStateService, SLOT(messageReceived(Message)));
+
+	CurrentDriveService = pluginInjectedFactory()->makeInjected<GaduDriveService>(account(), this);
+	CurrentDriveService->setGaduIMTokenService(CurrentImTokenService);
+
+	CurrentUserDataService = pluginInjectedFactory()->makeInjected<GaduUserDataService>(account(), this);
+
+	auto contacts = contactManager()->contacts(account(), ContactManager::ExcludeAnonymous);
+	auto rosterService = pluginInjectedFactory()->makeInjected<GaduRosterService>(m_gaduListHelper, contacts, this);
+	rosterService->setConnection(Connection);
+
+	CurrentNotifyService = new GaduNotifyService{Connection, this};
+	connect(rosterService, SIGNAL(contactAdded(Contact)), CurrentNotifyService, SLOT(contactAdded(Contact)));
+	connect(rosterService, SIGNAL(contactRemoved(Contact)), CurrentNotifyService, SLOT(contactRemoved(Contact)));
+	connect(rosterService, SIGNAL(contactUpdatedLocally(Contact)), CurrentNotifyService, SLOT(contactUpdatedLocally(Contact)));
+
+	setChatService(CurrentChatService);
+	setChatStateService(CurrentChatStateService);
+	setRosterService(rosterService);
+
+	configureServices();
+
+	connect(account(), SIGNAL(updated()), this, SLOT(accountUpdated()));
+
+	kdebugf2();
+}
+
 int GaduProtocol::maxDescriptionLength()
 {
 	return GG_STATUS_DESCR_MAXSIZE;
@@ -181,6 +219,7 @@ void GaduProtocol::sendStatusToServer()
 
 	setStatusFlags();
 
+	m_lastSentStatus = newStatus;
 	auto writableSessionToken = Connection->writableSessionToken();
 	if (hasDescription)
 		gg_change_status_descr(writableSessionToken.rawSession(), type | friends, newStatus.description().toUtf8().constData());
@@ -221,24 +260,23 @@ void GaduProtocol::configureServices()
 
 	CurrentChatStateService->setSendTypingNotifications(gaduAccountDetails->sendTypingNotification());
 
-	switch (status().group())
+	switch (statusTypeManager()->statusTypeData(status().type()).typeGroup())
 	{
-		case StatusTypeGroupOffline:
+		case StatusTypeGroup::Offline:
 			CurrentChatImageService->setReceiveImages(false);
 			break;
-		case StatusTypeGroupInvisible:
+		case StatusTypeGroup::Invisible:
 			CurrentChatImageService->setReceiveImages(gaduAccountDetails->receiveImagesDuringInvisibility());
 			break;
 		default:
 			CurrentChatImageService->setReceiveImages(true);
+			break;
 	}
 }
 
 void GaduProtocol::accountUpdated()
 {
 	sendStatusToServer();
-	setUpFileTransferService();
-
 	configureServices();
 }
 
@@ -250,7 +288,7 @@ void GaduProtocol::connectSocketNotifiersToServices()
 	        CurrentChatService, SLOT(handleEventMultilogonMsg(gg_event*)));
 	connect(SocketNotifiers, SIGNAL(ackEventReceived(gg_event*)),
 	        CurrentChatService, SLOT(handleEventAck(gg_event*)));
-	connect(SocketNotifiers, SIGNAL(typingNotifyEventReceived(gg_event*)),
+	connect(SocketNotifiers, SIGNAL(typingNotificationEventReceived(gg_event*)),
 	        CurrentChatStateService, SLOT(handleEventTypingNotify(gg_event*)));
 }
 
@@ -279,11 +317,12 @@ void GaduProtocol::login()
 	}
 
 	GaduProxyHelper::setupProxy(account().useDefaultProxy()
-			? NetworkProxyManager::instance()->defaultProxy()
+			? m_networkProxyManager->defaultProxy()
 			: account().proxy());
 
 	setupLoginParams();
 
+	m_lastSentStatus = loginStatus();
 	GaduSession = gg_login(&GaduLoginParams);
 
 	cleanUpLoginParams();
@@ -296,6 +335,8 @@ void GaduProtocol::login()
 	}
 
 	SocketNotifiers = new GaduProtocolSocketNotifiers(account(), this);
+	SocketNotifiers->setGaduIMTokenService(CurrentImTokenService);
+	SocketNotifiers->setGaduUserDataService(CurrentUserDataService);
 	connectSocketNotifiersToServices();
 	SocketNotifiers->watchFor(GaduSession);
 }
@@ -304,7 +345,7 @@ void GaduProtocol::connectedToServer()
 {
 	kdebugf();
 
-	GaduServersManager::instance()->markServerAsGood(ActiveServer);
+	m_gaduServersManager->markServerAsGood(ActiveServer);
 
 	PingTimer = new QTimer(0);
 	connect(PingTimer, SIGNAL(timeout()), this, SLOT(everyMinuteActions()));
@@ -312,23 +353,19 @@ void GaduProtocol::connectedToServer()
 
 	loggedIn();
 
-	// workaround about servers errors
-	if (StatusTypeInvisible == status().type())
-		sendStatusToServer();
-
 	kdebugf2();
 }
 
 void GaduProtocol::afterLoggedIn()
 {
 	// fetch current avatar after connection
-	AvatarManager::instance()->updateAvatar(account().accountContact(), true);
+	m_avatarManager->updateAvatar(account().accountContact(), true);
 
-	// set up DCC if needed
-	setUpFileTransferService();
+	auto contacts = contactManager()->contacts(account(), ContactManager::ExcludeAnonymous);
+	CurrentNotifyService->sendInitialData(contacts);
+
+	static_cast<GaduRosterService *>(rosterService())->prepareRoster();
 
-	// we do not need to wait for "rosterReady" signal in GaduGadu
-	rosterService()->prepareRoster(ContactManager::instance()->contacts(account(), ContactManager::ExcludeAnonymous));
 	sendStatusToServer();
 }
 
@@ -348,8 +385,6 @@ void GaduProtocol::disconnectedCleanup()
 {
 	Protocol::disconnectedCleanup();
 
-	setUpFileTransferService(true);
-
 	if (PingTimer)
 	{
 		PingTimer->stop();
@@ -386,46 +421,37 @@ void GaduProtocol::setupLoginParams()
 
 	GaduLoginParams.async = 1;
 
-	GaduLoginParams.status = (GaduProtocolHelper::gaduStatusFromStatus(loginStatus()) | (account().privateStatus() ? GG_STATUS_FRIENDS_MASK : 0));
+	auto gaduStatus = GaduProtocolHelper::gaduStatusFromStatus(loginStatus());
+	GaduLoginParams.status = gaduStatus | (account().privateStatus() ? GG_STATUS_FRIENDS_MASK : 0);
 
 	if (!loginStatus().description().isEmpty())
 		GaduLoginParams.status_descr = qstrdup(loginStatus().description().toUtf8().constData());
 
-	GaduLoginParams.tls = gaduAccountDetails->tlsEncryption() ? GG_SSL_ENABLED : GG_SSL_DISABLED;
+	SecureConnection = gg_libgadu_check_feature(GG_LIBGADU_FEATURE_SSL);
+	GaduLoginParams.tls = SecureConnection ? GG_SSL_ENABLED : GG_SSL_DISABLED;
 
-	ActiveServer = GaduServersManager::instance()->getServer(1 == GaduLoginParams.tls);
+	ActiveServer = m_gaduServersManager->getServer(1 == GaduLoginParams.tls);
 
 	bool haveServer = !ActiveServer.first.isNull();
 	GaduLoginParams.server_addr = haveServer ? htonl(ActiveServer.first.toIPv4Address()) : 0;
 	GaduLoginParams.server_port = haveServer ? ActiveServer.second : 0;
 
-	if (!gaduAccountDetails->externalIp().isEmpty())
-	{
-		QHostAddress externalIp(gaduAccountDetails->externalIp());
-		if (!externalIp.isNull())
-			GaduLoginParams.external_addr = htonl(externalIp.toIPv4Address());
-	}
-
-	GaduLoginParams.external_port = gaduAccountDetails->externalPort();
-	GaduLoginParams.protocol_version = 0;
-	GaduLoginParams.client_version = qstrdup(Core::nameWithVersion().toUtf8().constData());
+	GaduLoginParams.protocol_version = GG_PROTOCOL_VERSION_110;
+	GaduLoginParams.compatibility = GG_COMPAT_LEGACY; // TODO: #2961
+	GaduLoginParams.client_version = qstrdup(m_versionService->nameWithVersion().toUtf8().constData());
 	GaduLoginParams.protocol_features =
-			GG_FEATURE_UNKNOWN_4 | // GG_FEATURE_STATUS80
-			GG_FEATURE_DND_FFC |
-			GG_FEATURE_IMAGE_DESCR |
-			GG_FEATURE_UNKNOWN_40 |
-			GG_FEATURE_UNKNOWN_100 |
-			GG_FEATURE_USER_DATA |
-			GG_FEATURE_MSG_ACK |
-			GG_FEATURE_TYPING_NOTIFICATION |
-			GG_FEATURE_MULTILOGON;
+		GG_FEATURE_DND_FFC |
+		GG_FEATURE_TYPING_NOTIFICATION | GG_FEATURE_MULTILOGON |
+		GG_FEATURE_USER_DATA;
 
 	GaduLoginParams.encoding = GG_ENCODING_UTF8;
 
 	GaduLoginParams.has_audio = false;
-	GaduLoginParams.last_sysmsg = config_file.readNumEntry("General", "SystemMsgIndex", 1389);
+	GaduLoginParams.last_sysmsg = m_configuration->deprecatedApi()->readNumEntry("General", "SystemMsgIndex", 1389);
 
-	GaduLoginParams.image_size = qMax(qMin(config_file.readNumEntry("Chat", "MaximumImageSizeInKiloBytes", 255), 255), 0);
+	GaduLoginParams.image_size = qMax(qMin(m_configuration->deprecatedApi()->readNumEntry("Chat", "MaximumImageSizeInKiloBytes", 255), 255), 0);
+
+	GaduLoginParams.struct_size = sizeof(struct gg_login_params);
 
 	setStatusFlags();
 }
@@ -446,45 +472,31 @@ void GaduProtocol::cleanUpLoginParams()
 	GaduLoginParams.status_descr = 0;
 }
 
-void GaduProtocol::startFileTransferService()
+void GaduProtocol::socketContactStatusChanged(UinType uin, unsigned int ggStatusId, const QString &description, unsigned int maxImageSize)
 {
-	if (!CurrentFileTransferService)
-	{
-		CurrentFileTransferService = new GaduFileTransferService(this);
-		account().data()->fileTransferServiceChanged(CurrentFileTransferService);
-	}
-}
+	auto newStatus = Status{};
+	newStatus.setType(GaduProtocolHelper::statusTypeFromGaduStatus(ggStatusId));
+	newStatus.setDescription(description);
 
-void GaduProtocol::stopFileTransferService()
-{
-	delete CurrentFileTransferService;
-	CurrentFileTransferService = 0;
-	account().data()->fileTransferServiceChanged(0);
-}
-
-void GaduProtocol::setUpFileTransferService(bool forceClose)
-{
-	bool close = forceClose;
-	if (!close)
-		close = !isConnected();
-	if (!close)
+	if (uin == GaduLoginParams.uin)
 	{
-		GaduAccountDetails *gaduAccountDetails = dynamic_cast<GaduAccountDetails *>(account().details());
-		if (!gaduAccountDetails)
-			close = true;
-		else
-			close = !gaduAccountDetails->allowDcc();
+		if ((!m_lastRemoteStatusRequest.isValid() || m_lastRemoteStatusRequest.elapsed() > 10) && newStatus != m_lastSentStatus)
+		{
+			emit remoteStatusChangeRequest(account(), newStatus);
+			if (m_lastRemoteStatusRequest.isValid())
+				m_lastRemoteStatusRequest.restart();
+			else
+				m_lastRemoteStatusRequest.start();
+		}
+		return;
 	}
 
-	if (close)
-		stopFileTransferService();
-	else
-		startFileTransferService();
-}
+	auto contact = contactManager()->byId(account(), QString::number(uin), ActionReturnNull);
+	contact.setMaximumImageSize(maxImageSize);
 
-void GaduProtocol::socketContactStatusChanged(UinType uin, unsigned int status, const QString &description, unsigned int maxImageSize)
-{
-	Contact contact = ContactManager::instance()->byId(account(), QString::number(uin), ActionReturnNull);
+	auto oldStatus = contact.currentStatus();
+	contact.setCurrentStatus(newStatus);
+	contact.setBlocking(GaduProtocolHelper::isBlockingStatus(ggStatusId));
 
 	if (contact.isAnonymous())
 	{
@@ -495,15 +507,6 @@ void GaduProtocol::socketContactStatusChanged(UinType uin, unsigned int status,
 		return;
 	}
 
-	contact.setMaximumImageSize(maxImageSize);
-
-	Status oldStatus = contact.currentStatus();
-	Status newStatus;
-	newStatus.setType(GaduProtocolHelper::statusTypeFromGaduStatus(status));
-	newStatus.setDescription(description);
-	contact.setCurrentStatus(newStatus);
-	contact.setBlocking(GaduProtocolHelper::isBlockingStatus(status));
-
 	// see issue #2159 - we need a way to ignore first status of given contact
 	if (contact.ignoreNextStatusChange())
 		contact.setIgnoreNextStatusChange(false);
@@ -520,7 +523,7 @@ void GaduProtocol::socketConnFailed(GaduError error)
 	switch (error)
 	{
 		case ConnectionNeedEmail:
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), msg);
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), msg);
 			break;
 		case ConnectionIncorrectPassword:
 			passwordRequired();
@@ -548,7 +551,7 @@ void GaduProtocol::socketConnFailed(GaduError error)
 
 	if (!GaduProtocolHelper::isConnectionErrorFatal(error))
 	{
-		GaduServersManager::instance()->markServerAsBad(ActiveServer);
+		m_gaduServersManager->markServerAsBad(ActiveServer);
 		logout();
 		connectionError();
 	}
@@ -568,7 +571,7 @@ void GaduProtocol::disconnectedFromServer()
 
 QString GaduProtocol::statusPixmapPath()
 {
-	return QLatin1String("gadu-gadu");
+	return QStringLiteral("gadu-gadu");
 }
 
 void GaduProtocol::disableSocketNotifiers()
@@ -583,6 +586,16 @@ void GaduProtocol::enableSocketNotifiers()
 		SocketNotifiers->enable();
 }
 
+GaduDriveService * GaduProtocol::driveService() const
+{
+	return CurrentDriveService;
+}
+
+GaduUserDataService * GaduProtocol::userDataService() const
+{
+	return CurrentUserDataService;
+}
+
 void GaduProtocol::configurationUpdated()
 {
 #ifdef DEBUG_OUTPUT_ENABLED
@@ -591,4 +604,11 @@ void GaduProtocol::configurationUpdated()
 #endif
 }
 
+bool GaduProtocol::secureConnection() const
+{
+	return isConnected()
+			? SecureConnection
+			: false;
+}
+
 #include "moc_gadu-protocol.cpp"
