@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,8 +24,8 @@ Status GaduStatusAdapter::adapt(const Status &status)
 {
 	Status adapted = status;
 
-	if (adapted.type() == StatusTypeNotAvailable)
-		adapted.setType(StatusTypeAway);
+	if (adapted.type() == StatusType::NotAvailable)
+		adapted.setType(StatusType::Away);
 
 	return adapted;
 }
