@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,21 +18,24 @@
  */
 
 #include "dom/ignore-links-dom-visitor.h"
+#include "misc/memory.h"
 #include "url-handlers/simple-url-expander.h"
 
 #include "gadu-url-dom-visitor-provider.h"
 
-GaduUrlDomVisitorProvider::GaduUrlDomVisitorProvider()
+GaduUrlDomVisitorProvider::GaduUrlDomVisitorProvider(QObject *parent) :
+		QObject{parent},
+		m_ignoreLinks{std::make_unique<SimpleUrlExpander>(QRegExp{"\\bgg:(/){0,3}[0-9]{1,12}\\b"})}
 {
-	SimpleUrlExpander *expander = new SimpleUrlExpander(QRegExp("\\bgg:(/){0,3}[0-9]{1,12}\\b"));
-	IgnoreLinks.reset(new IgnoreLinksDomVisitor(expander));
 }
 
 GaduUrlDomVisitorProvider::~GaduUrlDomVisitorProvider()
 {
 }
 
-DomVisitor * GaduUrlDomVisitorProvider::provide() const
+const DomVisitor * GaduUrlDomVisitorProvider::provide() const
 {
-	return IgnoreLinks.data();
+	return &m_ignoreLinks;
 }
+
+#include "moc_gadu-url-dom-visitor-provider.cpp"
