@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,47 +18,79 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QRadioButton>
-#include <QtGui/QVBoxLayout>
+#include "gadu-add-account-widget.h"
+
+#include "gadu-account-details.h"
+#include "gadu-id-validator.h"
+#include "gadu-protocol-factory.h"
 
 #include "accounts/account-manager.h"
+#include "accounts/account-storage.h"
 #include "gui/widgets/identities-combo-box.h"
 #include "gui/widgets/simple-configuration-value-state-notifier.h"
 #include "gui/windows/message-dialog.h"
 #include "icons/icons-manager.h"
 #include "identities/identity-manager.h"
 #include "os/generic/url-opener.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/protocols-manager.h"
 
-#include "gadu-account-details.h"
-#include "gadu-id-validator.h"
-#include "gadu-protocol-factory.h"
-
-#include "gadu-add-account-widget.h"
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QVBoxLayout>
 
 GaduAddAccountWidget::GaduAddAccountWidget(bool showButtons, QWidget *parent) :
-		AccountAddWidget(parent)
+		AccountAddWidget{parent},
+		m_showButtons{showButtons}
 {
-	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)), this, SLOT(dataChanged()));
-
-	createGui(showButtons);
-	resetGui();
 }
 
 GaduAddAccountWidget::~GaduAddAccountWidget()
 {
 }
 
+void GaduAddAccountWidget::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void GaduAddAccountWidget::setAccountStorage(AccountStorage *accountStorage)
+{
+	m_accountStorage = accountStorage;
+}
+
+void GaduAddAccountWidget::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void GaduAddAccountWidget::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void GaduAddAccountWidget::setUrlOpener(UrlOpener *urlOpener)
+{
+	m_urlOpener = urlOpener;
+}
+
+void GaduAddAccountWidget::init()
+{
+	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)), this, SLOT(dataChanged()));
+
+	createGui(m_showButtons);
+	resetGui();
+}
+
 void GaduAddAccountWidget::createGui(bool showButtons)
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -71,7 +101,7 @@ void GaduAddAccountWidget::createGui(bool showButtons)
 	QFormLayout *layout = new QFormLayout(formWidget);
 
 	AccountId = new QLineEdit(this);
-	AccountId->setValidator(GaduIdValidator::instance());
+	AccountId->setValidator(createOwnedGaduIdValidator(AccountId).get());
 	connect(AccountId, SIGNAL(textEdited(QString)), this, SLOT(dataChanged()));
 	layout->addRow(tr("Gadu-Gadu number") + ':', AccountId);
 
@@ -98,7 +128,7 @@ void GaduAddAccountWidget::createGui(bool showButtons)
 	layout->addRow(0, remindPasswordLabel);
 	connect(remindPasswordLabel, SIGNAL(linkActivated(QString)), this, SLOT(remindPassword()));
 
-	Identity = new IdentitiesComboBox(this);
+	Identity = m_pluginInjectedFactory->makeInjected<IdentitiesComboBox>(this);
 	connect(Identity, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 	layout->addRow(tr("Account Identity") + ':', Identity);
 
@@ -131,7 +161,7 @@ void GaduAddAccountWidget::resetGui()
 	AccountId->clear();
 	AccountPassword->clear();
 	RememberPassword->setChecked(true);
-	IdentityManager::instance()->removeUnused();
+	m_identityManager->removeUnused();
 	Identity->setCurrentIndex(0);
 
 	dataChanged();
@@ -139,7 +169,7 @@ void GaduAddAccountWidget::resetGui()
 
 void GaduAddAccountWidget::apply()
 {
-	Account gaduAccount = Account::create("gadu");
+	auto gaduAccount = m_accountStorage->create("gadu");
 
 	gaduAccount.setId(AccountId->text());
 	gaduAccount.setPassword(AccountPassword->text());
@@ -168,7 +198,7 @@ void GaduAddAccountWidget::dataChanged()
 {
 	bool valid = !AccountId->text().isEmpty()
 			&& !AccountPassword->text().isEmpty()
-			&& !AccountManager::instance()->byId("gadu", AccountId->text())
+			&& !m_accountManager->byId("gadu", AccountId->text())
 			&& Identity->currentIdentity();
 
 	AddAccountButton->setEnabled(valid);
@@ -184,17 +214,17 @@ void GaduAddAccountWidget::dataChanged()
 
 void GaduAddAccountWidget::registerAccount()
 {
-	UrlOpener::openUrl("https://login.gg.pl/rejestracja-gg/");
+	m_urlOpener->openUrl("https://login.gg.pl/rejestracja-gg/");
 }
 
 void GaduAddAccountWidget::remindUin()
 {
-	UrlOpener::openUrl("https://login.gg.pl/account/remindGG_email/");
+	m_urlOpener->openUrl("https://login.gg.pl/account/remindGG_email/");
 }
 
 void GaduAddAccountWidget::remindPassword()
 {
-	UrlOpener::openUrl("https://login.gg.pl/account/remindPassword/");
+	m_urlOpener->openUrl("https://login.gg.pl/account/remindPassword/");
 }
 
 #include "moc_gadu-add-account-widget.cpp"
