@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,23 +19,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QGridLayout>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QSpinBox>
-#include <QtGui/QTabWidget>
-#include <QtGui/QVBoxLayout>
+#include "gadu-edit-account-widget.h"
+
+#include "gadu-account-details.h"
+#include "gadu-id-validator.h"
+#include "gadu-personal-info-widget.h"
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
 #include "gui/widgets/account-avatar-widget.h"
 #include "gui/widgets/account-buddy-list-widget.h"
@@ -50,32 +41,83 @@
 #include "icons/icons-manager.h"
 #include "identities/identity-manager.h"
 #include "os/generic/url-opener.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/protocol.h"
 #include "protocols/services/avatar-service.h"
-#include "protocols/services/contact-list-service.h"
 
-#include "services/gadu-contact-list-service.h"
-#include "gadu-account-details.h"
-#include "gadu-id-validator.h"
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QSpinBox>
+#include <QtWidgets/QTabWidget>
+#include <QtWidgets/QVBoxLayout>
 
-#include "gadu-personal-info-widget.h"
-
-#include "gadu-edit-account-widget.h"
-
-GaduEditAccountWidget::GaduEditAccountWidget(AccountConfigurationWidgetFactoryRepository *accountConfigurationWidgetFactoryRepository, Account account, QWidget *parent) :
-		AccountEditWidget(accountConfigurationWidgetFactoryRepository, account, parent)
+GaduEditAccountWidget::GaduEditAccountWidget(GaduServersManager *gaduServersManager, Account account, QWidget *parent) :
+		AccountEditWidget(account, parent),
+		m_gaduServersManager{gaduServersManager}
 {
-	Details = dynamic_cast<GaduAccountDetails *>(account.details());
-
-	createGui();
-	loadAccountData();
-	stateChangedSlot(stateNotifier()->state());
 }
 
 GaduEditAccountWidget::~GaduEditAccountWidget()
 {
 }
 
+void GaduEditAccountWidget::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void GaduEditAccountWidget::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void GaduEditAccountWidget::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void GaduEditAccountWidget::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void GaduEditAccountWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void GaduEditAccountWidget::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void GaduEditAccountWidget::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void GaduEditAccountWidget::setUrlOpener(UrlOpener *urlOpener)
+{
+	m_urlOpener = urlOpener;
+}
+
+void GaduEditAccountWidget::init()
+{
+	Details = dynamic_cast<GaduAccountDetails *>(account().details());
+
+	createGui();
+	loadAccountData();
+	stateChangedSlot(stateNotifier()->state());
+}
+
 void GaduEditAccountWidget::createGui()
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -122,7 +164,7 @@ void GaduEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 	QFormLayout *formLayout = new QFormLayout(form);
 
 	AccountId = new QLineEdit(this);
-	AccountId->setValidator(GaduIdValidator::instance());
+	AccountId->setValidator(createOwnedGaduIdValidator(AccountId).get());
 	connect(AccountId, SIGNAL(textEdited(QString)), this, SLOT(dataChanged()));
 	formLayout->addRow(tr("Gadu-Gadu number") + ':', AccountId);
 
@@ -146,7 +188,7 @@ void GaduEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 	formLayout->addRow(0, remindPasswordLabel);
 	connect(remindPasswordLabel, SIGNAL(linkActivated(QString)), this, SLOT(remindPassword()));
 
-	Identities = new IdentitiesComboBox(this);
+	Identities = m_pluginInjectedFactory->makeInjected<IdentitiesComboBox>(this);
 	connect(Identities, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 	formLayout->addRow(tr("Account Identity") + ':', Identities);
 
@@ -156,7 +198,7 @@ void GaduEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 	infoLabel->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
 	formLayout->addRow(0, infoLabel);
 
-	AccountAvatarWidget *avatarWidget = new AccountAvatarWidget(account(), this);
+	AccountAvatarWidget *avatarWidget = m_pluginInjectedFactory->makeInjected<AccountAvatarWidget>(account(), this);
 	layout->addWidget(avatarWidget, 0, 1, Qt::AlignTop);
 
 	tabWidget->addTab(generalTab, tr("General"));
@@ -164,17 +206,17 @@ void GaduEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 
 void GaduEditAccountWidget::createPersonalInfoTab(QTabWidget *tabWidget)
 {
-	gpiw = new GaduPersonalInfoWidget(account(), tabWidget);
+	gpiw = m_pluginInjectedFactory->makeInjected<GaduPersonalInfoWidget>(account(), tabWidget);
 	connect(gpiw, SIGNAL(dataChanged()), this, SLOT(dataChanged()));
 	tabWidget->addTab(gpiw, tr("Personal info"));
 }
 
 void GaduEditAccountWidget::createBuddiesTab(QTabWidget *tabWidget)
 {
-	QWidget *widget = new QWidget(this);
-	QVBoxLayout *layout = new QVBoxLayout(widget);
+	auto widget = new QWidget(this);
+	auto layout = new QVBoxLayout(widget);
 
-	AccountBuddyListWidget *buddiesWidget = new AccountBuddyListWidget(account(), widget);
+	auto buddiesWidget = m_pluginInjectedFactory->makeInjected<AccountBuddyListWidget>(account(), widget);
 	layout->addWidget(buddiesWidget);
 
 	tabWidget->addTab(widget, tr("Buddies"));
@@ -266,43 +308,17 @@ void GaduEditAccountWidget::createGeneralGroupBox(QVBoxLayout *layout)
 							"91.214.237.1 ; 91.214.237.3 ; 91.214.237.10:8074 ; 91.214.237.11-20 ; 91.214.237.21-30:8074");
 	generalLayout->addRow(ipAddressesLabel, ipAddresses);
 
-	AllowFileTransfers = new QCheckBox(tr("Enable file transfers"), general);
-	generalLayout->addRow(AllowFileTransfers);
-
 	connect(useDefaultServers, SIGNAL(toggled(bool)), ipAddressesLabel, SLOT(setDisabled(bool)));
 	connect(useDefaultServers, SIGNAL(toggled(bool)), ipAddresses, SLOT(setDisabled(bool)));
 
 	connect(useDefaultServers, SIGNAL(toggled(bool)), this, SLOT(dataChanged()));
 	connect(ipAddresses, SIGNAL(textEdited(QString)), this, SLOT(dataChanged()));
-	connect(AllowFileTransfers, SIGNAL(toggled(bool)), this, SLOT(dataChanged()));
-
-	UseTlsEncryption = new QCheckBox(tr("Use encrypted connection"), general);
-	generalLayout->addRow(UseTlsEncryption);
-
-	if (gg_libgadu_check_feature(GG_LIBGADU_FEATURE_SSL))
-		connect(UseTlsEncryption, SIGNAL(toggled(bool)), this, SLOT(dataChanged()));
-	else
-	{
-		UseTlsEncryption->setDisabled(true);
-		UseTlsEncryption->setToolTip(tr("You have to compile libgadu with SSL support to be able to enable encrypted connection"));
-	}
 
 	QGroupBox *connection = new QGroupBox(tr("Network"), this);
 	QFormLayout *connectionLayout = new QFormLayout(connection);
 
-	ExternalIp = new QLineEdit(connection);
-	connect(ExternalIp, SIGNAL(textChanged(QString)), this, SLOT(dataChanged()));
-
-	connectionLayout->addRow(new QLabel(tr("External IP") + ':', connection), ExternalIp);
-
-	ExternalPort = new QLineEdit(connection);
-	ExternalPort->setValidator(new QIntValidator(0, 99999, ExternalPort));
-	connect(ExternalPort, SIGNAL(textChanged(QString)), this, SLOT(dataChanged()));
-
-	connectionLayout->addRow(new QLabel(tr("External port") + ':', connection), ExternalPort);
-
 	QLabel *proxyLabel = new QLabel(tr("Proxy configuration") + ':', connection);
-	ProxyCombo = new ProxyComboBox(connection);
+	ProxyCombo = m_pluginInjectedFactory->makeInjected<ProxyComboBox>(connection);
 	ProxyCombo->enableDefaultProxyAction();
 	connect(ProxyCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 
@@ -337,28 +353,20 @@ void GaduEditAccountWidget::apply()
 	if (Details)
 	{
 		Details->setReceiveImagesDuringInvisibility(ReceiveImagesDuringInvisibility->isChecked());
-
 		Details->setChatImageSizeWarning(ChatImageSizeWarning->isChecked());
-
-		Details->setAllowDcc(AllowFileTransfers->isChecked());
-		if (gg_libgadu_check_feature(GG_LIBGADU_FEATURE_SSL))
-			Details->setTlsEncryption(UseTlsEncryption->isChecked());
 		Details->setSendTypingNotification(SendTypingNotification->isChecked());
 		Details->setReceiveSpam(!ReceiveSpam->isChecked());
-
-		Details->setExternalIp(ExternalIp->text());
-		Details->setExternalPort(ExternalPort->text().toUInt());
 	}
 
-	config_file.writeEntry("Network", "isDefServers", useDefaultServers->isChecked());
-	config_file.writeEntry("Network", "Server", ipAddresses->text());
-	GaduServersManager::instance()->buildServerList();
+	m_configuration->deprecatedApi()->writeEntry("Network", "isDefServers", useDefaultServers->isChecked());
+	m_configuration->deprecatedApi()->writeEntry("Network", "Server", ipAddresses->text());
+	m_gaduServersManager->buildServerList();
 
 	if (gpiw->isModified())
 		gpiw->apply();
 
-	IdentityManager::instance()->removeUnused();
-	ConfigurationManager::instance()->flush();
+	m_identityManager->removeUnused();
+	m_configurationManager->flush();
 
 	simpleStateNotifier()->setState(StateNotChanged);
 
@@ -374,7 +382,7 @@ void GaduEditAccountWidget::cancel()
 	loadAccountData();
 	gpiw->cancel();
 
-	IdentityManager::instance()->removeUnused();
+	m_identityManager->removeUnused();
 
 	simpleStateNotifier()->setState(StateNotChanged);
 }
@@ -394,24 +402,18 @@ void GaduEditAccountWidget::dataChanged()
 
 		&& Details->chatImageSizeWarning() == ChatImageSizeWarning->isChecked()
 
-		&& Details->allowDcc() == AllowFileTransfers->isChecked()
-
-		&& config_file.readBoolEntry("Network", "isDefServers", true) == useDefaultServers->isChecked()
-		&& config_file.readEntry("Network", "Server") == ipAddresses->text()
-		&& (!gg_libgadu_check_feature(GG_LIBGADU_FEATURE_SSL) || Details->tlsEncryption() == UseTlsEncryption->isChecked())
+		&& m_configuration->deprecatedApi()->readBoolEntry("Network", "isDefServers", true) == useDefaultServers->isChecked()
+		&& m_configuration->deprecatedApi()->readEntry("Network", "Server") == ipAddresses->text()
 		&& Details->sendTypingNotification() == SendTypingNotification->isChecked()
 		&& Details->receiveSpam() != ReceiveSpam->isChecked()
-		&& !gpiw->isModified()
-
-		&& Details->externalIp() == ExternalIp->text()
-		&& Details->externalPort() == ExternalPort->text().toUInt())
+		&& !gpiw->isModified())
 	{
 		simpleStateNotifier()->setState(StateNotChanged);
 		return;
 	}
 
-	bool sameIdExists = AccountManager::instance()->byId(account().protocolName(), AccountId->text())
-			&& AccountManager::instance()->byId(account().protocolName(), AccountId->text()) != account();
+	bool sameIdExists = m_accountManager->byId(account().protocolName(), AccountId->text())
+			&& m_accountManager->byId(account().protocolName(), AccountId->text()) != account();
 
 	if (AccountId->text().isEmpty() || sameIdExists || StateChangedDataInvalid == widgetsState)
 		simpleStateNotifier()->setState(StateChangedDataInvalid);
@@ -435,27 +437,20 @@ void GaduEditAccountWidget::loadAccountData()
 	if (details)
 	{
 		ReceiveImagesDuringInvisibility->setChecked(details->receiveImagesDuringInvisibility());;
-
 		ChatImageSizeWarning->setChecked(details->chatImageSizeWarning());
-
-		AllowFileTransfers->setChecked(details->allowDcc());
-		UseTlsEncryption->setChecked(gg_libgadu_check_feature(GG_LIBGADU_FEATURE_SSL) ? details->tlsEncryption() : false);
 		SendTypingNotification->setChecked(details->sendTypingNotification());
 		ReceiveSpam->setChecked(!details->receiveSpam());
-
-		ExternalIp->setText(details->externalIp());
-		ExternalPort->setText(QString::number(details->externalPort()));
 	}
 
-	useDefaultServers->setChecked(config_file.readBoolEntry("Network", "isDefServers", true));
-	ipAddresses->setText(config_file.readEntry("Network", "Server"));
+	useDefaultServers->setChecked(m_configuration->deprecatedApi()->readBoolEntry("Network", "isDefServers", true));
+	ipAddresses->setText(m_configuration->deprecatedApi()->readEntry("Network", "Server"));
 
 	simpleStateNotifier()->setState(StateNotChanged);
 }
 
 void GaduEditAccountWidget::removeAccount()
 {
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Confrim Account Removal"),
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Confrim Account Removal"),
 	                        tr("Are you sure do you want to remove account %1 (%2)?")
 				.arg(account().accountIdentity().name())
 				.arg(account().id()));
@@ -466,19 +461,19 @@ void GaduEditAccountWidget::removeAccount()
 
 	if (decision == QMessageBox::Yes)
 	{
-		AccountManager::instance()->removeAccountAndBuddies(account());
+		m_accountManager->removeAccountAndBuddies(account());
 		deleteLater();
 	}
 }
 
 void GaduEditAccountWidget::remindUin()
 {
-	UrlOpener::openUrl("https://login.gg.pl/account/remindGG_email/?id=frame_1");
+	m_urlOpener->openUrl("https://login.gg.pl/account/remindGG_email/?id=frame_1");
 }
 
 void GaduEditAccountWidget::remindPassword()
 {
-	UrlOpener::openUrl("https://login.gg.pl/account/remindPassword/?id=frame_1");
+	m_urlOpener->openUrl("https://login.gg.pl/account/remindPassword/?id=frame_1");
 }
 
 void GaduEditAccountWidget::showStatusToEveryoneToggled(bool toggled)
@@ -488,7 +483,7 @@ void GaduEditAccountWidget::showStatusToEveryoneToggled(bool toggled)
 
 	int count = 0;
 
-	const QVector<Contact> &contacts = ContactManager::instance()->contacts(account());
+	const QVector<Contact> &contacts = m_contactManager->contacts(account());
 	foreach (const Contact &contact, contacts)
 		if (!contact.isAnonymous() && contact.ownerBuddy().isOfflineTo())
 			count++;
@@ -496,7 +491,7 @@ void GaduEditAccountWidget::showStatusToEveryoneToggled(bool toggled)
 	if (!count)
 		return;
 
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Status Visibility"),
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Status Visibility"),
 	                        tr("You are going to reveal your status to several buddies which are currently not allowed to see it.\n"
 				  "Are you sure to allow them to know you are available?"));
 	dialog->addButton(QMessageBox::Yes, tr("Make my status visible anyway"));
