@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,26 +18,43 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QComboBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
 
+#include "buddies/buddy-storage.h"
+#include "core/core.h"
 #include "debug.h"
 #include "gadu-account-details.h"
 
 #include "gadu-personal-info-widget.h"
 
 GaduPersonalInfoWidget::GaduPersonalInfoWidget(Account account, QWidget* parent) :
-		QWidget(parent), Id(account.id()), MyBuddy(Buddy::create())
+		QWidget(parent), m_account{account}, Id(account.id())
 {
+}
+
+GaduPersonalInfoWidget::~GaduPersonalInfoWidget()
+{
+}
+
+void GaduPersonalInfoWidget::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void GaduPersonalInfoWidget::init()
+{
+	MyBuddy = m_buddyStorage->create();
+
 	createGui();
 	fillForm();
 
-	if (account.isNull() || !account.protocolHandler())
+	if (m_account.isNull() || !m_account.protocolHandler())
 		return;
 
-	Service = account.protocolHandler()->personalInfoService();
+	Service = m_account.protocolHandler()->personalInfoService();
 	if (!Service)
 		return;
 
@@ -48,10 +62,6 @@ GaduPersonalInfoWidget::GaduPersonalInfoWidget(Account account, QWidget* parent)
 	Service->fetchPersonalInfo(Id);
 }
 
-GaduPersonalInfoWidget::~GaduPersonalInfoWidget()
-{
-}
-
 void GaduPersonalInfoWidget::createGui()
 {
 	QFormLayout *layout = new QFormLayout(this);
@@ -127,7 +137,7 @@ bool GaduPersonalInfoWidget::isModified()
 
 void GaduPersonalInfoWidget::apply()
 {
-	Buddy buddy = Buddy::create();
+	Buddy buddy = m_buddyStorage->create();
 
 	buddy.setNickName((*NickName).text());
 	buddy.setFirstName((*FirstName).text());
