@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011, 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,43 +19,57 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "gadu-list-helper.h"
+
+#include "buddies/buddy-list.h"
+#include "buddies/buddy-manager.h"
+#include "buddies/buddy-storage.h"
+#include "buddies/group-manager.h"
+#include "buddies/group.h"
+#include "contacts/contact-manager.h"
+#include "contacts/contact-storage.h"
+#include "contacts/contact.h"
+#include "misc/misc.h"
+#include "protocols/protocol.h"
+#include "debug.h"
+
 #include <QtCore/QStringList>
 #include <QtCore/QTextCodec>
 #include <QtCore/QTextStream>
 
-#include "buddies/buddy-list.h"
-#include "buddies/buddy-manager.h"
-#include "buddies/group-manager.h"
-#include "buddies/group.h"
-#include "contacts/contact-manager.h"
-#include "contacts/contact.h"
-#include "protocols/protocol.h"
-#include "protocols/roster.h"
-
-#include "misc/misc.h"
-#include "debug.h"
-
-#include "../gadu-contact-details.h"
-
-#include "gadu-list-helper.h"
-
-void GaduListHelper::setSupportedBuddyInformation(const Buddy &destination, const Buddy &source)
+GaduListHelper::GaduListHelper(QObject *parent) :
+		QObject{parent}
 {
-	destination.setFirstName(source.firstName());
-	destination.setLastName(source.lastName());
-	destination.setNickName(source.nickName());
-	destination.setDisplay(source.display());
-	destination.setMobile(source.mobile());
-	destination.setGroups(source.groups());
-	destination.setEmail(source.email());
-	destination.setOfflineTo(source.isOfflineTo());
-	destination.setHomePhone(source.homePhone());
+}
+
+GaduListHelper::~GaduListHelper()
+{
+}
+
+void GaduListHelper::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void GaduListHelper::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void GaduListHelper::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
+void GaduListHelper::setGroupManager(GroupManager *groupManager)
+{
+	m_groupManager = groupManager;
 }
 
 QString GaduListHelper::contactToLine70(Contact contact)
 {
 	QStringList list;
-	Buddy buddy = BuddyManager::instance()->byContact(contact, ActionCreateAndAdd);
+	Buddy buddy = m_buddyManager->byContact(contact, ActionCreateAndAdd);
 
 	list.append(buddy.firstName());
 	list.append(buddy.lastName());
@@ -84,14 +96,19 @@ QString GaduListHelper::contactToLine70(Contact contact)
 
 QByteArray GaduListHelper::buddyListToByteArray(Account account, const BuddyList &buddies)
 {
-	kdebugf();
+	auto contacts = QVector<Contact>{};
+	for (auto &&buddy : buddies)
+		contacts += buddy.contacts(account);
+	return contactListToByteArray(contacts);
+}
 
-	QStringList result;
+QByteArray GaduListHelper::contactListToByteArray(const QVector<Contact> &contacts)
+{
+	auto result = QStringList{};
 	result.append("GG70ExportString");
 
-	foreach (const Buddy &buddy, buddies)
-		foreach (const Contact &contact, buddy.contacts(account))
-			result.append(contactToLine70(contact));
+	for (auto &&contact : contacts)
+		result.append(contactToLine70(contact));
 
 	return result.join("\n").toUtf8();
 }
@@ -111,9 +128,9 @@ BuddyList GaduListHelper::streamToBuddyList(Account account, QTextStream &conten
 
 	QString line = content.readLine(70);
 
-	if (line.startsWith(QLatin1String("<ContactBook>")))
+	if (line.startsWith(QStringLiteral("<ContactBook>")))
 		result = streamPost70ToBuddyList(line, account, content);
-	else if (line.startsWith(QLatin1String("GG70ExportString")))
+	else if (line.startsWith(QStringLiteral("GG70ExportString")))
 		result = stream70ToBuddyList(account, content);
 	else
 		result = streamPre70ToBuddyList(line, account, content);
@@ -208,14 +225,14 @@ BuddyList GaduListHelper::streamPost70ToBuddyList(const QString &line, Account a
 		for (; !groupElement.isNull(); groupElement = groupElement.nextSiblingElement("Group"))
 		{
 			QDomElement idElement = groupElement.firstChildElement("Id");
-			if (idElement.text().startsWith(QLatin1String("00000000-0000-0000-0000-")))
+			if (idElement.text().startsWith(QStringLiteral("00000000-0000-0000-0000-")))
 				continue;
 
 			QDomElement nameElement = groupElement.firstChildElement("Name");
 			if (nameElement.text().isEmpty())
 				continue;
 
-			importedGroups.insert(idElement.text(), GroupManager::instance()->byName(nameElement.text()));
+			importedGroups.insert(idElement.text(), m_groupManager->byName(nameElement.text()));
 		}
 	}
 
@@ -225,7 +242,7 @@ BuddyList GaduListHelper::streamPost70ToBuddyList(const QString &line, Account a
 		QDomElement contactElement = contactsNode.firstChildElement("Contact");
 		for (; !contactElement.isNull(); contactElement = contactElement.nextSiblingElement("Contact"))
 		{
-			Buddy buddy = Buddy::create();
+			Buddy buddy = m_buddyStorage->create();
 
 			buddy.setFirstName(contactElement.firstChildElement("FirstName").text());
 			buddy.setLastName(contactElement.firstChildElement("LastName").text());
@@ -250,16 +267,11 @@ BuddyList GaduListHelper::streamPost70ToBuddyList(const QString &line, Account a
 			QDomElement numberElement = contactElement.firstChildElement("GGNumber");
 			if (!numberElement.text().isEmpty() && numberElement.text() != account.id())
 			{
-				Contact contact = Contact::create();
+				Contact contact = m_contactStorage->create();
 				contact.setContactAccount(account);
-				GaduContactDetails *details = dynamic_cast<GaduContactDetails *>(contact.details());
-				if (details)
-					details->setState(StorableObject::StateNew);
 				contact.setId(numberElement.text());
 				contact.data()->setState(StorableObject::StateNew);
 				contact.setOwnerBuddy(buddy);
-
-				Roster::instance()->addContact(contact);
 			}
 
 			buddy.setAnonymous(false);
@@ -281,7 +293,7 @@ Buddy GaduListHelper::linePre70ToBuddy(Account account, QStringList &sections)
 	if (secCount < 5)
 		return Buddy::null;
 
-	Buddy buddy = Buddy::create();
+	Buddy buddy = m_buddyStorage->create();
 
 	buddy.setFirstName(sections[0]);
 	buddy.setLastName(sections[1]);
@@ -291,7 +303,7 @@ Buddy GaduListHelper::linePre70ToBuddy(Account account, QStringList &sections)
 
 	groups.clear();
 	if (!sections[5].isEmpty())
-		groups.insert(GroupManager::instance()->byName(sections[5]));
+		groups.insert(m_groupManager->byName(sections[5]));
 
 	i = 6;
 	while (!ok && i < secCount)
@@ -299,7 +311,7 @@ Buddy GaduListHelper::linePre70ToBuddy(Account account, QStringList &sections)
 		sections[i].toULong(&ok);
 		ok = ok || sections[i].isEmpty();
 		if (!ok)
-			groups.insert(GroupManager::instance()->byName(sections[i]));
+			groups.insert(m_groupManager->byName(sections[i]));
 		++i;
 	}
 	buddy.setGroups(groups);
@@ -312,16 +324,11 @@ Buddy GaduListHelper::linePre70ToBuddy(Account account, QStringList &sections)
 			uin = 0;
 		if (uin && QString::number(uin) != account.id())
 		{
-			Contact contact = Contact::create();
+			Contact contact = m_contactStorage->create();
 			contact.setContactAccount(account);
 			contact.setId(QString::number(uin));
-			GaduContactDetails *details = dynamic_cast<GaduContactDetails *>(contact.details());
-			if (details)
-				details->setState(StorableObject::StateNew);
 			contact.data()->setState(StorableObject::StateNew);
 			contact.setOwnerBuddy(buddy);
-
-			Roster::instance()->addContact(contact);
 		}
 	}
 
@@ -361,7 +368,7 @@ Buddy GaduListHelper::line70ToBuddy(Account account, QStringList &sections)
 	if (secCount < 6)
 		return Buddy::null;
 
-	Buddy buddy = Buddy::create();
+	Buddy buddy = m_buddyStorage->create();
 
 	buddy.setFirstName(sections[0]);
 	buddy.setLastName(sections[1]);
@@ -372,7 +379,7 @@ Buddy GaduListHelper::line70ToBuddy(Account account, QStringList &sections)
 	if (!sections[5].isEmpty())
 	{
 		foreach (const QString &group, sections[5].split(',', QString::SkipEmptyParts))
-			groups.insert(GroupManager::instance()->byName(group));
+			groups.insert(m_groupManager->byName(group));
 
 		buddy.setGroups(groups);
 	}
@@ -385,16 +392,11 @@ Buddy GaduListHelper::line70ToBuddy(Account account, QStringList &sections)
 			uin = 0;
 		if (uin && QString::number(uin) != account.id())
 		{
-			Contact contact = Contact::create();
+			Contact contact = m_contactStorage->create();
 			contact.setContactAccount(account);
 			contact.setId(QString::number(uin));
-			GaduContactDetails *details = dynamic_cast<GaduContactDetails *>(contact.details());
-			if (details)
-				details->setState(StorableObject::StateNew);
 			contact.data()->setState(StorableObject::StateNew);
 			contact.setOwnerBuddy(buddy);
-
-			Roster::instance()->addContact(contact);
 		}
 	}
 
@@ -422,3 +424,5 @@ Buddy GaduListHelper::line70ToBuddy(Account account, QStringList &sections)
 	buddy.setAnonymous(false);
 	return buddy;
 }
+
+#include "moc_gadu-list-helper.cpp"
