@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,22 +18,36 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GADU_LIST_HELPER_H
-#define GADU_LIST_HELPER_H
+#pragma once
+
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class Account;
+class BuddyList;
+class BuddyManager;
+class BuddyStorage;
+class Buddy;
+class ContactStorage;
+class Contact;
+class GroupManager;
 
 class QByteArray;
 class QString;
 class QTextStream;
 
-class Account;
-class Buddy;
-class BuddyList;
-class Contact;
-
-namespace GaduListHelper
+class GaduListHelper : public QObject
 {
+	Q_OBJECT
+
+public:
+	Q_INVOKABLE explicit GaduListHelper(QObject *parent = nullptr);
+	virtual ~GaduListHelper();
+
 	void setSupportedBuddyInformation(const Buddy &destination, const Buddy &source);
 	QByteArray buddyListToByteArray(Account account, const BuddyList &buddies);
+	QByteArray contactListToByteArray(const QVector<Contact> &contacts);
 	QString contactToLine70(Contact contact);
 	BuddyList byteArrayToBuddyList(Account account, QByteArray &content);
 	BuddyList streamToBuddyList(Account account, QTextStream &content);
@@ -46,6 +56,17 @@ namespace GaduListHelper
 	BuddyList streamPost70ToBuddyList(const QString &line, Account account, QTextStream &content);
 	BuddyList stream70ToBuddyList(Account account, QTextStream &content);
 	BuddyList streamPre70ToBuddyList(const QString &firstLine, Account account, QTextStream &content);
-}
 
-#endif // GADU_LIST_HELPER_H
+private:
+	QPointer<BuddyManager> m_buddyManager;
+	QPointer<BuddyStorage> m_buddyStorage;
+	QPointer<ContactStorage> m_contactStorage;
+	QPointer<GroupManager> m_groupManager;
+
+private slots:
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+	INJEQT_SET void setBuddyStorage(BuddyStorage *buddyStorage);
+	INJEQT_SET void setContactStorage(ContactStorage *contactStorage);
+	INJEQT_SET void setGroupManager(GroupManager *groupManager);
+
+};
