@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,12 +18,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
+#include "buddies/buddy-storage.h"
+#include "contacts/contact-storage.h"
 #include "debug.h"
 
-#include "gadu-contact-details.h"
-
 #include "gadu-protocol-helper.h"
 
 #define GG_STATUS_INVISIBLE2 0x0009
@@ -35,31 +35,31 @@ StatusType GaduProtocolHelper::statusTypeFromGaduStatus(unsigned int index)
 	{
 		case GG_STATUS_FFC_DESCR:
 		case GG_STATUS_FFC:
-			return StatusTypeFreeForChat;
+			return StatusType::FreeForChat;
 
 		case GG_STATUS_AVAIL_DESCR:
 		case GG_STATUS_AVAIL:
-			return StatusTypeOnline;
+			return StatusType::Online;
 
 		case GG_STATUS_BUSY_DESCR:
 		case GG_STATUS_BUSY:
-			return StatusTypeAway;
+			return StatusType::Away;
 
 		case GG_STATUS_DND_DESCR:
 		case GG_STATUS_DND:
-			return StatusTypeDoNotDisturb;
+			return StatusType::DoNotDisturb;
 
 		case GG_STATUS_INVISIBLE_DESCR:
 		case GG_STATUS_INVISIBLE:
 		case GG_STATUS_INVISIBLE2:
-			return StatusTypeInvisible;
+			return StatusType::Invisible;
 
 		case GG_STATUS_BLOCKED:
 		case GG_STATUS_NOT_AVAIL_DESCR:
 		case GG_STATUS_NOT_AVAIL:
 
 		default:
-			return StatusTypeOffline;
+			return StatusType::Offline;
 	}
 }
 
@@ -73,19 +73,19 @@ unsigned int GaduProtocolHelper::gaduStatusFromStatus(const Status &status)
 	bool hasDescription = !status.description().isEmpty();
 	StatusType type = status.type();
 
-	if (StatusTypeFreeForChat == type)
+	if (StatusType::FreeForChat == type)
 		return hasDescription ? GG_STATUS_FFC_DESCR : GG_STATUS_FFC;
 
-	if (StatusTypeOnline == type)
+	if (StatusType::Online == type)
 		return hasDescription ? GG_STATUS_AVAIL_DESCR : GG_STATUS_AVAIL;
 
-	if (StatusTypeAway == type || StatusTypeNotAvailable == type)
+	if (StatusType::Away == type || StatusType::NotAvailable == type)
 		return hasDescription ? GG_STATUS_BUSY_DESCR : GG_STATUS_BUSY;
 
-	if (StatusTypeDoNotDisturb == type)
+	if (StatusType::DoNotDisturb == type)
 		return hasDescription ? GG_STATUS_DND_DESCR : GG_STATUS_DND;
 
-	if (StatusTypeInvisible == type)
+	if (StatusType::Invisible == type)
 		return hasDescription ? GG_STATUS_INVISIBLE_DESCR : GG_STATUS_INVISIBLE;
 
 	return hasDescription ? GG_STATUS_NOT_AVAIL_DESCR : GG_STATUS_NOT_AVAIL;
@@ -140,11 +140,11 @@ bool GaduProtocolHelper::isConnectionErrorFatal(GaduProtocol::GaduError error)
 	}
 }
 
-Buddy GaduProtocolHelper::searchResultToBuddy(Account account, gg_pubdir50_t res, int number)
+Buddy GaduProtocolHelper::searchResultToBuddy(BuddyStorage *buddyStorage, ContactStorage *contactStorage, Account account, gg_pubdir50_t res, int number)
 {
-	Buddy result = Buddy::create();
+	Buddy result = buddyStorage->create();
 
-	Contact contact = Contact::create();
+	Contact contact = contactStorage->create();
 	contact.setContactAccount(account);
 	contact.setOwnerBuddy(result);
 	contact.setId(gg_pubdir50_get(res, number, GG_PUBDIR50_UIN));
@@ -171,15 +171,5 @@ Buddy GaduProtocolHelper::searchResultToBuddy(Account account, gg_pubdir50_t res
 
 unsigned int GaduProtocolHelper::uin(Contact contact)
 {
-	GaduContactDetails *data = GaduProtocolHelper::gaduContactDetails(contact);
-	return data
-			? data->uin()
-			: 0;
-}
-
-GaduContactDetails * GaduProtocolHelper::gaduContactDetails(Contact contact)
-{
-	if (contact.isNull())
-		return 0;
-	return dynamic_cast<GaduContactDetails *>(contact.details());
+	return contact.id().toUInt();
 }
