@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,16 +26,30 @@
 #include "contacts/contact.h"
 #include "debug.h"
 
-#include "gadu-contact-details.h"
 #include "gadu-id-validator.h"
 
 #include "gadu-open-chat-with-runner.h"
 
-GaduOpenChatWithRunner::GaduOpenChatWithRunner(Account account) :
-		ParentAccount(account)
+GaduOpenChatWithRunner::GaduOpenChatWithRunner(Account account, QObject *parent) :
+		QObject{parent},
+		m_account{account}
 {
 }
 
+GaduOpenChatWithRunner::~GaduOpenChatWithRunner()
+{
+}
+
+void GaduOpenChatWithRunner::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void GaduOpenChatWithRunner::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
 BuddyList GaduOpenChatWithRunner::matchingContacts(const QString &query)
 {
 	kdebugf();
@@ -46,11 +57,11 @@ BuddyList GaduOpenChatWithRunner::matchingContacts(const QString &query)
 	BuddyList matchedContacts;
 	QString queryCopy(query);
 	int pos = 0;
-	if (GaduIdValidator::instance()->validate(queryCopy, pos) != QValidator::Acceptable)
+	if (createNotOwnedGaduIdValidator()->validate(queryCopy, pos) != QValidator::Acceptable)
 		return matchedContacts;
 
-	Contact contact = ContactManager::instance()->byId(ParentAccount, query, ActionCreate);
-	Buddy buddy = BuddyManager::instance()->byContact(contact, ActionCreate);
+	auto contact = m_contactManager->byId(m_account, query, ActionCreate);
+	auto buddy = m_buddyManager->byContact(contact, ActionCreate);
 	matchedContacts.append(buddy);
 
 	return matchedContacts;
