@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -64,7 +64,7 @@ public:
 	 * @author Rafał 'Vogel' Malinowski
 	 * @param parent QObject parent
 	 */
-	explicit GaduAvatarDownloader(QObject *parent = 0);
+	explicit GaduAvatarDownloader(QObject *parent = nullptr);
 	virtual ~GaduAvatarDownloader();
 
 	virtual void downloadAvatar(const QString &id);
