@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Ziemniak (jziemkiewicz@gmail.com)
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,26 +23,32 @@
 
 #include <libgadu.h>
 
-#include "configuration/configuration-file.h"
-#include "misc/kadu-paths.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "misc/paths-provider.h"
 
 #include "gadu-servers-manager.h"
 
-GaduServersManager * GaduServersManager::Instance = 0;
-
-void GaduServersManager::createInstance()
+GaduServersManager::GaduServersManager(QObject *parent) :
+		QObject{parent}
 {
-	if (!Instance)
-		Instance = new GaduServersManager();
 }
 
-void GaduServersManager::destroyInstance()
+GaduServersManager::~GaduServersManager()
 {
-	delete Instance;
-	Instance = 0;
 }
 
-GaduServersManager::GaduServersManager()
+void GaduServersManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void GaduServersManager::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void GaduServersManager::init()
 {
 	buildServerList();
 }
@@ -57,7 +57,7 @@ QList<GaduServersManager::GaduServer> GaduServersManager::gaduServersFromString(
 {
 	QList<GaduServer> result;
 
-	if (serverAddress.isEmpty() || serverAddress.startsWith(QLatin1String("0.0.0.0")))
+	if (serverAddress.isEmpty() || serverAddress.startsWith(QStringLiteral("0.0.0.0")))
 		return result;
 
 	QString address;
@@ -102,7 +102,7 @@ QList<GaduServersManager::GaduServer> GaduServersManager::gaduServersFromString(
 void GaduServersManager::loadServerListFromFile(const QString &fileName)
 {
 	GoodServers << GaduServer(QHostAddress((quint32)0), 0); // for GG hub
-	GoodServers << gaduServersFromString(config_file.readEntry("Network", "LastServerIP"));
+	GoodServers << gaduServersFromString(m_configuration->deprecatedApi()->readEntry("Network", "LastServerIP"));
 
 	QFile file(fileName);
 
@@ -127,7 +127,7 @@ void GaduServersManager::loadServerListFromString(const QString& data)
 	foreach (const QString &server, servers)
 		GoodServers << gaduServersFromString(server.trimmed());
 	GoodServers << GaduServer(QHostAddress((quint32)0), 0); // for GG hub
-	GoodServers << gaduServersFromString(config_file.readEntry("Network", "LastServerIP"));
+	GoodServers << gaduServersFromString(m_configuration->deprecatedApi()->readEntry("Network", "LastServerIP"));
 }
 
 void GaduServersManager::buildServerList()
@@ -137,8 +137,8 @@ void GaduServersManager::buildServerList()
 	AllServers.clear();
 	AllPorts.clear();
 
-	int LastGoodPort = config_file.readNumEntry("Network", "LastServerPort",
-			config_file.readNumEntry("Network", "DefaultPort", 443));
+	int LastGoodPort = m_configuration->deprecatedApi()->readNumEntry("Network", "LastServerPort",
+			m_configuration->deprecatedApi()->readNumEntry("Network", "DefaultPort", 443));
 
 	if (8074 == LastGoodPort || 443 == LastGoodPort)
 		AllPorts << LastGoodPort;
@@ -147,10 +147,10 @@ void GaduServersManager::buildServerList()
 	if (443 != LastGoodPort)
 		AllPorts << 443;
 
-	if (config_file.readBoolEntry("Network", "isDefServers", true))
-		loadServerListFromFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/data/gadu_protocol/servers.txt"));
+	if (m_configuration->deprecatedApi()->readBoolEntry("Network", "isDefServers", true))
+		loadServerListFromFile(m_pathsProvider->dataPath() + QStringLiteral("plugins/data/gadu_protocol/servers.txt"));
 	else
-		loadServerListFromString(config_file.readEntry("Network", "Server"));
+		loadServerListFromString(m_configuration->deprecatedApi()->readEntry("Network", "Server"));
 
 	AllServers = GoodServers;
 }
@@ -185,8 +185,8 @@ const QList<GaduServersManager::GaduServer> & GaduServersManager::getServersList
 
 void GaduServersManager::markServerAsGood(GaduServersManager::GaduServer server)
 {
-	config_file.writeEntry("Network", "LastServerIP", server.first.toString());
-	config_file.writeEntry("Network", "LastServerPort", server.second);
+	m_configuration->deprecatedApi()->writeEntry("Network", "LastServerIP", server.first.toString());
+	m_configuration->deprecatedApi()->writeEntry("Network", "LastServerPort", server.second);
 }
 
 void GaduServersManager::markServerAsBad(GaduServersManager::GaduServer server)
