@@ -1,12 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,20 +20,27 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QtCore/QRegularExpression>
 #include <QtCore/QScopedArrayPointer>
 #include <QtCore/QTimer>
 
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact-set.h"
 #include "chat/type/chat-type-contact.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact-set.h"
-#include "core/core.h"
 #include "formatted-string/composite-formatted-string.h"
 #include "formatted-string/formatted-string-factory.h"
 #include "formatted-string/formatted-string-is-plain-text-visitor.h"
 #include "formatted-string/formatted-string-plain-text-visitor.h"
 #include "gui/windows/message-dialog.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "icons/icons-manager.h"
+#include "message/message-storage.h"
 #include "message/raw-message.h"
 #include "misc/misc.h"
 #include "services/image-storage-service.h"
@@ -71,19 +75,54 @@ GaduChatService::~GaduChatService()
 {
 }
 
+void GaduChatService::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void GaduChatService::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void GaduChatService::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void GaduChatService::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void GaduChatService::setFormattedStringFactory(FormattedStringFactory *formattedStringFactory)
+{
+	m_formattedStringFactory = formattedStringFactory;
+}
+
 void GaduChatService::setGaduChatImageService(GaduChatImageService *gaduChatImageService)
 {
 	CurrentGaduChatImageService = gaduChatImageService;
 }
 
+void GaduChatService::setGaduFileTransferService(GaduFileTransferService *gaduFileTransferService)
+{
+	CurrentFileTransferService = gaduFileTransferService;
+}
+
+void GaduChatService::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
 void GaduChatService::setImageStorageService(ImageStorageService *imageStorageService)
 {
 	CurrentImageStorageService = imageStorageService;
 }
 
-void GaduChatService::setFormattedStringFactory(FormattedStringFactory *formattedStringFactory)
+void GaduChatService::setMessageStorage(MessageStorage *messageStorage)
 {
-	CurrentFormattedStringFactory = formattedStringFactory;
+	m_messageStorage = messageStorage;
 }
 
 void GaduChatService::setConnection(GaduConnection *connection)
@@ -144,22 +183,24 @@ bool GaduChatService::sendMessage(const Message &message)
 	if (!Connection || !Connection.data()->hasSession())
 		return false;
 
+	auto formattedContent = m_formattedStringFactory->fromHtml(message.content());
+
 	FormattedStringIsPlainTextVisitor isPlainTextVisitor;
-	message.content()->accept(&isPlainTextVisitor);
+	formattedContent->accept(&isPlainTextVisitor);
 
 	FormattedStringPlainTextVisitor plainTextVisitor;
-	message.content()->accept(&plainTextVisitor);
+	formattedContent->accept(&plainTextVisitor);
 
 	FormattedStringGaduHtmlVisitor htmlVisitor(CurrentGaduChatImageService, CurrentImageStorageService);
-	message.content()->accept(&htmlVisitor);
+	formattedContent->accept(&htmlVisitor);
 
-	auto rawMessage = RawMessage{plainTextVisitor.result().toUtf8(), htmlVisitor.result().toUtf8()};
+	auto rawMessage = RawMessage{plainTextVisitor.result().toUtf8(), htmlVisitor.result().string().toUtf8()};
 	if (rawMessageTransformerService())
 		rawMessage = rawMessageTransformerService()->transform(rawMessage, message);
 
 	if (rawMessage.rawContent().length() > maxMessageLength())
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Message too long (%1 >= %2)").arg(rawMessage.rawContent().length()).arg(10000));
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Message too long (%1 >= %2)").arg(rawMessage.rawContent().length()).arg(10000));
 		kdebugmf(KDEBUG_FUNCTION_END, "end: filtered message too long\n");
 		return false;
 	}
@@ -188,17 +229,17 @@ bool GaduChatService::isSystemMessage(gg_event *e)
 
 Contact GaduChatService::getSender(gg_event *e)
 {
-	return ContactManager::instance()->byId(account(), QString::number(e->event.msg.sender), ActionCreateAndAdd);
+	return m_contactManager->byId(account(), QString::number(e->event.msg.sender), ActionCreateAndAdd);
 }
 
 bool GaduChatService::ignoreSender(gg_event *e, Buddy sender)
 {
 	bool ignore =
 			sender.isAnonymous() &&
-			config_file.readBoolEntry("Chat", "IgnoreAnonymousUsers") &&
+			m_configuration->deprecatedApi()->readBoolEntry("Chat", "IgnoreAnonymousUsers") &&
 			(
 				(e->event.msg.recipients_count == 0) ||
-				config_file.readBoolEntry("Chat", "IgnoreAnonymousUsersInConferences")
+				m_configuration->deprecatedApi()->readBoolEntry("Chat", "IgnoreAnonymousUsersInConferences")
 			);
 
 	return ignore;
@@ -208,7 +249,7 @@ ContactSet GaduChatService::getRecipients(gg_event *e)
 {
 	ContactSet recipients;
 	for (int i = 0; i < e->event.msg.recipients_count; ++i)
-		recipients.insert(ContactManager::instance()->byId(account(), QString::number(e->event.msg.recipients[i]), ActionCreateAndAdd));
+		recipients.insert(m_contactManager->byId(account(), QString::number(e->event.msg.recipients[i]), ActionCreateAndAdd));
 
 	return recipients;
 }
@@ -223,7 +264,7 @@ RawMessage GaduChatService::getRawMessage(gg_event *e)
 
 bool GaduChatService::ignoreRichText(Contact sender)
 {
-	return sender.isAnonymous() && config_file.readBoolEntry("Chat","IgnoreAnonymousRichtext");
+	return sender.isAnonymous() && m_configuration->deprecatedApi()->readBoolEntry("Chat","IgnoreAnonymousRichtext");
 }
 
 void GaduChatService::handleMsg(Contact sender, ContactSet recipients, MessageType type, gg_event *e)
@@ -238,14 +279,24 @@ void GaduChatService::handleMsg(Contact sender, ContactSet recipients, MessageTy
 		return;
 
 	Chat chat = 1 == chatContacts.size()
-			? ChatTypeContact::findChat(*chatContacts.constBegin(), ActionCreateAndAdd)
-			: ChatTypeContactSet::findChat(chatContacts, ActionCreateAndAdd);
+			? ChatTypeContact::findChat(m_chatManager, m_chatStorage, *chatContacts.constBegin(), ActionCreateAndAdd)
+			: ChatTypeContactSet::findChat(m_chatManager, m_chatStorage, chatContacts, ActionCreateAndAdd);
 
 	// create=true in our call for findChat(), but chat might be null for example if chatContacts was empty
 	if (!chat || chat.isIgnoreAllMessages())
 		return;
 
-	Message message = Message::create();
+	if (CurrentFileTransferService)
+	{
+		auto content = QString::fromUtf8(reinterpret_cast<const char *>(e->event.msg.message));
+		auto fileTransferRegExp = QRegularExpression{"^http\\:\\/\\/www\\.gg\\.pl\\/dysk\\/([a-zA-Z0-9-_]{23})\\/(.+)$"};
+		auto fileTransferMatch = fileTransferRegExp.match(content);
+
+		if (fileTransferMatch.hasMatch())
+			CurrentFileTransferService->fileTransferReceived(sender, fileTransferMatch.captured(1), fileTransferMatch.captured(2));
+	}
+
+	Message message = m_messageStorage->create();
 	message.setMessageChat(chat);
 	message.setType(type);
 	message.setMessageSender(sender);
@@ -253,29 +304,25 @@ void GaduChatService::handleMsg(Contact sender, ContactSet recipients, MessageTy
 	message.setReceiveDate(QDateTime::currentDateTime());
 
 	auto rawMessage = getRawMessage(e);
+
 	if (rawMessageTransformerService())
 		rawMessage = rawMessageTransformerService()->transform(rawMessage, message);
 
-	auto string = QString::fromUtf8(rawMessage.rawContent());
-	// TODO: this is a hack, we get <img name= from GG servers, but
-	// FormattedStringFactory requires <img src= as it cannot parse name= attribute
-	// this is because of QTextDocument usage, this needs to be fixed in a proper way
-	string.replace(QLatin1String{"<img name="}, QLatin1String{"<img src="});
-	auto formattedString = CurrentFormattedStringFactory->fromHtml(string);
-	if (ignoreRichText(sender))
+	auto htmlContent = normalizeHtml(HtmlString{QString::fromUtf8(rawMessage.rawContent())});
+	auto formattedString = m_formattedStringFactory->fromHtml(htmlContent);
+	if (!ignoreRichText(sender))
 	{
-		FormattedStringPlainTextVisitor visitor;
-		formattedString->accept(&visitor);
-
-		// for history and sorted messages we must use html format
-		auto htmlBody = replacedNewLine(Qt::escape(visitor.result()), QLatin1String("<br/>"));
-		formattedString = CurrentFormattedStringFactory->fromHtml(visitor.result());
+		FormattedStringHtmlVisitor htmlVisitor;
+		formattedString->accept(&htmlVisitor);
+		htmlContent = normalizeHtml(htmlVisitor.result());
 	}
+	else
+		htmlContent = normalizeHtml(plainToHtml(htmlToPlain(htmlContent)));
 
-	if (formattedString->isEmpty())
+	if (htmlContent.string().isEmpty())
 		return;
 
-	message.setContent(std::move(formattedString));
+	message.setContent(std::move(htmlContent));
 
 	if (MessageTypeReceived == type)
 	{
@@ -285,7 +332,7 @@ void GaduChatService::handleMsg(Contact sender, ContactSet recipients, MessageTy
 		connect(&imageKeyReceivedVisitor, SIGNAL(chatImageKeyReceived(QString,ChatImage)),
 		        this, SIGNAL(chatImageKeyReceived(QString,ChatImage)));
 
-		message.content()->accept(&imageKeyReceivedVisitor);
+		formattedString->accept(&imageKeyReceivedVisitor);
 	}
 	else
 		emit messageSent(message);
@@ -383,4 +430,9 @@ void GaduChatService::removeTimeoutUndeliveredMessages()
 	}
 }
 
+void GaduChatService::leaveChat(const Chat& chat)
+{
+	chat.setIgnoreAllMessages(true);
+}
+
 #include "moc_gadu-chat-service.cpp"
