@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,12 +18,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "buddies/buddy-storage.h"
+#include "contacts/contact-storage.h"
 #include "misc/misc.h"
 
 #include "helpers/gadu-protocol-helper.h"
 #include "server/gadu-connection.h"
 #include "server/gadu-writable-session-token.h"
-#include "gadu-contact-details.h"
 
 #include "gadu-contact-personal-info-service.h"
 
@@ -37,6 +33,16 @@ GaduContactPersonalInfoService::GaduContactPersonalInfoService(Account account,
 {
 }
 
+void GaduContactPersonalInfoService::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void GaduContactPersonalInfoService::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
 void GaduContactPersonalInfoService::setConnection(GaduConnection *connection)
 {
 	Connection = connection;
@@ -56,7 +62,7 @@ void GaduContactPersonalInfoService::handleEventPubdir50Read(struct gg_event *e)
 		return;
 	}
 
-	Buddy result = GaduProtocolHelper::searchResultToBuddy(account(), res, 0);
+	Buddy result = GaduProtocolHelper::searchResultToBuddy(m_buddyStorage, m_contactStorage, account(), res, 0);
 	emit personalInfoAvailable(result);
 }
 
