@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,26 +18,35 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GADU_CONTACT_PERSONAL_INFO_SERVICE_H
-#define GADU_CONTACT_PERSONAL_INFO_SERVICE_H
+#pragma once
 
+#include <injeqt/injeqt.h>
 #include <libgadu.h>
 
 #include "protocols/services/contact-personal-info-service.h"
 
+class BuddyStorage;
+class ContactStorage;
 class GaduConnection;
 
 class GaduContactPersonalInfoService : public ContactPersonalInfoService
 {
 	Q_OBJECT
 
+	QPointer<BuddyStorage> m_buddyStorage;
+	QPointer<ContactStorage> m_contactStorage;
 	QPointer<GaduConnection> Connection;
+
 	unsigned int FetchSeq;
 	QString Id;
 
 	friend class GaduProtocolSocketNotifiers;
 	void handleEventPubdir50Read(struct gg_event *e);
 
+private slots:
+	INJEQT_SET void setBuddyStorage(BuddyStorage *buddyStorage);
+	INJEQT_SET void setContactStorage(ContactStorage *contactStorage);
+
 public:
 	GaduContactPersonalInfoService(Account account, QObject *parent);
 
@@ -50,6 +55,3 @@ public:
 	virtual void fetchPersonalInfo(Contact contact);
 
 };
-
-#endif // GADU_CONTACT_PERSONAL_INFO_SERVICE_H
-
