@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,37 +18,44 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GADU_PERSONAL_INFO_SERVICE_H
-#define GADU_PERSONAL_INFO_SERVICE_H
+#pragma once
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 #include <libgadu.h>
 
 #include "protocols/services/personal-info-service.h"
 
-class GaduProtocol;
+class BuddyStorage;
+class ContactStorage;
+class GaduConnection;
 
 class GaduPersonalInfoService : public PersonalInfoService
 {
 	Q_OBJECT
 
-	GaduProtocol *Protocol;
+	QPointer<BuddyStorage> m_buddyStorage;
+	QPointer<ContactStorage> m_contactStorage;
+	QPointer<GaduConnection> Connection;
+
 	unsigned int FetchSeq;
 	unsigned int UpdateSeq;
 
-	void fetchReplyReceived(gg_pubdir50_t res);
-	void updateReplyReceived(gg_pubdir50_t res);
-
 	friend class GaduProtocolSocketNotifiers;
 	void handleEventPubdir50Read(struct gg_event *e);
 	void handleEventPubdir50Write(struct gg_event *e);
 
-public:
-	GaduPersonalInfoService(GaduProtocol *protocol);
+private slots:
+	INJEQT_SET void setBuddyStorage(BuddyStorage *buddyStorage);
+	INJEQT_SET void setContactStorage(ContactStorage *contactStorage);
 
-	virtual void fetchPersonalInfo();
-	virtual void updatePersonalInfo(Buddy buddy);
+public:
+	explicit GaduPersonalInfoService(Account account, QObject *parent = nullptr);
+	virtual ~GaduPersonalInfoService();
+
+	void setConnection(GaduConnection *connection);
+
+	virtual void fetchPersonalInfo(const QString &id);
+	virtual void updatePersonalInfo(const QString &id, Buddy buddy);
 
 };
-
-#endif // GADU_PERSONAL_INFO_SERVICE_H
-
