@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,18 +18,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "buddies/buddy-storage.h"
+#include "contacts/contact-storage.h"
 #include "misc/misc.h"
 #include "debug.h"
 
 #include "helpers/gadu-protocol-helper.h"
 #include "server/gadu-connection.h"
 #include "server/gadu-writable-session-token.h"
-#include "gadu-contact-details.h"
 
 #include "gadu-search-service.h"
 
 GaduSearchService::GaduSearchService(Account account, QObject *parent) :
-		SearchService(account, parent), Query(BuddySearchCriteria()),
+		SearchService(account, parent),
 		SearchSeq(0), From(0), Stopped(false)
 {
 }
@@ -41,12 +39,22 @@ GaduSearchService::~GaduSearchService()
 {
 }
 
+void GaduSearchService::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void GaduSearchService::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
 void GaduSearchService::setConnection(GaduConnection *connection)
 {
 	Connection = connection;
 }
 
-void GaduSearchService::searchFirst(BuddySearchCriteria criteria)
+void GaduSearchService::searchFirst(BuddySearchCriteria *criteria)
 {
 	Query = criteria;
 	From = 0;
@@ -61,23 +69,23 @@ void GaduSearchService::searchNext()
 	Stopped = false;
 	gg_pubdir50_t req = gg_pubdir50_new(GG_PUBDIR50_SEARCH);
 
-	if (Query.SearchBuddy.hasContact(account()))
-		gg_pubdir50_add(req, GG_PUBDIR50_UIN, Query.SearchBuddy.id(account()).toUtf8().constData());
-	if (!Query.SearchBuddy.firstName().isEmpty())
-		gg_pubdir50_add(req, GG_PUBDIR50_FIRSTNAME, Query.SearchBuddy.firstName().toUtf8().constData());
-	if (!Query.SearchBuddy.lastName().isEmpty())
-		gg_pubdir50_add(req, GG_PUBDIR50_LASTNAME, Query.SearchBuddy.lastName().toUtf8().constData());
-	if (!Query.SearchBuddy.nickName().isEmpty())
-		gg_pubdir50_add(req, GG_PUBDIR50_NICKNAME, Query.SearchBuddy.nickName().toUtf8().constData());
-	if (!Query.SearchBuddy.city().isEmpty())
-		gg_pubdir50_add(req, GG_PUBDIR50_CITY, Query.SearchBuddy.city().toUtf8().constData());
-	if (!Query.BirthYearFrom.isEmpty())
+	if (Query->SearchBuddy.hasContact(account()))
+		gg_pubdir50_add(req, GG_PUBDIR50_UIN, Query->SearchBuddy.id(account()).toUtf8().constData());
+	if (!Query->SearchBuddy.firstName().isEmpty())
+		gg_pubdir50_add(req, GG_PUBDIR50_FIRSTNAME, Query->SearchBuddy.firstName().toUtf8().constData());
+	if (!Query->SearchBuddy.lastName().isEmpty())
+		gg_pubdir50_add(req, GG_PUBDIR50_LASTNAME, Query->SearchBuddy.lastName().toUtf8().constData());
+	if (!Query->SearchBuddy.nickName().isEmpty())
+		gg_pubdir50_add(req, GG_PUBDIR50_NICKNAME, Query->SearchBuddy.nickName().toUtf8().constData());
+	if (!Query->SearchBuddy.city().isEmpty())
+		gg_pubdir50_add(req, GG_PUBDIR50_CITY, Query->SearchBuddy.city().toUtf8().constData());
+	if (!Query->BirthYearFrom.isEmpty())
 	{
-		QString bufYear = Query.BirthYearFrom + ' ' + Query.BirthYearTo;
+		QString bufYear = Query->BirthYearFrom + ' ' + Query->BirthYearTo;
 		gg_pubdir50_add(req, GG_PUBDIR50_BIRTHYEAR, bufYear.toUtf8().constData());
 	}
 
-	switch (Query.SearchBuddy.gender())
+	switch (Query->SearchBuddy.gender())
 	{
 		case GenderMale:
 			gg_pubdir50_add(req, GG_PUBDIR50_GENDER, GG_PUBDIR50_GENDER_MALE);
@@ -90,7 +98,7 @@ void GaduSearchService::searchNext()
 			break;
 	}
 
-	if (Query.Active)
+	if (Query->Active)
 		gg_pubdir50_add(req, GG_PUBDIR50_ACTIVE, GG_PUBDIR50_ACTIVE_TRUE);
 
 	gg_pubdir50_add(req, GG_PUBDIR50_START, QString::number(From).toUtf8().constData());
@@ -115,7 +123,7 @@ void GaduSearchService::handleEventPubdir50SearchReply(struct gg_event *e)
 	kdebugmf(KDEBUG_NETWORK|KDEBUG_INFO, "found %d results\n", count);
 
 	for (int i = 0; i < count; i++)
-		results.append(GaduProtocolHelper::searchResultToBuddy(account(), res, i));
+		results.append(GaduProtocolHelper::searchResultToBuddy(m_buddyStorage, m_contactStorage, account(), res, i));
 
 	From = gg_pubdir50_next(res);
 
