@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -48,7 +44,7 @@ protected:
 	virtual void connectionTimeout();
 
 public:
-	GaduTokenSocketNotifiers(QObject *parent = 0)
+	GaduTokenSocketNotifiers(QObject *parent = nullptr)
 		: GaduSocketNotifiers(parent), H(0) {}
 
 	void watchFor(struct gg_http *h);
