@@ -216,18 +216,10 @@
         <source>Use default servers</source>
         <translation>Použít výchozí servery</translation>
     </message>
-    <message>
-        <source>Use encrypted connection</source>
-        <translation>Použít šifrované připojení</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Odstranit účet</translation>
     </message>
-    <message>
-        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
-        <translation>Musíte libgadu sestavit s podporou pro SSL, abyste mohl povolit zašifrované spojení</translation>
-    </message>
     <message>
         <source>Other</source>
         <translation>Jiné</translation>
@@ -392,6 +384,13 @@ Jste si jistý, že jim chcete umožnit vědět, že jste dostupný?</translatio
         <translation>Rodné město</translation>
     </message>
 </context>
+<context>
+    <name>GaduPluginObject</name>
+    <message>
+        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
+        <translation>Nelze nahrát přídavný modul pro protokol Gadu-Gadu. Sestavte, prosím, libgadu s podporou pro zlib.</translation>
+    </message>
+</context>
 <context>
     <name>GaduProtocol</name>
     <message>
@@ -406,24 +405,6 @@ Jste si jistý, že jim chcete umožnit vědět, že jste dostupný?</translatio
         <translation>Číslo Gadu-Gadu:</translation>
     </message>
 </context>
-<context>
-    <name>GaduProtocolPlugin</name>
-    <message>
-        <source>Gadu-Gadu Protocol</source>
-        <translation>Protokol Gadu-Gadu</translation>
-    </message>
-    <message>
-        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
-        <translation>Nelze nahrát přídavný modul pro protokol Gadu-Gadu. Sestavte, prosím, libgadu s podporou pro zlib.</translation>
-    </message>
-</context>
-<context>
-    <name>GaduSendGiftAction</name>
-    <message>
-        <source>Send Gift...</source>
-        <translation>Poslat dárek...</translation>
-    </message>
-</context>
 <context>
     <name>GaduUrlIncomingFileTransferHandler</name>
     <message>
