@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -149,22 +151,6 @@
         <source>State/Province</source>
         <translation>State/Province</translation>
     </message>
-    <message>
-        <source>IP Address</source>
-        <translation>IP Address</translation>
-    </message>
-    <message>
-        <source>Port</source>
-        <translation>Port</translation>
-    </message>
-    <message>
-        <source>DNS Name</source>
-        <translation>DNS Name</translation>
-    </message>
-    <message>
-        <source>Protocol Version</source>
-        <translation>Protocol Version</translation>
-    </message>
     <message>
         <source>Female</source>
         <translation>Female</translation>
@@ -232,22 +218,10 @@
         <source>Use default servers</source>
         <translation>Use default servers</translation>
     </message>
-    <message>
-        <source>Use encrypted connection</source>
-        <translation>Use encrypted connection</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Remove account</translation>
     </message>
-    <message>
-        <source>External port</source>
-        <translation>External port</translation>
-    </message>
-    <message>
-        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
-        <translation>You have to compile libgadu with SSL support to be able to enable encrypted connection</translation>
-    </message>
     <message>
         <source>Other</source>
         <translation>Other</translation>
@@ -304,18 +278,10 @@
         <source>Custom server IP addresses</source>
         <translation>Custom server IP addresses</translation>
     </message>
-    <message>
-        <source>Enable file transfers</source>
-        <translation>Enable file transfers</translation>
-    </message>
     <message>
         <source>Network</source>
         <translation>Network</translation>
     </message>
-    <message>
-        <source>External IP</source>
-        <translation>External IP</translation>
-    </message>
     <message>
         <source>Confrim Account Removal</source>
         <translation>Confrim Account Removal</translation>
@@ -351,6 +317,28 @@ Are you sure to allow them to know you are available?</translation>
         <translation>Remind Password</translation>
     </message>
 </context>
+<context>
+    <name>GaduFileTransferService</name>
+    <message>
+        <source>Connect before sending files.</source>
+        <translation>Connect before sending files.</translation>
+    </message>
+    <message>
+        <source>Enable SSL in account configuration and reconnect before sending files.</source>
+        <translation>Enable SSL in account configuration and reconnect before sending files.</translation>
+    </message>
+    <message>
+        <source>Unable to login to GG Drive. Reconnect before sending files.</source>
+        <translation>Unable to login to GG Drive. Reconnect before sending files.</translation>
+    </message>
+</context>
+<context>
+    <name>GaduOutgoingFileTransferHandler</name>
+    <message>
+        <source>Valid GG Drive ticket not available</source>
+        <translation>Valid GG Drive ticket not available</translation>
+    </message>
+</context>
 <context>
     <name>GaduPersonalInfoWidget</name>
     <message>
@@ -398,6 +386,13 @@ Are you sure to allow them to know you are available?</translation>
         <translation>Family city</translation>
     </message>
 </context>
+<context>
+    <name>GaduPluginObject</name>
+    <message>
+        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
+        <translation type="unfinished">Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</translation>
+    </message>
+</context>
 <context>
     <name>GaduProtocol</name>
     <message>
@@ -413,14 +408,10 @@ Are you sure to allow them to know you are available?</translation>
     </message>
 </context>
 <context>
-    <name>GaduProtocolPlugin</name>
+    <name>GaduUrlIncomingFileTransferHandler</name>
     <message>
-        <source>Gadu-Gadu Protocol</source>
-        <translation>Gadu-Gadu Protocol</translation>
-    </message>
-    <message>
-        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
-        <translation>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</translation>
+        <source>Network error: %1</source>
+        <translation>Network error: %1</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
