@@ -216,18 +216,10 @@
         <source>Use default servers</source>
         <translation>Użyj domyślnych serwerów</translation>
     </message>
-    <message>
-        <source>Use encrypted connection</source>
-        <translation>Używaj szyfrowanego połączenia</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Usuń konto</translation>
     </message>
-    <message>
-        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
-        <translation>Libgadu skompilowane ze wsparciem dla SSL jest wymagane aby aktywować szyfrowane połączenie</translation>
-    </message>
     <message>
         <source>Other</source>
         <translation>Inne</translation>
@@ -392,6 +384,13 @@ Czy na pewno chcesz im ujawnić swoją dostępność?</translation>
         <translation>Miejscowość rodzinna</translation>
     </message>
 </context>
+<context>
+    <name>GaduPluginObject</name>
+    <message>
+        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
+        <translation>Nie można załadować wtyczki Gadu-Gadu. Libgadu ze wsparciem dla zlib jest wymagane.</translation>
+    </message>
+</context>
 <context>
     <name>GaduProtocol</name>
     <message>
@@ -406,24 +405,6 @@ Czy na pewno chcesz im ujawnić swoją dostępność?</translation>
         <translation>Numer Gadu-Gadu:</translation>
     </message>
 </context>
-<context>
-    <name>GaduProtocolPlugin</name>
-    <message>
-        <source>Gadu-Gadu Protocol</source>
-        <translation>Protokół Gadu-Gadu</translation>
-    </message>
-    <message>
-        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
-        <translation>Nie można załadować wtyczki Gadu-Gadu. Libgadu ze wsparciem dla zlib jest wymagane.</translation>
-    </message>
-</context>
-<context>
-    <name>GaduSendGiftAction</name>
-    <message>
-        <source>Send Gift...</source>
-        <translation>Wyślij prezent...</translation>
-    </message>
-</context>
 <context>
     <name>GaduUrlIncomingFileTransferHandler</name>
     <message>
