@@ -216,18 +216,10 @@
         <source>Use default servers</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Use encrypted connection</source>
-        <translation>Use conexão criptografada</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Remover conta</translation>
     </message>
-    <message>
-        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Other</source>
         <translation type="unfinished"/>
@@ -391,6 +383,13 @@ Are you sure to allow them to know you are available?</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>GaduPluginObject</name>
+    <message>
+        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>GaduProtocol</name>
     <message>
@@ -405,24 +404,6 @@ Are you sure to allow them to know you are available?</source>
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>GaduProtocolPlugin</name>
-    <message>
-        <source>Gadu-Gadu Protocol</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>GaduSendGiftAction</name>
-    <message>
-        <source>Send Gift...</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>GaduUrlIncomingFileTransferHandler</name>
     <message>
