@@ -216,18 +216,10 @@
         <source>Use default servers</source>
         <translation>Varsayılan sunucuları kullan</translation>
     </message>
-    <message>
-        <source>Use encrypted connection</source>
-        <translation>Şifreli bağlantı kullan</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Hesabı kaldır</translation>
     </message>
-    <message>
-        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
-        <translation>Şifreli bağlantı yapabilmek için SSL destekli libgadu derlemeniz lazım</translation>
-    </message>
     <message>
         <source>Other</source>
         <translation>Diğer</translation>
@@ -392,6 +384,13 @@ Müsait olduğunuzu bilmelerine izin veriyor musunuz?</translation>
         <translation>Aile şehir</translation>
     </message>
 </context>
+<context>
+    <name>GaduPluginObject</name>
+    <message>
+        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
+        <translation>Gadu-Gadu Protocol eklentisi yüklenemiyor. Lütfen libgadu yu zlib ile derleyiniz.</translation>
+    </message>
+</context>
 <context>
     <name>GaduProtocol</name>
     <message>
@@ -406,24 +405,6 @@ Müsait olduğunuzu bilmelerine izin veriyor musunuz?</translation>
         <translation>Gadu-Gadu numarası:</translation>
     </message>
 </context>
-<context>
-    <name>GaduProtocolPlugin</name>
-    <message>
-        <source>Gadu-Gadu Protocol</source>
-        <translation>Gadu-Gadu Protokolü</translation>
-    </message>
-    <message>
-        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
-        <translation>Gadu-Gadu Protocol eklentisi yüklenemiyor. Lütfen libgadu yu zlib ile derleyiniz.</translation>
-    </message>
-</context>
-<context>
-    <name>GaduSendGiftAction</name>
-    <message>
-        <source>Send Gift...</source>
-        <translation>Hediye Gönder...</translation>
-    </message>
-</context>
 <context>
     <name>GaduUrlIncomingFileTransferHandler</name>
     <message>
