@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,18 +19,22 @@
  */
 
 #include <QtCore/QFutureWatcher>
-#include <QtGui/QAction>
-#include <QtGui/QMenu>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QMenu>
 
 #include "chat/buddy-chat-manager.h"
 #include "chat/chat.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "gui/actions/actions.h"
 #include "gui/actions/action.h"
 #include "gui/widgets/chat-edit-box.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
 #include "message/sorted-messages.h"
+#include "plugin/plugin-injected-factory.h"
 
+#include "gui/windows/history-window-service.h"
 #include "gui/windows/history-window.h"
 #include "history-messages-prepender.h"
 #include "history-query.h"
@@ -41,26 +45,43 @@
 ShowHistoryActionDescription::ShowHistoryActionDescription(QObject *parent) :
 		ActionDescription(parent)
 {
-	setType(ActionDescription::TypeUser);
-	setName("showHistoryAction");
-	setIcon(KaduIcon("kadu_icons/history"));
-	setText(tr("View Chat History"));
-	setShortcut("kadu_viewhistory");
-
-	registerAction();
-
-	configurationUpdated();
 }
 
 ShowHistoryActionDescription::~ShowHistoryActionDescription()
 {
 }
 
+void ShowHistoryActionDescription::setBuddyChatManager(BuddyChatManager *buddyChatManager)
+{
+	m_buddyChatManager = buddyChatManager;
+}
+
+void ShowHistoryActionDescription::setHistoryWindowService(HistoryWindowService *historyWindowService)
+{
+	m_historyWindowService = historyWindowService;
+}
+
+void ShowHistoryActionDescription::setHistory(History *history)
+{
+	m_history = history;
+}
+
+void ShowHistoryActionDescription::init()
+{
+	setType(ActionDescription::TypeUser);
+	setName("showHistoryAction");
+	setIcon(KaduIcon("kadu_icons/history"));
+	setText(tr("View Chat History"));
+	setShortcut("kadu_viewhistory");
+
+	configurationUpdated();
+}
+
 void ShowHistoryActionDescription::configurationUpdated()
 {
 	ActionDescription::configurationUpdated();
 
-	ChatHistoryQuotationTime = config_file.readNumEntry("History", "ChatHistoryQuotationTime", -24);
+	ChatHistoryQuotationTime = configuration()->deprecatedApi()->readNumEntry("History", "ChatHistoryQuotationTime", -24);
 }
 
 void ShowHistoryActionDescription::actionInstanceCreated(Action *action)
@@ -79,9 +100,9 @@ void ShowHistoryActionDescription::actionInstanceCreated(Action *action)
 	// no parents for menu as it is destroyed manually by Action class
 	QMenu *menu = new QMenu();
 
-	if (config_file.readNumEntry("History", "ChatHistoryCitation", 10) > 0)
+	if (configuration()->deprecatedApi()->readNumEntry("History", "ChatHistoryCitation", 10) > 0)
 	{
-		int prune = config_file.readNumEntry("History", "ChatHistoryCitation", 10);
+		int prune = configuration()->deprecatedApi()->readNumEntry("History", "ChatHistoryCitation", 10);
 		menu->addAction(tr("Show last %1 messages").arg(prune), this, SLOT(showPruneMessages()))->setData(chatWidgetData);
 		menu->addSeparator();
 	}
@@ -134,14 +155,14 @@ void ShowHistoryActionDescription::showDaysMessages(QAction *action, int days)
 	ChatWidget *chatWidget = action->data().value<ChatWidget *>();
 	if (!chatWidget)
 	{
-		HistoryWindow::show(actionChat);
+		m_historyWindowService->show(actionChat);
 		return;
 	}
 
 	WebkitMessagesView *chatMessagesView = chatWidget->chatMessagesView();
 	if (!chatMessagesView)
 	{
-		HistoryWindow::show(actionChat);
+		m_historyWindowService->show(actionChat);
 		return;
 	}
 
@@ -149,13 +170,13 @@ void ShowHistoryActionDescription::showDaysMessages(QAction *action, int days)
 
 	if (-1 == days)
 	{
-		HistoryWindow::show(chatWidget->chat());
+		m_historyWindowService->show(chatWidget->chat());
 		return;
 	}
 
-	const Chat &buddyChat = BuddyChatManager::instance()->buddyChat(chatWidget->chat());
+	const Chat &buddyChat = m_buddyChatManager->buddyChat(chatWidget->chat());
 	const Chat &messagesChat = buddyChat ? buddyChat : chatWidget->chat();
-	HistoryStorage *historyStorage = History::instance()->currentStorage();
+	HistoryStorage *historyStorage = m_history->currentStorage();
 
 	if (!historyStorage)
 		return;
@@ -164,7 +185,7 @@ void ShowHistoryActionDescription::showDaysMessages(QAction *action, int days)
 	query.setTalkable(messagesChat);
 
 	if (0 == days)
-		query.setLimit(config_file.readUnsignedNumEntry("History", "ChatHistoryCitation", 10));
+		query.setLimit(configuration()->deprecatedApi()->readUnsignedNumEntry("History", "ChatHistoryCitation", 10));
 	else
 		query.setFromDate(QDate::currentDate().addDays(-days));
 
