@@ -1,9 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,29 +17,32 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUDDY_HISTORY_DELETE_HANDLER_H
-#define BUDDY_HISTORY_DELETE_HANDLER_H
+#pragma once
 
 #include "buddies/buddy-additional-data-delete-handler.h"
 
-class BuddyHistoryDeleteHandler : public BuddyAdditionalDataDeleteHandler
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class History;
+
+class BuddyHistoryDeleteHandler : public QObject, public BuddyAdditionalDataDeleteHandler
 {
-	Q_DISABLE_COPY(BuddyHistoryDeleteHandler)
-
-	static BuddyHistoryDeleteHandler *Instance;
-
-	BuddyHistoryDeleteHandler();
-	virtual ~BuddyHistoryDeleteHandler();
+	Q_OBJECT
 
 public:
-	static void createInstance();
-	static void destroyInstance();
-	static BuddyHistoryDeleteHandler *instance();
+	Q_INVOKABLE explicit BuddyHistoryDeleteHandler(QObject *parent = nullptr);
+	virtual ~BuddyHistoryDeleteHandler();
 
 	virtual QString name();
 	virtual QString displayName();
 	virtual void deleteBuddyAdditionalData(Buddy buddy);
 
-};
+private:
+	QPointer<History> m_history;
 
-#endif // BUDDY_HISTORY_DELETE_HANDLER_H
+private slots:
+	INJEQT_SET void setHistory(History *history);
+
+};
