@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,20 +18,34 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QModelIndexList>
-#include <QtGui/QAbstractItemView>
-
-#include "contacts/contact-set.h"
-#include "gui/widgets/talkable-tree-view.h"
-#include "model/model-chain.h"
+#include "chat-history-tab.h"
 
 #include "gui/widgets/timeline-chat-messages-view.h"
 #include "storage/history-messages-storage.h"
 
-#include "chat-history-tab.h"
+#include "contacts/contact-set.h"
+#include "gui/widgets/talkable-tree-view.h"
+#include "model/model-chain.h"
+#include "talkable/talkable-converter.h"
+
+#include <QtCore/QModelIndexList>
+#include <QtWidgets/QAbstractItemView>
 
 ChatHistoryTab::ChatHistoryTab(QWidget *parent) :
 		HistoryMessagesTab(parent)
+{
+}
+
+ChatHistoryTab::~ChatHistoryTab()
+{
+}
+
+void ChatHistoryTab::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void ChatHistoryTab::init()
 {
 	timelineView()->setTalkableVisible(false);
 	timelineView()->setTitleVisible(true);
@@ -39,19 +53,15 @@ ChatHistoryTab::ChatHistoryTab(QWidget *parent) :
 	setClearHistoryMenuItemTitle(tr("&Clear Chat History"));
 }
 
-ChatHistoryTab::~ChatHistoryTab()
-{
-}
-
 void ChatHistoryTab::talkablesAvailable()
 {
-	if (!TalkableToSelect.isValidChat())
+	if (!m_talkableToSelect.isValidChat())
 		return;
 
 	QModelIndexList indexesToSelect;
 
-	Chat chat = TalkableToSelect.toChat();
-	TalkableToSelect = Talkable();
+	auto chat = m_talkableConverter->toChat(m_talkableToSelect);
+	m_talkableToSelect = Talkable();
 
 	if (chat.contacts().size() == 1)
 		indexesToSelect = modelChain()->indexListForValue(chat.contacts().begin()->ownerBuddy());
@@ -70,7 +80,7 @@ void ChatHistoryTab::talkablesAvailable()
 
 void ChatHistoryTab::selectTalkable(const Talkable &talkable)
 {
-	TalkableToSelect = talkable;
+	m_talkableToSelect = talkable;
 }
 
 #include "moc_chat-history-tab.cpp"
