@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,11 +18,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QCheckBox>
-#include <QtGui/QLabel>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QVBoxLayout>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/widgets/simple-configuration-value-state-notifier.h"
 
 #include "history-buddy-configuration-widget.h"
@@ -30,16 +32,24 @@ HistoryBuddyConfigurationWidget::HistoryBuddyConfigurationWidget(const Buddy &bu
 		BuddyConfigurationWidget(buddy, parent), StateNotifier(new SimpleConfigurationValueStateNotifier(this))
 {
 	setWindowTitle(tr("History"));
-
-	createGui();
-	configurationUpdated();
-	loadValues();
 }
 
 HistoryBuddyConfigurationWidget::~HistoryBuddyConfigurationWidget()
 {
 }
 
+void HistoryBuddyConfigurationWidget::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void HistoryBuddyConfigurationWidget::init()
+{
+	createGui();
+	configurationUpdated();
+	loadValues();
+}
+
 void HistoryBuddyConfigurationWidget::createGui()
 {
 	QVBoxLayout *layout = new QVBoxLayout(this);
@@ -54,7 +64,7 @@ void HistoryBuddyConfigurationWidget::createGui()
 
 void HistoryBuddyConfigurationWidget::configurationUpdated()
 {
-	GlobalStoreHistory = config_file.readBoolEntry("History", "SaveChats", true);
+	GlobalStoreHistory = m_configuration->deprecatedApi()->readBoolEntry("History", "SaveChats", true);
 	StoreHistoryCheckBox->setEnabled(GlobalStoreHistory);
 }
 
@@ -91,3 +101,5 @@ void HistoryBuddyConfigurationWidget::cancel()
 {
 	loadValues();
 }
+
+#include "moc_history-buddy-configuration-widget.cpp"
