@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Marcel Zięba (marseel@gmail.com)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,12 +21,12 @@
  */
 
 #include <QtCore/QScopedPointer>
-#include <QtGui/QAction>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QMenu>
-#include <QtGui/QSplitter>
-#include <QtGui/QTreeView>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QSplitter>
+#include <QtWidgets/QTreeView>
+#include <QtWidgets/QVBoxLayout>
 
 #include "buddies/model/buddy-list-model.h"
 #include "chat/buddy-chat-manager.h"
@@ -43,13 +41,16 @@
 #include "gui/widgets/wait-overlay.h"
 #include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "message/sorted-messages.h"
 #include "model/merged-proxy-model-factory.h"
 #include "model/model-chain.h"
+#include "plugin/plugin-injected-factory.h"
 #include "talkable/filter/hide-temporary-talkable-filter.h"
 #include "talkable/filter/name-talkable-filter.h"
 #include "talkable/model/talkable-proxy-model.h"
+#include "talkable/talkable-converter.h"
 
 #include "storage/history-messages-storage.h"
 #include "chats-buddies-splitter.h"
@@ -62,18 +63,47 @@ HistoryMessagesTab::HistoryMessagesTab(QWidget *parent) :
 		HistoryTab(parent), Storage(0),
 		TabWaitOverlay(0), TalkablesFutureWatcher(0)
 {
-	createGui();
-	createModelChain();
 }
 
 HistoryMessagesTab::~HistoryMessagesTab()
 {
 }
 
+void HistoryMessagesTab::setBuddyChatManager(BuddyChatManager *buddyChatManager)
+{
+	m_buddyChatManager = buddyChatManager;
+}
+
+void HistoryMessagesTab::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void HistoryMessagesTab::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void HistoryMessagesTab::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void HistoryMessagesTab::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void HistoryMessagesTab::init()
+{
+	createGui();
+	createModelChain();
+}
+
 void HistoryMessagesTab::createGui()
 {
 	TimelinePopupMenu = new QMenu(this);
-	TimelinePopupMenu->addAction(KaduIcon("kadu_icons/clear-history").icon(), tr("&Remove entries"),
+	TimelinePopupMenu->addAction(m_iconsManager->iconByPath(KaduIcon("kadu_icons/clear-history")), tr("&Remove entries"),
 	                             this, SLOT(removeEntries()));
 
 	QVBoxLayout *layout = new QVBoxLayout(this);
@@ -81,16 +111,16 @@ void HistoryMessagesTab::createGui()
 
 	Splitter = new QSplitter(Qt::Horizontal, this);
 
-	FilteredView = new FilteredTreeView(FilteredTreeView::FilterAtTop, Splitter);
+	FilteredView = m_pluginInjectedFactory->makeInjected<FilteredTreeView>(FilteredTreeView::FilterAtTop, Splitter);
 	FilteredView->filterWidget()->setAutoVisibility(false);
 	FilteredView->filterWidget()->setLabel(tr("Filter") + ":");
 
-	TalkableTree = new TalkableTreeView(FilteredView);
+	TalkableTree = m_pluginInjectedFactory->makeInjected<TalkableTreeView>(FilteredView);
 	TalkableTree->setAlternatingRowColors(true);
 	TalkableTree->setContextMenuEnabled(true);
 	TalkableTree->setContextMenuPolicy(Qt::CustomContextMenu);
 	TalkableTree->setUseConfigurationColors(true);
-	TalkableTree->delegateConfiguration().setShowMessagePixmap(false);
+	TalkableTree->delegateConfiguration()->setShowMessagePixmap(false);
 
 	QString style;
 	style.append("QTreeView::branch:has-siblings:!adjoins-item { border-image: none; image: none }");
@@ -104,7 +134,7 @@ void HistoryMessagesTab::createGui()
 
 	FilteredView->setView(TalkableTree);
 
-	TimelineView = new TimelineChatMessagesView(Splitter);
+	TimelineView = m_pluginInjectedFactory->makeInjected<TimelineChatMessagesView>(Splitter);
 	TimelineView->searchBar()->setAutoVisibility(false);
 	TimelineView->searchBar()->setSearchWidget(this);
 	TimelineView->timeline()->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -124,8 +154,8 @@ void HistoryMessagesTab::createGui()
 
 void HistoryMessagesTab::createModelChain()
 {
-	ChatsModel = new ChatListModel(TalkableTree);
-	BuddiesModel = new BuddyListModel(TalkableTree);
+	ChatsModel = m_pluginInjectedFactory->makeInjected<ChatListModel>(TalkableTree);
+	BuddiesModel = m_pluginInjectedFactory->makeInjected<BuddyListModel>(TalkableTree);
 
 	QList<KaduAbstractModel *> models;
 	models.append(ChatsModel);
@@ -134,7 +164,7 @@ void HistoryMessagesTab::createModelChain()
 	Chain = new ModelChain(TalkableTree);
 	Chain->setBaseModel(MergedProxyModelFactory::createKaduModelInstance(models, Chain));
 
-	TalkableProxyModel *proxyModel = new TalkableProxyModel(Chain);
+	TalkableProxyModel *proxyModel = m_pluginInjectedFactory->makeInjected<TalkableProxyModel>(Chain);
 	proxyModel->setSortByStatusAndUnreadMessages(false);
 
 	proxyModel->addFilter(new HideTemporaryTalkableFilter(proxyModel));
@@ -153,10 +183,10 @@ void HistoryMessagesTab::displayTalkable(const Talkable &talkable, bool force)
 		return;
 
 	CurrentTalkable = talkable;
-	Chat chat = CurrentTalkable.toChat();
+	auto chat = m_talkableConverter->toChat(CurrentTalkable);
 	// if buddy do not have any contact we have to create chat manually
 	if (!chat)
-		chat = BuddyChatManager::instance()->buddyChat(CurrentTalkable.toBuddy());
+		chat = m_buddyChatManager->buddyChat(m_talkableConverter->toBuddy(CurrentTalkable));
 
 	TimelineView->messagesView()->setChat(chat);
 
@@ -187,7 +217,7 @@ ModelChain * HistoryMessagesTab::modelChain() const
 void HistoryMessagesTab::showTabWaitOverlay()
 {
 	if (!TabWaitOverlay)
-		TabWaitOverlay = new WaitOverlay(this);
+		TabWaitOverlay = m_pluginInjectedFactory->makeInjected<WaitOverlay>(this);
 	else
 		TabWaitOverlay->show();
 }
@@ -209,10 +239,10 @@ TimelineChatMessagesView * HistoryMessagesTab::timelineView() const
 
 void HistoryMessagesTab::setTalkables(const QVector<Talkable> &talkables)
 {
-	ChatsBuddiesSplitter chatsBuddies(talkables);
+	auto chatsBuddies = m_pluginInjectedFactory->makeUnique<ChatsBuddiesSplitter>(talkables);
 
-	ChatsModel->setChats(chatsBuddies.chats().toList().toVector());
-	BuddiesModel->setBuddyList(chatsBuddies.buddies().toList());
+	ChatsModel->setChats(chatsBuddies->chats().toList().toVector());
+	BuddiesModel->setBuddyList(chatsBuddies->buddies().toList());
 }
 
 void HistoryMessagesTab::futureTalkablesAvailable()
@@ -278,10 +308,10 @@ void HistoryMessagesTab::currentDateChanged()
 	query.setFromDate(date);
 	query.setToDate(date);
 
-	Chat chat = CurrentTalkable.toChat();
+	auto chat = m_talkableConverter->toChat(CurrentTalkable);
 	// if buddy do not have any contact we have to create chat manually
 	if (!chat)
-		chat = BuddyChatManager::instance()->buddyChat(CurrentTalkable.toBuddy());
+		chat = m_buddyChatManager->buddyChat(m_talkableConverter->toBuddy(CurrentTalkable));
 
 	timelineView()->messagesView()->setChat(chat);
 	TimelineView->setFutureMessages(Storage->messages(query));
@@ -295,12 +325,11 @@ void HistoryMessagesTab::setClearHistoryMenuItemTitle(const QString &clearHistor
 void HistoryMessagesTab::showTalkablePopupMenu()
 {
 	QScopedPointer<QMenu> menu(new QMenu());
-	MenuInventory::instance()->menu("buddy-list")->attachToMenu(menu.data());
-	MenuInventory::instance()->menu("buddy-list")->applyTo(menu.data(), TalkableTree->actionContext());
-	MenuInventory::instance()->menu("buddy-list")->update();
+	m_menuInventory->menu("buddy-list")->attachToMenu(menu.data());
+	m_menuInventory->menu("buddy-list")->applyTo(menu.data(), TalkableTree->actionContext());
 
 	menu->addSeparator();
-	menu->addAction(KaduIcon("kadu_icons/clear-history").icon(),
+	menu->addAction(m_iconsManager->iconByPath(KaduIcon("kadu_icons/clear-history")),
 	                ClearHistoryMenuItemTitle, this, SLOT(clearTalkableHistory()));
 
 	menu->exec(QCursor::pos());
@@ -316,7 +345,7 @@ void HistoryMessagesTab::clearTalkableHistory()
 	const QModelIndexList &selectedIndexes = TalkableTree->selectionModel()->selectedIndexes();
 	QList<Talkable> talkables;
 
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-question"), tr("Kadu"), tr("Do you really want to delete history?"));
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-question")), tr("Kadu"), tr("Do you really want to delete history?"));
 	dialog->addButton(QMessageBox::Yes, tr("Delete history"));
 	dialog->addButton(QMessageBox::No, tr("Cancel"));
 
