@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,18 +19,32 @@
  */
 
 #include <QtCore/QFutureWatcher>
-#include <QtGui/QAction>
+#include <QtWidgets/QAction>
 
 #include "buddies/model/buddy-list-model.h"
 #include "chat/model/chat-list-model.h"
 #include "model/action-list-model.h"
 #include "model/merged-proxy-model-factory.h"
+#include "plugin/plugin-injected-factory.h"
 #include "chats-buddies-splitter.h"
 
 #include "history-talkable-combo-box.h"
 
 HistoryTalkableComboBox::HistoryTalkableComboBox(QWidget *parent) :
 		SelectTalkableComboBox(parent), TalkablesFutureWatcher(0)
+{
+}
+
+HistoryTalkableComboBox::~HistoryTalkableComboBox()
+{
+}
+
+void HistoryTalkableComboBox::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void HistoryTalkableComboBox::init()
 {
 	setShowAnonymous(true);
 
@@ -38,8 +52,8 @@ HistoryTalkableComboBox::HistoryTalkableComboBox(QWidget *parent) :
 	AllAction = new QAction(this);
 	actionModel->appendAction(AllAction);
 
-	ChatsModel = new ChatListModel(this);
-	BuddiesModel = new BuddyListModel(this);
+	ChatsModel = m_pluginInjectedFactory->makeInjected<ChatListModel>(this);
+	BuddiesModel = m_pluginInjectedFactory->makeInjected<BuddyListModel>(this);
 
 	QList<KaduAbstractModel *> models;
 	models.append(actionModel);
@@ -49,10 +63,6 @@ HistoryTalkableComboBox::HistoryTalkableComboBox(QWidget *parent) :
 	setBaseModel(MergedProxyModelFactory::createKaduModelInstance(models, this));
 }
 
-HistoryTalkableComboBox::~HistoryTalkableComboBox()
-{
-}
-
 void HistoryTalkableComboBox::setAllLabel(const QString &allLabel)
 {
 	AllAction->setText(allLabel);
@@ -62,10 +72,10 @@ void HistoryTalkableComboBox::setTalkables(const QVector<Talkable> &talkables)
 {
 	futureTalkablesCanceled();
 
-	ChatsBuddiesSplitter chatsBuddies(talkables);
+	auto chatsBuddies = m_pluginInjectedFactory->makeUnique<ChatsBuddiesSplitter>(talkables);
 
-	ChatsModel->setChats(chatsBuddies.chats().toList().toVector());
-	BuddiesModel->setBuddyList(chatsBuddies.buddies().toList());
+	ChatsModel->setChats(chatsBuddies->chats().toList().toVector());
+	BuddiesModel->setBuddyList(chatsBuddies->buddies().toList());
 }
 
 void HistoryTalkableComboBox::setFutureTalkables(const QFuture<QVector<Talkable>> &talkables)
