@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,19 +19,21 @@
  */
 
 #include <QtCore/QVariant>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QCheckBox>
-#include <QtGui/QDateEdit>
-#include <QtGui/QFormLayout>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QRadioButton>
-#include <QtGui/QSplitter>
-#include <QtGui/QTreeView>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QButtonGroup>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDateEdit>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QSplitter>
+#include <QtWidgets/QTreeView>
+#include <QtWidgets/QVBoxLayout>
 
+#include "chat/chat-storage.h"
+#include "core/core.h"
 #include "gui/web-view-highlighter.h"
 #include "gui/widgets/search-bar.h"
 #include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
@@ -39,25 +41,46 @@
 #include "message/sorted-messages.h"
 #include "misc/misc.h"
 #include "model/roles.h"
+#include "plugin/plugin-injected-factory.h"
 #include "activate.h"
 
 #include "gui/widgets/history-talkable-combo-box.h"
 #include "gui/widgets/timeline-chat-messages-view.h"
 #include "storage/history-messages-storage.h"
+#include "talkable/talkable-converter.h"
 #include "history-query.h"
 
 #include "search-tab.h"
 
 SearchTab::SearchTab(QWidget *parent) :
-		HistoryTab(parent), ChatStorage(0), StatusStorage(0), SmsStorage(0), SearchedStorage(&ChatStorage)
+		HistoryTab(parent), m_historyChatStorage(0), StatusStorage(0), SmsStorage(0), SearchedStorage(&m_historyChatStorage)
 {
-	createGui();
 }
 
 SearchTab::~SearchTab()
 {
 }
 
+void SearchTab::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void SearchTab::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void SearchTab::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void SearchTab::init()
+{
+	createGui();
+}
+
 void SearchTab::createGui()
 {
 	QVBoxLayout *layout = new QVBoxLayout(this);
@@ -87,20 +110,20 @@ void SearchTab::createGui()
 
 	SearchInChats = new QRadioButton(tr("Chats"), queryFormWidget);
 	SearchInChats->setChecked(true);
-	SelectChat = new HistoryTalkableComboBox(queryFormWidget);
+	SelectChat = m_pluginInjectedFactory->makeInjected<HistoryTalkableComboBox>(queryFormWidget);
 	SelectChat->setAllLabel(tr(" - All chats - "));
 	SelectChat->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	queryFormLayout->addRow(SearchInChats, SelectChat);
 
 	SearchInStatuses = new QRadioButton(tr("Statuses"), queryFormWidget);
-	SelectStatusBuddy = new HistoryTalkableComboBox(queryFormWidget);
+	SelectStatusBuddy = m_pluginInjectedFactory->makeInjected<HistoryTalkableComboBox>(queryFormWidget);
 	SelectStatusBuddy->setAllLabel(tr(" - All buddies - "));
 	SelectStatusBuddy->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	SelectStatusBuddy->setEnabled(false);
 	queryFormLayout->addRow(SearchInStatuses, SelectStatusBuddy);
 
 	SearchInSmses = new QRadioButton(tr("Smses"), queryFormWidget);
-	SelectSmsRecipient = new HistoryTalkableComboBox(queryFormWidget);
+	SelectSmsRecipient = m_pluginInjectedFactory->makeInjected<HistoryTalkableComboBox>(queryFormWidget);
 	SelectSmsRecipient->setAllLabel(tr(" - All recipients - "));
 	SelectSmsRecipient->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	SelectSmsRecipient->setEnabled(false);
@@ -147,7 +170,7 @@ void SearchTab::createGui()
 
 	connect(searchButton, SIGNAL(clicked()), this, SLOT(performSearch()));
 
-	TimelineView = new TimelineChatMessagesView(Splitter);
+	TimelineView = m_pluginInjectedFactory->makeInjected<TimelineChatMessagesView>(Splitter);
 	TimelineView->setTalkableVisible(true);
 	TimelineView->setTitleVisible(true);
 	TimelineView->setLengthHeader(tr("Found"));
@@ -161,19 +184,19 @@ void SearchTab::createGui()
 	setFocusProxy(Query);
 }
 
-void SearchTab::setChatStorage(HistoryMessagesStorage *storage)
+void SearchTab::setHistoryChatStorage(HistoryMessagesStorage *storage)
 {
-	if (ChatStorage == storage)
+	if (m_historyChatStorage == storage)
 		return;
 
-	ChatStorage = storage;
+	m_historyChatStorage = storage;
 
-	if (!ChatStorage)
+	if (!m_historyChatStorage)
 		SelectChat->setTalkables(QVector<Talkable>());
 	else
-		SelectChat->setFutureTalkables(ChatStorage->talkables());
+		SelectChat->setFutureTalkables(m_historyChatStorage->talkables());
 
-	if (*SearchedStorage == ChatStorage)
+	if (*SearchedStorage == m_historyChatStorage)
 	{
 		TimelineView->setResults(QVector<HistoryQueryResult>());
 		TimelineView->messagesView()->clearMessages();
@@ -254,7 +277,7 @@ void SearchTab::performSearch()
 	if (SearchInChats->isChecked())
 	{
 		query.setTalkable(SelectChat->currentTalkable());
-		SearchedStorage = &ChatStorage;
+		SearchedStorage = &m_historyChatStorage;
 		TimelineView->setTalkableHeader(tr("Chat"));
 	}
 	else if (SearchInStatuses->isChecked())
@@ -295,10 +318,10 @@ void SearchTab::currentDateChanged()
 	const Talkable talkable = currentIndex.data(TalkableRole).value<Talkable>();
 	const QDate date = currentIndex.data(DateRole).value<QDate>();
 
-	Chat chat = talkable.toChat();
+	auto chat = m_talkableConverter->toChat(talkable);
 	if (!chat)
 	{
-		chat = Chat::create();
+		chat = m_chatStorage->create();
 		chat.setDisplay("?");
 	}
 	TimelineView->messagesView()->setChat(chat);
