@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,34 +19,71 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QScrollBar>
-#include <QtGui/QSplitter>
-#include <QtGui/QTreeView>
-#include <QtGui/QVBoxLayout>
-
-#include "chat-style/engine/chat-style-renderer-factory-provider.h"
-#include "core/core.h"
-#include "gui/scoped-updates-disabler.h"
-#include "gui/web-view-highlighter.h"
-#include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
-#include "gui/widgets/webkit-messages-view/webkit-messages-view-factory.h"
-#include "gui/widgets/search-bar.h"
-#include "gui/widgets/wait-overlay.h"
-#include "message/sorted-messages.h"
-#include "model/roles.h"
+#include "timeline-chat-messages-view.h"
 
 #include "model/history-query-results-model.h"
 #include "model/history-query-results-proxy-model.h"
 #include "history-query-result.h"
 
-#include "timeline-chat-messages-view.h"
+#include "chat-style/engine/chat-style-renderer-factory-provider.h"
+#include "contacts/contact-set.h"
+#include "formatted-string/formatted-string-factory.h"
+#include "formatted-string/formatted-string-plain-text-visitor.h"
+#include "formatted-string/formatted-string.h"
+#include "gui/scoped-updates-disabler.h"
+#include "gui/web-view-highlighter.h"
+#include "gui/widgets/search-bar.h"
+#include "gui/widgets/wait-overlay.h"
+#include "gui/widgets/webkit-messages-view/webkit-messages-view-factory.h"
+#include "gui/widgets/webkit-messages-view/webkit-messages-view.h"
+#include "message/message-manager.h"
+#include "message/sorted-messages.h"
+#include "model/roles.h"
+#include "plugin/plugin-injected-factory.h"
+
+#include <QtWidgets/QScrollBar>
+#include <QtWidgets/QSplitter>
+#include <QtWidgets/QTreeView>
+#include <QtWidgets/QVBoxLayout>
+
+#define DATE_TITLE_LENGTH 120
 
 TimelineChatMessagesView::TimelineChatMessagesView(QWidget *parent) :
 		QWidget(parent),
 		TimelineWaitOverlay(0), MessagesViewWaitOverlay(0),
 		ResultsFutureWatcher (0), MessagesFutureWatcher(0)
 {
-	ResultsModel = new HistoryQueryResultsModel(this);
+
+}
+
+TimelineChatMessagesView::~TimelineChatMessagesView()
+{
+}
+
+void TimelineChatMessagesView::setFormattedStringFactory(FormattedStringFactory *formattedStringFactory)
+{
+	m_formattedStringFactory = formattedStringFactory;
+}
+
+void TimelineChatMessagesView::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void TimelineChatMessagesView::setMessageManager(MessageManager *messageManager)
+{
+	connect(messageManager, SIGNAL(messageReceived(Message)), this, SLOT(newMessage(Message)));
+	connect(messageManager, SIGNAL(messageSent(Message)), this, SLOT(newMessage(Message)));
+}
+
+void TimelineChatMessagesView::setWebkitMessagesViewFactory(WebkitMessagesViewFactory *webkitMessagesViewFactory)
+{
+	m_webkitMessagesViewFactory = webkitMessagesViewFactory;
+}
+
+void TimelineChatMessagesView::init()
+{
+	ResultsModel = m_pluginInjectedFactory->makeInjected<HistoryQueryResultsModel>(this);
 	ResultsProxyModel = new HistoryQueryResultsProxyModel(ResultsModel);
 	ResultsProxyModel->setSourceModel(ResultsModel);
 
@@ -57,10 +94,6 @@ TimelineChatMessagesView::TimelineChatMessagesView(QWidget *parent) :
 	createGui();
 }
 
-TimelineChatMessagesView::~TimelineChatMessagesView()
-{
-}
-
 void TimelineChatMessagesView::createGui()
 {
 	Splitter = new QSplitter(Qt::Vertical, this);
@@ -82,7 +115,7 @@ void TimelineChatMessagesView::createGui()
 	frameLayout->setMargin(0);
 	frameLayout->setSpacing(0);
 
-	MessagesView = Core::instance()->webkitMessagesViewFactory()->createWebkitMessagesView(Chat::null, false, frame);
+	MessagesView = m_webkitMessagesViewFactory->createWebkitMessagesView(Chat::null, false, frame);
 	MessagesView->setFocusPolicy(Qt::StrongFocus);
 	MessagesView->setForcePruneDisabled(true);
 
@@ -175,6 +208,35 @@ void TimelineChatMessagesView::setMessages(const SortedMessages &messages)
 	emit messagesDisplayed();
 }
 
+void TimelineChatMessagesView::newMessage(const Message &message)
+{
+	auto chatMatch = message.messageChat() == MessagesView->chat();
+	if (!chatMatch)
+	{
+		if (message.messageChat().type() != "Contact" || MessagesView->chat().type() != "Buddy")
+			return;
+		if (!MessagesView->chat().contacts().toBuddySet().contains(message.messageChat().contacts().toContact().ownerBuddy()))
+			return;
+	}
+
+	auto formattedContent = m_formattedStringFactory->fromHtml(message.content());
+	FormattedStringPlainTextVisitor plainTextVisitor;
+	formattedContent->accept(&plainTextVisitor);
+
+	auto title = plainTextVisitor.result().replace('\n', ' ').replace('\r', ' ');
+	if (title.length() > DATE_TITLE_LENGTH)
+	{
+		title.truncate(DATE_TITLE_LENGTH);
+		title += " ...";
+	}
+
+	auto messageDate = message.receiveDate().date();
+	ResultsModel->addEntry(messageDate, message.messageChat(), title);
+
+	if (messageDate == currentDate())
+		MessagesView->add(message);
+}
+
 void TimelineChatMessagesView::futureMessagesAvailable()
 {
 	if (!MessagesFutureWatcher)
@@ -235,7 +297,7 @@ void TimelineChatMessagesView::hideTimelineWaitOverlay()
 void TimelineChatMessagesView::showMessagesViewWaitOverlay()
 {
 	if (!MessagesViewWaitOverlay)
-		MessagesViewWaitOverlay = new WaitOverlay(MessagesView.get());
+		MessagesViewWaitOverlay = m_pluginInjectedFactory->makeInjected<WaitOverlay>(MessagesView.get());
 	else
 		MessagesViewWaitOverlay->show();
 }
