@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,11 +18,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TIMELINE_CHAT_MESSAGES_VIEW_H
-#define TIMELINE_CHAT_MESSAGES_VIEW_H
+#pragma once
 
 #include <QtCore/QFutureWatcher>
-#include <QtGui/QWidget>
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 #include "misc/memory.h"
 
@@ -33,14 +31,18 @@ class QDate;
 class QSplitter;
 class QTreeView;
 
-class WebkitMessagesView;
+class FormattedStringFactory;
 class HistoryQueryResult;
 class HistoryQueryResultsModel;
 class HistoryQueryResultsProxyModel;
+class PluginInjectedFactory;
+class MessageManager;
 class Message;
 class SearchBar;
 class SortedMessages;
 class WaitOverlay;
+class WebkitMessagesViewFactory;
+class WebkitMessagesView;
 class WebViewHighlighter;
 
 /**
@@ -60,6 +62,10 @@ class TimelineChatMessagesView : public QWidget
 {
 	Q_OBJECT
 
+	QPointer<FormattedStringFactory> m_formattedStringFactory;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<WebkitMessagesViewFactory> m_webkitMessagesViewFactory;
+
 	WaitOverlay *TimelineWaitOverlay;
 	WaitOverlay *MessagesViewWaitOverlay;
 
@@ -68,7 +74,7 @@ class TimelineChatMessagesView : public QWidget
 	HistoryQueryResultsModel *ResultsModel;
 	HistoryQueryResultsProxyModel *ResultsProxyModel;
 	WebViewHighlighter *Highlighter;
-	qobject_ptr<WebkitMessagesView> MessagesView;
+	owned_qptr<WebkitMessagesView> MessagesView;
 	SearchBar *MessagesSearchBar;
 
 	QFutureWatcher<QVector<HistoryQueryResult> > *ResultsFutureWatcher;
@@ -77,19 +83,27 @@ class TimelineChatMessagesView : public QWidget
 	void createGui();
 
 private slots:
+	INJEQT_SET void setFormattedStringFactory(FormattedStringFactory *formattedStringFactory);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setMessageManager(MessageManager *messageManager);
+	INJEQT_SET void setWebkitMessagesViewFactory(WebkitMessagesViewFactory *webkitMessagesViewFactory);
+	INJEQT_INIT void init();
+
 	void futureResultsAvailable();
 	void futureResultsCanceled();
 
 	void futureMessagesAvailable();
 	void futureMessagesCanceled();
 
+	void newMessage(const Message &message);
+
 public:
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Creates new TimelineChatMessagesView.
 	 * @param parent parent widget
 	 */
-	explicit TimelineChatMessagesView(QWidget *parent = 0);
+	explicit TimelineChatMessagesView(QWidget *parent = nullptr);
 	virtual ~TimelineChatMessagesView();
 
 	/**
@@ -265,5 +279,3 @@ signals:
 /**
  * @}
  */
-
-#endif // TIMELINE_CHAT_MESSAGES_VIEW_H
