@@ -1,13 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2009, 2009, 2011 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,15 +20,17 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QPushButton>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QVBoxLayout>
 
 #include "chat/buddy-chat-manager.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "core/core.h"
+#include "core/session-service.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 #include "os/generic/window-geometry-manager.h"
+#include "plugin/plugin-injected-factory.h"
 #include "activate.h"
 
 #include "gui/widgets/chat-history-tab.h"
@@ -42,50 +40,54 @@
 
 #include "history-window.h"
 
-HistoryWindow * HistoryWindow::Instance = 0;
-
-HistoryWindow * HistoryWindow::instance()
-{
-	return Instance;
-}
-
-void HistoryWindow::show(const Chat &chat)
-{
-	Chat buddyChat = BuddyChatManager::instance()->buddyChat(chat);
-	if (!buddyChat)
-		buddyChat = chat;
-
-	if (!Instance)
-		Instance = new HistoryWindow();
-
-	Instance->updateData();
-	Instance->selectChat(buddyChat);
-
-	Instance->setVisible(true);
-	_activateWindow(Instance);
-}
-
 HistoryWindow::HistoryWindow(QWidget *parent) :
-		QWidget(parent), CurrentTab(-1)
+		QWidget(parent),
+		CurrentTab(-1)
+{
+}
+
+HistoryWindow::~HistoryWindow()
+{
+}
+
+void HistoryWindow::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void HistoryWindow::setHistory(History *history)
+{
+	m_history = history;
+}
+
+void HistoryWindow::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void HistoryWindow::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void HistoryWindow::setSessionService(SessionService *sessionService)
+{
+	m_sessionService = sessionService;
+}
+
+void HistoryWindow::init()
 {
 	setWindowRole("kadu-history");
 	setAttribute(Qt::WA_DeleteOnClose);
 
 	setWindowTitle(tr("History"));
-	setWindowIcon(KaduIcon("kadu_icons/history").icon());
+	setWindowIcon(m_iconsManager->iconByPath(KaduIcon("kadu_icons/history")));
 
 	createGui();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("History", "HistoryWindowGeometry"), QRect(200, 200, 750, 500), this);
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "History", "HistoryWindowGeometry"), QRect(200, 200, 750, 500), this);
 
-	connect(History::instance(), SIGNAL(storageChanged(HistoryStorage*)), this, SLOT(storageChanged(HistoryStorage*)));
-}
-
-HistoryWindow::~HistoryWindow()
-{
-	disconnect(History::instance(), 0, this, 0);
-
-	Instance = 0;
+	connect(m_history, SIGNAL(storageChanged(HistoryStorage*)), this, SLOT(storageChanged(HistoryStorage*)));
 }
 
 void HistoryWindow::createGui()
@@ -101,17 +103,17 @@ void HistoryWindow::createGui()
 	connect(TabWidget, SIGNAL(currentChanged(int)),
 			this, SLOT(currentTabChanged(int)));
 
-	ChatTab = new ChatHistoryTab(TabWidget);
+	ChatTab = m_pluginInjectedFactory->makeInjected<ChatHistoryTab>(TabWidget);
 
-	StatusTab = new HistoryMessagesTab(TabWidget);
+	StatusTab = m_pluginInjectedFactory->makeInjected<HistoryMessagesTab>(TabWidget);
 	StatusTab->timelineView()->setTalkableVisible(false);
 	StatusTab->setClearHistoryMenuItemTitle(tr("&Clear Status History"));
 
-	SmsTab = new HistoryMessagesTab(TabWidget);
+	SmsTab = m_pluginInjectedFactory->makeInjected<HistoryMessagesTab>(TabWidget);
 	SmsTab->timelineView()->setTalkableVisible(false);
 	SmsTab->setClearHistoryMenuItemTitle(tr("&Clear SMS History"));
 
-	MySearchTab = new SearchTab(TabWidget);
+	MySearchTab = m_pluginInjectedFactory->makeInjected<SearchTab>(TabWidget);
 
 	TabWidget->addTab(ChatTab, tr("Chats"));
 	TabWidget->addTab(StatusTab, tr("Statuses"));
@@ -143,7 +145,7 @@ void HistoryWindow::keyPressEvent(QKeyEvent *event)
 void HistoryWindow::storageChanged(HistoryStorage *historyStorage)
 {
 	// TODO: fix it right, this is workaround only for crash when closing kadu with this window open
-	if (Core::instance()->isClosing())
+	if (m_sessionService->isClosing())
 		return;
 
 	if (historyStorage)
@@ -151,7 +153,7 @@ void HistoryWindow::storageChanged(HistoryStorage *historyStorage)
 		ChatTab->setHistoryMessagesStorage(historyStorage->chatStorage());
 		StatusTab->setHistoryMessagesStorage(historyStorage->statusStorage());
 		SmsTab->setHistoryMessagesStorage(historyStorage->smsStorage());
-		MySearchTab->setChatStorage(historyStorage->chatStorage());
+		MySearchTab->setHistoryChatStorage(historyStorage->chatStorage());
 		MySearchTab->setStatusStorage(historyStorage->statusStorage());
 		MySearchTab->setSmsStorage(historyStorage->smsStorage());
 	}
@@ -160,7 +162,7 @@ void HistoryWindow::storageChanged(HistoryStorage *historyStorage)
 		ChatTab->setHistoryMessagesStorage(0);
 		StatusTab->setHistoryMessagesStorage(0);
 		SmsTab->setHistoryMessagesStorage(0);
-		MySearchTab->setChatStorage(0);
+		MySearchTab->setHistoryChatStorage(0);
 		MySearchTab->setStatusStorage(0);
 		MySearchTab->setSmsStorage(0);
 	}
@@ -168,7 +170,7 @@ void HistoryWindow::storageChanged(HistoryStorage *historyStorage)
 
 void HistoryWindow::updateData()
 {
-	storageChanged(History::instance()->currentStorage());
+	storageChanged(m_history->currentStorage());
 }
 
 void HistoryWindow::selectChat(const Chat &chat)
