@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2008, 2009, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,18 +19,24 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef HISTORY_WINDOW_H
-#define HISTORY_WINDOW_H
+#pragma once
 
-#include <QtGui/QWidget>
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 class QTabWidget;
 
 class Chat;
 class ChatHistoryTab;
+class Configuration;
 class HistoryMessagesTab;
 class HistoryStorage;
+class History;
+class IconsManager;
+class PluginInjectedFactory;
 class SearchTab;
+class SessionService;
 
 /*!
 \class HistoryWindow
@@ -44,7 +48,11 @@ class HistoryWindow : public QWidget
 
 	friend class History;
 
-	static HistoryWindow *Instance;
+	QPointer<Configuration> m_configuration;
+	QPointer<History> m_history;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<SessionService> m_sessionService;
 
 	QTabWidget *TabWidget;
 	int CurrentTab;
@@ -54,14 +62,16 @@ class HistoryWindow : public QWidget
 	HistoryMessagesTab *SmsTab;
 	SearchTab *MySearchTab;
 
-	explicit HistoryWindow(QWidget *parent = 0);
-
 	void createGui();
 
-	void updateData();
-	void selectChat(const Chat &chat);
-
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setHistory(History *history);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setSessionService(SessionService *sessionService);
+	INJEQT_INIT void init();
+
 	void currentTabChanged(int newTabIndex);
 	void storageChanged(HistoryStorage *historyStorage);
 
@@ -69,11 +79,10 @@ protected:
 	virtual void keyPressEvent(QKeyEvent *event);
 
 public:
-	static HistoryWindow * instance();
-	static void show(const Chat &chat);
-
+	explicit HistoryWindow(QWidget *parent = nullptr);
 	virtual ~HistoryWindow();
 
-};
+	void updateData();
+	void selectChat(const Chat &chat);
 
-#endif // HISTORY_WINDOW_H
+};
