@@ -1,22 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Tomasz Jarzynka (tomee@cpi.pl)
- * Copyright 2004, 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Roman Krzystyniak (Ron_K@tlen.pl)
- * Copyright 2002, 2003, 2004, 2007 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2003, 2004, 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2006, 2008 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2003 Dariusz Jagodzik (mast3r@kadu.net)
- * Copyright 2009 Longer (longer89@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -35,11 +22,11 @@
 
 #include <QtCore/QList>
 #include <QtCore/QMutex>
-#include <QtGui/QGridLayout>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QMenu>
-#include <QtGui/QPushButton>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QPushButton>
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
@@ -48,9 +35,10 @@
 #include "chat/buddy-chat-manager.h"
 #include "chat/chat-manager.h"
 #include "chat/chat.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-set.h"
-#include "core/core.h"
+#include "core/myself.h"
 #include "gui/actions/actions.h"
 #include "gui/menu/menu-inventory.h"
 #include "gui/widgets/chat-edit-box.h"
@@ -62,6 +50,7 @@
 #include "message/message-manager.h"
 #include "message/message.h"
 #include "message/sorted-messages.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/services/chat-service.h"
 #include "debug.h"
 
@@ -73,7 +62,7 @@
 
 #include "history.h"
 
-void disableNonHistoryContacts(Action *action)
+void disableNonHistoryContacts(Myself *myself, Action *action)
 {
 	kdebugf();
 	action->setEnabled(false);
@@ -84,7 +73,7 @@ void disableNonHistoryContacts(Action *action)
 
 	foreach (const Contact &contact, contacts)
 	{
-		if (Core::instance()->myself() == contact.ownerBuddy())
+		if (myself->buddy() == contact.ownerBuddy())
 			return;
 
 		Account account = contact.contactAccount();
@@ -96,107 +85,120 @@ void disableNonHistoryContacts(Action *action)
 	kdebugf2();
 }
 
-History * History::Instance = 0;
-
-void History::createInstance()
+History::History(QObject *parent) :
+		QObject{parent},
+		SyncEnabled(true), SaveThread(0), CurrentStorage(0)
 {
-	if (!Instance)
-	{
-		Instance = new History();
-		Instance->setChatWidgetRepository(Core::instance()->chatWidgetRepository());
-	}
-}
-
-void History::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-History * History::instance()
-{
-	return Instance;
-}
-
-History::History() :
-		ConfigurationUiHandler(0), SyncEnabled(true), SaveThread(0), CurrentStorage(0)
-{
-	kdebugf();
-	createActionDescriptions();
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)),
-		this, SLOT(accountRegistered(Account)));
-	connect(AccountManager::instance(), SIGNAL(accountUnregistered(Account)),
-		this, SLOT(accountUnregistered(Account)));
-	connect(MessageManager::instance(), SIGNAL(messageReceived(Message)),
-		this, SLOT(enqueueMessage(Message)));
-	connect(MessageManager::instance(), SIGNAL(messageSent(Message)),
-		this, SLOT(enqueueMessage(Message)));
-
-	createDefaultConfiguration();
-	configurationUpdated();
-	kdebugf2();
 }
 
 History::~History()
 {
-	kdebugf();
+}
 
-	disconnect(MessageManager::instance(), 0, this, 0);
+void History::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
 
-	stopSaveThread();
-	deleteActionDescriptions();
+void History::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
 
-	kdebugf2();
+void History::setBuddyChatManager(BuddyChatManager *buddyChatManager)
+{
+	m_buddyChatManager = buddyChatManager;
 }
 
 void History::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
 {
 	m_chatWidgetRepository = chatWidgetRepository;
+}
 
-	if (m_chatWidgetRepository)
-		connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetAdded(ChatWidget *)), this, SLOT(chatWidgetAdded(ChatWidget *)));
+void History::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void History::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void History::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void History::setMessageManager(MessageManager* messageManager)
+{
+	connect(messageManager, SIGNAL(messageReceived(Message)), this, SLOT(enqueueMessage(Message)));
+	connect(messageManager, SIGNAL(messageSent(Message)), this, SLOT(enqueueMessage(Message)));
+}
+
+void History::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void History::setShowHistoryActionDescription(ShowHistoryActionDescription *showHistoryActionDescription)
+{
+	m_showHistoryActionDescription = showHistoryActionDescription;
+}
+
+void History::init()
+{
+	createActionDescriptions();
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)), this, SLOT(accountRegistered(Account)));
+	connect(m_accountManager, SIGNAL(accountUnregistered(Account)), this, SLOT(accountUnregistered(Account)));
+	connect(m_chatWidgetRepository, SIGNAL(chatWidgetAdded(ChatWidget *)), this, SLOT(chatWidgetAdded(ChatWidget *)));
+
+	createDefaultConfiguration();
+	configurationUpdated();
+}
+
+void History::done()
+{
+	stopSaveThread();
+	deleteActionDescriptions();
 }
 
 void History::createActionDescriptions()
 {
-	Actions::instance()->blockSignals();
+	m_actions->blockSignals();
+	m_actions->insert(m_showHistoryActionDescription);
 
-	ShowHistoryActionDescriptionInstance = new ShowHistoryActionDescription(this);
-
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
-		->addAction(ShowHistoryActionDescriptionInstance, KaduMenu::SectionView, 100)
+		->addAction(m_showHistoryActionDescription, KaduMenu::SectionView, 100)
 		->update();
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("main")
-		->addAction(ShowHistoryActionDescriptionInstance, KaduMenu::SectionRecentChats)
+		->addAction(m_showHistoryActionDescription, KaduMenu::SectionRecentChats)
 		->update();
 
 	// The last ActionDescription will send actionLoaded() signal.
-	Actions::instance()->unblockSignals();
+	m_actions->unblockSignals();
 
-	ClearHistoryActionDescription = new ActionDescription(this,
+	ClearHistoryActionDescription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "clearHistoryAction",
 		this, SLOT(clearHistoryActionActivated(QAction *, bool)),
 		KaduIcon("kadu_icons/clear-history"), tr("Clear History"), false,
-		disableNonHistoryContacts
+		[this](Action *action){ return disableNonHistoryContacts(m_myself, action); }
 	);
 
 }
 
 void History::deleteActionDescriptions()
 {
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
-		->removeAction(ShowHistoryActionDescriptionInstance)
+		->removeAction(m_showHistoryActionDescription)
 		->update();
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("main")
-		->removeAction(ShowHistoryActionDescriptionInstance)
+		->removeAction(m_showHistoryActionDescription)
 		->update();
-
-	delete ShowHistoryActionDescriptionInstance;
-	ShowHistoryActionDescriptionInstance = 0;
 }
 
 void History::clearHistoryActionActivated(QAction *sender, bool toggled)
@@ -224,16 +226,16 @@ void History::chatWidgetAdded(ChatWidget *chatWidget)
 	if (!CurrentStorage)
 		return;
 
-	WebkitMessagesView *chatMessagesView = chatWidget->chatMessagesView();
+	auto chatMessagesView = chatWidget->chatMessagesView();
 	if (!chatMessagesView)
 		return;
 
-	Chat chat = BuddyChatManager::instance()->buddyChat(chatWidget->chat());
+	auto chat = m_buddyChatManager->buddyChat(chatWidget->chat());
 
 	HistoryQuery query;
 	query.setTalkable(chat ? chat : chatWidget->chat());
 	query.setFromDateTime(QDateTime::currentDateTime().addSecs(ChatHistoryQuotationTime * 3600));
-	query.setLimit(config_file.readNumEntry("History", "ChatHistoryCitation", 10));
+	query.setLimit(m_configuration->deprecatedApi()->readNumEntry("History", "ChatHistoryCitation", 10));
 
 	new HistoryMessagesPrepender(CurrentStorage->messages(query), chatMessagesView);
 }
@@ -381,22 +383,17 @@ void History::stopSaveThread()
 	}
 }
 
-void History::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
-{
-	Q_UNUSED(mainConfigurationWindow)
-}
-
 void History::configurationUpdated()
 {
 	kdebugf();
 
-	ChatHistoryCitation = config_file.readNumEntry("History", "ChatHistoryCitation");
-	ChatHistoryQuotationTime = config_file.readNumEntry("History", "ChatHistoryQuotationTime", -24);
+	ChatHistoryCitation = m_configuration->deprecatedApi()->readNumEntry("History", "ChatHistoryCitation");
+	ChatHistoryQuotationTime = m_configuration->deprecatedApi()->readNumEntry("History", "ChatHistoryQuotationTime", -24);
 
-	SaveChats = config_file.readBoolEntry("History", "SaveChats", true);
-	SaveChatsWithAnonymous = config_file.readBoolEntry("History", "SaveChatsWithAnonymous", true);
-	SaveStatuses = config_file.readBoolEntry("History", "SaveStatusChanges", false);
-	SaveOnlyStatusesWithDescription = config_file.readBoolEntry("History", "SaveOnlyStatusWithDescription", false);
+	SaveChats = m_configuration->deprecatedApi()->readBoolEntry("History", "SaveChats", true);
+	SaveChatsWithAnonymous = m_configuration->deprecatedApi()->readBoolEntry("History", "SaveChatsWithAnonymous", true);
+	SaveStatuses = m_configuration->deprecatedApi()->readBoolEntry("History", "SaveStatusChanges", false);
+	SaveOnlyStatusesWithDescription = m_configuration->deprecatedApi()->readBoolEntry("History", "SaveOnlyStatusWithDescription", false);
 
 	kdebugf2();
 }
@@ -416,7 +413,7 @@ void History::registerStorage(HistoryStorage *storage)
 		for (ChatWidget *chat : m_chatWidgetRepository.data())
 			chatWidgetAdded(chat);
 
-	foreach (const Account &account, AccountManager::instance()->items())
+	foreach (const Account &account, m_accountManager->items())
 		accountRegistered(account);
 
 	emit storageChanged(CurrentStorage);
@@ -427,12 +424,11 @@ void History::unregisterStorage(HistoryStorage *storage)
 	if (CurrentStorage != storage)
 		return;
 
-	foreach (const Account &account, AccountManager::instance()->items())
+	foreach (const Account &account, m_accountManager->items())
 		accountUnregistered(account);
 
 	stopSaveThread();
 
-	delete CurrentStorage;
 	CurrentStorage = 0;
 
 	emit storageChanged(CurrentStorage);
@@ -440,19 +436,19 @@ void History::unregisterStorage(HistoryStorage *storage)
 
 void History::createDefaultConfiguration()
 {
-	config_file.addVariable("History", "SaveChats", config_file.readBoolEntry("History", "Logging", true));
-	config_file.removeVariable("History", "Logging");
+	m_configuration->deprecatedApi()->addVariable("History", "SaveChats", m_configuration->deprecatedApi()->readBoolEntry("History", "Logging", true));
+	m_configuration->deprecatedApi()->removeVariable("History", "Logging");
 
-	config_file.addVariable("ShortCuts", "kadu_viewhistory", "Ctrl+H");
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "kadu_viewhistory", "Ctrl+H");
 
-	config_file.addVariable("History", "SaveStatusChanges", true);
+	m_configuration->deprecatedApi()->addVariable("History", "SaveStatusChanges", true);
 
-	config_file.addVariable("History", "SaveChatsWithAnonymous", true);
+	m_configuration->deprecatedApi()->addVariable("History", "SaveChatsWithAnonymous", true);
 
-	config_file.addVariable("History", "SaveOnlyStatusWithDescription", true);
+	m_configuration->deprecatedApi()->addVariable("History", "SaveOnlyStatusWithDescription", true);
 
-	config_file.addVariable("History", "ChatHistoryCitation", 10);
-	config_file.addVariable("History", "ChatHistoryQuotationTime", -24);
+	m_configuration->deprecatedApi()->addVariable("History", "ChatHistoryCitation", 10);
+	m_configuration->deprecatedApi()->addVariable("History", "ChatHistoryQuotationTime", -24);
 }
 
 void History::forceSync()
