@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -30,6 +29,8 @@
 #include "chat/chat.h"
 
 class HistoryQueryResult;
+class TalkableConverter;
+class Talkable;
 
 /**
  * @addtogroup History
@@ -52,17 +53,22 @@ class HistoryQueryResultsModel : public QAbstractListModel
 {
 	Q_OBJECT
 
+	QPointer<TalkableConverter> m_talkableConverter;
+
 	QString TalkableHeader;
 	QString LengthHeader;
 	QVector<HistoryQueryResult> Results;
 
+private slots:
+	INJEQT_SET void setTalkableConverter(TalkableConverter *talkableConverter);
+
 public:
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Create new model.
 	 * @param parent QObject parent of new model.
 	 */
-	explicit HistoryQueryResultsModel(QObject *parent = 0);
+	explicit HistoryQueryResultsModel(QObject *parent = nullptr);
 	virtual ~HistoryQueryResultsModel();
 
 	virtual int columnCount(const QModelIndex &parent) const;
@@ -96,6 +102,11 @@ public:
 	 */
 	void setResults(const QVector<HistoryQueryResult> &results);
 
+	/**
+	 * Adds entry for given date. If item for date is not available, new one is created.
+	 */
+	void addEntry(const QDate &date, const Talkable &talkable, const QString &title);
+
 };
 
 /**
