@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,7 +21,7 @@
 #ifndef HISTORY_QUERY_RESULTS_PROXY_MODEL_H
 #define HISTORY_QUERY_RESULTS_PROXY_MODEL_H
 
-#include <QtGui/QSortFilterProxyModel>
+#include <QtCore/QSortFilterProxyModel>
 
 /**
  * @addtogroup History
@@ -52,7 +53,7 @@ public:
 	 * @short Create new proxy model.
 	 * @param parent QObject parent of new proxy model.
 	 */
-	explicit HistoryQueryResultsProxyModel(QObject *parent = 0);
+	explicit HistoryQueryResultsProxyModel(QObject *parent = nullptr);
 	virtual ~HistoryQueryResultsProxyModel();
 
 	/**
