@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -292,4 +294,4 @@
         <translation>Show whole history</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
