@@ -1,295 +1,295 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>Chat</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma</translation>
     </message>
     <message>
         <source>History</source>
-        <translation type="unfinished"/>
+        <translation>Geçmiş</translation>
     </message>
     <message>
         <source>Chats History</source>
-        <translation type="unfinished"/>
+        <translation>Konuşmalar Geçmişi</translation>
     </message>
     <message>
         <source>Save messages in history</source>
-        <translation type="unfinished"/>
+        <translation>Eski mesajları kaydet</translation>
     </message>
     <message>
         <source>Save chats with anonymous users</source>
-        <translation type="unfinished"/>
+        <translation>Konuşmaları anonim kullanıcılar ile kaydet</translation>
     </message>
     <message>
         <source>Status Changes</source>
-        <translation type="unfinished"/>
+        <translation>Durum Değişiklikleri</translation>
     </message>
     <message>
         <source>Save status changes</source>
-        <translation type="unfinished"/>
+        <translation>Durum değişikliklerini kaydet</translation>
     </message>
     <message>
         <source>Save status changes in history</source>
-        <translation type="unfinished"/>
+        <translation>Eski durum değişikliklerini kaydet</translation>
     </message>
     <message>
         <source>Save status only with description</source>
-        <translation type="unfinished"/>
+        <translation>Durumları tanımlama ile kaydet</translation>
     </message>
     <message>
         <source>Shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Kısayollar</translation>
     </message>
     <message>
         <source>View history</source>
-        <translation type="unfinished"/>
+        <translation>Geçmişi göster</translation>
     </message>
     <message>
         <source>Save chats in history</source>
-        <translation type="unfinished"/>
+        <translation>Eski konuşmaları kaydet</translation>
     </message>
     <message>
         <source>History in chat window</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma penceresinde geçmiş</translation>
     </message>
     <message>
         <source>Show messages from history since</source>
-        <translation type="unfinished"/>
+        <translation>Mesajları geçmişten bu yana göster</translation>
     </message>
     <message>
         <source>Choose time period in which messages can be quoted in chat window</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma penceresinde alıntı olarak görüntülencek mesajların zaman periyodunu seçin</translation>
     </message>
     <message>
         <source>yesterday</source>
-        <translation type="unfinished"/>
+        <translation>dün</translation>
     </message>
     <message>
         <source>last week</source>
-        <translation type="unfinished"/>
+        <translation>geçen hafta</translation>
     </message>
     <message>
         <source>last month</source>
-        <translation type="unfinished"/>
+        <translation>geçen ay</translation>
     </message>
     <message>
         <source>Limit number of messages from history</source>
-        <translation type="unfinished"/>
+        <translation>Eski mesajların limit sayısı</translation>
     </message>
     <message>
         <source>Behavior</source>
-        <translation type="unfinished"/>
+        <translation>Davranış</translation>
     </message>
     <message>
         <source>Chat window</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma penceresi</translation>
     </message>
 </context>
 <context>
     <name>BuddyHistoryDeleteHandler</name>
     <message>
         <source>Chat history</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma geçmişi</translation>
     </message>
 </context>
 <context>
     <name>ChatHistoryTab</name>
     <message>
         <source>&amp;Clear Chat History</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Konuşma Geçmişini Temizle</translation>
     </message>
 </context>
 <context>
     <name>History</name>
     <message>
         <source>Clear History</source>
-        <translation type="unfinished"/>
+        <translation>Geçmişi Temizle</translation>
     </message>
 </context>
 <context>
     <name>HistoryBuddyConfigurationWidget</name>
     <message>
         <source>History</source>
-        <translation type="unfinished"/>
+        <translation>Geçmiş</translation>
     </message>
     <message>
         <source>Store history</source>
-        <translation type="unfinished"/>
+        <translation>Geçmişi sakla</translation>
     </message>
 </context>
 <context>
     <name>HistoryChatConfigurationWidget</name>
     <message>
         <source>History</source>
-        <translation type="unfinished"/>
+        <translation>Geçmiş</translation>
     </message>
     <message>
         <source>Store history</source>
-        <translation type="unfinished"/>
+        <translation>Geçmişi sakla</translation>
     </message>
 </context>
 <context>
     <name>HistoryMessagesTab</name>
     <message>
         <source>&amp;Remove entries</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Girdileri kaldır</translation>
     </message>
     <message>
         <source>Filter</source>
-        <translation type="unfinished"/>
+        <translation>Filtre</translation>
     </message>
     <message>
         <source>Kadu</source>
-        <translation type="unfinished"/>
+        <translation>Kadu</translation>
     </message>
     <message>
         <source>Do you really want to delete history?</source>
-        <translation type="unfinished"/>
+        <translation>Geçmişi silmek istediğinize emin misiniz?</translation>
     </message>
     <message>
         <source>Delete history</source>
-        <translation type="unfinished"/>
+        <translation>Geçmişi sil</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>İptal</translation>
     </message>
 </context>
 <context>
     <name>HistoryQueryResultsModel</name>
     <message>
         <source>Chat</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma</translation>
     </message>
     <message>
         <source>Length</source>
-        <translation type="unfinished"/>
+        <translation>Uzunluk</translation>
     </message>
     <message>
         <source>Date</source>
-        <translation type="unfinished"/>
+        <translation>Tarih</translation>
     </message>
     <message>
         <source>Title</source>
-        <translation type="unfinished"/>
+        <translation>Başlık</translation>
     </message>
 </context>
 <context>
     <name>HistoryWindow</name>
     <message>
         <source>History</source>
-        <translation type="unfinished"/>
+        <translation>Geçmiş</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation type="unfinished"/>
+        <translation>Arama</translation>
     </message>
     <message>
         <source>&amp;Clear Status History</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Durum Geçmişini Temizle</translation>
     </message>
     <message>
         <source>&amp;Clear SMS History</source>
-        <translation type="unfinished"/>
+        <translation>SMS &amp;Geçmişini Temizle</translation>
     </message>
     <message>
         <source>Chats</source>
-        <translation type="unfinished"/>
+        <translation>Konuşmalar</translation>
     </message>
     <message>
         <source>Statuses</source>
-        <translation type="unfinished"/>
+        <translation>Durumlar</translation>
     </message>
     <message>
         <source>SMS</source>
-        <translation type="unfinished"/>
+        <translation>SMS</translation>
     </message>
 </context>
 <context>
     <name>SearchTab</name>
     <message>
         <source>Search for:</source>
-        <translation type="unfinished"/>
+        <translation>Şurada ara:</translation>
     </message>
     <message>
         <source>Chats</source>
-        <translation type="unfinished"/>
+        <translation>Konuşmalar</translation>
     </message>
     <message>
         <source> - All chats - </source>
-        <translation type="unfinished"/>
+        <translation>- Tüm konuşmalar -</translation>
     </message>
     <message>
         <source>Statuses</source>
-        <translation type="unfinished"/>
+        <translation>Durumlar</translation>
     </message>
     <message>
         <source> - All buddies - </source>
-        <translation type="unfinished"/>
+        <translation>- Tüm arkadaşlar -</translation>
     </message>
     <message>
         <source>Smses</source>
-        <translation type="unfinished"/>
+        <translation>Smsler</translation>
     </message>
     <message>
         <source> - All recipients - </source>
-        <translation type="unfinished"/>
+        <translation>- Tüm alıcılar -</translation>
     </message>
     <message>
         <source>By date</source>
-        <translation type="unfinished"/>
+        <translation>Tarihe göre</translation>
     </message>
     <message>
         <source>to</source>
-        <translation type="unfinished"/>
+        <translation>den</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation type="unfinished"/>
+        <translation>Arama</translation>
     </message>
     <message>
         <source>Found</source>
-        <translation type="unfinished"/>
+        <translation>Bulunan</translation>
     </message>
     <message>
         <source>Chat</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma</translation>
     </message>
     <message>
         <source>Buddy</source>
-        <translation type="unfinished"/>
+        <translation>Arkadaş</translation>
     </message>
     <message>
         <source>Recipient</source>
-        <translation type="unfinished"/>
+        <translation>Alıcı</translation>
     </message>
 </context>
 <context>
     <name>ShowHistoryActionDescription</name>
     <message>
         <source>View Chat History</source>
-        <translation type="unfinished"/>
+        <translation>Konuşma Geçmişini Göster</translation>
     </message>
     <message>
         <source>Show last %1 messages</source>
-        <translation type="unfinished"/>
+        <translation>Son %1 mesajı göster</translation>
     </message>
     <message>
         <source>Show messages since yesterday</source>
-        <translation type="unfinished"/>
+        <translation>Dünden bu yana olan mesajları göster</translation>
     </message>
     <message>
         <source>Show messages from last 7 days</source>
-        <translation type="unfinished"/>
+        <translation>Son 7 günün mesajlarını göster</translation>
     </message>
     <message>
         <source>Show messages from last 30 days</source>
-        <translation type="unfinished"/>
+        <translation>Son 30 günün mesajlarını göster</translation>
     </message>
     <message>
         <source>Show whole history</source>
-        <translation type="unfinished"/>
+        <translation>Tüm geçmişi göster</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
