@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,24 +17,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IDLE_H
-#define IDLE_H
+#pragma once
+
+#include "idle-exports.h"
 
 #include <QtCore/QObject>
 
-#include "idle_exports.h"
-
 class IDLEAPI Idle : public QObject
 {
 	Q_OBJECT
 
 public:
-	explicit Idle(QObject *parent = 0);
+	Q_INVOKABLE explicit Idle(QObject *parent = nullptr);
 	virtual ~Idle();
 
 	long secondsIdle();
 
 };
 
-#endif // IDLE_H
-
