@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,7 +18,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/core.h"
 
 #include "configuration/image-link-configuration.h"
 #include "image-expander-dom-visitor-provider.h"
@@ -29,22 +31,30 @@
 ImageLinkConfigurator::ImageLinkConfigurator(QObject *parent)
 {
 	Q_UNUSED(parent);
-
-	createDefaultConfiguration();
 }
 
 ImageLinkConfigurator::~ImageLinkConfigurator()
 {
 }
 
+void ImageLinkConfigurator::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
 void ImageLinkConfigurator::setImageExpanderProvider(ImageExpanderDomVisitorProvider *imageExpander)
 {
-	ImageExpander = imageExpander;
+	m_imageExpander = imageExpander;
 }
 
 void ImageLinkConfigurator::setVideoExpanderProvider(VideoExpanderDomVisitorProvider *videoExpander)
 {
-	VideoExpander = videoExpander;
+	m_videoExpander = videoExpander;
+}
+
+void ImageLinkConfigurator::init()
+{
+	createDefaultConfiguration();
 }
 
 void ImageLinkConfigurator::configure()
@@ -54,20 +64,20 @@ void ImageLinkConfigurator::configure()
 
 void ImageLinkConfigurator::createDefaultConfiguration()
 {
-	config_file.addVariable("Imagelink", "show_image", true);
-	config_file.addVariable("Imagelink", "show_yt", true);
+	m_configuration->deprecatedApi()->addVariable("Imagelink", "show_image", true);
+	m_configuration->deprecatedApi()->addVariable("Imagelink", "show_yt", true);
 }
 
 void ImageLinkConfigurator::configurationUpdated()
 {
 	ImageLinkConfiguration configuration;
-	configuration.setShowImages(config_file.readBoolEntry("Imagelink", "show_image", true));
-	configuration.setShowVideos(config_file.readBoolEntry("Imagelink", "show_yt", true));
+	configuration.setShowImages(m_configuration->deprecatedApi()->readBoolEntry("Imagelink", "show_image", true));
+	configuration.setShowVideos(m_configuration->deprecatedApi()->readBoolEntry("Imagelink", "show_yt", true));
 
-	if (ImageExpander)
-		ImageExpander->setConfiguration(configuration);
-	if (VideoExpander)
-		VideoExpander->setConfiguration(configuration);
+	if (m_imageExpander)
+		m_imageExpander->setConfiguration(configuration);
+	if (m_videoExpander)
+		m_videoExpander->setConfiguration(configuration);
 }
 
 #include "moc_image-link-configurator.cpp"
