@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,13 +18,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IMAGE_LINK_CONFIGURATOR_H
-#define IMAGE_LINK_CONFIGURATOR_H
-
-#include <QtCore/QPointer>
+#pragma once
 
 #include "configuration/configuration-holder.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class Configuration;
 class ImageExpanderDomVisitorProvider;
 class VideoExpanderDomVisitorProvider;
 
@@ -37,24 +33,27 @@ class ImageLinkConfigurator : public ConfigurationHolder
 {
 	Q_OBJECT
 
-	QPointer<ImageExpanderDomVisitorProvider> ImageExpander;
-	QPointer<VideoExpanderDomVisitorProvider> VideoExpander;
+public:
+	Q_INVOKABLE explicit ImageLinkConfigurator(QObject *parent = nullptr);
+	virtual ~ImageLinkConfigurator();
 
-	void createDefaultConfiguration();
+	void configure();
 
 protected:
 	virtual void configurationUpdated();
 
-public:
-	explicit ImageLinkConfigurator(QObject *parent = 0);
-	virtual ~ImageLinkConfigurator();
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<ImageExpanderDomVisitorProvider> m_imageExpander;
+	QPointer<VideoExpanderDomVisitorProvider> m_videoExpander;
 
-	void setImageExpanderProvider(ImageExpanderDomVisitorProvider *imageExpander);
-	void setVideoExpanderProvider(VideoExpanderDomVisitorProvider *videoExpander);
+	void createDefaultConfiguration();
 
-	void configure();
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setImageExpanderProvider(ImageExpanderDomVisitorProvider *imageExpander);
+	INJEQT_SET void setVideoExpanderProvider(VideoExpanderDomVisitorProvider *videoExpander);
+	INJEQT_INIT void init();
 
 };
 
-
-#endif // IMAGE_LINK_CONFIGURATOR_H
