@@ -1,8 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,33 +17,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IMAGE_EXPANDER_DOM_VISITOR_PROVIDER_H
-#define IMAGE_EXPANDER_DOM_VISITOR_PROVIDER_H
-
-#include <QtCore/QObject>
-#include <QtCore/QScopedPointer>
+#pragma once
 
 #include "dom/ignore-links-dom-visitor.h"
+#include "dom/dom-visitor-provider.h"
 
 #include "configuration/image-link-configuration.h"
 
-#include "dom/dom-visitor-provider.h"
+#include <QtCore/QObject>
 
 class ImageExpanderDomVisitorProvider : public QObject, public DomVisitorProvider
 {
 	Q_OBJECT
 
-	ImageLinkConfiguration Configuration;
-	QScopedPointer<IgnoreLinksDomVisitor> Visitor;
-
 public:
-	ImageExpanderDomVisitorProvider();
+	Q_INVOKABLE explicit ImageExpanderDomVisitorProvider(QObject *parent = nullptr);
 	virtual ~ImageExpanderDomVisitorProvider();
 
-	virtual DomVisitor * provide() const;
+	virtual const DomVisitor * provide() const;
 
 	void setConfiguration(const ImageLinkConfiguration &configuration);
 
-};
+private:
+	ImageLinkConfiguration m_configuration;
+	IgnoreLinksDomVisitor m_ignoreLinksVisitor;
 
-#endif // IMAGE_EXPANDER_DOM_VISITOR_PROVIDER_H
+};
