@@ -1,12 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -38,7 +32,7 @@ ImageExpander::~ImageExpander()
 {
 }
 
-QList<QDomNode> ImageExpander::matchToDomNodes(QDomDocument document, QRegExp regExp)
+QList<QDomNode> ImageExpander::matchToDomNodes(QDomDocument document, QRegExp regExp) const
 {
 	QDomElement imageElement = document.createElement("img");
 	imageElement.setAttribute("src", regExp.cap());
