@@ -1,7 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,33 +17,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef VIDEO_LINK_DOM_VISITOR_PROVIDER_H
-#define VIDEO_LINK_DOM_VISITOR_PROVIDER_H
-
-#include <QtCore/QObject>
-#include <QtCore/QScopedPointer>
-
-#include "dom/ignore-links-dom-visitor.h"
+#pragma once
 
 #include "configuration/image-link-configuration.h"
 
+#include "dom/ignore-links-dom-visitor.h"
 #include "dom/dom-visitor-provider.h"
 
+#include <QtCore/QObject>
+
 class VideoExpanderDomVisitorProvider : public QObject, public DomVisitorProvider
 {
 	Q_OBJECT
 
-	ImageLinkConfiguration Configuration;
-	QScopedPointer<IgnoreLinksDomVisitor> Visitor;
-
 public:
-	VideoExpanderDomVisitorProvider();
+	Q_INVOKABLE VideoExpanderDomVisitorProvider(QObject *parent = nullptr);
 	virtual ~VideoExpanderDomVisitorProvider();
 
-	virtual DomVisitor * provide() const;
+	const virtual DomVisitor * provide() const;
 
 	void setConfiguration(const ImageLinkConfiguration &configuration);
 
-};
+private:
+	ImageLinkConfiguration m_configuration;
+	IgnoreLinksDomVisitor m_ignoreLinks;
 
-#endif // VIDEO_LINK_DOM_VISITOR_PROVIDER_H
+};
