@@ -3,7 +3,7 @@
     <name>@default</name>
     <message>
         <source>Indicator</source>
-        <translation type="unfinished"/>
+        <translation>Indicador</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
