@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,11 +21,12 @@
 #include "accounts/account.h"
 #include "buddies/buddy-set.h"
 #include "contacts/contact.h"
-#include "core/core.h"
+#include "core/myself.h"
 #include "gui/actions/action-context.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/protocol.h"
 
 #include "actions/show-xml-console-action-description.h"
@@ -34,15 +34,18 @@
 
 #include "jabber-actions.h"
 
-static void disableNoRosterContact(Action *action)
+static void disableNoRosterContact(Myself *myself, Action *action)
 {
 	action->setEnabled(false);
 
+	if (action->context()->buddies().isAnyTemporary())
+		return;
+
 	const Contact &contact = action->context()->contacts().toContact();
 	if (!contact)
 		return;
 
-	if (action->context()->buddies().contains(Core::instance()->myself()))
+	if (action->context()->buddies().contains(myself->buddy()))
 		return;
 
 	Account account = contact.contactAccount();
@@ -55,45 +58,55 @@ static void disableNoRosterContact(Action *action)
 	action->setEnabled(true);
 }
 
-JabberActions * JabberActions::Instance = 0;
-
-void JabberActions::registerActions()
+JabberActions::JabberActions(QObject *parent) :
+		QObject{parent}
 {
-	if (!Instance)
-		Instance = new JabberActions();
-}
-
-void JabberActions::unregisterActions()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-JabberActions::JabberActions()
-{
-	new ShowXmlConsoleActionDescription(this);
-
-	Actions::instance()->blockSignals();
-
-	ResendSubscription = new ActionDescription(this, ActionDescription::TypeUser, "rosterResendSubscription",
-			this, SLOT(resendSubscriptionActionActivated(QAction*)), KaduIcon(), tr("Resend Subscription"),
-			false, disableNoRosterContact);
-	RemoveSubscription = new ActionDescription(this, ActionDescription::TypeUser, "rosterRemoveSubscription",
-			this, SLOT(removeSubscriptionActionActivated(QAction*)), KaduIcon(), tr("Remove Subscription"),
-			false, disableNoRosterContact);
-
-	// The last ActionDescription will send actionLoaded() signal.
-	Actions::instance()->unblockSignals();
-
-	AskForSubscription = new ActionDescription(this, ActionDescription::TypeUser, "rosterAskForSubscription",
-			this, SLOT(askForSubscriptionActionActivated(QAction*)), KaduIcon(), tr("Ask for Subscription"),
-			false, disableNoRosterContact);
 }
 
 JabberActions::~JabberActions()
 {
 }
 
+void JabberActions::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void JabberActions::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void JabberActions::setMyself(Myself *myself)
+{
+	m_myself = myself;
+}
+
+void JabberActions::init()
+{
+	auto showXmlConsoleAction = m_pluginInjectedFactory->makeInjected<ShowXmlConsoleActionDescription>(this);
+	m_actions->insert(showXmlConsoleAction);
+
+	m_actions->blockSignals();
+
+	ResendSubscription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this, ActionDescription::TypeUser, "rosterResendSubscription",
+			this, SLOT(resendSubscriptionActionActivated(QAction*)), KaduIcon(), tr("Resend Subscription"),
+			false,
+			[this](Action *action){ return disableNoRosterContact(m_myself, action); });
+	RemoveSubscription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this, ActionDescription::TypeUser, "rosterRemoveSubscription",
+			this, SLOT(removeSubscriptionActionActivated(QAction*)), KaduIcon(), tr("Remove Subscription"),
+			false,
+			[this](Action *action){ return disableNoRosterContact(m_myself, action); });
+
+	// The last ActionDescription will send actionLoaded() signal.
+	m_actions->unblockSignals();
+
+	AskForSubscription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this, ActionDescription::TypeUser, "rosterAskForSubscription",
+			this, SLOT(askForSubscriptionActionActivated(QAction*)), KaduIcon(), tr("Ask for Subscription"),
+			false,
+			[this](Action *action){ return disableNoRosterContact(m_myself, action); });
+}
+
 Contact JabberActions::contactFromAction(QAction *action)
 {
 	Action *kaduAction = qobject_cast<Action *>(action);
@@ -105,7 +118,7 @@ Contact JabberActions::contactFromAction(QAction *action)
 
 SubscriptionService * JabberActions::subscriptionServiceFromContact(const Contact &contact)
 {
-	XMPP::JabberProtocol *jabberProtocolHandler = qobject_cast<XMPP::JabberProtocol *>(contact.contactAccount().protocolHandler());
+	JabberProtocol *jabberProtocolHandler = qobject_cast<JabberProtocol *>(contact.contactAccount().protocolHandler());
 	if (!jabberProtocolHandler)
 		return 0;
 
