@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,42 +18,35 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "actions/jabber-actions.h"
-#include "gui/menu/menu-inventory.h"
-
 #include "jabber-protocol-menu-manager.h"
 
-JabberProtocolMenuManager * JabberProtocolMenuManager::Instance = 0;
+#include "actions/jabber-actions.h"
 
-void JabberProtocolMenuManager::createInstance()
+JabberProtocolMenuManager::JabberProtocolMenuManager(QObject *parent) :
+		QObject{parent}
 {
-	if (!Instance)
-		Instance = new JabberProtocolMenuManager();
-}
-
-void JabberProtocolMenuManager::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-JabberProtocolMenuManager::JabberProtocolMenuManager()
-{
-	RosterActions.append(JabberActions::instance()->resendSubscription());
-	RosterActions.append(JabberActions::instance()->removeSubscription());
-	RosterActions.append(JabberActions::instance()->askForSubscription());
-
-	MenuInventory::instance()->registerProtocolMenuManager(this);
 }
 
 JabberProtocolMenuManager::~JabberProtocolMenuManager()
 {
-	RosterActions.clear();
+	m_rosterActions.clear();
+}
 
-	MenuInventory::instance()->unregisterProtocolMenuManager(this);
+void JabberProtocolMenuManager::setJabberActions(JabberActions *jabberActions)
+{
+	m_jabberActions = jabberActions;
 }
 
 const QList<ActionDescription *> & JabberProtocolMenuManager::protocolActions() const
 {
-	return RosterActions;
+	if (m_rosterActions.empty())
+	{
+		m_rosterActions.append(m_jabberActions->resendSubscription());
+		m_rosterActions.append(m_jabberActions->removeSubscription());
+		m_rosterActions.append(m_jabberActions->askForSubscription());
+	}
+
+	return m_rosterActions;
 }
+
+#include "moc_jabber-protocol-menu-manager.cpp"
