@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010, 2011, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,47 +19,83 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QRadioButton>
-#include <QtGui/QVBoxLayout>
+#include "jabber-add-account-widget.h"
+
+#include "services/jabber-servers-service.h"
+#include "jabber-account-details.h"
 
 #include "accounts/account-manager.h"
-#include "gui/widgets/choose-identity-widget.h"
+#include "accounts/account-storage.h"
 #include "gui/widgets/simple-configuration-value-state-notifier.h"
 #include "gui/windows/message-dialog.h"
 #include "icons/icons-manager.h"
 #include "identities/identity-manager.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/protocols-manager.h"
-#include "server/jabber-server-register-account.h"
 
-#include "jabber-account-details.h"
-#include "jabber-protocol-factory.h"
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QVBoxLayout>
 
-#include "jabber-add-account-widget.h"
-
-JabberAddAccountWidget::JabberAddAccountWidget(JabberProtocolFactory *factory, bool showButtons, QWidget *parent) :
-		AccountAddWidget(parent), Factory(factory)
+JabberAddAccountWidget::JabberAddAccountWidget(
+	bool isGmail,
+	QString defaultServer,
+	bool showButtons,
+	QWidget *parent) :
+		AccountAddWidget{parent},
+		m_isGmail{isGmail},
+		m_defaultServer{std::move(defaultServer)},
+		m_showButtons{showButtons}
 {
-	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-
-	connect(AccountManager::instance(), SIGNAL(accountRegistered(Account)), this, SLOT(dataChanged()));
-
-	createGui(showButtons);
-	resetGui();
 }
 
 JabberAddAccountWidget::~JabberAddAccountWidget()
 {
 }
 
+void JabberAddAccountWidget::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void JabberAddAccountWidget::setAccountStorage(AccountStorage *accountStorage)
+{
+	m_accountStorage = accountStorage;
+}
+
+void JabberAddAccountWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void JabberAddAccountWidget::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void JabberAddAccountWidget::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void JabberAddAccountWidget::init()
+{
+	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+
+	connect(m_accountManager, SIGNAL(accountRegistered(Account)), this, SLOT(dataChanged()));
+
+	createGui(m_showButtons);
+	resetGui();
+}
+
 void JabberAddAccountWidget::createGui(bool showButtons)
 {
   	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -88,26 +121,8 @@ void JabberAddAccountWidget::createGui(bool showButtons)
 
 	Domain = new QComboBox();
 	Domain->setEditable(true);
-	if (!Factory->allowChangeServer())
-	{
-		Domain->setVisible(false);
-		AtLabel->setVisible(false);
-
-		QString toolTip = Factory->whatIsMyUsername();
-		if (!toolTip.isEmpty())
-		{
-			QLabel *whatIsMyUsernameLabel = new QLabel(tr("<a href='#'>What is my username?</a>"), this);
-			whatIsMyUsernameLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
-			jidLayout->addWidget(whatIsMyUsernameLabel, 0, 2, Qt::AlignRight);
-
-			connect(whatIsMyUsernameLabel, SIGNAL(linkActivated(QString)), this, SLOT(showWhatIsMyUsername()));
-		}
-	}
-	else
-	{
-		connect(Domain, SIGNAL(currentIndexChanged(QString)), this, SLOT(dataChanged()));
-		connect(Domain, SIGNAL(editTextChanged(QString)), this, SLOT(dataChanged()));
-	}
+	connect(Domain, SIGNAL(currentIndexChanged(QString)), this, SLOT(dataChanged()));
+	connect(Domain, SIGNAL(editTextChanged(QString)), this, SLOT(dataChanged()));
 	jidLayout->addWidget(Domain, 0, 2);
 
 	layout->addRow(tr("Username") + ':', jidWidget);
@@ -120,7 +135,7 @@ void JabberAddAccountWidget::createGui(bool showButtons)
 	RememberPassword = new QCheckBox(tr("Remember Password"), this);
 	layout->addRow(0, RememberPassword);
 
-	Identity = new IdentitiesComboBox(this);
+	Identity = m_pluginInjectedFactory->makeInjected<IdentitiesComboBox>(this);
 	connect(Identity, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 	layout->addRow(tr("Account Identity") + ':', Identity);
 
@@ -148,12 +163,19 @@ void JabberAddAccountWidget::createGui(bool showButtons)
 		buttons->hide();
 }
 
+void JabberAddAccountWidget::setJabberServersService(JabberServersService* serversService)
+{
+	for (auto &&server : serversService->knownServers())
+		Domain->addItem(server);
+	Domain->setCurrentText(m_defaultServer);
+}
+
 void JabberAddAccountWidget::dataChanged()
 {
 	bool valid = !Username->text().isEmpty()
 			&& !AccountPassword->text().isEmpty()
 			&& !Domain->currentText().isEmpty()
-			&& !AccountManager::instance()->byId("jabber", Username->text() + '@' + Domain->currentText())
+			&& !m_accountManager->byId("jabber", Username->text() + '@' + Domain->currentText())
 			&& Identity->currentIdentity();
 
 	AddAccountButton->setEnabled(valid);
@@ -161,7 +183,7 @@ void JabberAddAccountWidget::dataChanged()
 	if (Username->text().isEmpty()
 			&& AccountPassword->text().isEmpty()
 			&& RememberPassword->isChecked()
-			&& Domain->currentText() == Factory->defaultServer()
+			&& Domain->currentText() == m_defaultServer
 			&& 0 == Identity->currentIndex())
 		simpleStateNotifier()->setState(StateNotChanged);
 	else
@@ -170,7 +192,7 @@ void JabberAddAccountWidget::dataChanged()
 
 void JabberAddAccountWidget::apply()
 {
-	Account jabberAccount = Account::create("jabber");
+	auto jabberAccount = m_accountStorage->create("jabber");
 
 	jabberAccount.setId(Username->text() + '@' + Domain->currentText());
 	jabberAccount.setPassword(AccountPassword->text());
@@ -188,17 +210,7 @@ void JabberAddAccountWidget::apply()
 		details->setResource("Kadu");
 		details->setPriority(5);
 
-		bool isFacebookAccount = Factory->name() == "facebook";
-		if (isFacebookAccount)
-		{
-			details->setEncryptionMode(JabberAccountDetails::Encryption_Yes);
-			details->setPlainAuthMode(JabberAccountDetails::AllowPlainOverTLS);
-			details->setUseCustomHostPort(false);
-			details->setCustomHost("chat.facebook.com");
-			details->setCustomPort(5222);
-		}
-
-		bool isGoogleAppsAccount = Factory->name() == "gmail/google talk" && !Domain->currentText().contains("gmail");
+		bool isGoogleAppsAccount = m_isGmail && !Domain->currentText().contains("gmail");
 		// Google Apps account sometimes needs custom host/port settings to work
 		if (isGoogleAppsAccount)
 		{
@@ -222,18 +234,13 @@ void JabberAddAccountWidget::resetGui()
 {
 	AccountPassword->clear();
 	Username->clear();
-	Domain->setEditText(Factory->defaultServer());
+	Domain->setEditText(m_defaultServer);
 	RememberPassword->setChecked(true);
-	IdentityManager::instance()->removeUnused();
+	m_identityManager->removeUnused();
 	Identity->setCurrentIndex(0);
 	AddAccountButton->setDisabled(true);
 
 	simpleStateNotifier()->setState(StateNotChanged);
 }
 
-void JabberAddAccountWidget::showWhatIsMyUsername()
-{
-	MessageDialog::show(KaduIcon("dialog-information"), Factory->displayName(), Factory->whatIsMyUsername());
-}
-
 #include "moc_jabber-add-account-widget.cpp"
