@@ -19,6 +19,27 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "jabber-edit-account-widget.h"
+
+#include "gui/windows/jabber-change-password-window.h"
+#include "jabber-protocol.h"
+
+#include "accounts/account-manager.h"
+#include "accounts/account.h"
+#include "configuration/configuration-manager.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "gui/widgets/account-avatar-widget.h"
+#include "gui/widgets/account-buddy-list-widget.h"
+#include "gui/widgets/account-configuration-widget-tab-adapter.h"
+#include "gui/widgets/proxy-combo-box.h"
+#include "gui/widgets/simple-configuration-value-state-notifier.h"
+#include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
+#include "identities/identity-manager.h"
+#include "plugin/plugin-injected-factory.h"
+#include "protocols/services/avatar-service.h"
+
 #include <QtWidgets/QApplication>
 #include <QtWidgets/QCheckBox>
 #include <QtWidgets/QComboBox>
@@ -31,27 +52,41 @@
 #include <QtWidgets/QTabWidget>
 #include <QtWidgets/QVBoxLayout>
 
-#include "accounts/account-manager.h"
-#include "accounts/account.h"
-#include "configuration/configuration.h"
-#include "configuration/deprecated-configuration-api.h"
-#include "gui/widgets/account-avatar-widget.h"
-#include "gui/widgets/account-buddy-list-widget.h"
-#include "gui/widgets/account-configuration-widget-tab-adapter.h"
-#include "gui/widgets/proxy-combo-box.h"
-#include "gui/widgets/simple-configuration-value-state-notifier.h"
-#include "gui/windows/message-dialog.h"
-#include "icons/icons-manager.h"
-#include "identities/identity-manager.h"
-#include "protocols/services/avatar-service.h"
+JabberEditAccountWidget::JabberEditAccountWidget(Account account, QWidget *parent) :
+		AccountEditWidget(account, parent)
+{
+}
 
-#include "gui/windows/jabber-change-password-window.h"
-#include "jabber-protocol.h"
+JabberEditAccountWidget::~JabberEditAccountWidget()
+{
+}
 
-#include "jabber-edit-account-widget.h"
+void JabberEditAccountWidget::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
 
-JabberEditAccountWidget::JabberEditAccountWidget(AccountConfigurationWidgetFactoryRepository *accountConfigurationWidgetFactoryRepository, Account account, QWidget *parent) :
-		AccountEditWidget(accountConfigurationWidgetFactoryRepository, account, parent)
+void JabberEditAccountWidget::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void JabberEditAccountWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void JabberEditAccountWidget::setIdentityManager(IdentityManager *identityManager)
+{
+	m_identityManager = identityManager;
+}
+
+void JabberEditAccountWidget::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void JabberEditAccountWidget::init()
 {
 	createGui();
 	loadAccountData();
@@ -60,10 +95,6 @@ JabberEditAccountWidget::JabberEditAccountWidget(AccountConfigurationWidgetFacto
 	stateChangedSlot(stateNotifier()->state());
 }
 
-JabberEditAccountWidget::~JabberEditAccountWidget()
-{
-}
-
 void JabberEditAccountWidget::createGui()
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -127,7 +158,7 @@ void JabberEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 	formLayout->addRow(0, changePasswordLabel);
 	connect(changePasswordLabel, SIGNAL(linkActivated(QString)), this, SLOT(changePasssword()));
 
-	Identities = new IdentitiesComboBox(this);
+	Identities = m_pluginInjectedFactory->makeInjected<IdentitiesComboBox>(this);
 	connect(Identities, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 	formLayout->addRow(tr("Account Identity") + ':', Identities);
 
@@ -137,7 +168,7 @@ void JabberEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 	infoLabel->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
 	formLayout->addRow(0, infoLabel);
 
-	AccountAvatarWidget *avatarWidget = new AccountAvatarWidget(account(), this);
+	AccountAvatarWidget *avatarWidget = m_pluginInjectedFactory->makeInjected<AccountAvatarWidget>(account(), this);
 	layout->addWidget(avatarWidget, 0, 1, Qt::AlignTop);
 
 	tabWidget->addTab(generalTab, tr("General"));
@@ -145,7 +176,7 @@ void JabberEditAccountWidget::createGeneralTab(QTabWidget *tabWidget)
 
 void JabberEditAccountWidget::createPersonalDataTab(QTabWidget *tabWidget)
 {
-	PersonalInfoWidget = new JabberPersonalInfoWidget(account(), tabWidget);
+	PersonalInfoWidget = m_pluginInjectedFactory->makeInjected<JabberPersonalInfoWidget>(account(), tabWidget);
 	connect(PersonalInfoWidget, SIGNAL(dataChanged()), this, SLOT(dataChanged()));
 	tabWidget->addTab(PersonalInfoWidget, tr("Personal Information"));
 }
@@ -242,7 +273,7 @@ void JabberEditAccountWidget::createGeneralGroupBox(QVBoxLayout *layout)
 	connectionBoxLayout->addWidget(RequireDataTransferProxy);
 
 	QLabel *proxyLabel = new QLabel(tr("Proxy configuration"), connection);
-	ProxyCombo = new ProxyComboBox(connection);
+	ProxyCombo = m_pluginInjectedFactory->makeInjected<ProxyComboBox>(connection);
 	ProxyCombo->enableDefaultProxyAction();
 	connect(ProxyCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(dataChanged()));
 
@@ -364,8 +395,8 @@ void JabberEditAccountWidget::dataChanged()
 		return;
 	}
 
-	bool sameIdExists = AccountManager::instance()->byId(account().protocolName(), AccountId->text())
-			&& AccountManager::instance()->byId(account().protocolName(), AccountId->text()) != account();
+	bool sameIdExists = m_accountManager->byId(account().protocolName(), AccountId->text())
+			&& m_accountManager->byId(account().protocolName(), AccountId->text()) != account();
 
 	if (/*AccountName->text().isEmpty()
 		|| sameNameExists
@@ -449,8 +480,8 @@ void JabberEditAccountWidget::apply()
 	if (PersonalInfoWidget->isModified())
 		PersonalInfoWidget->apply();
 
-	IdentityManager::instance()->removeUnused();
-	ConfigurationManager::instance()->flush();
+	m_identityManager->removeUnused();
+	m_configurationManager->flush();
 
 	simpleStateNotifier()->setState(StateNotChanged);
 }
@@ -463,14 +494,14 @@ void JabberEditAccountWidget::cancel()
 	loadAccountDetailsData();
 	PersonalInfoWidget->cancel();
 
-	IdentityManager::instance()->removeUnused();
+	m_identityManager->removeUnused();
 
 	simpleStateNotifier()->setState(StateNotChanged);
 }
 
 void JabberEditAccountWidget::removeAccount()
 {
-	MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-warning"), tr("Confrim Account Removal"),
+	MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Confrim Account Removal"),
 	                        tr("Are you sure do you want to remove account %1 (%2)?")
 				.arg(account().accountIdentity().name())
 				.arg(account().id()));
@@ -481,7 +512,7 @@ void JabberEditAccountWidget::removeAccount()
 
 	if (decision == QMessageBox::Yes)
 	{
-		AccountManager::instance()->removeAccountAndBuddies(account());
+		m_accountManager->removeAccountAndBuddies(account());
 		deleteLater();
 	}
 }
@@ -491,11 +522,11 @@ void JabberEditAccountWidget::changePasssword()
 	auto protocol = static_cast<JabberProtocol *>(account().protocolHandler());
 	if (!protocol->isConnected())
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Log in before changing password."), QMessageBox::Ok, this);
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Log in before changing password."), QMessageBox::Ok, this);
 		return;
 	}
 
-	JabberChangePasswordWindow *changePasswordWindow = new JabberChangePasswordWindow(protocol->changePasswordService(), account());
+	auto changePasswordWindow = m_pluginInjectedFactory->makeInjected<JabberChangePasswordWindow>(protocol->changePasswordService(), account());
 	connect(changePasswordWindow, SIGNAL(passwordChanged(const QString &)), this, SLOT(passwordChanged(const QString &)));
 	changePasswordWindow->show();
 }
