@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,23 +18,21 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QComboBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
+#include "jabber-personal-info-widget.h"
 
 #include "accounts/account.h"
+#include "buddies/buddy-storage.h"
 #include "protocols/protocol.h"
 #include "protocols/services/personal-info-service.h"
 
-#include "jabber-personal-info-widget.h"
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
 
 JabberPersonalInfoWidget::JabberPersonalInfoWidget(Account account, QWidget* parent) :
-		QWidget(parent), Id(account.id()), MyBuddy(Buddy::create())
+		QWidget(parent), Id(account.id())
 {
-	createGui();
-	fillForm();
-
 	if (account.isNull() || !account.protocolHandler())
 		return;
 
@@ -52,6 +48,19 @@ JabberPersonalInfoWidget::~JabberPersonalInfoWidget()
 {
 }
 
+void JabberPersonalInfoWidget::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void JabberPersonalInfoWidget::init()
+{
+	MyBuddy = m_buddyStorage->create();
+
+	createGui();
+	fillForm();
+}
+
 void JabberPersonalInfoWidget::createGui()
 {
 	QFormLayout *layout = new QFormLayout(this);
@@ -117,7 +126,7 @@ bool JabberPersonalInfoWidget::isModified()
 
 void JabberPersonalInfoWidget::apply()
 {
-	Buddy buddy = Buddy::create();
+	Buddy buddy = m_buddyStorage->create();
 
 	buddy.setNickName((*NickName).text());
 	buddy.setFirstName((*FullName).text());
