@@ -1,13 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,23 +18,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef JABBER_PERSONAL_INFO_WIDGET_H
-#define JABBER_PERSONAL_INFO_WIDGET_H
-
-#include <QtGui/QWidget>
+#pragma once
 
 #include "buddies/buddy.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
+class Account;
+class BuddyStorage;
+class PersonalInfoService;
+
 class QComboBox;
 class QLineEdit;
 
-class Account;
-class PersonalInfoService;
-
 class JabberPersonalInfoWidget : public QWidget
 {
 	Q_OBJECT
 
+public:
+	explicit JabberPersonalInfoWidget(Account account, QWidget *parent = nullptr);
+	virtual ~JabberPersonalInfoWidget();
+
+	bool isModified();
+
+	void apply();
+	void cancel();
+
+signals:
+	void dataChanged();
+
+private:
+	QPointer<BuddyStorage> m_buddyStorage;
+
 	PersonalInfoService *Service;
 	QString Id;
 	Buddy MyBuddy;
@@ -57,20 +68,9 @@ class JabberPersonalInfoWidget : public QWidget
 	void fillForm();
 
 private slots:
+	INJEQT_SET void setBuddyStorage(BuddyStorage *buddyStorage);
+	INJEQT_INIT void init();
+
 	void personalInfoAvailable(Buddy buddy);
 
-public:
-	explicit JabberPersonalInfoWidget(Account account, QWidget *parent = 0);
-	virtual ~JabberPersonalInfoWidget();
-
-	bool isModified();
-
-	void apply();
-	void cancel();
-
-signals:
-	void dataChanged();
-
 };
-
-#endif // JABBER_PERSONAL_INFO_WIDGET_H
