@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,46 +18,55 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef JABBER_CHANGE_PASSWORD_WINDOW_H
-#define JABBER_CHANGE_PASSWORD_WINDOW_H
-
-#include <QtGui/QWidget>
+#pragma once
 
 #include "accounts/account.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
 class QLineEdit;
 class QPushButton;
 
-class JabberServerChangePassword;
+class Configuration;
+class IconsManager;
+class JabberChangePasswordService;
 
 class JabberChangePasswordWindow : public QWidget
 {
 	Q_OBJECT
 
-	Account MyAccount;
-
-	QLineEdit *CurrentPassword;
-	QLineEdit *NewPassword;
-	QLineEdit *ReNewPassword;
-	QPushButton *ChangePasswordButton;
-
-	void createGui();
-
-private slots:
-	void dataChanged();
-	void changePassword();
-	void changingFinished(JabberServerChangePassword *gscp);
-
-protected:
-	virtual void keyPressEvent(QKeyEvent *e);
-
 public:
-	explicit JabberChangePasswordWindow(Account account, QWidget *parent = 0);
+	explicit JabberChangePasswordWindow(JabberChangePasswordService *changePasswordService, Account account, QWidget *parent = nullptr);
 	virtual ~JabberChangePasswordWindow();
 
 signals:
 	void passwordChanged(const QString &);
 
-};
+protected:
+	virtual void keyPressEvent(QKeyEvent *e);
 
-#endif // JABBER_CHANGE_PASSWORD_WINDOW_H
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<JabberChangePasswordService> m_changePasswordService;
+	Account m_account;
+
+	QLineEdit *m_newPassword;
+	QLineEdit *m_reNewPassword;
+	QPushButton *m_changePasswordButton;
+
+	void createGui();
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_INIT void init();
+
+	void dataChanged();
+	void changePassword();
+	void passwordChanged();
+	void error(const QString &errorMessage);
+
+};
