@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Piotr Pełzowski (floss@pelzowski.eu)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,9 +19,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "core/core.h"
 #include "icons/kadu-icon.h"
 #include "misc/misc.h"
+#include "plugin/plugin-injected-factory.h"
 #include "status/status-type.h"
 
 #include "actions/jabber-protocol-menu-manager.h"
@@ -33,38 +29,47 @@
 #include "gui/widgets/jabber-contact-personal-info-widget.h"
 #include "gui/widgets/jabber-create-account-widget.h"
 #include "gui/widgets/jabber-edit-account-widget.h"
+#include "services/jabber-servers-service.h"
+#include "facebook-depreceated-message.h"
 #include "jabber-account-details.h"
-#include "jabber-contact-details.h"
 #include "jabber-id-validator.h"
 #include "jabber-protocol-factory.h"
 #include "jabber-protocol.h"
 #include "jabber-status-adapter.h"
 
-JabberProtocolFactory * JabberProtocolFactory::Instance = 0;
-
-void JabberProtocolFactory::createInstance()
+JabberProtocolFactory::JabberProtocolFactory(QObject *parent) :
+		ProtocolFactory{}
 {
-	if (!Instance)
-		Instance = new JabberProtocolFactory();
-}
+	Q_UNUSED(parent);
 
-void JabberProtocolFactory::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-JabberProtocolFactory::JabberProtocolFactory()
-{
-	MyStatusAdapter = make_unique<JabberStatusAdapter>();
+	m_statusAdapter = std::make_unique<JabberStatusAdapter>();
 
 	// already sorted
-	SupportedStatusTypes.append(StatusTypeFreeForChat);
-	SupportedStatusTypes.append(StatusTypeOnline);
-	SupportedStatusTypes.append(StatusTypeAway);
-	SupportedStatusTypes.append(StatusTypeNotAvailable);
-	SupportedStatusTypes.append(StatusTypeDoNotDisturb);
-	SupportedStatusTypes.append(StatusTypeOffline);
+	m_supportedStatusTypes.append(StatusType::FreeForChat);
+	m_supportedStatusTypes.append(StatusType::Online);
+	m_supportedStatusTypes.append(StatusType::Away);
+	m_supportedStatusTypes.append(StatusType::NotAvailable);
+	m_supportedStatusTypes.append(StatusType::DoNotDisturb);
+	m_supportedStatusTypes.append(StatusType::Offline);
+}
+
+JabberProtocolFactory::~JabberProtocolFactory()
+{
+}
+
+void JabberProtocolFactory::setFacebookDepreceatedMessage(FacebookDepreceatedMessage *facebookDepreceatedMessage)
+{
+	m_facebookDepreceatedMessage = facebookDepreceatedMessage;
+}
+
+void JabberProtocolFactory::setJabberProtocolMenuManager(JabberProtocolMenuManager *jabberProtocolMenuManager)
+{
+	m_jabberProtocolMenuManager = jabberProtocolMenuManager;
+}
+
+void JabberProtocolFactory::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
 }
 
 KaduIcon JabberProtocolFactory::icon()
@@ -74,43 +79,43 @@ KaduIcon JabberProtocolFactory::icon()
 
 Protocol * JabberProtocolFactory::createProtocolHandler(Account account)
 {
-	return new XMPP::JabberProtocol(account, this);
+	if (account.id().toLower().endsWith("@chat.facebook.com"))
+		m_facebookDepreceatedMessage->showIfNotSeen();
+
+	return m_pluginInjectedFactory->makeInjected<JabberProtocol>(account, this);
 }
 
 AccountDetails * JabberProtocolFactory::createAccountDetails(AccountShared *accountShared)
 {
-	return new JabberAccountDetails(accountShared);
-}
-
-ContactDetails * JabberProtocolFactory::createContactDetails(ContactShared *contactShared)
-{
-	return new JabberContactDetails(contactShared);
+	return m_pluginInjectedFactory->makeInjected<JabberAccountDetails>(accountShared);
 }
 
 AccountAddWidget * JabberProtocolFactory::newAddAccountWidget(bool showButtons, QWidget *parent)
 {
-	JabberAddAccountWidget *result = new JabberAddAccountWidget(this, showButtons, parent);
+	auto result = m_pluginInjectedFactory->makeInjected<JabberAddAccountWidget>(false, QString{}, showButtons, parent);
+	result->setJabberServersService(new JabberServersService{result});
 	connect(this, SIGNAL(destroyed()), result, SLOT(deleteLater()));
 	return result;
 }
 
 AccountCreateWidget * JabberProtocolFactory::newCreateAccountWidget(bool showButtons, QWidget *parent)
 {
-	JabberCreateAccountWidget *result = new JabberCreateAccountWidget(showButtons, parent);
+	auto result = m_pluginInjectedFactory->makeInjected<JabberCreateAccountWidget>(showButtons, parent);
+	result->setJabberServersService(new JabberServersService{result});
 	connect(this, SIGNAL(destroyed()), result, SLOT(deleteLater()));
 	return result;
 }
 
 AccountEditWidget * JabberProtocolFactory::newEditAccountWidget(Account account, QWidget *parent)
 {
-	JabberEditAccountWidget *result = new JabberEditAccountWidget(Core::instance()->accountConfigurationWidgetFactoryRepository(), account, parent);
+	JabberEditAccountWidget *result = m_pluginInjectedFactory->makeInjected<JabberEditAccountWidget>(account, parent);
 	connect(this, SIGNAL(destroyed()), result, SLOT(deleteLater()));
 	return result;
 }
 
 QList<StatusType> JabberProtocolFactory::supportedStatusTypes()
 {
-	return SupportedStatusTypes;
+	return m_supportedStatusTypes;
 }
 
 QString JabberProtocolFactory::idLabel()
@@ -121,7 +126,8 @@ QString JabberProtocolFactory::idLabel()
 QValidator::State JabberProtocolFactory::validateId(QString id)
 {
 	int pos = 0;
-	return JabberIdValidator::instance()->validate(id, pos);
+	JabberIdValidator validator;
+	return validator.validate(id, pos);
 }
 
 bool JabberProtocolFactory::canRegister()
@@ -129,24 +135,14 @@ bool JabberProtocolFactory::canRegister()
 	return true;
 }
 
-bool JabberProtocolFactory::allowChangeServer()
-{
-	return true;
-}
-
-QString JabberProtocolFactory::defaultServer()
-{
-	return QString();
-}
-
 QWidget * JabberProtocolFactory::newContactPersonalInfoWidget(Contact contact, QWidget *parent)
 {
-	return new JabberContactPersonalInfoWidget(contact, parent);
+	return m_pluginInjectedFactory->makeInjected<JabberContactPersonalInfoWidget>(contact, parent);
 }
 
 ProtocolMenuManager * JabberProtocolFactory::protocolMenuManager()
 {
-	return JabberProtocolMenuManager::instance();
+	return m_jabberProtocolMenuManager;
 }
 
 #include "moc_jabber-protocol-factory.cpp"
