@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,30 +18,33 @@
  */
 
 #include "dom/ignore-links-dom-visitor.h"
+#include "misc/memory.h"
 #include "url-handlers/simple-url-expander.h"
 
 #include "jabber-url-dom-visitor-provider.h"
 
-JabberUrlDomVisitorProvider::JabberUrlDomVisitorProvider()
+JabberUrlDomVisitorProvider::JabberUrlDomVisitorProvider(QObject *parent) :
+		QObject{parent},
+		m_ignoreLinks{std::make_unique<SimpleUrlExpander>(
+			QRegExp{"\\b"
+					"xmpp:"
+					"(?://([^@ ]+)@([^/?# ]+)/?)?"                 // auth-xmpp
+					"(?:(?:([^@ ]+)@)?([^/?# ]+)(?:/([^?# ]+))?)?" // path-xmpp
+					"(?:\\?([^&# ]+)"                              // querytype
+					"(&[^# ]+)?)?"                                 // pair, will need to be reparsed, later
+					"(?:#(\\S*))?"                                 // fragment
+					"\\b"}
+		)}
 {
-	SimpleUrlExpander *expander = new SimpleUrlExpander(
-		QRegExp("\\b"
-	            "xmpp:"
-	            "(?://([^@ ]+)@([^/?# ]+)/?)?"                 // auth-xmpp
-	            "(?:(?:([^@ ]+)@)?([^/?# ]+)(?:/([^?# ]+))?)?" // path-xmpp
-	            "(?:\\?([^&# ]+)"                              // querytype
-	            "(&[^# ]+)?)?"                                 // pair, will need to be reparsed, later
-	            "(?:#(\\S*))?"                                 // fragment
-	            "\\b")
-	);
-	IgnoreLinks.reset(new IgnoreLinksDomVisitor(expander));
 }
 
 JabberUrlDomVisitorProvider::~JabberUrlDomVisitorProvider()
 {
 }
 
-DomVisitor * JabberUrlDomVisitorProvider::provide() const
+const DomVisitor * JabberUrlDomVisitorProvider::provide() const
 {
-	return IgnoreLinks.data();
+	return &m_ignoreLinks;
 }
+
+#include "moc_jabber-url-dom-visitor-provider.cpp"
