@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,40 +18,41 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef JABBER_PERSONAL_INFO_SERVICE_H
-#define JABBER_PERSONAL_INFO_SERVICE_H
-
-#include <xmpp_vcard.h>
-
-#include "buddies/buddy.h"
+#pragma once
 
 #include "protocols/services/personal-info-service.h"
 
-namespace XMPP
-{
-	class JabberProtocol;
-	class JabberVCardService;
-}
+#include "buddies/buddy.h"
+
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class BuddyStorage;
+class JabberVCardService;
+
+class QXmppVCardIq;
 
 class JabberPersonalInfoService : public PersonalInfoService
 {
 	Q_OBJECT
 
-	QPointer<XMPP::JabberVCardService> VCardService;
-	Buddy CurrentBuddy;
-
-private slots:
-	virtual void vCardDownloaded(bool ok, XMPP::VCard vCard);
-
 public:
-	explicit JabberPersonalInfoService(Account account, QObject *parent = 0);
+	explicit JabberPersonalInfoService(Account account, QObject *parent = nullptr);
 	virtual ~JabberPersonalInfoService();
 
-	void setVCardService(XMPP::JabberVCardService *vCardService);
+	void setVCardService(JabberVCardService *vCardService);
 
 	virtual void fetchPersonalInfo(const QString &id);
 	virtual void updatePersonalInfo(const QString &id, Buddy buddy);
 
-};
+private:
+	QPointer<BuddyStorage> m_buddyStorage;
+	QPointer<JabberVCardService> VCardService;
+	Buddy CurrentBuddy;
 
-#endif // JABBER_PERSONAL_INFO_SERVICE_H
+private slots:
+	INJEQT_SET void setBuddyStorage(BuddyStorage *buddyStorage);
+
+	virtual void vCardDownloaded(bool ok, const QXmppVCardIq &vCard);
+
+};
