@@ -1,36 +1,13 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
-<context>
-    <name>@default</name>
-    <message>
-        <source>External address</source>
-        <translation>Vnější adresa</translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation>Obecné</translation>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation>Pokročilé</translation>
-    </message>
-    <message>
-        <source>XMPP/Jabber</source>
-        <translation>XMPP/Jabber</translation>
-    </message>
-    <message>
-        <source>Port for data transfers</source>
-        <translation>Přípojka (port) pro přenosy dat</translation>
-    </message>
-</context>
 <context>
     <name>FacebookDepreceatedMessage</name>
     <message>
         <source>Facebook XMPP support is disabled since 01.05.2015. This means Kadu will be no longer able to connect to Facebook accounts. You can leave your Facebook accounts configured for chat history or you can remove them from Kadu using Your Account dialog</source>
-        <translation type="unfinished"/>
+        <translation>Podpora pro XMPP u služby Facebook je zakázána od verze 01.05.2015. Znamená to, že Kadu se už nebude moci připojit k účtům služby Facebook. Můžete své účty u služby Facebook ponechat nastaveny pro historii rozhovorů, nebo je můžete z Kadu odstranit pomocí dialogu pro váš účet.</translation>
     </message>
     <message>
         <source>Kadu - Facebook</source>
-        <translation type="unfinished"/>
+        <translation>Kadu - Facebook</translation>
     </message>
 </context>
 <context>
@@ -332,10 +309,6 @@ Heslo zadané do obou polí (nové heslo a nové zadání hesla) se musí shodov
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
-    <message>
-        <source>Legacy SSL is only available in combination with manual host/port.</source>
-        <translation>Legacy SSL je dostupné jen ve spojení s ručním hostitelem/přípojkou.</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Odstranit účet</translation>
@@ -618,6 +591,10 @@ Zpráva od serveru: %2</translation>
         <source>Unknown error: received stanza type %1</source>
         <translation>Neznáma chyba: Přijat typ sloky %1</translation>
     </message>
+    <message>
+        <source>SSL certificate rejected</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JabberStreamIncomingFileTransferHandler</name>
