@@ -1,27 +1,4 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
-<context>
-    <name>@default</name>
-    <message>
-        <source>External address</source>
-        <translation>Externe Adresse</translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>XMPP/Jabber</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Port for data transfers</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>FacebookDepreceatedMessage</name>
     <message>
@@ -326,10 +303,6 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
-    <message>
-        <source>Legacy SSL is only available in combination with manual host/port.</source>
-        <translation>Die veraltete sichere Verbindung (SSL) ist nur unter Angabe von Rechnername und Port möglich.</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Konto entfernen</translation>
@@ -610,6 +583,10 @@ Server message: %2</source>
         <source>Unknown error: received stanza type %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>SSL certificate rejected</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JabberStreamIncomingFileTransferHandler</name>
