@@ -1,27 +1,4 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
-<context>
-    <name>@default</name>
-    <message>
-        <source>External address</source>
-        <translation>Adresse externe</translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation>Général</translation>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation>Avancé</translation>
-    </message>
-    <message>
-        <source>XMPP/Jabber</source>
-        <translation>XMPP/Jabber</translation>
-    </message>
-    <message>
-        <source>Port for data transfers</source>
-        <translation>Port de communication pour le transfert de données</translation>
-    </message>
-</context>
 <context>
     <name>FacebookDepreceatedMessage</name>
     <message>
@@ -331,10 +308,6 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
-    <message>
-        <source>Legacy SSL is only available in combination with manual host/port.</source>
-        <translation>Le SSL hérité n&apos;est disponible qu&apos;en combinaison avec un hôte/port manuel.</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Supprimer un compte</translation>
@@ -409,7 +382,7 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
     </message>
     <message>
         <source>Log in before changing password.</source>
-        <translation type="unfinished"/>
+        <translation>S&apos;authentifier avant de changer le mot de passe.</translation>
     </message>
 </context>
 <context>
@@ -617,6 +590,10 @@ Message serveur: %2</translation>
         <source>Unknown error: received stanza type %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>SSL certificate rejected</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JabberStreamIncomingFileTransferHandler</name>
