@@ -1,27 +1,4 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
-<context>
-    <name>@default</name>
-    <message>
-        <source>External address</source>
-        <translation>Endereço externo</translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation>Geral</translation>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation>Avançado</translation>
-    </message>
-    <message>
-        <source>XMPP/Jabber</source>
-        <translation>XMPP/Jabber</translation>
-    </message>
-    <message>
-        <source>Port for data transfers</source>
-        <translation>Porta para transferência de dados</translation>
-    </message>
-</context>
 <context>
     <name>FacebookDepreceatedMessage</name>
     <message>
@@ -332,10 +309,6 @@ A senha informada em ambos os campos (&quot;Senha&quot; e &quot;Repita a nova se
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
-    <message>
-        <source>Legacy SSL is only available in combination with manual host/port.</source>
-        <translation>SSL legado está disponível apenas quando combinado com host/porta manual.</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Remover conta</translation>
@@ -618,6 +591,10 @@ Mensagem do servidor: %2</translation>
         <source>Unknown error: received stanza type %1</source>
         <translation>Erro desconhecido: received stanza type %1</translation>
     </message>
+    <message>
+        <source>SSL certificate rejected</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JabberStreamIncomingFileTransferHandler</name>
