@@ -1,27 +1,4 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
-<context>
-    <name>@default</name>
-    <message>
-        <source>External address</source>
-        <translation>Harici adres</translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation>Genel</translation>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation>Gelişmiş</translation>
-    </message>
-    <message>
-        <source>XMPP/Jabber</source>
-        <translation>XMPP/Jabber</translation>
-    </message>
-    <message>
-        <source>Port for data transfers</source>
-        <translation>Veri aktarımları için port:</translation>
-    </message>
-</context>
 <context>
     <name>FacebookDepreceatedMessage</name>
     <message>
@@ -332,10 +309,6 @@ Girilen şifre alanları (&quot;Şifre&quot; ve &quot;Şifreyi tekrar yazın&quo
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
-    <message>
-        <source>Legacy SSL is only available in combination with manual host/port.</source>
-        <translation>Yerleşik SSL sadece el ile girinlen host/port combinasyonununda mevcut</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>Hesabı kaldır</translation>
@@ -619,6 +592,10 @@ Sunucu mesajı: %2</translation>
         <source>Unknown error: received stanza type %1</source>
         <translation>Bilinmeyen hata: alınan dörtlük tipi %1</translation>
     </message>
+    <message>
+        <source>SSL certificate rejected</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JabberStreamIncomingFileTransferHandler</name>
