@@ -1,27 +1,4 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
-<context>
-    <name>@default</name>
-    <message>
-        <source>External address</source>
-        <translation>外部地址</translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>XMPP/Jabber</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Port for data transfers</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>FacebookDepreceatedMessage</name>
     <message>
@@ -330,10 +307,6 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
-    <message>
-        <source>Legacy SSL is only available in combination with manual host/port.</source>
-        <translation>传统 SSL 仅在手工指定主机/端口时可用.</translation>
-    </message>
     <message>
         <source>Remove account</source>
         <translation>删除帐号</translation>
@@ -614,6 +587,10 @@ Server message: %2</source>
         <source>Unknown error: received stanza type %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>SSL certificate rejected</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JabberStreamIncomingFileTransferHandler</name>
