@@ -1,11 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Dariusz Markowicz (darom@alari.pl)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,14 +22,16 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
-#include <QtGui/QApplication>
-#include <QtGui/QMenu>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account-manager.h"
 #include "contacts/contact-manager.h"
+#include "gui/actions/actions.h"
 #include "gui/actions/action-description.h"
 #include "gui/menu/menu-inventory.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
+#include "plugin/plugin-injected-factory.h"
 #include "debug.h"
 #include "exports.h"
 
@@ -42,12 +41,50 @@
 Infos::Infos(QObject *parent) :
 		QObject{parent},
 		menuID{}
+{
+}
+
+Infos::~Infos()
+{
+}
+
+void Infos::setAccountManager(AccountManager *accountManager)
+{
+	m_accountManager = accountManager;
+}
+
+void Infos::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void Infos::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void Infos::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void Infos::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void Infos::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void Infos::init()
 {
 	kdebugf();
 
-	triggerAllAccountsRegistered();
+	triggerAllAccountsRegistered(m_accountManager);
 
-	fileName = KaduPaths::instance()->profilePath() + QLatin1String("last_seen.data");
+	fileName = m_pathsProvider->profilePath() + QStringLiteral("last_seen.data");
 
 	if (QFile::exists(fileName))
 	{
@@ -68,9 +105,9 @@ Infos::Infos(QObject *parent) :
 
 				Contact contact;
 				// wstawiamy tylko konta, które są na liście kontaktów
-				foreach(Account account, AccountManager::instance()->byProtocolName(protocol))
+				foreach(Account account, m_accountManager->byProtocolName(protocol))
 				{
-					contact = ContactManager::instance()->byId(account, uin, ActionReturnNull);
+					contact = m_contactManager->byId(account, uin, ActionReturnNull);
 					if (contact.isNull())
 						continue;
 					if (!contact.isAnonymous())
@@ -92,13 +129,13 @@ Infos::Infos(QObject *parent) :
 	}
 
 	// Main menu entry
-	lastSeenActionDescription = new ActionDescription(
+	lastSeenActionDescription = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeMainMenu, "lastSeenAction",
 		this, SLOT(onShowInfos()),
 		KaduIcon(), qApp->translate("Infos", "&Show infos about buddies")
 	);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("tools")
 		->addAction(lastSeenActionDescription, KaduMenu::SectionTools, 3)
 		->update();
@@ -106,7 +143,7 @@ Infos::Infos(QObject *parent) :
 	kdebugf2();
 }
 
-Infos::~Infos()
+void Infos::done()
 {
 	kdebugf();
 
@@ -130,7 +167,7 @@ Infos::~Infos()
 		fflush(stderr);
 	}
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("tools")
 		->removeAction(lastSeenActionDescription)
 		->update();
@@ -142,7 +179,7 @@ void Infos::onShowInfos()
 {
 	kdebugf();
 	updateTimes();
-	InfosDialog *infosDialog = new InfosDialog(lastSeen);
+	InfosDialog *infosDialog = m_pluginInjectedFactory->makeInjected<InfosDialog>(lastSeen);
 	infosDialog->show();
 	kdebugf2();
 }
@@ -173,7 +210,7 @@ void Infos::contactStatusChanged(Contact contact, Status status)
 	if (contact.currentStatus().isDisconnected())
 	{
 		lastSeen[qMakePair(contact.contactAccount().protocolName(), contact.id())]
-		         = QDateTime::currentDateTime().toString("dd-MM-yyyy hh:mm");
+		         = QDateTime::currentDateTime().toString(QStringLiteral("dd-MM-yyyy hh:mm"));
 		//kdebugm(KDEBUG_INFO, "Last seen %s %s %s\n", qPrintable(contact.contactAccount().protocolName()), qPrintable(contact.id()), qPrintable(QDateTime::currentDateTime().toString("dd-MM-yyyy hh:mm")));
 	}
 	kdebugf2();
@@ -182,7 +219,7 @@ void Infos::contactStatusChanged(Contact contact, Status status)
 void Infos::updateTimes()
 {
 	kdebugf();
-	foreach (const Contact &contact, ContactManager::instance()->items())
+	foreach (const Contact &contact, m_contactManager->items())
 	{
 		if (!contact.currentStatus().isDisconnected())
 		{
