@@ -1,12 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010 Dariusz Markowicz (darom@alari.pl)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,15 +19,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QStringList>
-#include <QtGui/QApplication>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QMenu>
-#include <QtGui/QPushButton>
-#include <QtGui/QTreeWidget>
-#include <QtGui/QVBoxLayout>
-#include <QtNetwork/QHostAddress>
+#include "infos_dialog.h"
 
+#include "infos.h"
+
+#include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact.h"
 #include "configuration/config-file-variant-wrapper.h"
 #include "contacts/contact-manager.h"
@@ -43,22 +36,63 @@
 #include "status/status-type-manager.h"
 #include "debug.h"
 
-#include "infos.h"
-
-#include "infos_dialog.h"
+#include <QtCore/QStringList>
+#include <QtNetwork/QHostAddress>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTreeWidget>
+#include <QtWidgets/QVBoxLayout>
 
 InfosDialog::InfosDialog(const LastSeen &lastSeen, QWidget *parent) :
-	QDialog(parent)
+	QDialog(parent), m_lastSeen{lastSeen}
 {
-	kdebugf();
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(tr("Buddies Information"));
+}
 
+InfosDialog::~InfosDialog()
+{
+}
+
+void InfosDialog::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void InfosDialog::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void InfosDialog::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void InfosDialog::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void InfosDialog::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void InfosDialog::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void InfosDialog::init()
+{
 	QVBoxLayout *layout = new QVBoxLayout(this);
 
 	ListView = new QTreeWidget(this);
 	ListView->setAllColumnsShowFocus(true);
-	ListView->setColumnCount(9);
+	ListView->setColumnCount(7);
 	ListView->setContextMenuPolicy(Qt::CustomContextMenu);
 	ListView->setRootIsDecorated(false);
 	ListView->setSelectionMode(QAbstractItemView::SingleSelection);
@@ -71,35 +105,29 @@ InfosDialog::InfosDialog(const LastSeen &lastSeen, QWidget *parent) :
 			<< tr("Protocol")
 			<< tr("Username")
 			<< tr("Nick")
-			<< tr("IP")
-			<< tr("Domain name")
 			<< tr("Description")
 			<< tr("State")
 			<< tr("Last time seen on");
 	ListView->setHeaderLabels(labels);
 
-	foreach (const Contact &contact, ContactManager::instance()->items())
+	foreach (const Contact &contact, m_contactManager->items())
 	{
 		if (contact.isAnonymous())
 			continue;
 
-		QString desc, ip;
+		QString desc;
 		if (!contact.currentStatus().description().isEmpty())
 			desc = contact.currentStatus().description();
 		desc.replace('\n', ' ');
-		if (!contact.address().isNull())
-			ip = contact.address().toString();
 
 		QStringList labels;
 		labels << contact.display(true)
 				<< contact.contactAccount().protocolName()
 				<< contact.id()
 				<< contact.ownerBuddy().nickName()
-				<< ip
-				<< contact.dnsName()
 				<< desc
-				<< StatusTypeManager::instance()->statusTypeData(contact.currentStatus().type()).name()
-				<< lastSeen[qMakePair(contact.contactAccount().protocolName(), contact.id())];
+				<< m_statusTypeManager->statusTypeData(contact.currentStatus().type()).name()
+				<< m_lastSeen[qMakePair(contact.contactAccount().protocolName(), contact.id())];
 
 		QTreeWidgetItem *item = new QTreeWidgetItem(labels);
 		item->setData(0, ContactRole, contact);
@@ -119,16 +147,7 @@ InfosDialog::InfosDialog(const LastSeen &lastSeen, QWidget *parent) :
 
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("LastSeen", "LastSeenWidgetGeometry"), QRect(0, 0, 800, 300), this);
-
-	kdebugf2();
-}
-
-InfosDialog::~InfosDialog()
-{
-	kdebugf();
-
-	kdebugf2();
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "LastSeen", "LastSeenWidgetGeometry"), QRect(0, 0, 800, 300), this);
 }
 
 void InfosDialog::customContextMenuRequested(const QPoint &point)
@@ -147,16 +166,16 @@ void InfosDialog::customContextMenuRequested(const QPoint &point)
 	if (!contact)
 		return;
 
-	BaseActionContext actionContext;
+	BaseActionContext actionContext{this};
 	actionContext.setBuddies(BuddySet(contact.ownerBuddy()));
-	actionContext.setChat(ChatTypeContact::findChat(contact, ActionCreateAndAdd));
+	actionContext.setChat(ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd));
 	actionContext.setContacts(ContactSet(contact));
 	actionContext.setRoles(RoleSet() << ContactRole);
 
 	QScopedPointer<QMenu> menu(new QMenu());
-	MenuInventory::instance()->menu("buddy-list")->attachToMenu(menu.data());
-	MenuInventory::instance()->menu("buddy-list")->applyTo(menu.data(), &actionContext);
-	MenuInventory::instance()->menu("buddy-list")->update();
+	m_menuInventory->menu("buddy-list")->attachToMenu(menu.data());
+	m_menuInventory->menu("buddy-list")->applyTo(menu.data(), &actionContext);
+	m_menuInventory->menu("buddy-list")->update();
 	menu->exec(QCursor::pos());
 }
 
