@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>Infos</name>
     <message>
@@ -8,10 +10,6 @@
 </context>
 <context>
     <name>InfosDialog</name>
-    <message>
-        <source>Buddies Information</source>
-        <translation>Buddies Information</translation>
-    </message>
     <message>
         <source>Buddy</source>
         <translation>Buddy</translation>
@@ -24,14 +22,6 @@
         <source>Nick</source>
         <translation>Nick</translation>
     </message>
-    <message>
-        <source>IP</source>
-        <translation>IP</translation>
-    </message>
-    <message>
-        <source>Domain name</source>
-        <translation>Domain name</translation>
-    </message>
     <message>
         <source>Description</source>
         <translation>Description</translation>
@@ -53,4 +43,4 @@
         <translation>Username</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
