@@ -8,10 +8,6 @@
 </context>
 <context>
     <name>InfosDialog</name>
-    <message>
-        <source>Buddies Information</source>
-        <translation>Informations sur les amis</translation>
-    </message>
     <message>
         <source>Buddy</source>
         <translation>Ami</translation>
