@@ -1,15 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2008, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,14 +21,14 @@
  */
 
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QMenu>
-#include <QtGui/QTextEdit>
-#include <QtGui/QToolTip>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QTextEdit>
+#include <QtWidgets/QToolTip>
 
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/actions/actions.h"
@@ -44,20 +38,23 @@
 #include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/widgets/custom-input.h"
+#include "gui/windows/main-configuration-window.h"
 #include "gui/windows/message-dialog.h"
 #include "icons/kadu-icon.h"
-#include "notify/notification-manager.h"
-#include "notify/notification/notification.h"
-#include "notify/notify-event.h"
+#include "notification/notification-event-repository.h"
+#include "notification/notification.h"
+#include "notification/notification-event.h"
+#include "plugin/plugin-injected-factory.h"
 #include "status/status-changer-manager.h"
 #include "debug.h"
 
 #include "plugins/docking/docking.h"
+#include "plugins/docking/docking-menu-action-repository.h"
 
-#include "notify/mediaplayer-notification.h"
-#include "mp_status_changer.h"
-#include "player_commands.h"
-#include "player_info.h"
+#include "mediaplayer-notification-service.h"
+#include "media-player-status-changer.h"
+#include "player-commands.h"
+#include "player-info.h"
 
 #include "mediaplayer.h"
 
@@ -66,55 +63,76 @@
 
 #define SHORTCUT_KEY Qt::Key_Meta
 
-const char *MediaPlayerSyntaxText = QT_TRANSLATE_NOOP
-(
-	"@default",
-	"Syntax: %t - song title,\n%a - album, %r - artist, %f - file name,\n"
-	"%l - song length (MM:SS), %c - current song position (MM:SS),\n"
-	"%p - percents of played song, %n - player name, %v - player version\n"
-);
-
-#ifdef Q_OS_MAC
-const char *MediaPlayerChatShortCutsText = QT_TRANSLATE_NOOP
-(
-	"@default",
-	"With this option enabled you'll be able to control\n"
-	"your MediaPlayer in chat window by keyboard shortcuts:\n"
-	"Control+ Enter/Backspace/Left/Right/Up/Down."
-);
-#else
-const char *MediaPlayerChatShortCutsText = QT_TRANSLATE_NOOP
-(
-	"@default",
-	"With this option enabled you'll be able to control\n"
-	"your MediaPlayer in chat window by keyboard shortcuts:\n"
-	"Win+ Enter/Backspace/Left/Right/Up/Down."
-);
-#endif
-
 // For ID3 tags signatures cutter
 const char DEFAULT_SIGNATURES[] = "! WWW.POLSKIE-MP3.TK ! \n! www.polskie-mp3.tk ! ";
 
 // Implementation of MediaPlayer class
 
-MediaPlayer * MediaPlayer::Instance = 0;
-
-void MediaPlayer::createInstance()
+MediaPlayer::MediaPlayer(QObject *parent) :
+		QObject{parent}
 {
-	if (!Instance)
+}
+
+MediaPlayer::~MediaPlayer()
+{
+}
+
+void MediaPlayer::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void MediaPlayer::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
+{
+	m_chatWidgetRepository = chatWidgetRepository;
+
+	if (m_chatWidgetRepository)
 	{
-		Instance = new MediaPlayer();
-		Instance->setChatWidgetRepository(Core::instance()->chatWidgetRepository());
+		// Monitor of creating chats
+		connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetAdded(ChatWidget *)), this, SLOT(chatWidgetAdded(ChatWidget *)));
+		connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetRemoved(ChatWidget *)), this, SLOT(chatWidgetRemoved(ChatWidget *)));
+
+		for (ChatWidget *chatWidget : m_chatWidgetRepository.data())
+			chatWidgetAdded(chatWidget);
 	}
 }
 
-void MediaPlayer::destroyInstance()
+void MediaPlayer::setConfiguration(Configuration *configuration)
 {
-	delete Instance;
-	Instance = 0;
+	m_configuration = configuration;
 }
 
-MediaPlayer::MediaPlayer()
+void MediaPlayer::setDockingMenuActionRepository(DockingMenuActionRepository *dockingMenuActionRepository)
+{
+	m_dockingMenuActionRepository = dockingMenuActionRepository;
+}
+
+void MediaPlayer::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void MediaPlayer::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void MediaPlayer::setMediaplayerNotificationService(MediaplayerNotificationService *mediaplayerNotificationService)
+{
+	m_mediaplayerNotificationService = mediaplayerNotificationService;
+}
+
+void MediaPlayer::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void MediaPlayer::setStatusChangerManager(StatusChangerManager *statusChangerManager)
+{
+	m_statusChangerManager = statusChangerManager;
+}
+
+void MediaPlayer::init()
 {
 	kdebugf();
 
@@ -135,49 +153,49 @@ MediaPlayer::MediaPlayer()
 	timer = new QTimer(this);
 	connect(timer, SIGNAL(timeout()), this, SLOT(checkTitle()));
 
-	enableMediaPlayerStatuses = new ActionDescription(
+	enableMediaPlayerStatuses = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeGlobal, "enableMediaPlayerStatusesAction",
 		this, SLOT(mediaPlayerStatusChangerActivated(QAction *, bool)),
 		KaduIcon("external_modules/mediaplayer-media-playback-play"), tr("Enable MediaPlayer Statuses"), true
 	);
 
-	Actions::instance()->blockSignals();
+	m_actions->blockSignals();
 
-	mediaPlayerMenu = new ActionDescription(
+	mediaPlayerMenu = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_button",
 		this, SLOT(mediaPlayerMenuActivated(QAction *, bool)),
 		KaduIcon("external_modules/mediaplayer"), tr("MediaPlayer"), false
 	);
-	playAction = new ActionDescription(
+	playAction = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_play",
 		this, SLOT(playPause()),
 		KaduIcon("external_modules/mediaplayer-media-playback-play"), tr("Play"), false
 	);
-	stopAction = new ActionDescription(
+	stopAction = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_stop",
 		this, SLOT(stop()),
 		KaduIcon("external_modules/mediaplayer-media-playback-stop"), tr("Stop"), false
 	);
-	prevAction = new ActionDescription(
+	prevAction = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_prev",
 		this, SLOT(prevTrack()),
 		KaduIcon("external_modules/mediaplayer-media-skip-backward"), tr("Previous Track"), false
 	);
-	nextAction = new ActionDescription(
+	nextAction = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_next",
 		this, SLOT(nextTrack()),
 		KaduIcon("external_modules/mediaplayer-media-skip-forward"), tr("Next Track"), false
 	);
-	volUpAction = new ActionDescription(
+	volUpAction = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_vol_up",
 		this, SLOT(incrVolume()),
 		KaduIcon("audio-volume-high"), tr("Volume Up"), false
 	);
 
 	// The last ActionDescription will send actionLoaded() signal.
-	Actions::instance()->unblockSignals();
+	m_actions->unblockSignals();
 
-	volDownAction = new ActionDescription(
+	volDownAction = m_pluginInjectedFactory->makeInjected<ActionDescription>(
 		this, ActionDescription::TypeChat, "mediaplayer_vol_down",
 		this, SLOT(decrVolume()),
 		KaduIcon("audio-volume-low"), tr("Volume Down"), false
@@ -189,27 +207,26 @@ MediaPlayer::MediaPlayer()
 	winKeyPressed = false;
 
 	Changer = new MediaPlayerStatusChanger(this);
-	StatusChangerManager::instance()->registerStatusChanger(Changer);
-
-	createDefaultConfiguration();
-
-	Changer->changePositionInStatus((MediaPlayerStatusChanger::ChangeDescriptionTo)config_file.readNumEntry("MediaPlayer", "statusPosition"));
+	m_statusChangerManager->registerStatusChanger(Changer);
+	connect(m_statusChangerManager, SIGNAL(manualStatusAboutToBeChanged(StatusContainer*,Status)),
+			this, SLOT(statusAboutToBeChanged()));
 
 	setControlsEnabled(false);
 	isPaused = true;
 
-	MediaPlayerNotification::registerNotifications();
-
+	Changer->changePositionInStatus((MediaPlayerStatusChanger::ChangeDescriptionTo)m_configuration->deprecatedApi()->readNumEntry("MediaPlayer", "statusPosition"));
+	createDefaultConfiguration();
 	configurationUpdated();
 }
 
-MediaPlayer::~MediaPlayer()
+void MediaPlayer::done()
 {
+	if (DockedMediaplayerStatus)
+		m_dockingMenuActionRepository->removeAction(DockedMediaplayerStatus);
+
 	kdebugf();
 
-	MediaPlayerNotification::unregisterNotifications();
-
-	StatusChangerManager::instance()->unregisterStatusChanger(Changer);
+	m_statusChangerManager->unregisterStatusChanger(Changer);
 
 	timer->stop();
 
@@ -223,30 +240,10 @@ MediaPlayer::~MediaPlayer()
 
 	delete menu;
 
-	// Remove menu item (statuses)
-// 	Core::instance()->kaduWindow()->removeMenuActionDescription(enableMediaPlayerStatuses);
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("main")
 		->removeAction(enableMediaPlayerStatuses)
 		->update();
-
-	if (DockedMediaplayerStatus)
-		DockingManager::instance()->dockMenu()->removeAction(DockedMediaplayerStatus);
-}
-
-void MediaPlayer::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
-{
-	m_chatWidgetRepository = chatWidgetRepository;
-
-	if (m_chatWidgetRepository)
-	{
-		// Monitor of creating chats
-		connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetAdded(ChatWidget *)), this, SLOT(chatWidgetAdded(ChatWidget *)));
-		connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetRemoved(ChatWidget *)), this, SLOT(chatWidgetRemoved(ChatWidget *)));
-
-		for (ChatWidget *chatWidget : m_chatWidgetRepository.data())
-			chatWidgetAdded(chatWidget);
-	}
 }
 
 void MediaPlayer::setControlsEnabled(bool enabled)
@@ -278,14 +275,6 @@ void MediaPlayer::mediaPlayerMenuActivated(QAction *sender, bool toggled)
 	}
 }
 
-void MediaPlayer::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
-{
-	connect(mainConfigurationWindow->widget()->widgetById("mediaplayer/signature"), SIGNAL(toggled(bool)),
-		mainConfigurationWindow->widget()->widgetById("mediaplayer/signatures"), SLOT(setEnabled(bool)));
-	mainConfigurationWindow->widget()->widgetById("mediaplayer/syntax")->setToolTip(QCoreApplication::translate("@default", MediaPlayerSyntaxText));
-	mainConfigurationWindow->widget()->widgetById("mediaplayer/chatShortcuts")->setToolTip(QCoreApplication::translate("@default", MediaPlayerChatShortCutsText));
-}
-
 void MediaPlayer::chatWidgetAdded(ChatWidget *chat)
 {
 	kdebugf();
@@ -308,7 +297,7 @@ void MediaPlayer::chatKeyPressed(QKeyEvent *e, CustomInput *k, bool &handled)
 	if (handled)
 		return;
 
-	if (!config_file.readBoolEntry("MediaPlayer", "chatShortcuts", true))
+	if (!m_configuration->deprecatedApi()->readBoolEntry("MediaPlayer", "chatShortcuts", true))
 		return;
 
 	if (e->key() == SHORTCUT_KEY)
@@ -375,9 +364,9 @@ void MediaPlayer::putSongTitle(int ident)
 	{
 		// TODO: make it a notification
 		if (!getPlayerName().isEmpty())
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("%1 isn't running!").arg(getPlayerName()));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("%1 isn't running!").arg(getPlayerName()));
 		else
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Player isn't running!"));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Player isn't running!"));
 
 		return;
 	}
@@ -401,7 +390,7 @@ void MediaPlayer::putSongTitle(int ident)
 	switch (id)
 	{
 		case 0:
-			title = parse(config_file.readEntry("MediaPlayer", "chatString"));
+			title = parse(m_configuration->deprecatedApi()->readEntry("MediaPlayer", "chatString"));
 			break;
 		case 1:
 			title = getTitle();
@@ -456,9 +445,9 @@ void MediaPlayer::putPlayList(int ident)
 	if (!isActive())
 	{
 		if (!getPlayerName().isEmpty())
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("%1 isn't running!").arg(getPlayerName()));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("%1 isn't running!").arg(getPlayerName()));
 		else
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Player isn't running!"));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Player isn't running!"));
 
 		return;
 	}
@@ -519,7 +508,7 @@ void MediaPlayer::putPlayList(int ident)
 	{
 		QString question = tr("More than 1/10 of titles you're trying to send are empty.<br>Perhaps %1 hasn't read all titles yet, give its some more time.<br>Do you want to send playlist anyway?").arg(getPlayerName());
 
-		MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-question"), tr("Kadu"), question);
+		MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-question")), tr("Kadu"), question);
 		dialog->addButton(QMessageBox::Yes, tr("Send anyway"));
 		dialog->addButton(QMessageBox::No, tr("Cancel"));
 
@@ -531,7 +520,7 @@ void MediaPlayer::putPlayList(int ident)
 	{
 		QString question = tr("You're trying to send %1 entries of %2 playlist.<br>It will be split and sent in few messages<br>Are you sure to do that?")
 			.arg(QString::number(lgt)).arg(getPlayerName());
-		MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-question"), tr("Kadu"), question);
+		MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-question")), tr("Kadu"), question);
 		dialog->addButton(QMessageBox::Yes, tr("Send"));
 		dialog->addButton(QMessageBox::No, tr("Cancel"));
 
@@ -693,21 +682,30 @@ void MediaPlayer::mediaPlayerStatusChangerActivated(QAction *sender, bool toggle
 	toggleStatuses(toggled);
 }
 
+void MediaPlayer::statusAboutToBeChanged()
+{
+	if (Changer->changeDescriptionTo() == MediaPlayerStatusChanger::DescriptionReplace)
+		toggleStatuses(false);
+}
+
 void MediaPlayer::toggleStatuses(bool toggled)
 {
 	if (!isActive() && toggled)
 	{
-		foreach (Action *action, enableMediaPlayerStatuses->actions())
+		for (auto &&action : enableMediaPlayerStatuses->actions())
 			action->setChecked(false);
 
 		if (!getPlayerName().isEmpty())
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("%1 isn't running!").arg(getPlayerName()));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("%1 isn't running!").arg(getPlayerName()));
 		else
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Player isn't running!"));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Player isn't running!"));
 
 		return;
 	}
 
+	for (auto &&action : enableMediaPlayerStatuses->actions())
+		action->setChecked(toggled);
+
 	Changer->setDisable(!toggled);
 	if (toggled)
 	{
@@ -743,10 +741,10 @@ void MediaPlayer::checkTitle()
 	int pos = getCurrentPos();
 
 	// If OSD is enabled and current track position is betwean 0 and 1000 ms, then shows OSD
-	if (config_file.readBoolEntry("MediaPlayer", "osd", true) && pos < 1000 && pos > 0)
-		MediaPlayerNotification::notifyTitleHint(getTitle());
+	if (m_configuration->deprecatedApi()->readBoolEntry("MediaPlayer", "osd", true) && pos < 1000 && pos > 0)
+		m_mediaplayerNotificationService->notifyPlayingTitle(getTitle());
 
-	Changer->setTitle(parse(config_file.readEntry("MediaPlayer", "statusTagString")));
+	Changer->setTitle(parse(m_configuration->deprecatedApi()->readEntry("MediaPlayer", "statusTagString")));
 }
 
 void MediaPlayer::configurationUpdated()
@@ -756,9 +754,9 @@ void MediaPlayer::configurationUpdated()
 	// Statuses switch
 	bool enabled = !Changer->isDisabled();
 
-	if (config_file.readBoolEntry("MediaPlayer", "dockMenu", false))
+	if (m_configuration->deprecatedApi()->readBoolEntry("MediaPlayer", "dockMenu", false))
 	{
-		MenuInventory::instance()
+		m_menuInventory
 			->menu("main")
 			->removeAction(enableMediaPlayerStatuses)
 			->update();
@@ -770,25 +768,25 @@ void MediaPlayer::configurationUpdated()
 			DockedMediaplayerStatus->setChecked(enabled);
 			connect(DockedMediaplayerStatus, SIGNAL(toggled(bool)), this, SLOT(toggleStatuses(bool)));
 
-			DockingManager::instance()->registerModuleAction(DockedMediaplayerStatus);
+			m_dockingMenuActionRepository->addAction(DockedMediaplayerStatus);
 		}
 	}
 	else
 	{
-		MenuInventory::instance()
+		m_menuInventory
 			->menu("main")
 			->addAction(enableMediaPlayerStatuses, KaduMenu::SectionMiscTools, 7)
 			->update();
 
 		if (DockedMediaplayerStatus)
 		{
-			DockingManager::instance()->unregisterModuleAction(DockedMediaplayerStatus);
+			m_dockingMenuActionRepository->removeAction(DockedMediaplayerStatus);
 			delete DockedMediaplayerStatus;
 			DockedMediaplayerStatus = 0;
 		}
 	}
 
-	Changer->changePositionInStatus((MediaPlayerStatusChanger::ChangeDescriptionTo)config_file.readNumEntry("MediaPlayer", "statusPosition"));
+	Changer->changePositionInStatus((MediaPlayerStatusChanger::ChangeDescriptionTo)m_configuration->deprecatedApi()->readNumEntry("MediaPlayer", "statusPosition"));
 }
 
 bool MediaPlayer::playerInfoSupported()
@@ -937,9 +935,9 @@ QString MediaPlayer::getTitle()
 		QString title = playerInfo->getTitle();
 
 		// Lets cut nasty signatures
-		if (config_file.readBoolEntry("MediaPlayer", "signature", true))
+		if (m_configuration->deprecatedApi()->readBoolEntry("MediaPlayer", "signature", true))
 		{
-			QStringList sigList(config_file.readEntry("MediaPlayer", "signatures", DEFAULT_SIGNATURES).split('\n'));
+			QStringList sigList(m_configuration->deprecatedApi()->readEntry("MediaPlayer", "signatures", DEFAULT_SIGNATURES).split('\n'));
 			for (int i = 0; i < sigList.count(); i++)
 				title.remove(sigList[i]);
 		}
@@ -1023,14 +1021,14 @@ QStringList MediaPlayer::getPlayListFiles()
 
 void MediaPlayer::createDefaultConfiguration()
 {
-	config_file.addVariable("MediaPlayer", "chatString", "MediaPlayer: %t [%c / %l]");
-	config_file.addVariable("MediaPlayer", "statusTagString", "%r - %t");
-	config_file.addVariable("MediaPlayer", "osd", true);
-	config_file.addVariable("MediaPlayer", "signature", true);
-	config_file.addVariable("MediaPlayer", "signatures", DEFAULT_SIGNATURES);
-	config_file.addVariable("MediaPlayer", "chatShortcuts", true);
-	config_file.addVariable("MediaPlayer", "dockMenu", false);
-	config_file.addVariable("MediaPlayer", "statusPosition", 0);
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "chatString", "MediaPlayer: %t [%c / %l]");
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "statusTagString", "%r - %t");
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "osd", true);
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "signature", true);
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "signatures", DEFAULT_SIGNATURES);
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "chatShortcuts", true);
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "dockMenu", false);
+	m_configuration->deprecatedApi()->addVariable("MediaPlayer", "statusPosition", 0);
 }
 
 void MediaPlayer::insertFormattedSong()
