@@ -1,32 +1,53 @@
 #pragma once
 
-#include "gui/windows/main-configuration-window.h"
+#include "configuration/configuration-aware-object.h"
+#include "configuration/gui/configuration-ui-handler.h"
 
-#include "mediaplayer_exports.h"
+#include "mediaplayer-exports.h"
+
+#include <QtCore/QMap>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class QAction;
+class QKeyEvent;
 class QMenu;
+class QPushButton;
 class QTimer;
 
 class ActionDescription;
+class Actions;
 class ChatWidget;
 class ChatWidgetRepository;
+class Configuration;
 class CustomInput;
+class DockingMenuActionRepository;
+class IconsManager;
+class PluginInjectedFactory;
+class MediaplayerNotificationService;
+class MenuInventory;
 class PlayerCommands;
 class PlayerInfo;
+class StatusChangerManager;
 class ToolBar;
 class ToolButton;
 class UserGroup;
 
 class MediaPlayerStatusChanger;
 
-class MEDIAPLAYERAPI MediaPlayer : public ConfigurationUiHandler, ConfigurationAwareObject
+class MEDIAPLAYERAPI MediaPlayer : public QObject, ConfigurationAwareObject
 {
 	Q_OBJECT
 
-	static MediaPlayer *Instance;
-
+	QPointer<Actions> m_actions;
 	QPointer<ChatWidgetRepository> m_chatWidgetRepository;
+	QPointer<Configuration> m_configuration;
+	QPointer<DockingMenuActionRepository> m_dockingMenuActionRepository;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<MediaplayerNotificationService> m_mediaplayerNotificationService;
+	QPointer<MenuInventory> m_menuInventory;
+	QPointer<StatusChangerManager> m_statusChangerManager;
 
 	MediaPlayerStatusChanger *Changer;
 	PlayerInfo *playerInfo;
@@ -48,9 +69,6 @@ class MEDIAPLAYERAPI MediaPlayer : public ConfigurationUiHandler, ConfigurationA
 
 	bool isPaused;
 
-	MediaPlayer();
-	virtual ~MediaPlayer();
-
 	int pos();
 
 	/**
@@ -75,6 +93,18 @@ class MEDIAPLAYERAPI MediaPlayer : public ConfigurationUiHandler, ConfigurationA
 	void createDefaultConfiguration();
 
 private slots:
+	INJEQT_SET void setActions(Actions *actions);
+	INJEQT_SET void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setDockingMenuActionRepository(DockingMenuActionRepository *dockingMenuActionRepository);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setMediaplayerNotificationService(MediaplayerNotificationService *mediaplayerNotificationService);
+	INJEQT_SET void setMenuInventory(MenuInventory *menuInventory);
+	INJEQT_SET void setStatusChangerManager(StatusChangerManager *statusChangerManager);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
 	// Proxy methods for 3rd party modules
 	void nextTrack();
 	void prevTrack();
@@ -126,18 +156,15 @@ private slots:
 
 	void mediaPlayerStatusChangerActivated(QAction *sender, bool toggled);
 	void mediaPlayerMenuActivated(QAction *sender, bool toggled);
+	void statusAboutToBeChanged();
 	void toggleStatuses(bool toggled);
 
 protected:
 	void configurationUpdated();
 
 public:
-	static void createInstance();
-	static void destroyInstance();
-
-	static MediaPlayer * instance() { return Instance; }
-
-	void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+	Q_INVOKABLE explicit MediaPlayer(QObject *parent = nullptr);
+	virtual ~MediaPlayer();
 
 	/*
 		Looks for special tags in string 'str' and replaces it by
@@ -181,8 +208,6 @@ public:
 	*/
 	void unregisterMediaPlayer();
 
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
-
 	void titleChanged();
 	void statusChanged();
 	void setInterval(int seconds);
