@@ -75,14 +75,6 @@
     <message>
         <source>With this option enabled you'll be able to control
 your MediaPlayer in chat window by keyboard shortcuts:
-Control+ Enter/Backspace/Left/Right/Up/Down.</source>
-        <translation>Při povolení této volby budete moci ovládat svůj
-přehrávač v okně pro rozhovor klávesovými zkratkami:
-Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
-    </message>
-    <message>
-        <source>With this option enabled you'll be able to control
-your MediaPlayer in chat window by keyboard shortcuts:
 Win+ Enter/Backspace/Left/Right/Up/Down.</source>
         <translation>Při povolení této volby budete moci ovládat svůj
 přehrávač v okně pro rozhovor klávesovými zkratkami:
