@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -74,15 +76,7 @@
         <translation>Other Settings</translation>
     </message>
     <message>
-        <source>With this option enabled you'll be able to control
-your MediaPlayer in chat window by keyboard shortcuts:
-Control+ Enter/Backspace/Left/Right/Up/Down.</source>
-        <translation>With this option enabled you&apos;ll be able to control
-your MediaPlayer in chat window by keyboard shortcuts:
-Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
-    </message>
-    <message>
-        <source>With this option enabled you'll be able to control
+        <source>With this option enabled you&apos;ll be able to control
 your MediaPlayer in chat window by keyboard shortcuts:
 Win+ Enter/Backspace/Left/Right/Up/Down.</source>
         <translation>With this option enabled you&apos;ll be able to control
@@ -225,4 +219,4 @@ Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
         <translation>Send</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
