@@ -76,14 +76,6 @@
     <message>
         <source>With this option enabled you'll be able to control
 your MediaPlayer in chat window by keyboard shortcuts:
-Control+ Enter/Backspace/Left/Right/Up/Down.</source>
-        <translation>Con esta opción habilitada, usted será capaz de controlar
-su reproductor multimedia en la ventana de conversación mediante los accesos rápidos:
-Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
-    </message>
-    <message>
-        <source>With this option enabled you'll be able to control
-your MediaPlayer in chat window by keyboard shortcuts:
 Win+ Enter/Backspace/Left/Right/Up/Down.</source>
         <translation>Con esta opción habilitada, usted será capaz de controlar
 su reproductor multimedia en la ventana de conversación mediante los accesos rápidos:
