@@ -76,14 +76,6 @@
     <message>
         <source>With this option enabled you'll be able to control
 your MediaPlayer in chat window by keyboard shortcuts:
-Control+ Enter/Backspace/Left/Right/Up/Down.</source>
-        <translation>Po włączeniu tej opcji będziesz móc kontrolować
-swój odtwarzacz z okna rozmowy za pomocą następujących skrótów:
-Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
-    </message>
-    <message>
-        <source>With this option enabled you'll be able to control
-your MediaPlayer in chat window by keyboard shortcuts:
 Win+ Enter/Backspace/Left/Right/Up/Down.</source>
         <translation>Po włączeniu tej opcji będziesz móc kontrolować
 swój odtwarzacz z okna rozmowy za pomocą następujących skrótów:
