@@ -76,14 +76,6 @@
     <message>
         <source>With this option enabled you'll be able to control
 your MediaPlayer in chat window by keyboard shortcuts:
-Control+ Enter/Backspace/Left/Right/Up/Down.</source>
-        <translation>Bu seçeneği aktif ettiğinizde konuşma penceresinde Medya 
-Oynatıcınızı klavye kısayol tuşlarıyla kontrol edebilceksiniz:
-Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
-    </message>
-    <message>
-        <source>With this option enabled you'll be able to control
-your MediaPlayer in chat window by keyboard shortcuts:
 Win+ Enter/Backspace/Left/Right/Up/Down.</source>
         <translation>Bu seçeneği aktif ettiğinizde konuşma penceresinde Medya 
 Oynatıcınızı klavye kısayol tuşlarıyla kontrol edebilceksiniz:
