@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 badboy (badboy@gen2.org)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,13 +18,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MPD_CONFIG
-#define MPD_CONFIG
+#pragma once
 
 #include "gui/windows/main-configuration-window.h"
 
+#include <QtCore/QPointer>
+
+class Configuration;
+
 class MPDConfig : public ConfigurationAwareObject
 {
+	QPointer<Configuration> m_configuration;
+
 	QString Host;
 	QString Port;
 	QString Timeout;
@@ -38,6 +41,7 @@ protected:
 
 public:
 	MPDConfig();
+	MPDConfig(Configuration *configuration);
 	virtual ~MPDConfig();
 	
 	const QString & host() const { return Host; }
@@ -45,5 +49,3 @@ public:
 	const QString & timeout() const { return Timeout; }
 
 };
-
-#endif // MPD_CONFIG
