@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,8 +22,10 @@
 
 #include "mpd-mediaplayer.h"
 
+#include "configuration/configuration.h"
+
 MPDMediaPlayer::MPDMediaPlayer(QObject *parent) :
-		PlayerCommands(parent)
+		QObject(parent)
 {
 }
 
@@ -33,16 +33,14 @@ MPDMediaPlayer::~MPDMediaPlayer()
 {
 }
 
-bool MPDMediaPlayer::init(bool firstLoad)
+void MPDMediaPlayer::setConfiguration(Configuration *configuration)
 {
-	Q_UNUSED(firstLoad)
-
-	return MediaPlayer::instance()->registerMediaPlayer(this, this);
+	m_configuration = configuration;
 }
 
-void MPDMediaPlayer::done()
+void MPDMediaPlayer::init()
 {
-	MediaPlayer::instance()->unregisterMediaPlayer();
+	Config = MPDConfig(m_configuration);
 }
 
 mpd_connection * MPDMediaPlayer::mpdConnect()
@@ -273,7 +271,7 @@ QStringList MPDMediaPlayer::getPlayListFiles()
 
 QString MPDMediaPlayer::getPlayerName()
 {
-	return QLatin1String("mpd");
+	return QStringLiteral("mpd");
 }
 
 QString MPDMediaPlayer::getPlayerVersion()
@@ -414,6 +412,4 @@ void MPDMediaPlayer::decrVolume()
 	mpd_connection_free(con);
 }
 
-Q_EXPORT_PLUGIN2(mpd_mediaplayer, MPDMediaPlayer)
-
 #include "moc_mpd-mediaplayer.cpp"
