@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,32 +18,33 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MPD_MEDIAPLAYER
-#define MPD_MEDIAPLAYER
+#pragma once
 
 #include <mpd/client.h>
+#include <injeqt/injeqt.h>
 
-#include "plugin/plugin-root-component.h"
-
-#include "plugins/mediaplayer/player_commands.h"
-#include "plugins/mediaplayer/player_info.h"
+#include "plugins/mediaplayer/player-commands.h"
+#include "plugins/mediaplayer/player-info.h"
 
 #include "mpd-config.h"
 
-class MPDMediaPlayer : public PlayerCommands, PlayerInfo, PluginRootComponent
+class Configuration;
+
+class MPDMediaPlayer : public QObject, public PlayerCommands, public PlayerInfo
 {
 	Q_OBJECT
-	Q_INTERFACES(PluginRootComponent)
-	Q_PLUGIN_METADATA(IID "im.kadu.PluginRootComponent")
+	
+	QPointer<Configuration> m_configuration;
 
 	MPDConfig Config;
 
-public:
-	explicit MPDMediaPlayer(QObject *parent = 0);
-	virtual ~MPDMediaPlayer();
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_INIT void init();
 
-	virtual bool init(bool firstLoad);
-	virtual void done();
+public:
+	Q_INVOKABLE explicit MPDMediaPlayer(QObject *parent = nullptr);
+	virtual ~MPDMediaPlayer();
 
 	mpd_connection * mpdConnect();
 
@@ -76,5 +73,3 @@ public:
 	virtual void decrVolume();
 
 };
-
-#endif // MPD_MEDIAPLAYER
