@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,56 +20,50 @@
  */
 
 #include <QtCore/QFile>
-#include <QtGui/QApplication>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialog>
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
+#include <QtCore/QSettings>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QDialog>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "configuration/gui/configuration-ui-handler-repository.h"
 #include "gui/widgets/configuration/config-group-box.h"
 #include "gui/widgets/configuration/configuration-widget.h"
-#include "misc/kadu-paths.h"
+#include "gui/windows/main-configuration-window.h"
+#include "misc/paths-provider.h"
 
 #include "gui/windows/mpris-player-dialog.h"
 #include "mpris-player-configuration-ui-handler.h"
 #include "mpris-player.h"
 
-MPRISPlayerConfigurationUiHandler *MPRISPlayerConfigurationUiHandler::Instance = 0;
-
-void MPRISPlayerConfigurationUiHandler::registerConfigurationUi()
+MPRISPlayerConfigurationUiHandler::MPRISPlayerConfigurationUiHandler(QObject *parent) :
+		QObject{parent},
+		PlayersBox{}
 {
-	if (Instance)
-		return;
-
-	Instance = new MPRISPlayerConfigurationUiHandler();
-	MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/mprisplayer_mediaplayer.ui"));
-	MainConfigurationWindow::registerUiHandler(Instance);
-}
-
-void MPRISPlayerConfigurationUiHandler::unregisterConfigurationUi()
-{
-	if (!Instance)
-		return;
-
-	MainConfigurationWindow::unregisterUiHandler(Instance);
-	delete Instance;
-	Instance = 0;
-
-	MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/mprisplayer_mediaplayer.ui"));
-}
-
-MPRISPlayerConfigurationUiHandler::MPRISPlayerConfigurationUiHandler() :
-	PlayersBox(0)
-{
-
 }
 
 MPRISPlayerConfigurationUiHandler::~MPRISPlayerConfigurationUiHandler()
 {
+}
 
+void MPRISPlayerConfigurationUiHandler::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void MPRISPlayerConfigurationUiHandler::setMPRISPlayer(MPRISPlayer *mprisPlayer)
+{
+	m_mprisPlayer = mprisPlayer;
+}
+
+void MPRISPlayerConfigurationUiHandler::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
 }
 
 void MPRISPlayerConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
@@ -99,9 +93,9 @@ void MPRISPlayerConfigurationUiHandler::mainConfigurationWindowCreated(MainConfi
 
 	optionsGroupBox->addWidgets(0, options);
 
-	loadPlayersListFromFile(MPRISPlayer::globalPlayersListFileName(), MPRISPlayer::userPlayersListFileName());
+	loadPlayersListFromFile();
 	fillPlayersBox();
-	PlayersBox->setCurrentIndex(PlayersBox->findText(config_file.readEntry("MPRISPlayer", "Player")));
+	PlayersBox->setCurrentIndex(PlayersBox->findText(m_configuration->deprecatedApi()->readEntry("MPRISPlayer", "Player")));
 
 	connect(add, SIGNAL(clicked()), this, SLOT(addPlayer()));
 	connect(edit, SIGNAL(clicked()), this, SLOT(editPlayer()));
@@ -109,20 +103,31 @@ void MPRISPlayerConfigurationUiHandler::mainConfigurationWindowCreated(MainConfi
 	connect(mainConfigurationWindow, SIGNAL(configurationWindowApplied()), this, SLOT(configurationApplied()));
 }
 
-void MPRISPlayerConfigurationUiHandler::loadPlayersListFromFile(const QString &globalFileName, const QString &userFileName)
+void MPRISPlayerConfigurationUiHandler::mainConfigurationWindowDestroyed()
 {
-	PlainConfigFile globalPlayersFile(globalFileName);
-	PlainConfigFile userPlayersFile(userFileName);
+}
 
-	QStringList globalSections = globalPlayersFile.getGroupList();
-	QStringList userSections = userPlayersFile.getGroupList();
+void MPRISPlayerConfigurationUiHandler::mainConfigurationWindowApplied()
+{
+}
+
+void MPRISPlayerConfigurationUiHandler::loadPlayersListFromFile()
+{
+	QSettings userPlayersSettings(MPRISPlayer::userPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	userPlayersSettings.setIniCodec("ISO8859-2");
+
+	QSettings globalPlayersSettings(MPRISPlayer::globalPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	globalPlayersSettings.setIniCodec("ISO8859-2");
+
+	QStringList globalSections = globalPlayersSettings.childGroups();
+	QStringList userSections = userPlayersSettings.childGroups();
 
 	PlayersMap.clear();
 
 	foreach (const QString &section, userSections)
 	{
-		QString player = userPlayersFile.readEntry(section, "player");
-		QString service = userPlayersFile.readEntry(section, "service");
+		QString player = userPlayersSettings.value(section + "/player").toString();
+		QString service = userPlayersSettings.value(section + "/service").toString();
 
 		if (!player.isEmpty() && !service.isEmpty())
 			PlayersMap.insert(player, service);
@@ -133,8 +138,8 @@ void MPRISPlayerConfigurationUiHandler::loadPlayersListFromFile(const QString &g
 		if (userSections.contains(globalSection))
 			continue;
 
-		QString player = globalPlayersFile.readEntry(globalSection, "player");
-		QString service = globalPlayersFile.readEntry(globalSection, "service");
+		QString player = globalPlayersSettings.value(globalSection + "/player").toString();
+		QString service = globalPlayersSettings.value(globalSection + "/service").toString();
 
 		if (!player.isEmpty() && !service.isEmpty())
 			PlayersMap.insert(player, service);
@@ -166,14 +171,15 @@ void MPRISPlayerConfigurationUiHandler::addPlayer()
 	if (newPlayer.isEmpty() || newService.isEmpty())
 		return;
 
-	QString oldPlayerName = config_file.readEntry("MPRISPlayer", "Player");
-	PlainConfigFile userPlayersFile(MPRISPlayer::userPlayersListFileName());
+	QString oldPlayerName = m_configuration->deprecatedApi()->readEntry("MPRISPlayer", "Player");
+	QSettings userPlayersSettings(MPRISPlayer::userPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	userPlayersSettings.setIniCodec("ISO8859-2");
 
-	userPlayersFile.writeEntry(newPlayer, "player", newPlayer);
-	userPlayersFile.writeEntry(newPlayer, "service", newService);
-	userPlayersFile.sync();
+	userPlayersSettings.setValue(newPlayer + "/player", newPlayer);
+	userPlayersSettings.setValue(newPlayer + "/service", newService);
+	userPlayersSettings.sync();
 
-	loadPlayersListFromFile(MPRISPlayer::globalPlayersListFileName(), MPRISPlayer::userPlayersListFileName());
+	loadPlayersListFromFile();
 	fillPlayersBox();
 
 	PlayersBox->setCurrentIndex(PlayersBox->findText(oldPlayerName));
@@ -201,29 +207,31 @@ void MPRISPlayerConfigurationUiHandler::editPlayer()
 	if ((newPlayer.isEmpty() || newService.isEmpty()) || (newPlayer == oldPlayer && oldService == newService))
 		return;
 
-	PlainConfigFile globalPlayersFile(MPRISPlayer::globalPlayersListFileName());
-	PlainConfigFile userPlayersFile(MPRISPlayer::userPlayersListFileName());
-	QStringList sections = globalPlayersFile.getGroupList();
+	QSettings globalPlayersSettings(MPRISPlayer::globalPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	globalPlayersSettings.setIniCodec("ISO8859-2");
+	QSettings userPlayersSettings(MPRISPlayer::userPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	userPlayersSettings.setIniCodec("ISO8859-2");
+	QStringList sections = globalPlayersSettings.childGroups();
 
 	if (!sections.contains(oldPlayer))
-		sections = userPlayersFile.getGroupList();
+		sections = userPlayersSettings.childGroups();
 
 	foreach (const QString &section, sections)
 	{
 		if (section != oldPlayer)
 			continue;
 
-		userPlayersFile.writeEntry(section, "player", QString());
-		userPlayersFile.writeEntry(section, "service", QString());
+		userPlayersSettings.remove(section + "/player");
+		userPlayersSettings.remove(section + "/service");
 
-		userPlayersFile.writeEntry(newPlayer, "player", newPlayer);
-		userPlayersFile.writeEntry(newPlayer, "service", newService);
+		userPlayersSettings.setValue(newPlayer + "/player", newPlayer);
+		userPlayersSettings.setValue(newPlayer + "/service", newService);
 		break;
 	}
 
-	userPlayersFile.sync();
+	userPlayersSettings.sync();
 
-	loadPlayersListFromFile(MPRISPlayer::globalPlayersListFileName(), MPRISPlayer::userPlayersListFileName());
+	loadPlayersListFromFile();
 	fillPlayersBox();
 
 	PlayersBox->setCurrentIndex(PlayersBox->findText(newPlayer));
@@ -233,27 +241,29 @@ void MPRISPlayerConfigurationUiHandler::delPlayer()
 {
 	QString playerToRemove = PlayersBox->currentText();
 
-	PlainConfigFile globalPlayersFile(MPRISPlayer::globalPlayersListFileName());
-	PlainConfigFile userPlayersFile(MPRISPlayer::userPlayersListFileName());
+	QSettings globalPlayersSettings(MPRISPlayer::globalPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	globalPlayersSettings.setIniCodec("ISO8859-2");
+	QSettings userPlayersSettings(MPRISPlayer::userPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+	userPlayersSettings.setIniCodec("ISO8859-2");
 
-	QStringList sections = globalPlayersFile.getGroupList();
+	QStringList sections = globalPlayersSettings.childGroups();
 
 	if (!sections.contains(playerToRemove))
-		sections = userPlayersFile.getGroupList();
+		sections = userPlayersSettings.childGroups();
 
 	foreach (const QString &section, sections)
 	{
 		if (section != playerToRemove)
 			continue;
 
-		userPlayersFile.writeEntry(section, "player", QString());
-		userPlayersFile.writeEntry(section, "service", QString());
+		userPlayersSettings.remove(section + "/player");
+		userPlayersSettings.remove(section + "/service");
 		break;
 	}
 
-	userPlayersFile.sync();
+	userPlayersSettings.sync();
 
-	loadPlayersListFromFile(MPRISPlayer::globalPlayersListFileName(), MPRISPlayer::userPlayersListFileName());
+	loadPlayersListFromFile();
 	fillPlayersBox();
 
 	PlayersBox->setCurrentIndex(-1);
@@ -261,10 +271,10 @@ void MPRISPlayerConfigurationUiHandler::delPlayer()
 
 void MPRISPlayerConfigurationUiHandler::configurationApplied()
 {
-	config_file.writeEntry("MPRISPlayer", "Player", PlayersBox->currentText());
-	config_file.writeEntry("MPRISPlayer", "Service", PlayersMap.value(PlayersBox->currentText()));
+	m_configuration->deprecatedApi()->writeEntry("MPRISPlayer", "Player", PlayersBox->currentText());
+	m_configuration->deprecatedApi()->writeEntry("MPRISPlayer", "Service", PlayersMap.value(PlayersBox->currentText()));
 
-	MPRISPlayer::instance()->configurationApplied();
+	m_mprisPlayer->configurationApplied();
 }
 
 #include "moc_mpris-player-configuration-ui-handler.cpp"
