@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,40 +18,51 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MPRIS_PLAYER_CONFIGURATION_UI_HANDLER_H
-#define MPRIS_PLAYER_CONFIGURATION_UI_HANDLER_H
+#pragma once
 
 #include <QtCore/QMap>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 #include "configuration/configuration-aware-object.h"
-#include "configuration/configuration-file.h"
-#include "gui/windows/main-configuration-window.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "configuration/gui/configuration-ui-handler.h"
+
+class Configuration;
+class MPRISPlayer;
+class PathsProvider;
 
 class QComboBox;
 
-class MPRISPlayerConfigurationUiHandler : public ConfigurationUiHandler
+class MPRISPlayerConfigurationUiHandler : public QObject, public ConfigurationUiHandler
 {
 	Q_OBJECT
-
-	static MPRISPlayerConfigurationUiHandler *Instance;
+	
+	QPointer<Configuration> m_configuration;
+	QPointer<MPRISPlayer> m_mprisPlayer;
+	QPointer<PathsProvider> m_pathsProvider;
 
 	QMap<QString, QString> PlayersMap;
 	QComboBox *PlayersBox;
 
-	MPRISPlayerConfigurationUiHandler();
-	virtual ~MPRISPlayerConfigurationUiHandler();
-
-	void loadPlayersListFromFile(const QString &globalFileName, const QString &userFileName);
+	void loadPlayersListFromFile();
 	void fillPlayersBox();
 
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setMPRISPlayer(MPRISPlayer *mprisPlayer);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+
 	void configurationApplied();
 
 public:
-	static void registerConfigurationUi();
-	static void unregisterConfigurationUi();
+	Q_INVOKABLE explicit MPRISPlayerConfigurationUiHandler(QObject *parent = nullptr);
+	virtual ~MPRISPlayerConfigurationUiHandler();
 
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
+	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow) override;
+	virtual void mainConfigurationWindowDestroyed() override;
+	virtual void mainConfigurationWindowApplied() override;
 
 public slots:
 	void addPlayer();
@@ -61,5 +70,3 @@ public slots:
 	void delPlayer();
 
 };
-
-#endif /* MPRIS_PLAYER_CONFIGURATION_UI_HANDLER_H */
