@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,54 +21,59 @@
  */
 
 #include <QtCore/QFile>
+#include <QtCore/QSettings>
 
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/windows/main-configuration-window.h"
 #include "plugin/metadata/plugin-metadata.h"
-#include "plugin/state/plugin-state.h"
 #include "plugin/state/plugin-state-service.h"
+#include "plugin/state/plugin-state.h"
 
+#include "plugins/mediaplayer/mediaplayer-plugin-object.h"
 #include "plugins/mediaplayer/mediaplayer.h"
 
 #include "mpris-player.h"
 
 const QString MPRISPlayer::UserPlayersListFile = "mprisplayer-players.data";
 const QString MPRISPlayer::GlobalPlayersListFile = "plugins/data/mprisplayer_mediaplayer/" + MPRISPlayer::UserPlayersListFile;
-MPRISPlayer *MPRISPlayer::Instance = 0;
-
-void MPRISPlayer::createInstance()
-{
-	if (!Instance)
-		Instance = new MPRISPlayer();
-
-	Instance->configurationApplied();
-}
-
-void MPRISPlayer::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
 
 MPRISPlayer::MPRISPlayer(QObject *parent) :
 		MPRISMediaPlayer(parent)
+{
+}
+
+MPRISPlayer::~MPRISPlayer()
+{
+}
+
+void MPRISPlayer::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void MPRISPlayer::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
+void MPRISPlayer::setPluginStateService(PluginStateService *pluginStateService)
+{
+	m_pluginStateService = pluginStateService;
+}
+
+void MPRISPlayer::init()
 {
 	prepareUserPlayersFile();
 	replacePlugin();
 }
 
-MPRISPlayer::~MPRISPlayer()
-{
-
-}
-
 void MPRISPlayer::prepareUserPlayersFile()
 {
-	if (QFile::exists(MPRISPlayer::userPlayersListFileName()))
+	if (QFile::exists(MPRISPlayer::userPlayersListFileName(m_pathsProvider)))
 		return;
 
-	QFile userFile(MPRISPlayer::userPlayersListFileName());
+	QFile userFile(MPRISPlayer::userPlayersListFileName(m_pathsProvider));
 	if (!userFile.open(QIODevice::ReadWrite))
 		return;
 
@@ -89,10 +94,10 @@ void MPRISPlayer::replacePlugin()
 	foreach (const QString &value, replaceMap)
 	{
 		QString key = replaceMap.key(value);
-		if (Core::instance()->pluginStateService()->pluginState(key) == PluginState::Enabled)
+		if (m_pluginStateService->pluginState(key) == PluginState::Enabled)
 		{
 			choosePlayer(key, value);
-			Core::instance()->pluginStateService()->setPluginState(key, PluginState::Disabled);
+			m_pluginStateService->setPluginState(key, PluginState::Disabled);
 			break;
 		}
 	}
@@ -100,38 +105,40 @@ void MPRISPlayer::replacePlugin()
 
 void MPRISPlayer::choosePlayer(const QString &key, const QString &value)
 {
-	PlainConfigFile globalPlayersFile(MPRISPlayer::globalPlayersListFileName());
-	PlainConfigFile userPlayersFile(MPRISPlayer::userPlayersListFileName());
-
 	// Save service value from mpris_mediaplayer module
 	if (key == "mpris_mediaplayer")
 	{
-		QString oldMPRISService = config_file.readEntry("MediaPlayer", "MPRISService");
+		QString oldMPRISService = m_configuration->deprecatedApi()->readEntry("MediaPlayer", "MPRISService");
+		QSettings userPlayersSettings(MPRISPlayer::userPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+		userPlayersSettings.setIniCodec("ISO8859-2");
 
-		userPlayersFile.writeEntry(value, "player", value);
-		userPlayersFile.writeEntry(value, "service", oldMPRISService);
-		userPlayersFile.sync();
+		userPlayersSettings.setValue(value + "/player", value);
+		userPlayersSettings.setValue(value +  "/service", oldMPRISService);
+		userPlayersSettings.sync();
 
-		config_file.writeEntry("MPRISPlayer", "Player", value);
-		config_file.writeEntry("MPRISPlayer", "Service", oldMPRISService);
+		m_configuration->deprecatedApi()->writeEntry("MPRISPlayer", "Player", value);
+		m_configuration->deprecatedApi()->writeEntry("MPRISPlayer", "Service", oldMPRISService);
 	}
 	else // Choose player based on old module loaded.
 	{
-		config_file.writeEntry("MPRISPlayer", "Player", value);
-		config_file.writeEntry("MPRISPlayer", "Service", globalPlayersFile.readEntry(value, "service"));
+		QSettings globalPlayersSettings(MPRISPlayer::globalPlayersListFileName(m_pathsProvider), QSettings::IniFormat);
+		globalPlayersSettings.setIniCodec("ISO8859-2");
+
+		m_configuration->deprecatedApi()->writeEntry("MPRISPlayer", "Player", value);
+		m_configuration->deprecatedApi()->writeEntry("MPRISPlayer", "Service", globalPlayersSettings.value(value + "/service").toString());
 	}
 }
 
 void MPRISPlayer::configurationApplied()
 {
-	setName(config_file.readEntry("MPRISPlayer", "Player"));
-	setService(config_file.readEntry("MPRISPlayer", "Service"));
+	auto name = m_configuration->deprecatedApi()->readEntry("MPRISPlayer", "Player");
+	setName(name);
+	setService(m_configuration->deprecatedApi()->readEntry("MPRISPlayer", "Service"));
 
-	if (!MediaPlayer::instance()->registerMediaPlayer(MPRISPlayer::instance(), MPRISPlayer::instance()))
-	{
-		MediaPlayer::instance()->unregisterMediaPlayer();
-		MediaPlayer::instance()->registerMediaPlayer(MPRISPlayer::instance(), MPRISPlayer::instance());
-	}
+	if (name == "Audacious")
+		m_mediaPlayer->setInterval(5);
+	else
+		m_mediaPlayer->setInterval(0);
 }
 
 #include "moc_mpris-player.cpp"
