@@ -1,10 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,44 +20,53 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MPRIS_PLAYER_H
-#define MPRIS_PLAYER_H
+#pragma once
 
 #include <QtCore/QMap>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 #include "configuration/configuration-aware-object.h"
-#include "misc/kadu-paths.h"
+#include "core/core.h"
+#include "misc/paths-provider.h"
 
 #include "mpris_mediaplayer.h"
 
+class Configuration;
+class MediaPlayer;
+class PathsProvider;
+class PluginStateService;
+
 class QString;
 
 class MPRISPlayer : public MPRISMediaPlayer
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(MPRISPlayer)
 
-	static MPRISPlayer *Instance;
 	static const QString UserPlayersListFile;
 	static const QString GlobalPlayersListFile;
 
-	explicit MPRISPlayer(QObject *parent = 0);
-	virtual ~MPRISPlayer();
+	QPointer<Configuration> m_configuration;
+	QPointer<PathsProvider> m_pathsProvider;
+	QPointer<PluginStateService> m_pluginStateService;
 
 	void prepareUserPlayersFile();
 	void replacePlugin();
 	void choosePlayer(const QString &key, const QString &value);
 
-public:
-	static void createInstance();
-	static void destroyInstance();
-	static MPRISPlayer *instance() { return Instance; }
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+	INJEQT_SET void setPluginStateService(PluginStateService *pluginStateService);
+	INJEQT_INIT void init();
 
-	static QString userPlayersListFileName() { return KaduPaths::instance()->profilePath() + UserPlayersListFile; }
-	static QString globalPlayersListFileName() { return KaduPaths::instance()->dataPath() + GlobalPlayersListFile; }
+public:
+	static QString userPlayersListFileName(PathsProvider *pathsProvider) { return pathsProvider->profilePath() + UserPlayersListFile; }
+	static QString globalPlayersListFileName(PathsProvider *pathsProvider) { return pathsProvider->dataPath() + GlobalPlayersListFile; }
+
+	Q_INVOKABLE explicit MPRISPlayer(QObject *parent = nullptr);
+	virtual ~MPRISPlayer();
 
 	void configurationApplied();
 
 };
-
-#endif /* MPRIS_PLAYER_H */
