@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -39,13 +34,17 @@
 
 #include "mpris_controller.h"
 
-MPRISController::MPRISController(const QString &service, QObject *parent) :
-		QObject(parent), CurrentStatus(StatusStopped), Active(false), Service(service)
+MPRISController::MPRISController(MediaPlayer *mediaPlayer, const QString &service, QObject *parent) :
+		QObject(parent),
+		m_mediaPlayer(mediaPlayer),
+		CurrentStatus(StatusStopped),
+		Active(false),
+		Service(service)
 {
 	QDBusConnection bus = QDBusConnection::sessionBus();
 
 	bus.connect("org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus",
-	            QLatin1String("NameOwnerChanged"), this, SLOT(nameOwnerChanged(QString, QString, QString)));
+	            QStringLiteral("NameOwnerChanged"), this, SLOT(nameOwnerChanged(QString, QString, QString)));
 
 	if (bus.interface()->registeredServiceNames().value().contains(Service))
 		activate();
@@ -56,7 +55,7 @@ MPRISController::~MPRISController()
 	QDBusConnection bus = QDBusConnection::sessionBus();
 
 	bus.disconnect("org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus",
-	               QLatin1String("NameOwnerChanged"), this, SLOT(nameOwnerChanged(QString, QString, QString)));
+	               QStringLiteral("NameOwnerChanged"), this, SLOT(nameOwnerChanged(QString, QString, QString)));
 }
 
 void MPRISController::call(const QString &methodName)
@@ -110,7 +109,8 @@ void MPRISController::activate()
 	fetchStatus();
 	fetchMetadata();
 
-	MediaPlayer::instance()->statusChanged();
+	if (m_mediaPlayer)
+		m_mediaPlayer->statusChanged();
 }
 
 void MPRISController::deactivate()
@@ -122,7 +122,8 @@ void MPRISController::deactivate()
 
 	updateStatus(StatusStopped);
 
-	MediaPlayer::instance()->statusChanged();
+	if (m_mediaPlayer)
+		m_mediaPlayer->statusChanged();
 }
 
 void MPRISController::updateStatus(const PlayerStatus newStatus)
@@ -131,7 +132,9 @@ void MPRISController::updateStatus(const PlayerStatus newStatus)
 		return;
 
 	CurrentStatus = newStatus;
-	MediaPlayer::instance()->statusChanged();
+
+	if (m_mediaPlayer)
+		m_mediaPlayer->statusChanged();
 }
 
 void MPRISController::updateStatus(const QString &newStatus)
@@ -161,7 +164,9 @@ TrackInfo MPRISController::toTrackInfo(const QVariantMap &metadata) const
 void MPRISController::updateMetadata(const QVariantMap &metadata)
 {
 	CurrentTrack = toTrackInfo(metadata);
-	MediaPlayer::instance()->titleChanged();
+
+	if (m_mediaPlayer)
+		m_mediaPlayer->titleChanged();
 }
 
 void MPRISController::nameOwnerChanged(const QString &service, const QString &previousOwner, const QString &currentOwner)
