@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,24 +23,27 @@
  * See http://mpris.org/ for more details about the standard
  */
 
-#ifndef MPRIS_MEDIAPLAYER_H
-#define MPRIS_MEDIAPLAYER_H
+#pragma once
 
-#include "plugins/mediaplayer/player_commands.h"
-#include "plugins/mediaplayer/player_info.h"
+#include "plugins/mediaplayer/player-commands.h"
+#include "plugins/mediaplayer/player-info.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class MediaPlayer;
 class MPRISController;
 
-class MPRISMediaPlayer : public PlayerCommands, public PlayerInfo
+class MPRISMediaPlayer : public QObject, public PlayerCommands, public PlayerInfo
 {
 	Q_OBJECT
 
-	MPRISController *controller;
+	QPointer<MPRISController> m_controller;
 	QString service;
 	QString name;
 
 public:
-	explicit MPRISMediaPlayer(QObject *parent = 0);
+	explicit MPRISMediaPlayer(QObject *parent = nullptr);
 	virtual ~MPRISMediaPlayer();
 
 	QString getTitle();
@@ -72,6 +70,10 @@ public:
 	void incrVolume();
 	void decrVolume();
 
-};
+protected:
+	QPointer<MediaPlayer> m_mediaPlayer;
 
-#endif // MPRIS_MEDIAPLAYER_H
+private slots:
+	INJEQT_SET void setMediaPlayer(MediaPlayer *mediaPlayer);
+
+};
