@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -13,4 +15,4 @@
         <translation>Put the played sounds separate by space, _ for pause, eg. D2 C1# G0</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
