@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,41 +21,20 @@
 
 #include <QtGui/QImageWriter>
 
-#include "misc/kadu-paths.h"
+#include "configuration/gui/configuration-ui-handler-repository.h"
+#include "core/core.h"
+#include "core/core.h"
+#include "misc/paths-provider.h"
 
 #include "gui/widgets/configuration/config-combo-box.h"
 #include "gui/widgets/configuration/configuration-widget.h"
+#include "gui/windows/main-configuration-window.h"
 
 #include "screenshot-configuration-ui-handler.h"
 
-ScreenShotConfigurationUiHandler *ScreenShotConfigurationUiHandler::Instance = 0;
-
-void ScreenShotConfigurationUiHandler::registerConfigurationUi()
-{
-	if (Instance)
-		return;
-
-	Instance = new ScreenShotConfigurationUiHandler();
-
-	MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/screenshot.ui"));
-	MainConfigurationWindow::registerUiHandler(Instance);
-}
-
-void ScreenShotConfigurationUiHandler::unregisterConfigurationUi()
-{
-	if (Instance)
-		MainConfigurationWindow::unregisterUiHandler(Instance);
-
-	delete Instance;
-	Instance = 0;
-
-	MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/screenshot.ui"));
-}
-
 ScreenShotConfigurationUiHandler::ScreenShotConfigurationUiHandler(QObject *parent) :
-		ConfigurationUiHandler()
+		QObject{parent}
 {
-	Q_UNUSED(parent)
 }
 
 ScreenShotConfigurationUiHandler::~ScreenShotConfigurationUiHandler()
@@ -64,8 +43,9 @@ ScreenShotConfigurationUiHandler::~ScreenShotConfigurationUiHandler()
 
 void ScreenShotConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
 {
-	connect(mainConfigurationWindow->widget()->widgetById("screenshot/enableSizeLimit"), SIGNAL(toggled(bool)),
-			mainConfigurationWindow->widget()->widgetById("screenshot/sizeLimit"), SLOT(setEnabled(bool)));
+	QObject::connect(
+		mainConfigurationWindow->widget()->widgetById("screenshot/enableSizeLimit"), SIGNAL(toggled(bool)),
+		mainConfigurationWindow->widget()->widgetById("screenshot/sizeLimit"), SLOT(setEnabled(bool)));
 
 	QStringList opts;
 	QList<QByteArray> byteArrayOpts = QImageWriter::supportedImageFormats();
@@ -78,4 +58,12 @@ void ScreenShotConfigurationUiHandler::mainConfigurationWindowCreated(MainConfig
 		formats->setItems(opts, opts);
 }
 
+void ScreenShotConfigurationUiHandler::mainConfigurationWindowDestroyed()
+{
+}
+
+void ScreenShotConfigurationUiHandler::mainConfigurationWindowApplied()
+{
+}
+
 #include "moc_screenshot-configuration-ui-handler.cpp"
