@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,27 +18,23 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SCREENSHOT_CONFIGURATION_UI_HANDLER_H
-#define SCREENSHOT_CONFIGURATION_UI_HANDLER_H
+#pragma once
 
-#include "gui/windows/main-configuration-window.h"
+#include "configuration/gui/configuration-ui-handler.h"
 
-class ScreenShotConfigurationUiHandler : public ConfigurationUiHandler
+#include <QtCore/QObject>
+
+class ScreenShotConfigurationUiHandler : public QObject, public ConfigurationUiHandler
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(ScreenShotConfigurationUiHandler)
-
-	static ScreenShotConfigurationUiHandler *Instance;
-
-	explicit ScreenShotConfigurationUiHandler(QObject *parent = 0);
-	virtual ~ScreenShotConfigurationUiHandler();
 
 public:
-	static void registerConfigurationUi();
-	static void unregisterConfigurationUi();
+	Q_INVOKABLE explicit ScreenShotConfigurationUiHandler(QObject *parent = nullptr);
+	virtual ~ScreenShotConfigurationUiHandler();
 
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
+private:
+	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow) override;
+	virtual void mainConfigurationWindowDestroyed() override;
+	virtual void mainConfigurationWindowApplied() override;
 
 };
-
-#endif // SCREENSHOT_CONFIGURATION_UI_HANDLER_H
