@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,33 +20,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QMenu>
+#include <QtWidgets/QMenu>
 
 #include "accounts/account.h"
+#include "core/core.h"
 #include "gui/actions/action.h"
 #include "gui/widgets/chat-edit-box.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/protocol.h"
 
+#include "configuration/screen-shot-configuration.h"
 #include "screenshot.h"
 
 #include "screenshot-action.h"
 
-ScreenshotAction::ScreenshotAction(QObject *parent) :
-		ActionDescription(parent)
+ScreenshotAction::ScreenshotAction(ScreenShotConfiguration *screenShotConfiguration, QObject *parent) :
+		ActionDescription(parent),
+		m_screenShotConfiguration{screenShotConfiguration}
 {
 	setType(ActionDescription::TypeChat);
 	setName("ScreenShotAction");
 	setIcon(KaduIcon("external_modules/screenshot-camera-photo"));
 	setText(tr("ScreenShot"));
-
-	registerAction();
 }
 
 ScreenshotAction::~ScreenshotAction()
 {
 }
 
+void ScreenshotAction::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
 void ScreenshotAction::actionInstanceCreated(Action *action)
 {
 	ChatEditBox *chatEditBox = qobject_cast<ChatEditBox *>(action->parent());
@@ -64,9 +71,7 @@ void ScreenshotAction::actionInstanceCreated(Action *action)
 	QMenu *menu = new QMenu();
 	menu->addAction(tr("Simple Shot"), this, SLOT(takeStandardShotSlot()))->setData(chatWidgetData);
 	menu->addAction(tr("With Chat Window Hidden"), this, SLOT(takeShotWithChatWindowHiddenSlot()))->setData(chatWidgetData);
-#ifndef Q_OS_MAC
 	menu->addAction(tr("Window Shot"), this, SLOT(takeWindowShotSlot()))->setData(chatWidgetData);
-#endif
 	action->setMenu(menu);
 }
 
@@ -102,6 +107,7 @@ ChatWidget * ScreenshotAction::findChatWidget(QObject *object)
 	QAction *action = qobject_cast<QAction *>(object);
 	if (!action)
 		return 0;
+
 	return static_cast<ChatWidget *>((void*)(action->data().toLongLong()));
 }
 
@@ -111,21 +117,21 @@ void ScreenshotAction::takeStandardShotSlot(ChatWidget *chatWidget)
 	if (!chatWidget)
 		chatWidget = findChatWidget(sender());
 	if (chatWidget)
-		(new ScreenShot(chatWidget))->takeStandardShot();
+		(m_pluginInjectedFactory->makeInjected<ScreenShot>(m_screenShotConfiguration, chatWidget))->takeStandardShot();
 }
 
 void ScreenshotAction::takeShotWithChatWindowHiddenSlot()
 {
 	ChatWidget *chatWidget = findChatWidget(sender());
 	if (chatWidget)
-		(new ScreenShot(chatWidget))->takeShotWithChatWindowHidden();
+		(m_pluginInjectedFactory->makeInjected<ScreenShot>(m_screenShotConfiguration, chatWidget))->takeShotWithChatWindowHidden();
 }
 
 void ScreenshotAction::takeWindowShotSlot()
 {
 	ChatWidget *chatWidget = findChatWidget(sender());
 	if (chatWidget)
-		(new ScreenShot(chatWidget))->takeWindowShot();
+		(m_pluginInjectedFactory->makeInjected<ScreenShot>(m_screenShotConfiguration, chatWidget))->takeWindowShot();
 }
 
 #include "moc_screenshot-action.cpp"
