@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,22 +18,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SCREENSHOT_ACTION_H
-#define SCREENSHOT_ACTION_H
+#pragma once
 
-#include <QtGui/QAction>
+#include <QtCore/QPointer>
+#include <QtWidgets/QAction>
 
 #include "gui/actions/action-description.h"
 
 class ChatWidget;
+class PluginInjectedFactory;
+class ScreenShotConfiguration;
 
 class ScreenshotAction : public ActionDescription
 {
 	Q_OBJECT
 
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<ScreenShotConfiguration> m_screenShotConfiguration;
+
 	ChatWidget * findChatWidget(QObject *obejct);
 
 private slots:
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+
 	void takeStandardShotSlot(ChatWidget *chatWidget = 0);
 	void takeShotWithChatWindowHiddenSlot();
 	void takeWindowShotSlot();
@@ -45,9 +51,7 @@ protected:
 	virtual void updateActionState(Action *action);
 
 public:
-	explicit ScreenshotAction(QObject *parent);
+	explicit ScreenshotAction(ScreenShotConfiguration *screenShotConfiguration, QObject *parent);
 	virtual ~ScreenshotAction();
 
 };
-
-#endif // SCREENSHOT_ACTION_H
