@@ -1,13 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,9 +25,9 @@
 #include <QtCore/QBuffer>
 #include <QtCore/QTimer>
 #include <QtGui/QCursor>
-#include <QtGui/QGraphicsPixmapItem>
-#include <QtGui/QGraphicsProxyWidget>
 #include <QtGui/QResizeEvent>
+#include <QtWidgets/QGraphicsPixmapItem>
+#include <QtWidgets/QGraphicsProxyWidget>
 
 #include "gui/graphics-items/selection-frame-item.h"
 #include "gui/widgets/screenshot-tool-box.h"
