@@ -2,9 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +23,7 @@
 #ifndef CROP_IMAGE_WIDGET_H
 #define CROP_IMAGE_WIDGET_H
 
-#include <QtGui/QGraphicsView>
+#include <QtWidgets/QGraphicsView>
 
 #include "gui/graphics-items/handler-rect-item.h"
 
@@ -79,7 +78,7 @@ protected:
 	virtual void showEvent(QShowEvent *event);
 
 public:
-	explicit CropImageWidget(QWidget *parent = 0);
+	explicit CropImageWidget(QWidget *parent = nullptr);
 	virtual ~CropImageWidget();
 
 	void setPixmap(QPixmap pixmap);
