@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,17 +22,18 @@
 
 #include <QtCore/QBuffer>
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QHBoxLayout>
 #include <QtGui/QMouseEvent>
-#ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtWidgets/QHBoxLayout>
+#if defined(Q_OS_UNIX)
+#include <QtX11Extras/QX11Info>
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
 #endif
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "debug.h"
 
 #include "gui/widgets/crop-image-widget.h"
@@ -47,7 +48,7 @@ ScreenshotWidget::ScreenshotWidget(QWidget *parent) :
 	setWindowRole("kadu-screenshot");
 
 	setFocusPolicy(Qt::StrongFocus);
-#ifdef Q_WS_X11
+#if defined(Q_OS_UNIX)
 	// set always-on-top and force taskbar and pager skipping
 	Atom win_state = XInternAtom( QX11Info::display(), "_NET_WM_STATE", False );
 	Atom win_state_setting[] =
