@@ -2,10 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +24,7 @@
 #define SCREENSHOT_WIDGET_H
 
 #include <QtGui/QPixmap>
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 #include "screenshot-mode.h"
 
@@ -49,7 +47,7 @@ protected:
 	virtual void keyPressEvent(QKeyEvent *event);
 
 public:
-	explicit ScreenshotWidget(QWidget *parent = 0);
+	explicit ScreenshotWidget(QWidget *parent = nullptr);
 	virtual ~ScreenshotWidget();
 
 	void setShotMode(ScreenShotMode shotMode);
