@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,17 +26,15 @@
 #include <QtGui/QBitmap>
 #include <QtGui/QPainter>
 #include <QtGui/QPixmap>
-#ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#if defined(Q_OS_UNIX)
+#include <QtX11Extras/QX11Info>
 #else
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
 #endif
-#ifdef Q_OS_MAC
-#include <Carbon/Carbon.h>
-#endif
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
 #include <QtCore/QLibrary>
+#include <QtWinExtras/QtWinExtras>
 #include <windows.h>
 #undef MessageBox
 typedef BOOL (WINAPI *PrintWindow_t)(HWND hwnd, HDC  hdcBlt, UINT nFlags);
@@ -47,7 +45,7 @@ typedef BOOL (WINAPI *PrintWindow_t)(HWND hwnd, HDC  hdcBlt, UINT nFlags);
 
 #define MINIMUM_SIZE 8
 
-#ifdef Q_WS_X11
+#if defined(Q_OS_UNIX)
 
 //////////////////////////////////////////////////////////////////
 // Code below is copied (and changed a little) from KSnapShot,
@@ -228,7 +226,7 @@ Window PixmapGrabber::findRealWindow( Window w, int depth )
 // End of code copied from KSnapShot
 //////////////////////////////////////////////////////////////////
 
-#elif defined Q_OS_WIN32
+#elif defined Q_OS_WIN
 
 QPixmap PixmapGrabber::grabCurrent()
 {
@@ -283,7 +281,7 @@ QPixmap PixmapGrabber::grabCurrent()
 			DeleteDC(hdcMem);
 			ReleaseDC(winId, hDC);
 
-			QPixmap ret = QPixmap::fromWinHBITMAP(hBitmap);
+			QPixmap ret = QtWin::fromHBITMAP(hBitmap);
 
 			DeleteObject(hBitmap);
 			return ret;
@@ -293,30 +291,4 @@ QPixmap PixmapGrabber::grabCurrent()
 		return QPixmap();
 
 }
-
-#elif defined Q_OS_MAC
-
-QPixmap PixmapGrabber::grabCurrent()
-{
-	WindowRef window;
-	Point mousePos;
-	Rect rect;
-	int err;
-
-	GetGlobalMouse(&mousePos);
-
-	/* This code works only with our application windows.
-	 * In order to capture other application's windows the private CoreGraphics API must be used.
-	 */
-	err = MacFindWindow(mousePos, &window);
-	err = GetWindowBounds(window, kWindowStructureRgn, &rect);
-	if (err == noErr)
-	{
-		QPixmap desktop = QPixmap::grabWindow(QApplication::desktop()->winId());
-		return desktop.copy(rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top);
-	}
-	else
-		return QPixmap();
-}
-
 #endif
