@@ -2,9 +2,7 @@
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +22,7 @@
 #ifndef PIXMAP_GRABBER_H
 #define PIXMAP_GRABBER_H
 
-#ifdef Q_WS_X11
+#if defined(Q_OS_UNIX)
 #include <X11/extensions/shape.h>
 #include <vector>
 #endif
@@ -39,7 +37,7 @@ class PixmapGrabber
 public:
 	// Methods from KSnapShot
 	static QPixmap grabCurrent();
-#ifdef Q_WS_X11
+#if defined(Q_OS_UNIX)
 	static Window findRealWindow(Window w, int depth = 0);
 	static void getWindowsRecursive(std::vector<QRect> &windows, Window w, int rx = 0, int ry = 0, int depth = 0);
 	static QPixmap grabWindow(Window child, int x, int y, uint w, uint h, uint border);
