@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,11 +24,14 @@
 
 #include "configuration/screen-shot-configuration.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
 
 #include "screen-shot-saver.h"
 
-ScreenShotSaver::ScreenShotSaver(QObject *parent) :
+ScreenShotSaver::ScreenShotSaver(IconsManager *iconsManager, ScreenShotConfiguration *screenShotConfiguration, QObject *parent) :
 		QObject{parent},
+		m_iconsManager{iconsManager},
+		m_screenShotConfiguration{screenShotConfiguration},
 		Size{}
 {
 }
@@ -40,20 +42,20 @@ ScreenShotSaver::~ScreenShotSaver()
 
 QString ScreenShotSaver::createScreenshotPath()
 {
-	QString dirPath = ScreenShotConfiguration::instance()->imagePath();
+	QString dirPath = m_screenShotConfiguration->imagePath();
 
 	QDir dir(dirPath);
 	if (!dir.exists() && !dir.mkpath(dirPath))
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Unable to create direcotry %1 for storing screenshots!").arg(dirPath));
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Unable to create direcotry %1 for storing screenshots!").arg(dirPath));
 		return QString();
 	}
 
 	return QDir::cleanPath(QString("%1/%2%3.%4")
 			.arg(dir.absolutePath())
-			.arg(ScreenShotConfiguration::instance()->fileNamePrefix())
+			.arg(m_screenShotConfiguration->fileNamePrefix())
 			.arg(QString::number(QDateTime::currentDateTime().toTime_t()))
-			.arg(ScreenShotConfiguration::instance()->screenshotFileNameExtension().toLower()));
+			.arg(m_screenShotConfiguration->screenshotFileNameExtension().toLower()));
 }
 
 QString ScreenShotSaver::saveScreenShot(QPixmap pixmap)
@@ -62,12 +64,12 @@ QString ScreenShotSaver::saveScreenShot(QPixmap pixmap)
 	if (path.isEmpty())
 		return QString();
 
-	int quality = ScreenShotConfiguration::instance()->quality();
+	int quality = m_screenShotConfiguration->quality();
 
 	// do not extract qPrintable... to variable
-	if (!pixmap.save(path, qPrintable(ScreenShotConfiguration::instance()->fileFormat()), quality))
+	if (!pixmap.save(path, qPrintable(m_screenShotConfiguration->fileFormat()), quality))
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Can't write file %1.\nAccess denied or other problem!").arg(path));
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Can't write file %1.\nAccess denied or other problem!").arg(path));
 		return QString();
 	}
 
@@ -76,7 +78,7 @@ QString ScreenShotSaver::saveScreenShot(QPixmap pixmap)
 
 	if (Size == 0)
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Screenshot %1 has 0 size!\nIt should be bigger.").arg(path));
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Screenshot %1 has 0 size!\nIt should be bigger.").arg(path));
 		return QString();
 	}
 
