@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,23 +18,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SCREEN_SHOT_SAVER_H
-#define SCREEN_SHOT_SAVER_H
+#pragma once
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 
 class QPixmap;
 
+class IconsManager;
+class ScreenShotConfiguration;
+
 class ScreenShotSaver : public QObject
 {
 	Q_OBJECT
 
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<ScreenShotConfiguration> m_screenShotConfiguration;
+
 	long int Size;
 
 	QString createScreenshotPath();
 
 public:
-	explicit ScreenShotSaver(QObject *parent = 0);
+	explicit ScreenShotSaver(IconsManager *iconsManager, ScreenShotConfiguration *screenShotConfiguration, QObject *parent = nullptr);
 	virtual ~ScreenShotSaver();
 
 	QString saveScreenShot(QPixmap pixmap);
@@ -44,5 +48,3 @@ public:
 	long int size() { return Size; }
 
 };
-
-#endif // SCREEN_SHOT_SAVER_H
