@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,16 +21,17 @@
  */
 
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
 #include <QtGui/QPixmap>
-#include <QtGui/QPushButton>
-#include <QtGui/QStyle>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QStyle>
+#include <QtWidgets/QVBoxLayout>
 
 #include "gui/widgets/chat-widget/chat-widget.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "pixmap-grabber.h"
 
@@ -39,28 +40,31 @@
 ScreenshotTaker::ScreenshotTaker(ChatWidget *chatWidget) :
 		QWidget(chatWidget->window(), Qt::Window), CurrentChatWidget(chatWidget), Dragging(false)
 {
-	setWindowRole("kadu-screenshot-taker");
-
-	setWindowModality(Qt::WindowModal);
-
-	setAttribute(Qt::WA_DeleteOnClose);
-
-	setMouseTracking(true);
-
-	setWindowTitle(tr("Window Shot"));
-	setWindowIcon(qApp->windowIcon()); // don't use status icon from the chat window!
-
-	createLayout();
-
-	connect(CancelButton, SIGNAL(clicked()), this, SLOT(close()));
-
-	setFixedSize(sizeHint());
 }
 
 ScreenshotTaker::~ScreenshotTaker()
 {
 }
 
+void ScreenshotTaker::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void ScreenshotTaker::init()
+{
+	setWindowRole("kadu-screenshot-taker");
+	setWindowModality(Qt::WindowModal);
+	setAttribute(Qt::WA_DeleteOnClose);
+	setMouseTracking(true);
+	setWindowTitle(tr("Window Shot"));
+	setWindowIcon(qApp->windowIcon()); // don't use status icon from the chat window!
+
+	createLayout();
+	connect(CancelButton, SIGNAL(clicked()), this, SLOT(close()));
+	setFixedSize(sizeHint());
+}
+
 void ScreenshotTaker::createLayout()
 {
 	QVBoxLayout *layout = new QVBoxLayout(this);
@@ -75,7 +79,7 @@ void ScreenshotTaker::createLayout()
 	iconLayout->addStretch();
 	IconLabel = new QLabel(this);
 	IconLabel->setAlignment(Qt::AlignCenter);
-	IconLabel->setPixmap(KaduIcon("external_modules/screenshot-camera-photo").icon().pixmap(32, 32));
+	IconLabel->setPixmap(m_iconsManager->iconByPath(KaduIcon("external_modules/screenshot-camera-photo")).pixmap(32, 32));
 	iconLayout->addWidget(IconLabel);
 	iconLayout->addStretch();
 
@@ -131,7 +135,7 @@ void ScreenshotTaker::mousePressEvent(QMouseEvent *e)
 
 	Dragging = true;
 
-	setCursor(KaduIcon("external_modules/screenshot-camera-photo").icon().pixmap(32, 32));
+	setCursor(m_iconsManager->iconByPath(KaduIcon("external_modules/screenshot-camera-photo")).pixmap(32, 32));
 }
 
 void ScreenshotTaker::mouseReleaseEvent(QMouseEvent *e)
@@ -162,4 +166,6 @@ void ScreenshotTaker::takeShot()
 	emit screenshotTaken(pixmap, true);
 }
 
+#undef Bool
+
 #include "moc_screenshot-taker.cpp"
