@@ -1,11 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2008, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,45 +25,72 @@
 #include <QtCore/QDir>
 #include <QtCore/QTimer>
 
+#include "contacts/contact-set.h"
+#include "core/core.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/custom-input.h"
 #include "gui/windows/message-dialog.h"
+#include "icons/icons-manager.h"
+#include "plugin/plugin-injected-factory.h"
 #include "activate.h"
 #include "debug.h"
 
 #include "configuration/screen-shot-configuration.h"
 #include "gui/widgets/screenshot-widget.h"
-#include "notify/screenshot-notification.h"
 #include "pixmap-grabber.h"
+#include "screenshot-notification-service.h"
 #include "screenshot-taker.h"
 
 #include "screen-shot-saver.h"
 #include "screenshot.h"
 
-ScreenShot::ScreenShot(ChatWidget *chatWidget) :
+ScreenShot::ScreenShot(ScreenShotConfiguration *screenShotConfiguration, ChatWidget *chatWidget) :
+		m_screenShotConfiguration{screenShotConfiguration},
 		Mode{},
 		MyScreenshotTaker{},
 		MyChatWidget{chatWidget}
 {
-	kdebugf();
-
-	MyScreenshotTaker = new ScreenshotTaker(MyChatWidget);
-	connect(MyScreenshotTaker, SIGNAL(screenshotTaken(QPixmap, bool)), this, SLOT(screenshotTaken(QPixmap, bool)));
-	connect(MyScreenshotTaker, SIGNAL(screenshotNotTaken()), this, SLOT(screenshotNotTaken()));
-
-	// Rest stuff
-	warnedAboutSize = false;
 }
 
 ScreenShot::~ScreenShot()
 {
 	if (MyChatWidget)
-		_activateWindow(MyChatWidget->window());
+		_activateWindow(m_configuration, MyChatWidget->window());
 
 	delete MyScreenshotTaker;
 	MyScreenshotTaker = 0;
 }
 
+void ScreenShot::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void ScreenShot::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void ScreenShot::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void ScreenShot::setScreenshotNotificationService(ScreenshotNotificationService *screenshotNotificationService)
+{
+	m_screenshotNotificationService = screenshotNotificationService;
+}
+
+void ScreenShot::init()
+{
+	MyScreenshotTaker = m_pluginInjectedFactory->makeInjected<ScreenshotTaker>(MyChatWidget);
+	connect(MyScreenshotTaker, SIGNAL(screenshotTaken(QPixmap, bool)), this, SLOT(screenshotTaken(QPixmap, bool)));
+	connect(MyScreenshotTaker, SIGNAL(screenshotNotTaken()), this, SLOT(screenshotNotTaken()));
+
+	// Rest stuff
+	warnedAboutSize = false;
+}
+
 void ScreenShot::takeStandardShot()
 {
 	MyScreenshotTaker->takeStandardShot();
@@ -98,7 +123,7 @@ void ScreenShot::screenshotTaken(QPixmap screenshot, bool needsCrop)
 	screenshotWidget->showFullScreen();
 	screenshotWidget->show();
 	QCoreApplication::processEvents(); // ensure window was shown, otherwise it won't be activated
-	_activateWindow(screenshotWidget);
+	_activateWindow(m_configuration, screenshotWidget);
 }
 
 void ScreenShot::screenshotNotTaken()
@@ -108,14 +133,14 @@ void ScreenShot::screenshotNotTaken()
 
 void ScreenShot::screenshotReady(QPixmap p)
 {
-	ScreenShotSaver *saver = new ScreenShotSaver(this);
-	QString screenShotPath = saver->saveScreenShot(p);
+	auto saver = new ScreenShotSaver(m_iconsManager, m_screenShotConfiguration, this);
+	auto screenShotPath = saver->saveScreenShot(p);
 
-	if (ScreenShotConfiguration::instance()->pasteImageClauseIntoChatWidget())
+	if (m_screenShotConfiguration->pasteImageClauseIntoChatWidget())
 	{
 		pasteImageClause(screenShotPath);
 		if (!checkImageSize(saver->size()))
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Image size is bigger than maximal image size for this chat."));
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"), tr("Image size is bigger than maximal image size for this chat."));
 	}
 
 	deleteLater();
@@ -141,15 +166,15 @@ bool ScreenShot::checkImageSize(long int size)
 void ScreenShot::checkShotsSize()
 {
 	kdebugf();
-	if (!ScreenShotConfiguration::instance()->warnAboutDirectorySize())
+	if (!m_screenShotConfiguration->warnAboutDirectorySize())
 		return;
 
 	long size = 0;
 
-	long limit = ScreenShotConfiguration::instance()->directorySizeLimit();
-	QDir dir(ScreenShotConfiguration::instance()->imagePath());
+	long limit = m_screenShotConfiguration->directorySizeLimit();
+	QDir dir(m_screenShotConfiguration->imagePath());
 
-	QString prefix = ScreenShotConfiguration::instance()->fileNamePrefix();
+	QString prefix = m_screenShotConfiguration->fileNamePrefix();
 	QStringList filters;
 	filters << prefix + '*';
 	QFileInfoList list = dir.entryInfoList(filters, QDir::Files);
@@ -158,7 +183,9 @@ void ScreenShot::checkShotsSize()
 		size += f.size();
 
 	if (size/1024 >= limit)
-		ScreenshotNotification::notifySizeLimit(size);
+		m_screenshotNotificationService->notifySizeLimit(size);
 }
 
+#undef Bool
+
 #include "moc_screenshot.cpp"
