@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +18,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SCREENSHOT_H
-#define SCREENSHOT_H
+#pragma once
 
 #include <vector>
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtCore/QRect>
 #include <QtGui/QPixmap>
+#include <injeqt/injeqt.h>
 
 #include "screenshot-mode.h"
 
@@ -37,7 +37,12 @@ class QMenu;
 class ActionDescription;
 class ChatWidget;
 class ConfigurationUiHandler;
+class Configuration;
 class CropImageWidget;
+class IconsManager;
+class PluginInjectedFactory;
+class ScreenShotConfiguration;
+class ScreenshotNotificationService;
 class ScreenshotTaker;
 class ScreenshotToolBox;
 class ScreenshotWidget;
@@ -46,6 +51,12 @@ class ScreenShot : public QObject
 {
 	Q_OBJECT
 
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<ScreenShotConfiguration> m_screenShotConfiguration;
+	QPointer<ScreenshotNotificationService> m_screenshotNotificationService;
+
 	ScreenShotMode Mode;
 	ScreenshotTaker *MyScreenshotTaker;
 	ChatWidget *MyChatWidget;
@@ -58,13 +69,19 @@ class ScreenShot : public QObject
 	bool checkImageSize(long int size);
 
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setScreenshotNotificationService(ScreenshotNotificationService *screenshotNotificationService);
+	INJEQT_INIT void init();
+
 	void screenshotTaken(QPixmap screenshot, bool needsCrop);
 	void screenshotNotTaken();
 
 	void screenshotReady(QPixmap pixmap);
 
 public:
-	explicit ScreenShot(ChatWidget *chatWidget);
+	explicit ScreenShot(ScreenShotConfiguration *screenShotConfiguration, ChatWidget *chatWidget);
 	virtual ~ScreenShot();
 
 	void takeStandardShot();
@@ -72,5 +89,3 @@ public:
 	void takeWindowShot();
 
 };
-
-#endif // SCREENSHOT_H
