@@ -118,10 +118,6 @@ Měl by být větší.</translation>
 </context>
 <context>
     <name>ScreenshotAction</name>
-    <message>
-        <source>ScreenShot</source>
-        <translation>Snímek obrazovky</translation>
-    </message>
     <message>
         <source>Simple Shot</source>
         <translation>Jednoduchý snímek</translation>
@@ -136,7 +132,7 @@ Měl by být větší.</translation>
     </message>
 </context>
 <context>
-    <name>ScreenshotNotification</name>
+    <name>ScreenshotNotificationService</name>
     <message>
         <source>ScreenShot size limit</source>
         <translation>Omezení velikosti snímku obrazovky</translation>
