@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -104,7 +106,7 @@
         <translation>Unable to create direcotry %1 for storing screenshots!</translation>
     </message>
     <message>
-        <source>Can't write file %1.
+        <source>Can&apos;t write file %1.
 Access denied or other problem!</source>
         <translation>Can&apos;t write file %1.
 Access denied or other problem!</translation>
@@ -118,10 +120,6 @@ It should be bigger.</translation>
 </context>
 <context>
     <name>ScreenshotAction</name>
-    <message>
-        <source>ScreenShot</source>
-        <translation>ScreenShot</translation>
-    </message>
     <message>
         <source>Simple Shot</source>
         <translation>Simple Shot</translation>
@@ -136,14 +134,14 @@ It should be bigger.</translation>
     </message>
 </context>
 <context>
-    <name>ScreenshotNotification</name>
+    <name>ScreenshotNotificationService</name>
     <message>
         <source>ScreenShot size limit</source>
-        <translation>ScreenShot size limit</translation>
+        <translation type="unfinished">ScreenShot size limit</translation>
     </message>
     <message>
         <source>Images size limit exceed: %1 KB</source>
-        <translation>Images size limit exceed: %1 KB</translation>
+        <translation type="unfinished">Images size limit exceed: %1 KB</translation>
     </message>
 </context>
 <context>
@@ -176,4 +174,4 @@ It should be bigger.</translation>
         <translation>Cancel</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
