@@ -118,10 +118,6 @@ Debería ser más grande.</translation>
 </context>
 <context>
     <name>ScreenshotAction</name>
-    <message>
-        <source>ScreenShot</source>
-        <translation>Captura de Pantalla</translation>
-    </message>
     <message>
         <source>Simple Shot</source>
         <translation>Toma Simple</translation>
@@ -136,7 +132,7 @@ Debería ser más grande.</translation>
     </message>
 </context>
 <context>
-    <name>ScreenshotNotification</name>
+    <name>ScreenshotNotificationService</name>
     <message>
         <source>ScreenShot size limit</source>
         <translation>Tamaño límite de la captura de pantalla</translation>
