@@ -118,10 +118,6 @@ Elle devrait être plus grosse.</translation>
 </context>
 <context>
     <name>ScreenshotAction</name>
-    <message>
-        <source>ScreenShot</source>
-        <translation>Capture d&apos;écran</translation>
-    </message>
     <message>
         <source>Simple Shot</source>
         <translation>Capture d&apos;écran globle</translation>
@@ -136,7 +132,7 @@ Elle devrait être plus grosse.</translation>
     </message>
 </context>
 <context>
-    <name>ScreenshotNotification</name>
+    <name>ScreenshotNotificationService</name>
     <message>
         <source>ScreenShot size limit</source>
         <translation>Limite de la taille des captures d&apos;écran</translation>
