@@ -116,10 +116,6 @@ It should be bigger.</source>
 </context>
 <context>
     <name>ScreenshotAction</name>
-    <message>
-        <source>ScreenShot</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Simple Shot</source>
         <translation type="unfinished"/>
@@ -134,7 +130,7 @@ It should be bigger.</source>
     </message>
 </context>
 <context>
-    <name>ScreenshotNotification</name>
+    <name>ScreenshotNotificationService</name>
     <message>
         <source>ScreenShot size limit</source>
         <translation type="unfinished"/>
