@@ -118,10 +118,6 @@ Büyük olmalıdır.</translation>
 </context>
 <context>
     <name>ScreenshotAction</name>
-    <message>
-        <source>ScreenShot</source>
-        <translation>Ekran Görüntüsü</translation>
-    </message>
     <message>
         <source>Simple Shot</source>
         <translation>Basit Çekim</translation>
@@ -136,7 +132,7 @@ Büyük olmalıdır.</translation>
     </message>
 </context>
 <context>
-    <name>ScreenshotNotification</name>
+    <name>ScreenshotNotificationService</name>
     <message>
         <source>ScreenShot size limit</source>
         <translation>Ekran Görüntüsü boyut limiti</translation>
