@@ -1,8 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,38 +17,17 @@
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+
 #ifndef SIMPLEVIEW_CONFIG_UI_H
 #define SIMPLEVIEW_CONFIG_UI_H
 
-#include <QtCore/QObject>
+class Configuration;
 
-
-#include "gui/windows/main-configuration-window.h"
-
-class SimpleViewConfigUi :
-	public ConfigurationUiHandler
+class SimpleViewConfigUi
 {
-	Q_OBJECT
-	Q_DISABLE_COPY(SimpleViewConfigUi)
-
-	static SimpleViewConfigUi *Instance;
-
-	SimpleViewConfigUi();
-	virtual ~SimpleViewConfigUi();
-
-	void createDefaultConfiguration();
-
-	/* Keep this code for further use:
-private slots:
-	void mainConfigurationWindowDestroyed();
-	 */
-
 public:
-	static void createInstance();
-	static void destroyInstance();
-	static SimpleViewConfigUi *instance(){return Instance; }
+	static void createDefaultConfiguration(Configuration *configuration);
 
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
 };
 
 #endif
