@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Przemysław Rudy (prudy1@o2.pl)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2014 Przemek Rudy (prudy1@o2.pl)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,82 +20,92 @@
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-#include <QtGui/QMenu>
-#include <QtGui/QMenuBar>
-#include <QtGui/QToolBar>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QMenuBar>
+#include <QtWidgets/QToolBar>
 
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "configuration/gui/configuration-ui-handler-repository.h"
 #include "gui/hot-key.h"
 #include "gui/widgets/buddy-info-panel.h"
 #include "gui/widgets/group-tab-bar/group-tab-bar.h"
 #include "gui/widgets/roster-widget.h"
 #include "gui/widgets/status-buttons.h"
 #include "gui/widgets/talkable-tree-view.h"
+#include "gui/windows/main-configuration-window.h"
+#include "gui/windows/kadu-window-service.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/main-window.h"
 #include "icons/kadu-icon.h"
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
+#include "plugin/plugin-repository.h"
 
 #include "plugins/docking/docking.h"
+#include "plugins/docking/docking-menu-action-repository.h"
+#include "plugins/docking/docking-plugin-object.h"
 
 #include "simpleview-config-ui.h"
 #include "simpleview.h"
 
-SimpleView *SimpleView::Instance = 0;
-
-SimpleView::SimpleView() :
+SimpleView::SimpleView(QObject *parent) :
+	QObject{parent},
 	SimpleViewActive(false)
 {
-	RosterWidget *roster;
-
-	SimpleViewConfigUi::createInstance();
-
-	MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/simpleview.ui"));
-	MainConfigurationWindow::registerUiHandler(SimpleViewConfigUi::instance());
-
-	DockAction = new QAction(KaduIcon("view-refresh").icon(), tr("Simple view"), this);
-	DockAction->setCheckable(true);
-	connect(DockAction, SIGNAL(triggered(bool)), this, SLOT(simpleViewToggle(bool)));
-	DockingManager::instance()->registerModuleAction(DockAction);
-
-	KaduWindowHandle = Core::instance()->kaduWindow();
-	MainWindowHandle = KaduWindowHandle->findMainWindow(KaduWindowHandle);
-	roster = KaduWindowHandle->findChild<RosterWidget *>();
-	GroupTabBarHandle = roster->findChild<GroupTabBar *>();
-	TalkableTreeViewHandle = roster->talkableTreeView();
-	StatusButtonsHandle = KaduWindowHandle->findChild<StatusButtons *>();
-
-	configurationUpdated();
-
-	DiffRect = config_file.readRectEntry("Look", "SimpleViewGeometry");
-	if (DiffRect != QRect(0,0,0,0))
-		simpleViewToggle(true);
 }
 
 SimpleView::~SimpleView()
 {
-	config_file.writeEntry("Look", "SimpleViewGeometry", DiffRect);
-
 	simpleViewToggle(false);
-
-	DockingManager::instance()->unregisterModuleAction(DockAction);
-
-	MainConfigurationWindow::unregisterUiHandler(SimpleViewConfigUi::instance());
-	MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/simpleview.ui"));
-	SimpleViewConfigUi::destroyInstance();
 }
 
-void SimpleView::createInstance()
+void SimpleView::setConfiguration(Configuration *configuration)
 {
-	if (!Instance)
-		Instance = new SimpleView();
+	m_configuration = configuration;
 }
 
-void SimpleView::destroyInstance()
+void SimpleView::setDockingMenuActionRepository(DockingMenuActionRepository *dockingMenuActionRepository)
 {
-	delete Instance;
-	Instance = 0;
+	m_dockingMenuActionRepository = dockingMenuActionRepository;
+}
+
+void SimpleView::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void SimpleView::setKaduWindowService(KaduWindowService *kaduWindowService)
+{
+	m_kaduWindowService = kaduWindowService;
+}
+
+void SimpleView::init()
+{
+	SimpleViewConfigUi::createDefaultConfiguration(m_configuration);
+
+	DockAction = new QAction(m_iconsManager->iconByPath(KaduIcon("view-refresh")), tr("Simple view"), this);
+	DockAction->setCheckable(true);
+	connect(DockAction, SIGNAL(triggered(bool)), this, SLOT(simpleViewToggle(bool)));
+
+	KaduWindowHandle = m_kaduWindowService->kaduWindow();
+	MainWindowHandle = KaduWindowHandle->findMainWindow(KaduWindowHandle);
+	auto roster = KaduWindowHandle->findChild<RosterWidget *>();
+	GroupTabBarHandle = roster->findChild<GroupTabBar *>();
+	TalkableTreeViewHandle = roster->talkableTreeView();
+	StatusButtonsHandle = KaduWindowHandle->findChild<StatusButtons *>();
+
+	m_dockingMenuActionRepository->addAction(DockAction);
+
+	DiffRect = m_configuration->deprecatedApi()->readRectEntry("Look", "SimpleViewGeometry");
+	if (DiffRect != QRect(0,0,0,0))
+		simpleViewToggle(true);
+	configurationUpdated();
+}
+
+void SimpleView::done()
+{
+	m_configuration->deprecatedApi()->writeEntry("Look", "SimpleViewGeometry", DiffRect);
+	m_dockingMenuActionRepository->removeAction(DockAction);
 }
 
 void SimpleView::simpleViewToggle(bool activate)
@@ -202,10 +212,10 @@ void SimpleView::simpleViewToggle(bool activate)
 			MainWindowHandle->setGeometry(r);
 
 			/* Status button */
-			StatusButtonsHandle->setVisible(config_file.readBoolEntry("Look", "ShowStatusButton"));
+			StatusButtonsHandle->setVisible(m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowStatusButton"));
 
 			/* Info panel*/
-			if (config_file.readBoolEntry("Look", "ShowInfoPanel"))
+			if (m_configuration->deprecatedApi()->readBoolEntry("Look", "ShowInfoPanel"))
 				KaduWindowHandle->infoPanel()->show();
 
 			/* ScrollBar */
@@ -217,7 +227,7 @@ void SimpleView::simpleViewToggle(bool activate)
 			 */
 
 			/* GroupBar */
-			if (config_file.readBoolEntry("Look", "DisplayGroupTabs"))
+			if (m_configuration->deprecatedApi()->readBoolEntry("Look", "DisplayGroupTabs"))
 				GroupTabBarHandle->setVisible(true);
 
 			/* Menu bar */
@@ -254,9 +264,9 @@ void SimpleView::configurationUpdated()
 	/* Give the kadu update the GUI with old configuration */
 	simpleViewToggle(false);
 
-	KeepSize = config_file.readBoolEntry("Look", "SimpleViewKeepSize", true);
-	NoScrollBar = config_file.readBoolEntry("Look", "SimpleViewNoScrollBar", true);
-	Borderless = config_file.readBoolEntry("Look", "SimpleViewBorderless", true);
+	KeepSize = m_configuration->deprecatedApi()->readBoolEntry("Look", "SimpleViewKeepSize", true);
+	NoScrollBar = m_configuration->deprecatedApi()->readBoolEntry("Look", "SimpleViewNoScrollBar", true);
+	Borderless = m_configuration->deprecatedApi()->readBoolEntry("Look", "SimpleViewBorderless", true);
 
 }
 
