@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Przemysław Rudy (prudy1@o2.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Przemysław Rudy (prudy1@o2.pl)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,11 +18,13 @@
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef SIMPLEVIEW_H
-#define SIMPLEVIEW_H
+
+#pragma once
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtCore/QRect>
+#include <injeqt/injector.h>
 
 #include "configuration/configuration-aware-object.h"
 #include "os/generic/compositing-aware-object.h"
@@ -31,19 +33,32 @@ class QAction;
 class QString;
 class QWidget;
 
+class Configuration;
+class DockingMenuActionRepository;
 class GroupTabBar;
+class IconsManager;
+class KaduWindowService;
 class KaduWindow;
 class MainWindow;
 class StatusButtons;
 class TalkableTreeView;
 
-class SimpleView :
-	public QObject, private ConfigurationAwareObject, CompositingAwareObject
+class SimpleView : public QObject, private ConfigurationAwareObject, CompositingAwareObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(SimpleView)
 
-	static SimpleView *Instance;
+public:
+	Q_INVOKABLE explicit SimpleView(QObject *parent = nullptr);
+	virtual ~SimpleView();
+
+public slots:
+	void simpleViewToggle(bool activate);
+
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<DockingMenuActionRepository> m_dockingMenuActionRepository;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<KaduWindowService> m_kaduWindowService;
 
 	bool KeepSize;
 	bool NoScrollBar;
@@ -60,20 +75,16 @@ class SimpleView :
 	StatusButtons *StatusButtonsHandle;
 	TalkableTreeView *TalkableTreeViewHandle;
 
-	SimpleView();
-	virtual ~SimpleView();
-
 	virtual void compositingEnabled();
 	virtual void compositingDisabled();
 	virtual void configurationUpdated();
 
-public:
-	static void createInstance();
-	static void destroyInstance();
-	static SimpleView *instance(){return Instance; }
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setDockingMenuActionRepository(DockingMenuActionRepository *dockingMenuActionRepository);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setKaduWindowService(KaduWindowService *kaduWindowService);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
 
-public slots:
-	void simpleViewToggle(bool activate);
 };
-
-#endif
