@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,6 +21,8 @@
 
 #include "single-window.h"
 
+#include "gui/widgets/chat-widget/chat-widget-container-handler-repository.h"
+
 SingleWindowChatWidgetContainerHandler::SingleWindowChatWidgetContainerHandler(QObject *parent) :
 		ChatWidgetContainerHandler(parent)
 {
@@ -35,6 +32,11 @@ SingleWindowChatWidgetContainerHandler::~SingleWindowChatWidgetContainerHandler(
 {
 }
 
+void SingleWindowChatWidgetContainerHandler::setChatWidgetContainerHandlerRepository(ChatWidgetContainerHandlerRepository *chatWidgetContainerHandlerRepository)
+{
+	m_chatWidgetContainerHandlerRepository = chatWidgetContainerHandlerRepository;
+}
+
 void SingleWindowChatWidgetContainerHandler::setSingleWindow(SingleWindow *singleWindow)
 {
 	m_singleWindow = singleWindow;
@@ -43,27 +45,37 @@ void SingleWindowChatWidgetContainerHandler::setSingleWindow(SingleWindow *singl
 			this, SIGNAL(chatWidgetActivated(ChatWidget*)));
 }
 
-bool SingleWindowChatWidgetContainerHandler::acceptChatWidget(ChatWidget *chatWidget) const
+void SingleWindowChatWidgetContainerHandler::init()
 {
-	Q_UNUSED(chatWidget);
-
-	return m_singleWindow;
+	m_chatWidgetContainerHandlerRepository->registerChatWidgetContainerHandler(this);
 }
 
-void SingleWindowChatWidgetContainerHandler::addChatWidget(ChatWidget *chatWidget)
+void SingleWindowChatWidgetContainerHandler::done()
 {
-	if (!chatWidget || !m_singleWindow)
-		return;
-
-	m_singleWindow.data()->addChatWidget(chatWidget);
+	m_chatWidgetContainerHandlerRepository->unregisterChatWidgetContainerHandler(this);
 }
 
-void SingleWindowChatWidgetContainerHandler::removeChatWidget(ChatWidget *chatWidget)
+bool SingleWindowChatWidgetContainerHandler::acceptChat(Chat chat) const
 {
-	if (!chatWidget || !m_singleWindow)
+	Q_UNUSED(chat);
+
+	return m_singleWindow != nullptr;
+}
+
+ChatWidget * SingleWindowChatWidgetContainerHandler::addChat(Chat chat, OpenChatActivation activation)
+{
+	if (!chat || !m_singleWindow)
+		return nullptr;
+
+	return m_singleWindow.data()->addChat(chat, activation);
+}
+
+void SingleWindowChatWidgetContainerHandler::removeChat(Chat chat)
+{
+	if (!chat || !m_singleWindow)
 		return;
 
-	m_singleWindow.data()->removeChatWidget(chatWidget);
+	m_singleWindow.data()->removeChat(chat);
 }
 
 bool SingleWindowChatWidgetContainerHandler::isChatWidgetActive(ChatWidget *chatWidget)
@@ -76,3 +88,9 @@ void SingleWindowChatWidgetContainerHandler::tryActivateChatWidget(ChatWidget *c
 	if (m_singleWindow)
 		m_singleWindow.data()->tryActivateChatWidget(chatWidget);
 }
+
+void SingleWindowChatWidgetContainerHandler::tryMinimizeChatWidget(ChatWidget *)
+{
+}
+
+#include "moc_single-window-chat-widget-container-handler.cpp"
