@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -29,10 +29,6 @@
         <source>Right</source>
         <translation>Droite</translation>
     </message>
-    <message>
-        <source>Show number of messages on tab</source>
-        <translation>Afficher le nombre de messages dans l&apos;onglet</translation>
-    </message>
     <message>
         <source>Shortcuts</source>
         <translation>Raccourcis</translation>
@@ -55,14 +51,7 @@
     </message>
     <message>
         <source>Behavior</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>SingleWindow</name>
-    <message>
-        <source>Conference [%1]</source>
-        <translation>Conférence [%1]</translation>
+        <translation>Comportement</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
