@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -29,10 +29,6 @@
         <source>Right</source>
         <translation>Strona prawa</translation>
     </message>
-    <message>
-        <source>Show number of messages on tab</source>
-        <translation>Wyświetl liczbę wiadomości na zakładce</translation>
-    </message>
     <message>
         <source>Shortcuts</source>
         <translation>Skróty</translation>
@@ -58,11 +54,4 @@
         <translation>Zachowanie</translation>
     </message>
 </context>
-<context>
-    <name>SingleWindow</name>
-    <message>
-        <source>Conference [%1]</source>
-        <translation>Konferencja [%1]</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
