@@ -1,68 +1,57 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>Look</source>
-        <translation type="unfinished"/>
+        <translation>Görünüm</translation>
     </message>
     <message>
         <source>SingleWindow</source>
-        <translation type="unfinished"/>
+        <translation>TekliPencere</translation>
     </message>
     <message>
         <source>General</source>
-        <translation type="unfinished"/>
+        <translation>Genel</translation>
     </message>
     <message>
         <source>Roster position</source>
-        <translation type="unfinished"/>
+        <translation>Görev listesini konumu</translation>
     </message>
     <message>
         <source>Choose position of roster in Single Window mode</source>
-        <translation type="unfinished"/>
+        <translation>Tekli Pencere modunda görev listesinin konumunu seçin</translation>
     </message>
     <message>
         <source>Left</source>
-        <translation type="unfinished"/>
+        <translation>Sol</translation>
     </message>
     <message>
         <source>Right</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Show number of messages on tab</source>
-        <translation type="unfinished"/>
+        <translation>Sağ</translation>
     </message>
     <message>
         <source>Shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Kısayollar</translation>
     </message>
     <message>
         <source>Switch to previous tab</source>
-        <translation type="unfinished"/>
+        <translation>Önceki sekmeye geç</translation>
     </message>
     <message>
         <source>Switch to next tab</source>
-        <translation type="unfinished"/>
+        <translation>Sonraki sekmeye geç</translation>
     </message>
     <message>
         <source>Show/hide roster</source>
-        <translation type="unfinished"/>
+        <translation>Görev listesini göster/gizle</translation>
     </message>
     <message>
         <source>Switch focus between roster and tabs</source>
-        <translation type="unfinished"/>
+        <translation>Görev listesi ve sekmeler arasında geçiş yap</translation>
     </message>
     <message>
         <source>Behavior</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>SingleWindow</name>
-    <message>
-        <source>Conference [%1]</source>
-        <translation type="unfinished"/>
+        <translation>Davranış</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
