@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi_VN" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi_VN" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -29,10 +29,6 @@
         <source>Right</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Show number of messages on tab</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Shortcuts</source>
         <translation type="unfinished"/>
@@ -58,11 +54,4 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>SingleWindow</name>
-    <message>
-        <source>Conference [%1]</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 </TS>
\ No newline at end of file
