@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,35 +18,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QCheckBox>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QFormLayout>
-#include <QtGui/QHBoxLayout>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QTextEdit>
-#include <QtGui/QVBoxLayout>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFormLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTextEdit>
+#include <QtWidgets/QVBoxLayout>
 
 #include "buddies/buddy-manager.h"
 #include "buddies/model/buddy-list-model.h"
 #include "buddies/model/buddy-manager-adapter.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/widgets/select-talkable-combo-box.h"
 #include "gui/windows/message-dialog.h"
 #include "gui/windows/progress-window.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "os/generic/window-geometry-manager.h"
+#include "plugin/plugin-injected-factory.h"
 #include "talkable/filter/mobile-talkable-filter.h"
+#include "talkable/talkable-converter.h"
 #include "debug.h"
 
+#include "plugins/history/history-plugin-object.h"
 #include "plugins/history/history.h"
 
+#include "scripts/sms-script-manager.h"
 #include "mobile-number-manager.h"
 #include "sms-external-sender.h"
 #include "sms-gateway-manager.h"
@@ -57,28 +60,57 @@
 
 #include "sms-dialog.h"
 
-SmsDialog::SmsDialog(QWidget* parent) :
-		QWidget(parent, Qt::Window), MaxLength(0)
+SmsDialog::SmsDialog(History *history, MobileNumberManager *mobileNumberManager, SmsGatewayManager *smsGatewayManager, SmsScriptsManager *smsScriptsManager, QWidget* parent) :
+		QWidget{parent, Qt::Window},
+		m_history{history},
+		m_mobileNumberManager{mobileNumberManager},
+		m_smsGatewayManager{smsGatewayManager},
+		m_smsScriptsManager{smsScriptsManager},
+		MaxLength{0}
 {
-	kdebugf();
-
 	setWindowTitle(tr("Send SMS"));
 	setAttribute(Qt::WA_DeleteOnClose);
+}
 
+SmsDialog::~SmsDialog()
+{
+}
+
+void SmsDialog::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void SmsDialog::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void SmsDialog::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void SmsDialog::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void SmsDialog::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void SmsDialog::init()
+{
 	createGui();
 	validate();
 
 	configurationUpdated();
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("Sms", "SmsDialogGeometry"), QRect(200, 200, 400, 250), this);
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "Sms", "SmsDialogGeometry"), QRect(200, 200, 400, 250), this);
 
 	RecipientEdit->setFocus();
-
-	kdebugf2();
-}
-
-SmsDialog::~SmsDialog()
-{
 }
 
 void SmsDialog::createGui()
@@ -103,11 +135,11 @@ void SmsDialog::createGui()
 
 	recipientLayout->addWidget(RecipientEdit);
 
-	RecipientComboBox = new SelectTalkableComboBox(this);
+	RecipientComboBox = m_pluginInjectedFactory->makeInjected<SelectTalkableComboBox>(this);
 	RecipientComboBox->addBeforeAction(new QAction(tr(" - Select recipient - "), RecipientComboBox));
 
-	BuddyListModel *buddyListModel = new BuddyListModel(RecipientComboBox);
-	new BuddyManagerAdapter(buddyListModel);
+	auto buddyListModel = m_pluginInjectedFactory->makeInjected<BuddyListModel>(RecipientComboBox);
+	m_pluginInjectedFactory->makeInjected<BuddyManagerAdapter>(buddyListModel);
 
 	RecipientComboBox->setBaseModel(buddyListModel);
 	RecipientComboBox->addFilter(new MobileTalkableFilter(RecipientComboBox));
@@ -120,7 +152,7 @@ void SmsDialog::createGui()
 	ProviderComboBox = new QComboBox(this);
 	ProviderComboBox->addItem(tr("Select automatically"), QString());
 
-	foreach (const SmsGateway &gateway, SmsGatewayManager::instance()->items())
+	for (auto gateway : m_smsGatewayManager->items())
 		ProviderComboBox->addItem(gateway.name(), gateway.id());
 
 	connect(ProviderComboBox, SIGNAL(activated(int)), this, SLOT(gatewayActivated(int)));
@@ -138,7 +170,7 @@ void SmsDialog::createGui()
 	LengthLabel = new QLabel("0", this);
 	formLayout->addRow(0, LengthLabel);
 
-	SignatureEdit = new QLineEdit(config_file.readEntry("SMS", "SmsNick"), this);
+	SignatureEdit = new QLineEdit(m_configuration->deprecatedApi()->readEntry("SMS", "SmsNick"), this);
 	connect(SignatureEdit, SIGNAL(returnPressed()), this, SLOT(editReturnPressed()));
 
 	formLayout->addRow(tr("Signature") + ':', SignatureEdit);
@@ -153,7 +185,7 @@ void SmsDialog::createGui()
 	mainLayout->addWidget(buttons);
 
 	SendButton = new QPushButton(this);
-	SendButton->setIcon(KaduIcon("go-next").icon());
+	SendButton->setIcon(m_iconsManager->iconByPath(KaduIcon("go-next")));
 	SendButton->setText(tr("&Send"));
 	SendButton->setDefault(true);
 	SendButton->setMaximumWidth(200);
@@ -191,7 +223,7 @@ void SmsDialog::validate()
 
 void SmsDialog::configurationUpdated()
 {
-	ContentEdit->setFont(config_file.readFontEntry("Look", "ChatFont"));
+	ContentEdit->setFont(m_configuration->deprecatedApi()->readFontEntry("Look", "ChatFont"));
 }
 
 void SmsDialog::setRecipient(const QString &phone)
@@ -207,12 +239,12 @@ void SmsDialog::setRecipient(const QString &phone)
 
 void SmsDialog::recipientBuddyChanged()
 {
-	RecipientEdit->setText(RecipientComboBox->currentTalkable().toBuddy().mobile());
+	RecipientEdit->setText(m_talkableConverter->toBuddy(RecipientComboBox->currentTalkable()).mobile());
 }
 
 void SmsDialog::recipientNumberChanged(const QString &number)
 {
-	QString gatewayId = MobileNumberManager::instance()->gatewayId(RecipientEdit->text());
+	QString gatewayId = m_mobileNumberManager->gatewayId(RecipientEdit->text());
 	ProviderComboBox->setCurrentIndex(ProviderComboBox->findData(gatewayId));
 
 	if (-1 == ProviderComboBox->currentIndex())
@@ -224,7 +256,7 @@ void SmsDialog::recipientNumberChanged(const QString &number)
 		return;
 	}
 
-	foreach (const Buddy &buddy, BuddyManager::instance()->items())
+	foreach (const Buddy &buddy, m_buddyManager->items())
 		if (buddy.mobile() == number)
 		{
 			RecipientComboBox->setCurrentTalkable(buddy);
@@ -247,7 +279,7 @@ void SmsDialog::editReturnPressed()
 void SmsDialog::gatewayActivated(int index)
 {
 	QString id = ProviderComboBox->itemData(index).toString();
-	const SmsGateway &gateway = SmsGatewayManager::instance()->byId(id);
+	const SmsGateway &gateway = m_smsGatewayManager->byId(id);
 
 	MaxLength = gateway.maxLength();
 
@@ -261,7 +293,7 @@ void SmsDialog::gatewayActivated(int index)
 
 void SmsDialog::gatewayAssigned(const QString &number, const QString &gatewayId)
 {
-	MobileNumberManager::instance()->registerNumber(number, gatewayId);
+	m_mobileNumberManager->registerNumber(number, gatewayId);
 }
 
 void SmsDialog::sendSms()
@@ -270,28 +302,28 @@ void SmsDialog::sendSms()
 
 	SmsSender *sender;
 
-	if (config_file.readBoolEntry("SMS", "BuiltInApp"))
+	if (m_configuration->deprecatedApi()->readBoolEntry("SMS", "BuiltInApp"))
 	{
 		int gatewayIndex = ProviderComboBox->currentIndex();
 		QString gatewayId = ProviderComboBox->itemData(gatewayIndex, Qt::UserRole).toString();
-		sender = new SmsInternalSender(RecipientEdit->text(), SmsGatewayManager::instance()->byId(gatewayId), this);
+		sender = m_pluginInjectedFactory->makeInjected<SmsInternalSender>(m_smsGatewayManager, m_smsScriptsManager, RecipientEdit->text(), m_smsGatewayManager->byId(gatewayId), this);
 	}
 	else
 	{
-		if (config_file.readEntry("SMS", "SmsApp").isEmpty())
+		if (m_configuration->deprecatedApi()->readEntry("SMS", "SmsApp").isEmpty())
 		{
-			MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"),
+			MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"),
 					tr("SMS application was not specified. Visit the configuration section"), QMessageBox::Ok, this);
 			kdebugm(KDEBUG_WARNING, "SMS application NOT specified. Exit.\n");
 			return;
 		}
-		sender = new SmsExternalSender(RecipientEdit->text(), this);
+		sender = m_pluginInjectedFactory->makeInjected<SmsExternalSender>(RecipientEdit->text(), this);
 	}
 
 	connect(sender, SIGNAL(gatewayAssigned(QString, QString)), this, SLOT(gatewayAssigned(QString, QString)));
 	sender->setSignature(SignatureEdit->text());
 
-	ProgressWindow *window = new ProgressWindow(tr("Sending SMS..."));
+	auto window = m_pluginInjectedFactory->makeInjected<ProgressWindow>(tr("Sending SMS..."));
 	window->setCancellable(true);
 	window->show();
 
@@ -318,8 +350,8 @@ void SmsDialog::updateCounter()
 
 void SmsDialog::saveSmsInHistory(const QString &number, const QString &message)
 {
-	if (History::instance()->currentStorage())
-		History::instance()->currentStorage()->appendSms(number, message);
+	if (m_history->currentStorage())
+		m_history->currentStorage()->appendSms(number, message);
 }
 
 void SmsDialog::clear()
