@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,10 +18,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SMS_DIALOG_H
-#define SMS_DIALOG_H
+#pragma once
 
-#include <QtGui/QWidget>
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
 
 #include "buddies/buddy.h"
 #include "configuration/configuration-aware-object.h"
@@ -35,12 +33,31 @@ class QLineEdit;
 class QPushButton;
 class QTextEdit;
 
+class BuddyManager;
+class Configuration;
+class History;
+class IconsManager;
+class PluginInjectedFactory;
+class MobileNumberManager;
 class SelectTalkableComboBox;
+class SmsGatewayManager;
+class SmsScriptsManager;
+class TalkableConverter;
 
 class SmsDialog : public QWidget, ConfigurationAwareObject
 {
 	Q_OBJECT
 
+	QPointer<BuddyManager> m_buddyManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<History> m_history;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<MobileNumberManager> m_mobileNumberManager;
+	QPointer<SmsGatewayManager> m_smsGatewayManager;
+	QPointer<SmsScriptsManager> m_smsScriptsManager;
+	QPointer<TalkableConverter> m_talkableConverter;
+
 	QLineEdit *RecipientEdit;
 	SelectTalkableComboBox *RecipientComboBox;
 	QComboBox *ProviderComboBox;
@@ -56,6 +73,13 @@ class SmsDialog : public QWidget, ConfigurationAwareObject
 	void createGui();
 
 private slots:
+	INJEQT_SET void setBuddyManager(BuddyManager *buddyManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setTalkableConverter(TalkableConverter *talkableConverter);
+	INJEQT_INIT void init();
+
 	void validate();
 
 	void recipientBuddyChanged();
@@ -77,11 +101,9 @@ protected:
 	virtual void keyPressEvent(QKeyEvent *e);
 
 public:
-	explicit SmsDialog(QWidget *parent = 0);
+	explicit SmsDialog(History *history, MobileNumberManager *mobileNumberManager, SmsGatewayManager *smsGatewayManager, SmsScriptsManager *smsScriptsManager, QWidget *parent = nullptr);
 	virtual ~SmsDialog();
 
 	void setRecipient(const QString &phone);
 
 };
-
-#endif // SMS_DIALOG_H
