@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,41 +23,44 @@
 #include <QtCore/QtAlgorithms>
 
 #include "configuration/configuration-manager.h"
+#include "plugin/plugin-injected-factory.h"
+#include "storage/storage-point-factory.h"
 
 #include "mobile-number.h"
 
 #include "mobile-number-manager.h"
 
-MobileNumberManager * MobileNumberManager::Instance = 0;
-
-void MobileNumberManager::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-MobileNumberManager * MobileNumberManager::instance()
-{
-	if (!Instance)
-		Instance = new MobileNumberManager();
-
-	return Instance;
-}
-
-MobileNumberManager::MobileNumberManager()
+MobileNumberManager::MobileNumberManager(QObject *parent) :
+		StorableObject{parent}
 {
 	setState(StateNotLoaded);
-
-	ConfigurationManager::instance()->registerStorableObject(this);
 }
 
 MobileNumberManager::~MobileNumberManager()
 {
-	ConfigurationManager::instance()->unregisterStorableObject(this);
-
 	qDeleteAll(Numbers);
 }
 
+void MobileNumberManager::setConfigurationManager(ConfigurationManager *configurationManager)
+{
+	m_configurationManager = configurationManager;
+}
+
+void MobileNumberManager::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void MobileNumberManager::init()
+{
+	m_configurationManager->registerStorableObject(this);
+}
+
+void MobileNumberManager::done()
+{
+	m_configurationManager->unregisterStorableObject(this);
+}
+
 void MobileNumberManager::registerNumber(QString number, QString gatewayId)
 {
 	foreach (MobileNumber *n, Numbers)
@@ -68,7 +70,7 @@ void MobileNumberManager::registerNumber(QString number, QString gatewayId)
 			return;
 		}
 
-	Numbers.append(new MobileNumber(number, gatewayId));
+	Numbers.append(m_pluginInjectedFactory->makeInjected<MobileNumber>(this, number, gatewayId));
 }
 
 void MobileNumberManager::unregisterNumber(QString number)
@@ -84,7 +86,7 @@ void MobileNumberManager::unregisterNumber(QString number)
 
 std::shared_ptr<StoragePoint> MobileNumberManager::createStoragePoint()
 {
-	return std::make_shared<StoragePoint>(xml_config_file, xml_config_file->getNode("MobileNumbers"));
+	return storagePointFactory()->createStoragePoint("MobileNumbers");
 }
 
 StorableObject * MobileNumberManager::storageParent()
@@ -99,7 +101,7 @@ void MobileNumberManager::load()
 
 	StorableObject::load();
 
-	XmlConfigFile *configurationStorage = storage()->storage();
+	ConfigurationApi *configurationStorage = storage()->storage();
 	QDomElement mobileNumbersNode = storage()->point();
 	if (mobileNumbersNode.isNull())
 		return;
@@ -111,7 +113,7 @@ void MobileNumberManager::load()
 			continue;
 
 		auto numberStoragePoint = std::make_shared<StoragePoint>(configurationStorage, mobileNumberElement);
-		MobileNumber *number = new MobileNumber();
+		MobileNumber *number = m_pluginInjectedFactory->makeInjected<MobileNumber>(this);
 		number->setStorage(numberStoragePoint);
 		number->setState(StateNotLoaded);
 		number->ensureLoaded();
@@ -141,3 +143,5 @@ QString MobileNumberManager::gatewayId(const QString &mobileNumber)
 
 	return QString();
 }
+
+#include "moc_mobile-number-manager.cpp"
