@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,24 +18,26 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MOBILE_NUMBER_MANAGER_H
-#define MOBILE_NUMBER_MANAGER_H
+#pragma once
 
 #include "storage/storable-object.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class ConfigurationManager;
+class PluginInjectedFactory;
 class MobileNumber;
 
 class MobileNumberManager : public StorableObject
 {
-	Q_DISABLE_COPY(MobileNumberManager)
+	Q_OBJECT
 
-	static MobileNumberManager *Instance;
+	QPointer<ConfigurationManager> m_configurationManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
 
 	QList<MobileNumber *> Numbers;
 
-	MobileNumberManager();
-	virtual ~MobileNumberManager();
-
 protected:
 	virtual std::shared_ptr<StoragePoint> createStoragePoint();
 
@@ -45,18 +45,22 @@ protected:
 	virtual void store();
 
 public:
-	static MobileNumberManager * instance();
-	static void destroyInstance();
+	Q_INVOKABLE explicit MobileNumberManager(QObject *parent = nullptr);
+	virtual ~MobileNumberManager();
 
 	void registerNumber(QString number, QString gatewayId);
 	void unregisterNumber(QString number);
 
-	virtual QString storageNodeName() { return QLatin1String("MobileNumbers"); }
-	virtual QString storageNodeItemName() { return QLatin1String("MobileNumber"); }
+	virtual QString storageNodeName() { return QStringLiteral("MobileNumbers"); }
+	virtual QString storageNodeItemName() { return QStringLiteral("MobileNumber"); }
 	virtual StorableObject * storageParent();
 
 	QString gatewayId(const QString &mobileNumber);
 
-};
+private slots:
+	INJEQT_SET void setConfigurationManager(ConfigurationManager *configurationManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
 
-#endif // MOBILE_NUMBER_MANAGER_H
+};
