@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,13 +21,16 @@
 
 #include "mobile-number.h"
 
-MobileNumber::MobileNumber()
+MobileNumber::MobileNumber(MobileNumberManager *mobileNumberManager) :
+		m_mobileNumberManager{mobileNumberManager}
 {
 	setUuid(QUuid::createUuid());
 }
 
-MobileNumber::MobileNumber(QString number, QString gatewayId) :
-		Number(number), GatewayId(gatewayId)
+MobileNumber::MobileNumber(MobileNumberManager *mobileNumberManager, QString number, QString gatewayId) :
+		m_mobileNumberManager{mobileNumberManager},
+		m_number{number},
+		m_gatewayId{gatewayId}
 {
 	setUuid(QUuid::createUuid());
 }
@@ -49,8 +47,8 @@ void MobileNumber::load()
 	UuidStorableObject::load();
 
 	setUuid(loadAttribute<QString>("uuid"));
-	Number = loadValue<QString>("Number");
-	GatewayId = loadValue<QString>("Gateway");
+	m_number = loadValue<QString>("Number");
+	m_gatewayId = loadValue<QString>("Gateway");
 }
 
 void MobileNumber::store()
@@ -63,11 +61,11 @@ void MobileNumber::store()
 	UuidStorableObject::store();
 
 	storeAttribute("uuid", uuid().toString());
-	storeValue("Number", Number);
-	storeValue("Gateway", GatewayId);
+	storeValue("Number", m_number);
+	storeValue("Gateway", m_gatewayId);
 }
 
 StorableObject * MobileNumber::storageParent()
 {
-	return MobileNumberManager::instance();
+	return m_mobileNumberManager;
 }
