@@ -1,13 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
  * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,37 +19,52 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "network-access-manager-wrapper.h"
+
+#include "scripts/network-reply-wrapper.h"
+
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "network/proxy/network-proxy-manager.h"
+
 #include <QtCore/QUrl>
 #include <QtNetwork/QNetworkProxy>
 #include <QtNetwork/QNetworkReply>
 #include <QtNetwork/QNetworkRequest>
 #include <QtScript/QScriptEngine>
 
-#include "configuration/configuration-file.h"
-#include "network/proxy/network-proxy-manager.h"
-
-#include "scripts/network-reply-wrapper.h"
-
-#include "network-access-manager-wrapper.h"
-
 NetworkAccessManagerWrapper::NetworkAccessManagerWrapper(QScriptEngine *engine, QObject *parent) :
 		QNetworkAccessManager(parent), Engine(engine), Utf8(false)
 {
-	configurationUpdated();
 }
 
 NetworkAccessManagerWrapper::~NetworkAccessManagerWrapper()
 {
 }
 
+void NetworkAccessManagerWrapper::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void NetworkAccessManagerWrapper::setNetworkProxyManager(NetworkProxyManager *networkProxyManager)
+{
+	m_networkProxyManager = networkProxyManager;
+}
+
+void NetworkAccessManagerWrapper::init()
+{
+	configurationUpdated();
+}
+
 void NetworkAccessManagerWrapper::configurationUpdated()
 {
 	NetworkProxy networkProxy;
 
-	if (config_file.readBoolEntry("SMS", "DefaultProxy", true))
-		networkProxy = NetworkProxyManager::instance()->defaultProxy();
+	if (m_configuration->deprecatedApi()->readBoolEntry("SMS", "DefaultProxy", true))
+		networkProxy = m_networkProxyManager->defaultProxy();
 	else
-		networkProxy = NetworkProxyManager::instance()->byUuid(config_file.readEntry("SMS", "Proxy"));
+		networkProxy = m_networkProxyManager->byUuid(m_configuration->deprecatedApi()->readEntry("SMS", "Proxy"));
 
 	QNetworkProxy proxy;
 
