@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,73 +24,67 @@
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
 #include <QtCore/QTextStream>
-#include <QtGui/QMainWindow>
 #include <QtScript/QScriptEngine>
+#include <QtWidgets/QMainWindow>
 #if SMS_USE_DEBUGGER
 #include <QtScriptTools/QScriptEngineDebugger>
 #endif
 
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "scripts/network-access-manager-wrapper.h"
 #include "scripts/sms-translator.h"
 
 #include "sms-script-manager.h"
 
-SmsScriptsManager * SmsScriptsManager::Instance = 0;
-
-SmsScriptsManager * SmsScriptsManager::instance()
+SmsScriptsManager::SmsScriptsManager(QObject *parent) :
+		QObject{parent}
 {
-	if (!Instance)
-	{
-		Instance = new SmsScriptsManager();
-		Instance->init();
-	}
-
-	return Instance;
-}
-
-void SmsScriptsManager::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-SmsScriptsManager::SmsScriptsManager()
-{
-	Engine = new QScriptEngine(this);
-	Network = new NetworkAccessManagerWrapper(Engine, this);
-
-	Engine->globalObject().setProperty("network", Engine->newQObject(Network));
-	Engine->globalObject().setProperty("translator", Engine->newQObject(new SmsTranslator(this)));
 }
 
 SmsScriptsManager::~SmsScriptsManager()
 {
 }
 
+void SmsScriptsManager::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void SmsScriptsManager::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
 void SmsScriptsManager::init()
 {
+	Engine = new QScriptEngine(this);
+	Network = m_pluginInjectedFactory->makeInjected<NetworkAccessManagerWrapper>(Engine, this);
+
+	Engine->globalObject().setProperty("network", Engine->newQObject(Network));
+	Engine->globalObject().setProperty("translator", Engine->newQObject(new SmsTranslator(this)));
+
 #if SMS_USE_DEBUGGER
  	QScriptEngineDebugger *debugger = new QScriptEngineDebugger(this);
  	debugger->attachTo(Engine);
  	debugger->standardWindow()->show();
 #endif
 
-	QString scriptPath = KaduPaths::instance()->profilePath() + QLatin1String("plugins/data/sms/scripts/gateway.js");
+	QString scriptPath = m_pathsProvider->profilePath() + QStringLiteral("plugins/data/sms/scripts/gateway.js");
 	if (QFile::exists(scriptPath))
 		loadScript(scriptPath);
 	else
 	{
-		scriptPath = KaduPaths::instance()->dataPath() + QLatin1String("plugins/data/sms/scripts/gateway.js");
+		scriptPath = m_pathsProvider->dataPath() + QStringLiteral("plugins/data/sms/scripts/gateway.js");
 		if (QFile::exists(scriptPath))
 			loadScript(scriptPath);
 		// TODO: maybe we should return here if no gateway.js was found?
 	}
 
 	// scripts from profile path can replace the ones from data path if the file name is the same
-	loadScripts(QDir(KaduPaths::instance()->profilePath() + QLatin1String("plugins/data/sms/scripts")));
-	loadScripts(QDir(KaduPaths::instance()->dataPath() + QLatin1String("plugins/data/sms/scripts")));
+	loadScripts(QDir(m_pathsProvider->profilePath() + QStringLiteral("plugins/data/sms/scripts")));
+	loadScripts(QDir(m_pathsProvider->dataPath() + QStringLiteral("plugins/data/sms/scripts")));
 }
 
 void SmsScriptsManager::loadScripts(const QDir &dir)
