@@ -1,12 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,43 +18,46 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SMS_SCRIPTS_MANAGER_H
-#define SMS_SCRIPTS_MANAGER_H
+#pragma once
 
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
 class QFileInfo;
 class QDir;
 class QScriptEngine;
 
+class PluginInjectedFactory;
 class NetworkAccessManagerWrapper;
+class PathsProvider;
 
 class SmsScriptsManager : public QObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(SmsScriptsManager)
 
-	static SmsScriptsManager *Instance;
+public:
+	Q_INVOKABLE explicit SmsScriptsManager(QObject *parent = nullptr);
+	virtual ~SmsScriptsManager();
+
+	void loadScript(const QFileInfo &fileInfo);
+
+	QScriptEngine * engine() { return Engine; }
+
+private:
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<PathsProvider> m_pathsProvider;
 
 	QScriptEngine *Engine;
 	NetworkAccessManagerWrapper *Network;
 
 	QList<QString> LoadedFiles;
 
-	SmsScriptsManager();
-	virtual ~SmsScriptsManager();
-
 	void loadScripts(const QDir &dir);
-	void init();
 
-public:
-	static SmsScriptsManager * instance();
-	static void destroyInstance();
-
-	void loadScript(const QFileInfo &fileInfo);
-
-	QScriptEngine * engine() { return Engine; }
+private slots:
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setPathsProvider(PathsProvider *pathsProvider);
+	INJEQT_INIT void init();
 
 };
-
-#endif // SMS_SCRIPTS_MANAGER_H
