@@ -1,11 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -50,7 +45,7 @@ public:
 	 * @short Create new instance of SmsTranslator.
 	 * @param parent QObject parent of new instance of SmsTranslator
 	 */
-	explicit SmsTranslator(QObject *parent = 0);
+	explicit SmsTranslator(QObject *parent = nullptr);
 	virtual ~SmsTranslator();
 
 public slots:
