@@ -1,17 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004, 2008, 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2011 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2004, 2005, 2006, 2007 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2009 Longer (longer89@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,16 +20,19 @@
  */
 
 #include <QtCore/QProcess>
-#include <QtGui/QCheckBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QGridLayout>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QListWidget>
-#include <QtGui/QPushButton>
-#include <QtGui/QTextEdit>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTextEdit>
 
 #include "buddies/buddy-manager.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "configuration/gui/configuration-ui-handler-repository.h"
+#include "core/core.h"
 #include "core/core.h"
 #include "gui/hot-key.h"
 #include "gui/widgets/configuration/config-combo-box.h"
@@ -46,11 +40,12 @@
 #include "gui/widgets/configuration/config-line-edit.h"
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/windows/kadu-window.h"
+#include "gui/windows/main-configuration-window.h"
 #include "gui/windows/message-dialog.h"
 #include "icons/icons-manager.h"
 #include "debug.h"
 
-#include "misc/kadu-paths.h"
+#include "misc/paths-provider.h"
 
 #include "gui/windows/sms-dialog.h"
 
@@ -58,30 +53,8 @@
 
 #include "sms-configuration-ui-handler.h"
 
-SmsConfigurationUiHandler *SmsConfigurationUiHandler::Instance = 0;
-
-void SmsConfigurationUiHandler::registerConfigurationUi()
-{
-	if (!Instance)
-	{
-		Instance = new SmsConfigurationUiHandler();
-		MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/sms.ui"));
-		MainConfigurationWindow::registerUiHandler(Instance);
-	}
-}
-
-void SmsConfigurationUiHandler::unregisterConfigurationUi()
-{
-	if (Instance)
-	{
-		MainConfigurationWindow::unregisterUiHandler(Instance);
-		MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/sms.ui"));
-		delete Instance;
-		Instance = 0;
-	}
-}
-
-SmsConfigurationUiHandler::SmsConfigurationUiHandler() :
+SmsConfigurationUiHandler::SmsConfigurationUiHandler(QObject *parent) :
+	QObject{parent},
 	useBuiltIn{},
 	customApp{},
 	useCustomString{},
@@ -92,13 +65,22 @@ SmsConfigurationUiHandler::SmsConfigurationUiHandler() :
 	EraOmnixUser{},
 	EraOmnixPassword{}
 {
-	createDefaultConfiguration();
 }
 
 SmsConfigurationUiHandler::~SmsConfigurationUiHandler()
 {
 }
 
+void SmsConfigurationUiHandler::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void SmsConfigurationUiHandler::init()
+{
+	createDefaultConfiguration();
+}
+
 void SmsConfigurationUiHandler::onSmsBuildInCheckToggle(bool value)
 {
 	if (value)
@@ -158,14 +140,22 @@ void SmsConfigurationUiHandler::mainConfigurationWindowCreated(MainConfiguration
 	EraOmnixPassword->setEchoMode(QLineEdit::Password);
 }
 
+void SmsConfigurationUiHandler::mainConfigurationWindowDestroyed()
+{
+}
+
+void SmsConfigurationUiHandler::mainConfigurationWindowApplied()
+{
+}
+
 void SmsConfigurationUiHandler::createDefaultConfiguration()
 {
-	config_file.addVariable("SMS", "Priority", QString());
-	config_file.addVariable("SMS", "BuiltInApp", true);
-	config_file.addVariable("SMS", "SmsNick", QString());
-	config_file.addVariable("SMS", "UseCustomString", false);
+	m_configuration->deprecatedApi()->addVariable("SMS", "Priority", QString());
+	m_configuration->deprecatedApi()->addVariable("SMS", "BuiltInApp", true);
+	m_configuration->deprecatedApi()->addVariable("SMS", "SmsNick", QString());
+	m_configuration->deprecatedApi()->addVariable("SMS", "UseCustomString", false);
 
-	config_file.addVariable("ShortCuts", "kadu_sendsms", "Ctrl+S");
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "kadu_sendsms", "Ctrl+S");
 }
 
 #include "moc_sms-configuration-ui-handler.cpp"
