@@ -1,17 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2004, 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2011 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2003, 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2002, 2003 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2008, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2004, 2005, 2006 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2002 Dariusz Jagodzik (mast3r@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,25 +18,26 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SMS_CONFIGURATION_UI_HANDLER_H
-#define SMS_CONFIGURATION_UI_HANDLER_H
+#pragma once
 
 #include <QtCore/QBuffer>
 #include <QtCore/QMap>
-#include <QtGui/QDialog>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QWidget>
+#include <QtWidgets/QDialog>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 #include "buddies/buddy-manager.h"
 #include "chat/chat.h"
+#include "configuration/gui/configuration-ui-handler.h"
 #include "gui/actions/action.h"
-#include "gui/windows/main-configuration-window.h"
 
 #include "sms_exports.h"
 
 class ConfigComboBox;
 class ConfigLineEdit;
+class Configuration;
 
 class QCheckBox;
 class QComboBox;
@@ -54,11 +45,11 @@ class QListWidget;
 class QProcess;
 class QTextEdit;
 
-class SMSAPI SmsConfigurationUiHandler : public ConfigurationUiHandler
+class SMSAPI SmsConfigurationUiHandler : public QObject, public ConfigurationUiHandler
 {
 	Q_OBJECT
 
-	static SmsConfigurationUiHandler *Instance;
+	QPointer<Configuration> m_configuration;
 
 	QCheckBox *useBuiltIn;
 	QLineEdit *customApp;
@@ -72,18 +63,19 @@ class SMSAPI SmsConfigurationUiHandler : public ConfigurationUiHandler
 
 	void createDefaultConfiguration();
 
-	SmsConfigurationUiHandler();
-	virtual ~SmsConfigurationUiHandler();
-
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_INIT void init();
+
 	void onSmsBuildInCheckToggle(bool);
 	void onEraGatewayChanged(int);
 
 public:
-	static void registerConfigurationUi();
-	static void unregisterConfigurationUi();
+	Q_INVOKABLE explicit SmsConfigurationUiHandler(QObject *parent = nullptr);
+	virtual ~SmsConfigurationUiHandler();
+
+	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow) override;
+	virtual void mainConfigurationWindowDestroyed() override;
+	virtual void mainConfigurationWindowApplied() override;
 
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
 };
-
-#endif // SMS_CONFIGURATION_UI_HANDLER_H
