@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2007, 2008, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,26 +17,33 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SMS_EXTERNAL_SENDER_H
-#define SMS_EXTERNAL_SENDER_H
+#pragma once
 
 #include "sms-sender.h"
 
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+
 class QProcess;
 
 class SmsExternalSender : public SmsSender
 {
 	Q_OBJECT
 
+	QPointer<Configuration> m_configuration;
 	QProcess *Process;
 
 	QStringList buildProgramArguments(const QString &message);
 
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+
 	void processFinished();
 
 public:
-	explicit SmsExternalSender(const QString &number, QObject *parent = 0);
+	explicit SmsExternalSender(const QString &number, QObject *parent = nullptr);
 	virtual ~SmsExternalSender();
 
 	virtual void sendMessage(const QString& message);
@@ -49,5 +52,3 @@ public slots:
 	virtual void cancel();
 
 };
-
-#endif // SMS_EXTERNAL_SENDER_H
