@@ -1,10 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,35 +17,36 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SMS_GATEWAY_MANAGER_H
-#define SMS_GATEWAY_MANAGER_H
+#pragma once
 
 #include <QtCore/QPair>
+#include <QtCore/QPointer>
 #include <QtCore/QStringList>
+#include <injeqt/injeqt.h>
 
 class SmsGateway;
+class SmsScriptsManager;
 
-class SmsGatewayManager
+class SmsGatewayManager : public QObject
 {
-	Q_DISABLE_COPY(SmsGatewayManager)
+	Q_OBJECT
 
-	static SmsGatewayManager *Instance;
-
-	QList<SmsGateway> Items;
-
-	SmsGatewayManager();
-	~SmsGatewayManager();
+public:
+	Q_INVOKABLE explicit SmsGatewayManager(QObject *parent = nullptr);
+	virtual ~SmsGatewayManager();
 
 	void load();
 
-public:
-	static SmsGatewayManager * instance();
-	static void destroyInstance();
-
-	const QList<SmsGateway> & items() const { return Items; }
+	const QList<SmsGateway> & items() const { return m_items; }
 
 	SmsGateway byId(const QString &id) const;
 
-};
+private:
+	QPointer<SmsScriptsManager> m_smsScriptsManager;
 
-#endif // SMS_GATEWAY_MANAGER_H
+	QList<SmsGateway> m_items;
+
+private slots:
+	INJEQT_SET void setSmsScriptsManager(SmsScriptsManager *smsScriptsManager);
+
+};
