@@ -1,9 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +23,8 @@
 #include <QtNetwork/QNetworkReply>
 #include <QtScript/QScriptEngine>
 
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "gui/windows/message-dialog.h"
 #include "debug.h"
 
@@ -35,8 +35,12 @@
 
 #include "sms-internal-sender.h"
 
-SmsInternalSender::SmsInternalSender(const QString &number, const SmsGateway &gateway, QObject *parent) :
-		SmsSender(number, parent), Gateway(gateway), TokenJob(0)
+SmsInternalSender::SmsInternalSender(SmsGatewayManager *smsGatewayManager, SmsScriptsManager *smsScriptsManager, const QString &number, const SmsGateway &gateway, QObject *parent) :
+		SmsSender{number, parent},
+		m_smsGatewayManager{smsGatewayManager},
+		m_smsScriptsManager{smsScriptsManager},
+		Gateway{gateway},
+		TokenJob{0}
 {
 }
 
@@ -44,6 +48,11 @@ SmsInternalSender::~SmsInternalSender()
 {
 }
 
+void SmsInternalSender::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
 void SmsInternalSender::sendMessage(const QString &message)
 {
 	Message = message;
@@ -106,7 +115,7 @@ void SmsInternalSender::gatewayQueryDone(const QString &gatewayId)
 		return;
 	}
 
-	Gateway = SmsGatewayManager::instance()->byId(gatewayId);
+	Gateway = m_smsGatewayManager->byId(gatewayId);
 
 	emit progress("dialog-information", tr("Detected gateway: %1.").arg(Gateway.name()));
 
@@ -115,7 +124,7 @@ void SmsInternalSender::gatewayQueryDone(const QString &gatewayId)
 
 QScriptValue SmsInternalSender::readFromConfiguration(const QString &group, const QString &name, const QString &defaultValue)
 {
-	return config_file.readEntry(group, name, defaultValue);
+	return m_configuration->deprecatedApi()->readEntry(group, name, defaultValue);
 }
 
 void SmsInternalSender::sendSms()
@@ -124,7 +133,7 @@ void SmsInternalSender::sendSms()
 
 	emit progress("dialog-information", tr("Sending SMS..."));
 
-	QScriptEngine *engine = SmsScriptsManager::instance()->engine();
+	QScriptEngine *engine = m_smsScriptsManager->engine();
 
 	QScriptValue jsGatewayManagerObject = engine->evaluate("gatewayManager");
 	QScriptValue jsSendSms = jsGatewayManagerObject.property("sendSms");
