@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,21 +18,29 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SMS_INTERNAL_SENDER_H
-#define SMS_INTERNAL_SENDER_H
+#pragma once
 
+#include <QtCore/QPointer>
 #include <QtScript/QScriptValue>
+#include <injeqt/injeqt.h>
 
 #include "sms-gateway.h"
 
 #include "sms-sender.h"
 
+class Configuration;
+class SmsGatewayManager;
+class SmsScriptsManager;
 class SmsTokenReadJob;
 
 class SmsInternalSender : public SmsSender
 {
 	Q_OBJECT
 
+	QPointer<Configuration> m_configuration;
+	QPointer<SmsGatewayManager> m_smsGatewayManager;
+	QPointer<SmsScriptsManager> m_smsScriptsManager;
+
 	SmsGateway Gateway;
 	SmsTokenReadJob *TokenJob;
 
@@ -44,10 +50,12 @@ class SmsInternalSender : public SmsSender
 	void sendSms();
 
 private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+
 	void jobFinished(bool ok, const QString &entryIcon, const QString &entryMessage);
 
 public:
-	explicit SmsInternalSender(const QString &number, const SmsGateway &gateway, QObject *parent = 0);
+	explicit SmsInternalSender(SmsGatewayManager *smsGatewayManager, SmsScriptsManager *smsScriptsManager, const QString &number, const SmsGateway &gateway, QObject *parent = nullptr);
 	virtual ~SmsInternalSender();
 
 	virtual void sendMessage(const QString &message);
@@ -66,5 +74,3 @@ public slots:
 	void failure(const QString &errorMessage);
 
 };
-
-#endif // SMS_INTERNAL_SENDER_H
