@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -104,12 +104,12 @@ void SmsTokenReadJob::tokenValueEntered(const QString &tokenValue)
 {
 	if (tokenValue.isEmpty())
 	{
-		emit progress("dialog-error", tr("No token value provided."));
-		emit finished(false, "dialog-error", QString());
+		emit progress(QStringLiteral("dialog-error"), tr("No token value provided."));
+		emit finished(false, QStringLiteral("dialog-error"), QString());
 		return;
 	}
 
-	emit progress("dialog-information", tr("Received token value."));
+	emit progress(QStringLiteral("dialog-information"), tr("Received token value."));
 
 	QScriptValueList arguments;
 	arguments.append(tokenValue);
