@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -60,7 +60,7 @@ public:
 	 * @short Create new SmsTokenReadJob instance.
 	 * @param parent QObject parent of new object
 	 */
-	explicit SmsTokenReadJob(QObject *parent = 0);
+	explicit SmsTokenReadJob(QObject *parent = nullptr);
 	virtual ~SmsTokenReadJob();
 
 	/**
