@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -89,10 +91,6 @@ Arguments should be separated with spaces. %k argument is converted to number, %
 </context>
 <context>
     <name>SmsDialog</name>
-    <message>
-        <source>Send SMS</source>
-        <translation>Send SMS</translation>
-    </message>
     <message>
         <source>Recipient</source>
         <translation>Recipient</translation>
@@ -219,4 +217,4 @@ Arguments should be separated with spaces. %k argument is converted to number, %
         <translation>Received token value.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
