@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -35,10 +37,25 @@
     </message>
 </context>
 <context>
-    <name>SoundActions</name>
+    <name>SoundBuddyConfigurationWidget</name>
     <message>
-        <source>Play Sounds</source>
-        <translation>Play Sounds</translation>
+        <source>Use custom sound</source>
+        <translation>Use custom sound</translation>
+    </message>
+    <message>
+        <source>Sound</source>
+        <translation>Sound</translation>
+    </message>
+</context>
+<context>
+    <name>SoundChatConfigurationWidget</name>
+    <message>
+        <source>Sound</source>
+        <translation>Sound</translation>
+    </message>
+    <message>
+        <source>Use custom sound</source>
+        <translation>Use custom sound</translation>
     </message>
 </context>
 <context>
@@ -48,4 +65,11 @@
         <translation>Custom</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>SoundMuteAction</name>
+    <message>
+        <source>Play Sounds</source>
+        <translation>Play Sounds</translation>
+    </message>
+</context>
+</TS>
