@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -35,10 +35,25 @@
     </message>
 </context>
 <context>
-    <name>SoundActions</name>
+    <name>SoundBuddyConfigurationWidget</name>
     <message>
-        <source>Play Sounds</source>
-        <translation>Jouer les sons</translation>
+        <source>Use custom sound</source>
+        <translation>Utiliser des sons personnalisés</translation>
+    </message>
+    <message>
+        <source>Sound</source>
+        <translation>Son</translation>
+    </message>
+</context>
+<context>
+    <name>SoundChatConfigurationWidget</name>
+    <message>
+        <source>Sound</source>
+        <translation>Son</translation>
+    </message>
+    <message>
+        <source>Use custom sound</source>
+        <translation>Utiliser des sons personnalisés</translation>
     </message>
 </context>
 <context>
@@ -48,4 +63,11 @@
         <translation>Personnalisé</translation>
     </message>
 </context>
+<context>
+    <name>SoundMuteAction</name>
+    <message>
+        <source>Play Sounds</source>
+        <translation>Jouer les sons</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
