@@ -1,51 +1,73 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
 <context>
     <name>@default</name>
     <message>
         <source>Sound</source>
-        <translation type="unfinished"/>
+        <translation>Ses</translation>
     </message>
     <message>
         <source>Notifications</source>
-        <translation type="unfinished"/>
+        <translation>Uyarılar</translation>
     </message>
     <message>
         <source>General</source>
-        <translation type="unfinished"/>
+        <translation>Genel</translation>
     </message>
     <message>
         <source>Sound theme</source>
-        <translation type="unfinished"/>
+        <translation>Ses teması</translation>
     </message>
     <message>
         <source>Sound paths</source>
-        <translation type="unfinished"/>
+        <translation>Ses yolları</translation>
     </message>
     <message>
         <source>Test sound playing</source>
-        <translation type="unfinished"/>
+        <translation>Ses çalarak test edin</translation>
     </message>
     <message>
         <source>Play a sound</source>
-        <translation type="unfinished"/>
+        <translation>Bir ses çal</translation>
     </message>
     <message>
         <source>Enable sound notifications</source>
-        <translation type="unfinished"/>
+        <translation>Sesli uyarılar olsun</translation>
     </message>
 </context>
 <context>
-    <name>SoundActions</name>
+    <name>SoundBuddyConfigurationWidget</name>
     <message>
-        <source>Play Sounds</source>
-        <translation type="unfinished"/>
+        <source>Use custom sound</source>
+        <translation>Özel ses kullan</translation>
+    </message>
+    <message>
+        <source>Sound</source>
+        <translation>Ses</translation>
+    </message>
+</context>
+<context>
+    <name>SoundChatConfigurationWidget</name>
+    <message>
+        <source>Sound</source>
+        <translation>Ses</translation>
+    </message>
+    <message>
+        <source>Use custom sound</source>
+        <translation>Özel ses kullan</translation>
     </message>
 </context>
 <context>
     <name>SoundConfigurationUiHandler</name>
     <message>
         <source>Custom</source>
-        <translation type="unfinished"/>
+        <translation>Özel</translation>
+    </message>
+</context>
+<context>
+    <name>SoundMuteAction</name>
+    <message>
+        <source>Play Sounds</source>
+        <translation>Sesleri Yürüt</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
