@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,33 +18,40 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SPEECH_CONFIGURATION_WIDGET_H
-#define SPEECH_CONFIGURATION_WIDGET_H
-
-#include <QtCore/QMap>
+#pragma once
 
 #include "gui/widgets/configuration/notifier-configuration-widget.h"
 
+#include <QtCore/QMap>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+
 class QLineEdit;
 
 class SpeechConfigurationWidget : public NotifierConfigurationWidget
 {
 	Q_OBJECT
 
+	QPointer<Configuration> m_configuration;
+
 	QMap<QString, QString> maleFormat;
 	QMap<QString, QString> femaleFormat;
-	QString currentNotifyEvent;
+	QString currentNotificationEvent;
 
 	QLineEdit *maleLineEdit;
 	QLineEdit *femaleLineEdit;
 
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+
 public:
-	explicit SpeechConfigurationWidget(QWidget *parent = 0);
+	explicit SpeechConfigurationWidget(QWidget *parent = nullptr);
 	virtual ~SpeechConfigurationWidget();
 
 	virtual void loadNotifyConfigurations() {}
 	virtual void saveNotifyConfigurations();
 	virtual void switchToEvent(const QString &event);
-};
 
-#endif // SPEECH_CONFIGURATION_WIDGET_H
+};
