@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,50 +18,52 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SPEECH_H
-#define SPEECH_H
+#pragma once
 
+#include "notification/notifier.h"
+
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtCore/QTime>
+#include <injeqt/injeqt.h>
 
-#include "notify/notifier.h"
-
-class Notification;
+class Configuration;
+struct Notification;
+class Parser;
 
 /**
  * @defgroup speech Speech
  * @{
  */
 
-class Speech : public Notifier
+class Speech : public QObject, public Notifier
 {
 	Q_OBJECT
 
-	static Speech *Instance;
-
 	QTime lastSpeech;
 
-	void import_0_5_0_Configuration();
-	void import_0_5_0_ConfigurationFromTo(const QString &from, const QString &to);
-	void import_0_6_5_configuration();
-
 public:
-	Speech();
+	Q_INVOKABLE explicit Speech(QObject *parent = nullptr);
 	virtual ~Speech();
 
-	virtual void notify(Notification *notification);
+	virtual void notify(const Notification &notification);
 	NotifierConfigurationWidget * createConfigurationWidget(QWidget *parent);
 
 	void say(const QString &s,
-		const QString &path = QString(),
-		bool klatt = false, bool melodie = false,
-		const QString &sound_system = QString(), const QString &device = QString(),
-		int freq = 0, int tempo = 0, int basefreq = 0);
+	const QString &path = QString(),
+	bool klatt = false, bool melodie = false,
+	const QString &sound_system = QString(), const QString &device = QString(),
+	int freq = 0, int tempo = 0, int basefreq = 0);
+
+private:
+	QPointer<Configuration> m_configuration;
+	QPointer<Parser> m_parser;
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setParser(Parser *parser);
+	INJEQT_INIT void init();
 
-	static Speech * instance();
-	static void createInstance();
-	static void destroyInstance();
 };
 
 /** @} */
-
-#endif // SPEECH_H
