@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -83,7 +83,7 @@
     </message>
     <message>
         <source>Read a text</source>
-        <translation type="unfinished"/>
+        <translation>Leggi un testo</translation>
     </message>
 </context>
 <context>
