@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,44 +19,24 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SPELLCHECKER_CONFIGURATION_H
-#define SPELLCHECKER_CONFIGURATION_H
-
-#include <QtCore/QStringList>
-#include <QtGui/QColor>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 
-class SpellcheckerConfiguration : private ConfigurationAwareObject
+#include <QtCore/QPointer>
+#include <QtCore/QStringList>
+#include <QtGui/QColor>
+#include <injeqt/injeqt.h>
+
+class Configuration;
+
+class SpellcheckerConfiguration : public QObject, private ConfigurationAwareObject
 {
-	Q_DISABLE_COPY(SpellcheckerConfiguration)
-
-	static SpellcheckerConfiguration *Instance;
-
-	bool FullyLoaded;
-	bool Bold;
-	bool Italic;
-	bool Underline;
-	bool Accents;
-	bool Case;
-	bool Suggester;
-	QColor Color;
-	QStringList Checked;
-	int SuggesterWordCount;
-
-	explicit SpellcheckerConfiguration();
-	virtual ~SpellcheckerConfiguration();
-
-	void createDefaultConfiguration();
-
-protected:
-	virtual void configurationUpdated();
+	Q_OBJECT
 
 public:
-	static SpellcheckerConfiguration *instance();
-
-	static void createInstance();
-	static void destroyInstance();
+	Q_INVOKABLE explicit SpellcheckerConfiguration(QObject *parent = nullptr);
+	virtual ~SpellcheckerConfiguration();
 
 	bool bold() const { return Bold; }
 	bool italic() const { return Italic; }
@@ -70,6 +50,29 @@ public:
 
 	void setChecked(const QStringList &checked);
 
-};
+signals:
+	void updated();
 
-#endif /* SPELLCHECKER_CONFIGURATION_H */
+protected:
+	virtual void configurationUpdated();
+
+private:
+	QPointer<Configuration> m_configuration;
+
+	bool Bold;
+	bool Italic;
+	bool Underline;
+	bool Accents;
+	bool Case;
+	bool Suggester;
+	QColor Color;
+	QStringList Checked;
+	int SuggesterWordCount;
+
+	void createDefaultConfiguration();
+
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_INIT void init();
+
+};
