@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2008, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +18,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "spellchecker-plugin.h"
 #include "spellchecker.h"
 
 #include "highlighter.h"
@@ -35,8 +31,9 @@ void Highlighter::rehighlightAll()
 		highlighter->rehighlight();
 }
 
-Highlighter::Highlighter(QTextDocument *document) :
-		QSyntaxHighlighter(document)
+Highlighter::Highlighter(SpellChecker *spellChecker, QTextDocument *document) :
+		QSyntaxHighlighter(document),
+		m_spellChecker{spellChecker}
 {
 	Highlighters.append(this);
 }
@@ -53,7 +50,7 @@ void Highlighter::highlightBlock(const QString& text)
 	int index = 0;
 	while ((index = word.indexIn(text, index)) != -1)
 	{
-		if (!SpellCheckerPlugin::instance()->spellChecker()->checkWord(word.cap()))
+		if (!m_spellChecker->checkWord(word.cap()))
 			setFormat(index, word.matchedLength(), HighlightFormat);
 		index += word.matchedLength();
 	}
