@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,37 +20,23 @@
  */
 
 #include <QtGui/QMouseEvent>
-#include <QtGui/QTextEdit>
+#include <QtWidgets/QTextEdit>
 
+#include "gui/actions/actions.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
 #include "gui/widgets/custom-input-menu-manager.h"
 #include "gui/widgets/custom-input.h"
 #include "icons/kadu-icon.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "configuration/spellchecker-configuration.h"
-#include "spellchecker-plugin.h"
 #include "spellchecker.h"
 
 #include "suggester.h"
 
-Suggester * Suggester::Instance = 0;
-
-Suggester *Suggester::instance()
-{
-	if (!Instance)
-		Instance = new Suggester();
-
-	return Instance;
-}
-
-void Suggester::destroyInstance()
-{
-	delete Instance;
-	Instance = 0;
-}
-
-Suggester::Suggester()
+Suggester::Suggester(QObject *parent) :
+		QObject{parent}
 {
 }
 
@@ -59,9 +45,34 @@ Suggester::~Suggester()
 	clearWordMenu();
 }
 
+void Suggester::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void Suggester::setCustomInputMenuManager(CustomInputMenuManager *customInputMenuManager)
+{
+	m_customInputMenuManager = customInputMenuManager;
+}
+
+void Suggester::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void Suggester::setSpellcheckerConfiguration(SpellcheckerConfiguration *spellcheckerConfiguration)
+{
+	m_spellcheckerConfiguration = spellcheckerConfiguration;
+}
+
+void Suggester::setSpellChecker(SpellChecker *spellChecker)
+{
+	m_spellChecker = spellChecker;
+}
+
 void Suggester::buildSuggestList(const QString &word)
 {
-	SuggestionWordList = SpellCheckerPlugin::instance()->spellChecker()->buildSuggestList(word);
+	SuggestionWordList = m_spellChecker->buildSuggestList(word);
 }
 
 void Suggester::addWordListToMenu(const QTextCursor &textCursor)
@@ -70,19 +81,19 @@ void Suggester::addWordListToMenu(const QTextCursor &textCursor)
 
 	// Add new actions
 	foreach (const QString &listWord, SuggestionWordList)
-		SuggestActions.append(new ActionDescription(this, ActionDescription::TypeGlobal,
+		SuggestActions.append(m_pluginInjectedFactory->makeInjected<ActionDescription>(this, ActionDescription::TypeGlobal,
 					"spellcheckerSuggest#" + listWord, this, SLOT(replaceWithSuggest(QAction *)), KaduIcon(), listWord));
 
 	unsigned int actionPriority = 0;
 	foreach (ActionDescription *action, SuggestActions)
-		CustomInputMenuManager::instance()->addActionDescription(action, CustomInputMenuItem::MenuCategorySuggestion, actionPriority++);
+		m_customInputMenuManager->addActionDescription(action, CustomInputMenuItem::MenuCategorySuggestion, actionPriority++);
 }
 
 void Suggester::clearWordMenu()
 {
 	// Remove old actions
 	foreach (ActionDescription *action, SuggestActions)
-		CustomInputMenuManager::instance()->removeActionDescription(action);
+		m_customInputMenuManager->removeActionDescription(action);
 
 	qDeleteAll(SuggestActions);
 	SuggestActions.clear();
@@ -102,8 +113,8 @@ bool Suggester::eventFilter(QObject *object, QEvent *event)
 			textCursor.select(QTextCursor::WordUnderCursor);
 
 			if ((!textCursor.selectedText().isEmpty()) &&
-					(!SpellCheckerPlugin::instance()->spellChecker()->checkWord(textCursor.selectedText())) &&
-					 (SpellcheckerConfiguration::instance()->suggester()))
+					(!m_spellChecker->checkWord(textCursor.selectedText())) &&
+					 (m_spellcheckerConfiguration->suggester()))
 			{
 				buildSuggestList(textCursor.selectedText());
 				clearWordMenu();
