@@ -1,10 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 SÅawomir StÄpieÅ (s.stepien@interia.pl)
- * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
- * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2011 Slawomir Stepien (s.stepien@interia.pl)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,40 +18,53 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SUGGESTER_H
-#define SUGGESTER_H
+#pragma once
 
 #include <QtCore/QList>
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtCore/QStringList>
-#include <QtGui/QAction>
 #include <QtGui/QTextCursor>
+#include <QtWidgets/QAction>
+#include <injeqt/injeqt.h>
 
 class ActionDescription;
+class Actions;
+class CustomInputMenuManager;
+class PluginInjectedFactory;
+class SpellcheckerConfiguration;
+class SpellChecker;
 
 class Suggester : public QObject
 {
 	Q_OBJECT
-	Q_DISABLE_COPY(Suggester);
 
-	static Suggester *Instance;
+	QPointer<Actions> m_actions;
+	QPointer<CustomInputMenuManager> m_customInputMenuManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<SpellcheckerConfiguration> m_spellcheckerConfiguration;
+	QPointer<SpellChecker> m_spellChecker;
 
 	QStringList SuggestionWordList;
 	QTextCursor CurrentTextSelection;
 	QList<ActionDescription *> SuggestActions;
 
-	Suggester();
-	virtual ~Suggester();
-
 	void buildSuggestList(const QString &word);
 	void addWordListToMenu(const QTextCursor &textCursor);
 
+private slots:
+	INJEQT_SET void setActions(Actions *actions);
+	INJEQT_SET void setCustomInputMenuManager(CustomInputMenuManager *customInputMenuManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setSpellcheckerConfiguration(SpellcheckerConfiguration *spellcheckerConfiguration);
+	INJEQT_SET void setSpellChecker(SpellChecker *spellChecker);
+
 protected:
 	virtual bool eventFilter(QObject *object, QEvent *event);
 
 public:
-	static Suggester *instance();
-	static void destroyInstance();
+	Q_INVOKABLE explicit Suggester(QObject *parent = nullptr);
+	virtual ~Suggester();
 
 	void clearWordMenu();
 
@@ -62,5 +72,3 @@ public slots:
 	void replaceWithSuggest(QAction *sender);
 
 };
-
-#endif // SUGGESTER_H
