@@ -60,25 +60,28 @@
         <source>Could not find dictionary for %1 language.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Move to &apos;Checked&apos;</source>
-        <translation>Zu &apos;Überprüft&apos;</translation>
-    </message>
-    <message>
-        <source>Available languages</source>
-        <translation>Verfügbare Sprachen</translation>
-    </message>
-    <message>
-        <source>Move to &apos;Available languages&apos;</source>
-        <translation>Zu &apos;Verfügbare Sprachen&apos;</translation>
-    </message>
-    <message>
-        <source>Checked</source>
-        <translation>Überprüft</translation>
-    </message>
     <message>
         <source>Details</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SpellcheckerConfigurationUiHandler</name>
+    <message>
+        <source>Move to &apos;Checked&apos;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Available languages</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Move to &apos;Available languages&apos;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Checked</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 </TS>
\ No newline at end of file
