@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>@default</name>
     <message>
@@ -60,25 +62,28 @@
         <source>Could not find dictionary for %1 language.</source>
         <translation>Could not find dictionary for %1 language.</translation>
     </message>
-    <message>
-        <source>Move to &apos;Checked&apos;</source>
-        <translation>Move to &apos;Checked&apos;</translation>
-    </message>
-    <message>
-        <source>Available languages</source>
-        <translation>Available languages</translation>
-    </message>
-    <message>
-        <source>Move to &apos;Available languages&apos;</source>
-        <translation>Move to &apos;Available languages&apos;</translation>
-    </message>
-    <message>
-        <source>Checked</source>
-        <translation>Checked</translation>
-    </message>
     <message>
         <source>Details</source>
         <translation>Details</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>SpellcheckerConfigurationUiHandler</name>
+    <message>
+        <source>Move to &apos;Checked&apos;</source>
+        <translation type="unfinished">Move to &apos;Checked&apos;</translation>
+    </message>
+    <message>
+        <source>Available languages</source>
+        <translation type="unfinished">Available languages</translation>
+    </message>
+    <message>
+        <source>Move to &apos;Available languages&apos;</source>
+        <translation type="unfinished">Move to &apos;Available languages&apos;</translation>
+    </message>
+    <message>
+        <source>Checked</source>
+        <translation type="unfinished">Checked</translation>
+    </message>
+</context>
+</TS>
