@@ -60,25 +60,28 @@
         <source>Could not find dictionary for %1 language.</source>
         <translation>Não foi possível encontrar o dicionário para o idioma %1.</translation>
     </message>
-    <message>
-        <source>Move to &apos;Checked&apos;</source>
-        <translation>Mover para &apos;Verificado&apos;</translation>
-    </message>
-    <message>
-        <source>Available languages</source>
-        <translation>Idiomas disponíveis</translation>
-    </message>
-    <message>
-        <source>Move to &apos;Available languages&apos;</source>
-        <translation>Mover para &apos;Idiomas disponíveis&apos;</translation>
-    </message>
-    <message>
-        <source>Checked</source>
-        <translation>Verificado</translation>
-    </message>
     <message>
         <source>Details</source>
         <translation>Detalhes</translation>
     </message>
 </context>
+<context>
+    <name>SpellcheckerConfigurationUiHandler</name>
+    <message>
+        <source>Move to &apos;Checked&apos;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Available languages</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Move to &apos;Available languages&apos;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Checked</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 </TS>
\ No newline at end of file
