@@ -1,13 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2009, 2009, 2009, 2010, 2011 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2014 Michał Ziąbkowski (mziab@o2.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,10 +22,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QtConcurrent/QtConcurrentRun>
 #include <QtCore/QDir>
 #include <QtCore/QMutexLocker>
 #include <QtCore/QThread>
-#include <QtCore/QtConcurrentRun>
 #include <QtGui/QTextDocument>
 #include <QtSql/QSqlError>
 #include <QtSql/QSqlRecord>
@@ -35,26 +33,35 @@
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
 #include "buddies/buddy-manager.h"
+#include "buddies/buddy-storage.h"
 #include "chat/buddy-chat-manager.h"
 #include "chat/chat-details-buddy.h"
 #include "chat/chat-details.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/type/chat-type-contact.h"
-#include "configuration/configuration-file.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact-set.h"
-#include "core/core.h"
+#include "contacts/contact-storage.h"
 #include "formatted-string/composite-formatted-string.h"
 #include "formatted-string/formatted-string-factory.h"
 #include "formatted-string/formatted-string-plain-text-visitor.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/windows/message-dialog.h"
 #include "gui/windows/progress-window.h"
+#include "html/html-conversion.h"
+#include "html/html-string.h"
+#include "icons/icons-manager.h"
+#include "message/message-storage.h"
 #include "message/message.h"
 #include "message/sorted-messages.h"
 #include "misc/misc.h"
+#include "plugin/plugin-injected-factory.h"
 #include "status/status-type-data.h"
 #include "status/status-type-manager.h"
+#include "talkable/talkable-converter.h"
 #include "talkable/talkable.h"
 #include "debug.h"
 
@@ -76,42 +83,11 @@
 #define DATE_TITLE_LENGTH 120
 
 HistorySqlStorage::HistorySqlStorage(QObject *parent) :
-		HistoryStorage(parent), InitializerThread{}, ImportProgressWindow{},
-		AccountsMapping{}, ContactsMapping{}, ChatsMapping{}, DatabaseMutex{QMutex::NonRecursive},
-		ChatStorage{}, StatusStorage{}, SmsStorage{}
+		// using C++ initializers breaks Qt's lupdate
+		HistoryStorage(parent), InitializerThread(), ImportProgressWindow(),
+		AccountsMapping(), ContactsMapping(), ChatsMapping(), DatabaseMutex(QMutex::NonRecursive),
+		m_historyChatStorage(), StatusStorage(), SmsStorage()
 {
-	kdebugf();
-
-	if (!QSqlDatabase::isDriverAvailable("QSQLITE"))
-	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"),
-				tr("It seems your Qt library does not provide support for selected database. "
-				   "Please install Qt with %1 plugin.").arg("QSQLITE"));
-		return;
-	}
-
-	qRegisterMetaType<QSqlError>("QSqlError");
-
-	InitializerThread = new QThread();
-
-	// this object cannot have parent as it will be moved to a new thread
-	SqlInitializer *initializer = new SqlInitializer();
-	initializer->moveToThread(InitializerThread);
-
-	connect(InitializerThread, SIGNAL(started()), initializer, SLOT(initialize()));
-	connect(initializer, SIGNAL(progressMessage(QString,QString)),
-	        this, SLOT(initializerProgressMessage(QString,QString)));
-	connect(initializer, SIGNAL(progressFinished(bool,QString,QString)),
-	        this, SLOT(initializerProgressFinished(bool,QString,QString)));
-	connect(initializer, SIGNAL(databaseReady(bool)), this, SLOT(databaseReady(bool)));
-
-	InitializerThread->start();
-
-	ChatStorage = new SqlMessagesChatStorage(this);
-	StatusStorage = new SqlMessagesStatusStorage(this);
-	SmsStorage = new SqlMessagesSmsStorage(this);
-
-	History::instance()->registerStorage(this);
 }
 
 HistorySqlStorage::~HistorySqlStorage()
@@ -131,9 +107,106 @@ HistorySqlStorage::~HistorySqlStorage()
 		Database.commit();
 }
 
+void HistorySqlStorage::setBuddyChatManager(BuddyChatManager *buddyChatManager)
+{
+	m_buddyChatManager = buddyChatManager;
+}
+
+void HistorySqlStorage::setBuddyManager(BuddyManager *buddyManager)
+{
+	m_buddyManager = buddyManager;
+}
+
+void HistorySqlStorage::setBuddyStorage(BuddyStorage *buddyStorage)
+{
+	m_buddyStorage = buddyStorage;
+}
+
+void HistorySqlStorage::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void HistorySqlStorage::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void HistorySqlStorage::setContactStorage(ContactStorage *contactStorage)
+{
+	m_contactStorage = contactStorage;
+}
+
 void HistorySqlStorage::setFormattedStringFactory(FormattedStringFactory *formattedStringFactory)
 {
-	CurrentFormattedStringFactory = formattedStringFactory;
+	m_formattedStringFactory = formattedStringFactory;
+}
+
+void HistorySqlStorage::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void HistorySqlStorage::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void HistorySqlStorage::setMessageStorage(MessageStorage *messageStorage)
+{
+	m_messageStorage = messageStorage;
+}
+
+void HistorySqlStorage::setStatusTypeManager(StatusTypeManager *statusTypeManager)
+{
+	m_statusTypeManager = statusTypeManager;
+}
+
+void HistorySqlStorage::setTalkableConverter(TalkableConverter *talkableConverter)
+{
+	m_talkableConverter = talkableConverter;
+}
+
+void HistorySqlStorage::init()
+{
+	kdebugf();
+
+	if (!QSqlDatabase::isDriverAvailable("QSQLITE"))
+	{
+		MessageDialog::show(m_iconsManager->iconByPath(KaduIcon("dialog-warning")), tr("Kadu"),
+				tr("It seems your Qt library does not provide support for selected database. "
+				   "Please install Qt with %1 plugin.").arg("QSQLITE"));
+		return;
+	}
+
+	qRegisterMetaType<QSqlError>("QSqlError");
+
+	InitializerThread = new QThread();
+
+	// this object cannot have parent as it will be moved to a new thread
+	auto initializer = m_pluginInjectedFactory->makeInjected<SqlInitializer>();
+	initializer->moveToThread(InitializerThread);
+
+	connect(InitializerThread, SIGNAL(started()), initializer, SLOT(initialize()));
+	connect(initializer, SIGNAL(progressMessage(QString,QString)),
+	        this, SLOT(initializerProgressMessage(QString,QString)));
+	connect(initializer, SIGNAL(progressFinished(bool,QString,QString)),
+	        this, SLOT(initializerProgressFinished(bool,QString,QString)));
+	connect(initializer, SIGNAL(databaseReady(bool)), this, SLOT(databaseReady(bool)));
+
+	InitializerThread->start();
+
+	m_historyChatStorage = new SqlMessagesChatStorage(this);
+	StatusStorage = new SqlMessagesStatusStorage(this);
+	SmsStorage = new SqlMessagesSmsStorage(this);
+}
+
+void HistorySqlStorage::done()
+{
+	if (Database.isOpen())
+		Database.close();
+
+	QSqlDatabase::removeDatabase("kadu-history");
 }
 
 void HistorySqlStorage::ensureProgressWindowReady()
@@ -141,7 +214,7 @@ void HistorySqlStorage::ensureProgressWindowReady()
 	if (ImportProgressWindow)
 		return;
 
-	ImportProgressWindow = new ProgressWindow(tr("Preparing history database..."));
+	ImportProgressWindow = m_pluginInjectedFactory->makeInjected<ProgressWindow>(tr("Preparing history database..."));
 	ImportProgressWindow->setWindowTitle(tr("History"));
 	ImportProgressWindow->show();
 }
@@ -170,7 +243,7 @@ void HistorySqlStorage::databaseReady(bool ok)
 	{
 		initializerProgressFinished(false, "dialog-error",
 				tr("Opening database failed. Error message:\n%1").arg(Database.lastError().text()));
-		History::instance()->unregisterStorage(this);
+		// History::instance()->unregisterStorage(this); TODO: may be needed
 
 		if (InitializerThread)
 			InitializerThread->quit();
@@ -180,9 +253,9 @@ void HistorySqlStorage::databaseReady(bool ok)
 	Database.transaction();
 	initQueries();
 
-	AccountsMapping = new SqlAccountsMapping(Database, this);
-	ContactsMapping = new SqlContactsMapping(Database, AccountsMapping, this);
-	ChatsMapping = new SqlChatsMapping(Database, AccountsMapping, ContactsMapping, this);
+	AccountsMapping = m_pluginInjectedFactory->makeInjected<SqlAccountsMapping>(Database, this);
+	ContactsMapping = m_pluginInjectedFactory->makeInjected<SqlContactsMapping>(Database, AccountsMapping, this);
+	ChatsMapping = m_pluginInjectedFactory->makeInjected<SqlChatsMapping>(Database, AccountsMapping, ContactsMapping, this);
 
 	if (InitializerThread)
 		InitializerThread->quit();
@@ -222,7 +295,7 @@ void HistorySqlStorage::initQueries()
 QString HistorySqlStorage::chatIdList(const Chat &chat)
 {
 	if (!chat)
-		return QLatin1String("(0)");
+		return QStringLiteral("(0)");
 
 	ChatDetailsBuddy *buddyChat = qobject_cast<ChatDetailsBuddy *>(chat.details());
 	if (!buddyChat)
@@ -232,29 +305,29 @@ QString HistorySqlStorage::chatIdList(const Chat &chat)
 	foreach (const Chat &aggregatedChat, buddyChat->chats())
 		ids.append(QString::number(ChatsMapping->idByChat(aggregatedChat, false)));
 
-	return QString("(%1)").arg(ids.join(QLatin1String(", ")));
+	return QString("(%1)").arg(ids.join(QStringLiteral(", ")));
 }
 
 QString HistorySqlStorage::talkableContactsWhere(const Talkable &talkable)
 {
 	if (talkable.isValidBuddy())
-		return buddyContactsWhere(talkable.toBuddy());
+		return buddyContactsWhere(m_talkableConverter->toBuddy(talkable));
 	else if (talkable.isValidContact())
-		return QString("contact_id = %1").arg(ContactsMapping->idByContact(talkable.toContact(), true));
+		return QString("contact_id = %1").arg(ContactsMapping->idByContact(m_talkableConverter->toContact(talkable), true));
 
-	return QLatin1String("1");
+	return QStringLiteral("1");
 }
 
 QString HistorySqlStorage::buddyContactsWhere(const Buddy &buddy)
 {
 	if (!buddy || buddy.contacts().isEmpty())
-		return QLatin1String("0");
+		return QStringLiteral("0");
 
 	QStringList ids;
 	foreach (const Contact &contact, buddy.contacts())
 		ids.append(QString("%1").arg(ContactsMapping->idByContact(contact, true)));
 
-	return QString("contact_id IN (%1)").arg(ids.join(QLatin1String(", ")));
+	return QString("contact_id IN (%1)").arg(ids.join(QStringLiteral(", ")));
 }
 
 void HistorySqlStorage::sync()
@@ -297,7 +370,7 @@ int HistorySqlStorage::findOrCreateDate(const QDate &date)
 	if (query.next())
 	{
 		dateId = query.value(0).toInt();
-		Q_ASSERT(!query.next());
+		// Q_ASSERT(!query.next());
 	}
 	else
 	{
@@ -321,7 +394,7 @@ int HistorySqlStorage::saveMessageContent(const Message& message)
 	QSqlQuery saveMessageQuery = QSqlQuery(Database);
 	saveMessageQuery.prepare("INSERT INTO kadu_message_contents (content) VALUES (:content)");
 
-	saveMessageQuery.bindValue(":content", message.htmlContent());
+	saveMessageQuery.bindValue(":content", message.content().string());
 
 	executeQuery(saveMessageQuery);
 	int contentId = saveMessageQuery.lastInsertId().toInt();
@@ -368,7 +441,7 @@ void HistorySqlStorage::appendStatus(const Contact &contact, const Status &statu
 
 	QMutexLocker locker(&DatabaseMutex);
 
-	StatusTypeData statusTypeData = StatusTypeManager::instance()->statusTypeData(status.type());
+	StatusTypeData statusTypeData = m_statusTypeManager->statusTypeData(status.type());
 
 	AppendStatusQuery.bindValue(":contact_id", ContactsMapping->idByContact(contact, true));
 	AppendStatusQuery.bindValue(":status", statusTypeData.name());
@@ -410,7 +483,7 @@ void HistorySqlStorage::clearChatHistory(const Talkable &talkable, const QDate &
 	QMutexLocker locker(&DatabaseMutex);
 
 	QSqlQuery query(Database);
-	QString queryString = "DELETE FROM kadu_messages WHERE chat_id IN " + chatIdList(talkable.toChat());
+	QString queryString = "DELETE FROM kadu_messages WHERE chat_id IN " + chatIdList(m_talkableConverter->toChat(talkable));
 	if (!date.isNull())
 		queryString += " AND date_id IN (SELECT id FROM kadu_dates WHERE date = :date)";
 
@@ -428,7 +501,7 @@ void HistorySqlStorage::clearChatHistory(const Talkable &talkable, const QDate &
 
 	executeQuery(removeChatsQuery);
 
-	ChatsMapping->removeChat(talkable.toChat());
+	ChatsMapping->removeChat(m_talkableConverter->toChat(talkable));
 }
 
 void HistorySqlStorage::clearStatusHistory(const Talkable &talkable, const QDate &date)
@@ -456,7 +529,7 @@ void HistorySqlStorage::clearStatusHistory(const Talkable &talkable, const QDate
 
 void HistorySqlStorage::clearSmsHistory(const Talkable &talkable, const QDate &date)
 {
-	if (!talkable.isValidBuddy() || talkable.toBuddy().mobile().isEmpty())
+	if (!talkable.isValidBuddy() || m_talkableConverter->toBuddy(talkable).mobile().isEmpty())
 		return;
 
 	if (!waitForDatabase())
@@ -471,7 +544,7 @@ void HistorySqlStorage::clearSmsHistory(const Talkable &talkable, const QDate &d
 
 	query.prepare(queryString);
 
-	query.bindValue(":receipient", talkable.toBuddy().mobile());
+	query.bindValue(":receipient", m_talkableConverter->toBuddy(talkable).mobile());
 	if (!date.isNull())
 		query.bindValue(":date", date.toString(Qt::ISODate));
 
@@ -480,13 +553,13 @@ void HistorySqlStorage::clearSmsHistory(const Talkable &talkable, const QDate &d
 
 void HistorySqlStorage::deleteHistory(const Talkable &talkable)
 {
-	foreach (const Contact &contact, talkable.toBuddy().contacts())
+	foreach (const Contact &contact, m_talkableConverter->toBuddy(talkable).contacts())
 	{
-		Chat chat = ChatTypeContact::findChat(contact, ActionReturnNull);
+		Chat chat = ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionReturnNull);
 		clearChatHistory(chat, QDate());
 	}
 
-	clearStatusHistory(talkable.toBuddy(), QDate());
+	clearStatusHistory(m_talkableConverter->toBuddy(talkable), QDate());
 }
 
 QVector<Talkable> HistorySqlStorage::syncChats()
@@ -526,7 +599,7 @@ QVector<Talkable> HistorySqlStorage::syncStatusBuddies()
 		if (!contact)
 			continue;
 
-		Buddy buddy = BuddyManager::instance()->byContact(contact, ActionCreate);
+		Buddy buddy = m_buddyManager->byContact(contact, ActionCreate);
 		Q_ASSERT(buddy);
 
 		if (!result.contains(buddy))
@@ -555,7 +628,7 @@ QVector<Talkable> HistorySqlStorage::syncSmsRecipients()
 	QVector<Talkable> result;
 	while (query.next())
 	{
-		Buddy buddy = Buddy::create();
+		Buddy buddy = m_buddyStorage->create();
 		buddy.setDisplay(query.value(0).toString());
 		buddy.setMobile(query.value(0).toString());
 		result.append(buddy);
@@ -585,7 +658,7 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncChatDates(const HistoryQuery
 		"LEFT JOIN kadu_dates d ON (km.date_id=d.id) WHERE 1";
 
 	if (!talkable.isEmpty())
-		queryString += QString(" AND chat_id IN %1").arg(chatIdList(talkable.toChat()));
+		queryString += QString(" AND chat_id IN %1").arg(chatIdList(m_talkableConverter->toChat(talkable)));
 	if (!historyQuery.string().isEmpty())
 		queryString += " AND kmc.content LIKE :query";
 	if (historyQuery.fromDate().isValid())
@@ -623,12 +696,12 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncChatDates(const HistoryQuery
 		if (!date.isValid())
 			continue;
 
-		QString message = query.value(2).toString();
-		if (message.isEmpty())
+		auto message = HtmlString{query.value(2).toString()};
+		if (message.string().isEmpty())
 			continue;
 
 		Chat chat = ChatsMapping->chatById(query.value(3).toInt());
-		Chat buddyChat = BuddyChatManager::instance()->buddyChat(chat);
+		Chat buddyChat = m_buddyChatManager->buddyChat(chat);
 		chat = buddyChat ? buddyChat : chat;
 
 		if (chat != lastChat || date != lastDate)
@@ -646,9 +719,9 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncChatDates(const HistoryQuery
 			// TODO: this should be done in different place
 
 			QString title;
-			if (CurrentFormattedStringFactory)
+			if (m_formattedStringFactory)
 			{
-				auto formattedString = CurrentFormattedStringFactory.data()->fromHtml(message);
+				auto formattedString = m_formattedStringFactory.data()->fromHtml(message);
 
 				FormattedStringPlainTextVisitor plainTextVisitor;
 				formattedString->accept(&plainTextVisitor);
@@ -656,7 +729,7 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncChatDates(const HistoryQuery
 				title = plainTextVisitor.result().replace('\n', ' ').replace('\r', ' ');
 			}
 			else
-				title = message.replace('\n', ' ').replace('\r', ' ');
+				title = QString{message.string()}.replace('\n', ' ').replace('\r', ' ');
 
 			if (title.length() > DATE_TITLE_LENGTH)
 			{
@@ -739,15 +812,15 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncStatusDates(const HistoryQuer
 		Contact contact = ContactsMapping->contactById(query.value(2).toInt());
 		if (contact)
 		{
-			const Buddy &buddy = BuddyManager::instance()->byContact(contact, ActionCreate);
+			const Buddy &buddy = m_buddyManager->byContact(contact, ActionCreate);
 			result.setTalkable(Talkable(buddy));
 		}
 		else
 		{
-			const Buddy &buddy = Buddy::create();
+			const Buddy &buddy = m_buddyStorage->create();
 			buddy.setDisplay("?");
 
-			contact = Contact::create();
+			contact = m_contactStorage->create();
 			contact.setOwnerBuddy(buddy);
 
 			result.setTalkable(Talkable(contact));
@@ -780,7 +853,7 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncSmsRecipientDates(const Histo
 	QString queryString = "SELECT count(1), substr(send_time,0,11), receipient, content";
 	queryString += " FROM (SELECT send_time, receipient, content FROM kadu_sms WHERE ";
 
-	if (talkable.isValidBuddy() && !talkable.toBuddy().mobile().isEmpty())
+	if (talkable.isValidBuddy() && !m_talkableConverter->toBuddy(talkable).mobile().isEmpty())
 		queryString += "receipient = :receipient";
 	else
 		queryString += "1";
@@ -797,8 +870,8 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncSmsRecipientDates(const Histo
 
 	query.prepare(queryString);
 
-	if (talkable.isValidBuddy() && !talkable.toBuddy().mobile().isEmpty())
-		query.bindValue(":receipient", talkable.toBuddy().mobile());
+	if (talkable.isValidBuddy() && !m_talkableConverter->toBuddy(talkable).mobile().isEmpty())
+		query.bindValue(":receipient", m_talkableConverter->toBuddy(talkable).mobile());
 
 	if (!historyQuery.string().isEmpty())
 		query.bindValue(":query", QString("%%%1%%").arg(historyQuery.string()));
@@ -818,7 +891,7 @@ QVector<HistoryQueryResult> HistorySqlStorage::syncSmsRecipientDates(const Histo
 
 		HistoryQueryResult result;
 
-		Buddy buddy = Buddy::create();
+		Buddy buddy = m_buddyStorage->create();
 		buddy.setDisplay(query.value(2).toString());
 		buddy.setMobile(query.value(2).toString());
 
@@ -852,7 +925,7 @@ SortedMessages HistorySqlStorage::syncMessages(const HistoryQuery &historyQuery)
 			"LEFT JOIN kadu_message_contents kmc ON (kadu_messages.content_id=kmc.id) WHERE 1";
 
 	if (!talkable.isEmpty())
-		queryString += QString(" AND chat_id IN %1").arg(chatIdList(talkable.toChat()));
+		queryString += QString(" AND chat_id IN %1").arg(chatIdList(m_talkableConverter->toChat(talkable)));
 	if (historyQuery.fromDate().isValid())
 		queryString += " AND date >= :fromDate";
 	if (historyQuery.toDate().isValid())
@@ -923,7 +996,7 @@ SortedMessages HistorySqlStorage::syncStatuses(const HistoryQuery &historyQuery)
 		query.bindValue(":toDate", historyQuery.toDate().toString("yyyyMMdd"));
 
 	executeQuery(query);
-	statuses = statusesFromQuery(talkable.toContact(), query);
+	statuses = statusesFromQuery(m_talkableConverter->toContact(talkable), query);
 
 	return statuses;
 }
@@ -945,7 +1018,7 @@ SortedMessages HistorySqlStorage::syncSmses(const HistoryQuery &historyQuery)
 	QSqlQuery query(Database);
 	QString queryString = "SELECT content, send_time FROM kadu_sms WHERE 1";
 
-	if (talkable.isValidBuddy() && !talkable.toBuddy().mobile().isEmpty())
+	if (talkable.isValidBuddy() && !m_talkableConverter->toBuddy(talkable).mobile().isEmpty())
 		queryString += " AND receipient = :receipient";
 	if (historyQuery.fromDate().isValid())
 		queryString += " AND replace(substr(send_time,0,11), '-', '') >= :fromDate";
@@ -956,8 +1029,8 @@ SortedMessages HistorySqlStorage::syncSmses(const HistoryQuery &historyQuery)
 
 	query.prepare(queryString);
 
-	if (talkable.isValidBuddy() && !talkable.toBuddy().mobile().isEmpty())
-		query.bindValue(":receipient", talkable.toBuddy().mobile());
+	if (talkable.isValidBuddy() && !m_talkableConverter->toBuddy(talkable).mobile().isEmpty())
+		query.bindValue(":receipient", m_talkableConverter->toBuddy(talkable).mobile());
 
 	if (historyQuery.fromDate().isValid())
 		query.bindValue(":fromDate", historyQuery.fromDate().toString("yyyyMMdd"));
@@ -996,24 +1069,9 @@ void HistorySqlStorage::executeQuery(QSqlQuery &query)
 */
 }
 
-QString HistorySqlStorage::stripAllScriptTags(const QString &string)
-{
-	QString beforeReplace = string;
-	QString afterReplace = beforeReplace;
-
-	afterReplace.replace("<script", "", Qt::CaseInsensitive);
-	while (beforeReplace != afterReplace)
-	{
-		beforeReplace = afterReplace;
-		afterReplace.replace("<script", "", Qt::CaseInsensitive);
-	}
-
-	return afterReplace;
-}
-
 SortedMessages HistorySqlStorage::messagesFromQuery(QSqlQuery &query)
 {
-	if (!CurrentFormattedStringFactory)
+	if (!m_formattedStringFactory)
 		return {};
 
 	auto messages = std::vector<Message>{};
@@ -1027,17 +1085,17 @@ SortedMessages HistorySqlStorage::messagesFromQuery(QSqlQuery &query)
 		Contact sender = ContactsMapping->contactById(query.value(1).toInt());
 		if (!sender)
 		{
-			Contact sender = Contact::create();
-			Buddy senderBuddy = Buddy::create();
+			Contact sender = m_contactStorage->create();
+			Buddy senderBuddy = m_buddyStorage->create();
 			senderBuddy.setDisplay("?");
 			sender.setOwnerBuddy(senderBuddy);
 		}
 
-		auto message = Message::create();
+		auto message = m_messageStorage->create();
 		message.setMessageChat(ChatsMapping->chatById(query.value(0).toInt()));
 		message.setType(type);
 		message.setMessageSender(sender);
-		message.setContent(CurrentFormattedStringFactory.data()->fromHtml(stripAllScriptTags(query.value(2).toString())));
+		message.setContent(normalizeHtml(HtmlString{query.value(2).toString()}));
 		message.setSendDate(query.value(3).toDateTime());
 		message.setReceiveDate(query.value(4).toDateTime());
 		if (outgoing)
@@ -1054,23 +1112,23 @@ SortedMessages HistorySqlStorage::messagesFromQuery(QSqlQuery &query)
 
 SortedMessages HistorySqlStorage::statusesFromQuery(const Contact &contact, QSqlQuery &query)
 {
-	if (!CurrentFormattedStringFactory)
+	if (!m_formattedStringFactory)
 		return {};
 
 	auto statuses = std::vector<Message>{};
 	while (query.next())
 	{
-		StatusType type = StatusTypeManager::instance()->fromName(query.value(1).toString());
-		const StatusTypeData &typeData = StatusTypeManager::instance()->statusTypeData(type);
+		StatusType type = m_statusTypeManager->fromName(query.value(1).toString());
+		const StatusTypeData &typeData = m_statusTypeManager->statusTypeData(type);
 
-		auto message = Message::create();
+		auto message = m_messageStorage->create();
 
-		const QString description = query.value(2).toString();
-		const QString htmlContent = description.isEmpty()
-				? Qt::escape(typeData.name())
-				: Qt::escape(QString("%1 with description: %2").arg(typeData.name()).arg(description));
+		auto description = query.value(2).toString();
+		auto htmlContent = description.isEmpty()
+				? normalizeHtml(plainToHtml(typeData.name()))
+				: normalizeHtml(plainToHtml(QString("%1 with description: %2").arg(typeData.name()).arg(description)));
 
-		message.setContent(CurrentFormattedStringFactory.data()->fromHtml(htmlContent));
+		message.setContent(htmlContent);
 		message.setType(MessageTypeSystem);
 		message.setMessageSender(contact);
 		message.setReceiveDate(query.value(3).toDateTime());
@@ -1084,17 +1142,17 @@ SortedMessages HistorySqlStorage::statusesFromQuery(const Contact &contact, QSql
 
 SortedMessages HistorySqlStorage::smsFromQuery(QSqlQuery &query)
 {
-	if (!CurrentFormattedStringFactory)
+	if (!m_formattedStringFactory)
 		return {};
 
 	auto messages = std::vector<Message>{};
 	while (query.next())
 	{
-		auto message = Message::create();
+		auto message = m_messageStorage->create();
 		message.setType(MessageTypeSystem);
 		message.setReceiveDate(query.value(1).toDateTime());
 		message.setSendDate(query.value(1).toDateTime());
-		message.setContent(CurrentFormattedStringFactory.data()->fromPlainText(Qt::escape(query.value(0).toString())));
+		message.setContent(normalizeHtml(plainToHtml(query.value(0).toString())));
 
 		messages.push_back(message);
 	}
@@ -1104,7 +1162,7 @@ SortedMessages HistorySqlStorage::smsFromQuery(QSqlQuery &query)
 
 HistoryMessagesStorage * HistorySqlStorage::chatStorage()
 {
-	return ChatStorage;
+	return m_historyChatStorage;
 }
 
 HistoryMessagesStorage * HistorySqlStorage::smsStorage()
