@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,6 +23,7 @@
 #include "accounts/account.h"
 #include "chat/chat-details-room.h"
 #include "chat/chat-manager.h"
+#include "chat/chat-storage.h"
 #include "chat/chat.h"
 #include "chat/type/chat-type-contact-set.h"
 #include "chat/type/chat-type-contact.h"
@@ -36,17 +37,31 @@
 
 SqlChatsMapping::SqlChatsMapping(const QSqlDatabase &database, SqlAccountsMapping *accountsMapping, SqlContactsMapping *contactsMapping, QObject *parent) :
 		QObject(parent), Database(database), Mutex(QMutex::Recursive), AccountsMapping(accountsMapping), ContactsMapping(contactsMapping)
+{
+}
+
+SqlChatsMapping::~SqlChatsMapping()
+{
+}
+
+void SqlChatsMapping::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void SqlChatsMapping::setChatStorage(ChatStorage *chatStorage)
+{
+	m_chatStorage = chatStorage;
+}
+
+void SqlChatsMapping::init()
 {
 	Q_ASSERT(AccountsMapping);
 	Q_ASSERT(ContactsMapping);
 
 	loadMappingsFromDatabase();
 
-	connect(ChatManager::instance(), SIGNAL(chatUpdated(Chat)), this, SLOT(chatUpdated(Chat)));
-}
-
-SqlChatsMapping::~SqlChatsMapping()
-{
+	connect(m_chatManager, SIGNAL(chatUpdated(Chat)), this, SLOT(chatUpdated(Chat)));
 }
 
 void SqlChatsMapping::chatUpdated(const Chat &chat)
@@ -180,18 +195,18 @@ QString SqlChatsMapping::chatToString(const Chat &chat)
 Chat SqlChatsMapping::stringToChat(const Account &account, const QString &string)
 {
 	if (!account)
-		return Chat::create();
+		return m_chatStorage->create();
 
 	QStringList items = string.split(";", QString::SkipEmptyParts);
 	int len = items.length();
 
 	if (len < 2)
-		return Chat::create();
+		return m_chatStorage->create();
 
 	QString chatType = items.at(0);
 
 	if ("Room" == chatType)
-		return ChatTypeRoom::findChat(account, items.at(1), ActionCreateAndAdd);
+		return ChatTypeRoom::findChat(m_chatManager, m_chatStorage, account, items.at(1), ActionCreateAndAdd);
 
 	if ("Contact" == chatType)
 	{
@@ -199,7 +214,7 @@ Chat SqlChatsMapping::stringToChat(const Account &account, const QString &string
 		if (!contact)
 			return Chat::null;
 
-		return ChatTypeContact::findChat(contact, ActionCreateAndAdd);
+		return ChatTypeContact::findChat(m_chatManager, m_chatStorage, contact, ActionCreateAndAdd);
 	}
 
 	if ("ContactSet" == chatType)
@@ -214,10 +229,10 @@ Chat SqlChatsMapping::stringToChat(const Account &account, const QString &string
 			contacts.insert(contact);
 		}
 
-		return ChatTypeContactSet::findChat(contacts, ActionCreateAndAdd);
+		return ChatTypeContactSet::findChat(m_chatManager, m_chatStorage, contacts, ActionCreateAndAdd);
 	}
 
-	return Chat::create();
+	return m_chatStorage->create();
 }
 
 #include "moc_sql-chats-mapping.cpp"
