@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,16 +17,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SQL_CHATS_MAPPING_H
-#define SQL_CHATS_MAPPING_H
+#pragma once
 
 #include <QtCore/QMap>
 #include <QtCore/QMutex>
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtSql/QSqlDatabase>
+#include <injeqt/injeqt.h>
 
 #include "chat/chat.h"
 
+class ChatManager;
+class ChatStorage;
 class SqlAccountsMapping;
 class SqlContactsMapping;
 
@@ -60,6 +63,9 @@ class SqlChatsMapping : public QObject
 {
 	Q_OBJECT
 
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+
 	const QSqlDatabase &Database;
 	mutable QMutex Mutex;
 	SqlAccountsMapping *AccountsMapping;
@@ -87,6 +93,10 @@ class SqlChatsMapping : public QObject
 	void loadMappingsFromDatabase();
 
 private slots:
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_INIT void init();
+
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Update SQL mapping of changed chat.
@@ -108,7 +118,7 @@ public:
 	 * Database provided in this constructor is not checked for existence or validity of kadu_chats table. It is caller responsibility
 	 * to provide proper database.
 	 */
-	explicit SqlChatsMapping(const QSqlDatabase &database, SqlAccountsMapping *accountsMapping, SqlContactsMapping *contactsMapping, QObject *parent = 0);
+	explicit SqlChatsMapping(const QSqlDatabase &database, SqlAccountsMapping *accountsMapping, SqlContactsMapping *contactsMapping, QObject *parent = nullptr);
 	virtual ~SqlChatsMapping();
 
 	/**
@@ -174,5 +184,3 @@ public:
 /**
  * @}
  */
-
-#endif // SQL_CHATS_MAPPING_H
