@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,6 +23,7 @@
 #include "accounts/account.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact.h"
+#include "core/core.h"
 
 #include "storage/sql-accounts-mapping.h"
 
@@ -32,16 +33,24 @@ SqlContactsMapping::SqlContactsMapping(const QSqlDatabase &database, SqlAccounts
 		QObject(parent), Database(database), Mutex(QMutex::Recursive), AccountsMapping(accountsMapping)
 {
 	Q_ASSERT(AccountsMapping);
-
-	loadMappingsFromDatabase();
-
-	connect(ContactManager::instance(), SIGNAL(contactUpdated(Contact)), this, SLOT(contactUpdated(Contact)));
 }
 
 SqlContactsMapping::~SqlContactsMapping()
 {
 }
 
+void SqlContactsMapping::setContactManager(ContactManager *contactManager)
+{
+	m_contactManager = contactManager;
+}
+
+void SqlContactsMapping::init()
+{
+	loadMappingsFromDatabase();
+
+	connect(m_contactManager, SIGNAL(contactUpdated(Contact)), this, SLOT(contactUpdated(Contact)));
+}
+
 void SqlContactsMapping::contactUpdated(const Contact &contact)
 {
 	QMutexLocker locker(&Mutex);
@@ -88,7 +97,7 @@ void SqlContactsMapping::loadMappingsFromDatabase()
 
 		// This contact needs to be known to the manager even if it's not on our roster,
 		// in case we want to add him later or even talk to her without adding.
-		Contact contact = ContactManager::instance()->byId(account, contactId, ActionCreateAndAdd);
+		Contact contact = m_contactManager->byId(account, contactId, ActionCreateAndAdd);
 		if (contact)
 			addMapping(id, contact);
 	}
