@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,16 +17,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SQL_CONTACTS_MAPPING_H
-#define SQL_CONTACTS_MAPPING_H
+#pragma once
+
+#include "contacts/contact.h"
 
 #include <QtCore/QMap>
 #include <QtCore/QMutex>
 #include <QtCore/QObject>
+#include <QtCore/QPointer>
 #include <QtSql/QSqlDatabase>
+#include <injeqt/injeqt.h>
 
-#include "contacts/contact.h"
-
+class ContactManager;
 class SqlAccountsMapping;
 
 /**
@@ -60,6 +62,8 @@ class SqlContactsMapping : public QObject
 {
 	Q_OBJECT
 
+	QPointer<ContactManager> m_contactManager;
+
 	const QSqlDatabase &Database;
 	mutable QMutex Mutex;
 	SqlAccountsMapping *AccountsMapping;
@@ -86,6 +90,9 @@ class SqlContactsMapping : public QObject
 	void loadMappingsFromDatabase();
 
 private slots:
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_INIT void init();
+
 	/**
 	 * @author Rafał 'Vogel' Malinowski
 	 * @short Update kadu_contacts entry to new contact's data.
@@ -107,7 +114,7 @@ public:
 	 * Database provided in this constructor is not checked for existence or validity of kadu_contacts table. It is caller responsibility
 	 * to provide proper database.
 	 */
-	explicit SqlContactsMapping(const QSqlDatabase &database, SqlAccountsMapping *accountsMapping, QObject *parent = 0);
+	explicit SqlContactsMapping(const QSqlDatabase &database, SqlAccountsMapping *accountsMapping, QObject *parent = nullptr);
 	virtual ~SqlContactsMapping();
 
 	/**
@@ -142,5 +149,3 @@ public:
 /**
  * @}
  */
-
-#endif // SQL_CONTACTS_MAPPING_H
