@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
  *
@@ -25,8 +25,10 @@
 #include <QtCore/QThread>
 #include <QtSql/QSqlError>
 
-#include "configuration/configuration-file.h"
-#include "misc/kadu-paths.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "misc/paths-provider.h"
+#include "plugin/plugin-injected-factory.h"
 
 #include "storage/history-sql-storage.h"
 #include "storage/sql-import.h"
@@ -47,6 +49,21 @@ SqlInitializer::~SqlInitializer()
 {
 }
 
+void SqlInitializer::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void SqlInitializer::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void SqlInitializer::setPathsProvider(PathsProvider *pathsProvider)
+{
+	m_pathsProvider = pathsProvider;
+}
+
 void SqlInitializer::initialize()
 {
 	initDatabase();
@@ -61,28 +78,28 @@ void SqlInitializer::initialize()
 
 bool SqlInitializer::oldHistoryFileExists()
 {
-	QFileInfo scheme0FileInfo(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_0));
-	QFileInfo scheme1FileInfo(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_1));
+	QFileInfo scheme0FileInfo(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_0));
+	QFileInfo scheme1FileInfo(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_1));
 	return scheme0FileInfo.exists() || scheme1FileInfo.exists();
 }
 
 bool SqlInitializer::currentHistoryFileExists()
 {
-	QFileInfo schemeCurrentFileInfo(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_CURRENT));
+	QFileInfo schemeCurrentFileInfo(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_CURRENT));
 	return schemeCurrentFileInfo.exists();
 }
 
 bool SqlInitializer::copyHistoryFile()
 {
-	QFileInfo schemeCurrentFileInfo(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_CURRENT));
+	QFileInfo schemeCurrentFileInfo(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_CURRENT));
 	if (schemeCurrentFileInfo.exists())
 		return true;
 
-	QFileInfo scheme1FileInfo(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_1));
+	QFileInfo scheme1FileInfo(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_1));
 	if (scheme1FileInfo.exists())
 		return QFile::copy(scheme1FileInfo.absoluteFilePath(), schemeCurrentFileInfo.absoluteFilePath());
 
-	QFileInfo scheme0FileInfo(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_0));
+	QFileInfo scheme0FileInfo(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_0));
 	if (scheme0FileInfo.exists())
 		return QFile::copy(scheme0FileInfo.absoluteFilePath(), schemeCurrentFileInfo.absoluteFilePath());
 
@@ -103,7 +120,7 @@ void SqlInitializer::initDatabase()
 
 	if (!currentFileExists && oldHistoryFileExists())
 	{
-		emit progressMessage("dialog-information", tr("Copying history file to new location: %1 ...").arg(KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_CURRENT)));
+		emit progressMessage("dialog-information", tr("Copying history file to new location: %1 ...").arg(m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_CURRENT)));
 		if (!copyHistoryFile())
 		{
 			emit progressFinished(false, "dialog-error", tr("Unable to copy history file to new location. Check if disk is full."));
@@ -111,7 +128,7 @@ void SqlInitializer::initDatabase()
 		}
 	}
 
-	QString historyFilePath = KaduPaths::instance()->profilePath() + QLatin1String(HISTORY_FILE_CURRENT);
+	QString historyFilePath = m_pathsProvider->profilePath() + QStringLiteral(HISTORY_FILE_CURRENT);
 
 	Database = QSqlDatabase::addDatabase("QSQLITE", "kadu-history");
 	Database.setDatabaseName(historyFilePath);
@@ -128,8 +145,8 @@ void SqlInitializer::initDatabase()
 
 		emit progressMessage("dialog-warning", tr("History file is corrupted, performing recovery..."));
 
-		SqlRestore sqlRestore;
-		SqlRestore::RestoreError error = sqlRestore.performRestore(historyFilePath);
+		auto sqlRestore = m_pluginInjectedFactory->makeUnique<SqlRestore>();
+		SqlRestore::RestoreError error = sqlRestore->performRestore(historyFilePath);
 		if (SqlRestore::ErrorNoError == error)
 			emit progressMessage("dialog-information", tr("Recovery completed."));
 		else
@@ -147,15 +164,15 @@ void SqlInitializer::initDatabase()
 		if (anyHistoryFileExists)
 			emit progressMessage("dialog-warning", tr("History file is outdated, performing import..."));
 
-		SqlImport sqlImport;
-		sqlImport.performImport(Database);
+		auto sqlImport = m_pluginInjectedFactory->makeUnique<SqlImport>();
+		sqlImport->performImport(Database);
 
 		if (anyHistoryFileExists)
 			emit progressFinished(true, "dialog-information", tr("Import completed."));
 	}
 	else
 	{
-		config_file.writeEntry("History", "Schema", SqlImport::databaseSchemaVersion(Database));
+		m_configuration->deprecatedApi()->writeEntry("History", "Schema", SqlImport::databaseSchemaVersion(Database));
 		emit progressFinished(true, "dialog-information", tr("Copying completed."));
 	}
 }
