@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
 <context>
     <name>HistorySqlStorage</name>
     <message>
@@ -15,6 +15,14 @@
         <translation>Otevření databáze se nezdařilo. Hlášení o chybě:
 %1</translation>
     </message>
+    <message>
+        <source>Kadu</source>
+        <translation>Kadu</translation>
+    </message>
+    <message>
+        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
+        <translation>Zdá se, že vaše knihovna Qt neposkytuje podporu pro vybranou databázi. Nainstalujte, prosím, Qt s přídavným modulem %1.</translation>
+    </message>
 </context>
 <context>
     <name>SqlInitializer</name>
