@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
 <context>
     <name>HistorySqlStorage</name>
     <message>
@@ -15,6 +15,14 @@
         <translation>L&apos;ouverture de la base de données a échouée. Message d&apos;erreur :
 %1</translation>
     </message>
+    <message>
+        <source>Kadu</source>
+        <translation>Kadu</translation>
+    </message>
+    <message>
+        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
+        <translation>Il semble que votre bibliothèque Qt ne prenne pas en charge la base de données sélectionnée. Veuillez installer Qt avec l&apos;extension %1.</translation>
+    </message>
 </context>
 <context>
     <name>SqlInitializer</name>
