@@ -1,88 +1,97 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>HistorySqlStorage</name>
     <message>
         <source>Preparing history database...</source>
-        <translation type="unfinished"/>
+        <translation>Preparando banco de dados de histórico</translation>
     </message>
     <message>
         <source>History</source>
-        <translation type="unfinished"/>
+        <translation>Histórico</translation>
     </message>
     <message>
         <source>Opening database failed. Error message:
 %1</source>
-        <translation type="unfinished"/>
+        <translation>Falha ao abrir banco de dados. Mensagem de erro:
+%1</translation>
+    </message>
+    <message>
+        <source>Kadu</source>
+        <translation>Kadu</translation>
+    </message>
+    <message>
+        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
+        <translation>Aparentemente a sua biblioteca Qt não suporta o banco de dados selecionado. Por favor instale Qt com o plugin %1.</translation>
     </message>
 </context>
 <context>
     <name>SqlInitializer</name>
     <message>
         <source>Copying history file to new location: %1 ...</source>
-        <translation type="unfinished"/>
+        <translation>Copiando arquivo de histórico para nova localização: %1 ...</translation>
     </message>
     <message>
         <source>Unable to copy history file to new location. Check if disk is full.</source>
-        <translation type="unfinished"/>
+        <translation>Não foi possível copiar o arquivo de histórico para a nova localização. Verifique se há espaço em disco.</translation>
     </message>
     <message>
         <source>Unable to open database: %1</source>
-        <translation type="unfinished"/>
+        <translation>Não foi possível abrir banco de dados: %1</translation>
     </message>
     <message>
         <source>History file is corrupted, performing recovery...</source>
-        <translation type="unfinished"/>
+        <translation>Arquivo de histórico está corrompido, executando recuperação...</translation>
     </message>
     <message>
         <source>Recovery completed.</source>
-        <translation type="unfinished"/>
+        <translation>Recuperação concluída.</translation>
     </message>
     <message>
         <source>Recovery failed: %s</source>
-        <translation type="unfinished"/>
+        <translation>Recuperação falhou: %s</translation>
     </message>
     <message>
         <source>History file is outdated, performing import...</source>
-        <translation type="unfinished"/>
+        <translation>Arquivo de histórico está desatualizado, executando importação...</translation>
     </message>
     <message>
         <source>Import completed.</source>
-        <translation type="unfinished"/>
+        <translation>Importação concluída.</translation>
     </message>
     <message>
         <source>Copying completed.</source>
-        <translation type="unfinished"/>
+        <translation>Cópia concluída</translation>
     </message>
 </context>
 <context>
     <name>SqlRestore</name>
     <message>
         <source>No error.</source>
-        <translation type="unfinished"/>
+        <translation>Sem erro.</translation>
     </message>
     <message>
         <source>sqlite3 executable not found.</source>
-        <translation type="unfinished"/>
+        <translation>Executável do sqlite3 não encontrado.</translation>
     </message>
     <message>
         <source>Invalid invocation of recovery script.</source>
-        <translation type="unfinished"/>
+        <translation>Chamada de script de recuperação inválida.</translation>
     </message>
     <message>
         <source>Unable to read corrupted database.</source>
-        <translation type="unfinished"/>
+        <translation>Não foi possível ler o banco de dados corrompido.</translation>
     </message>
     <message>
         <source>Unable to create backup file. Disc may be full.</source>
-        <translation type="unfinished"/>
+        <translation>Não foi possível criar arquivo de backup. Disco pode estar cheio.</translation>
     </message>
     <message>
         <source>Recovery script not found or not executable.</source>
-        <translation type="unfinished"/>
+        <translation>Script de recuperação não encontrado ou não executável.</translation>
     </message>
     <message>
         <source>Unknown error during database recovery.</source>
-        <translation type="unfinished"/>
+        <translation>Erro desconhecido durante a recuperação do banco de dados.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
