@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -22,9 +23,9 @@
 #define TAB_BAR_H
 
 #include <QtCore/QPoint>
-#include <QtGui/QMenu>
 #include <QtGui/QMouseEvent>
-#include <QtGui/QTabBar>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QTabBar>
 
 
 class TabBar: public QTabBar
@@ -54,7 +55,7 @@ protected:
 	virtual void mouseDoubleClickEvent(QMouseEvent *e);
 
 public:
-	explicit TabBar(QWidget *parent = 0);
+	explicit TabBar(QWidget *parent = nullptr);
 
 signals:
 	void contextMenu(int id, const QPoint &pos);
