@@ -1,15 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 koudy (koudy@koudy-Aspire-3820.(none))
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2012 Vladimir Kloucek (kelmhell@gmail.com)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2012 Zamazal Jiri (zamazal.jiri@gmail.com)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,26 +22,28 @@
 #include <QtCore/QPoint>
 #include <QtCore/QVariant>
 #include <QtGui/QDrag>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QMenu>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QMenu>
 
 #include "chat/chat.h"
 #include "chat/model/chat-data-extractor.h"
-#include "chat/recent-chat-manager.h"
-#include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
+#include "core/application.h"
 #include "gui/hot-key.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/chat-widget/chat-widget.h"
 #include "gui/widgets/filtered-tree-view.h"
 #include "gui/widgets/recent-chats-menu.h"
 #include "gui/windows/message-dialog.h"
+#include "gui/windows/open-chat-with/open-chat-with-service.h"
 #include "gui/windows/open-chat-with/open-chat-with.h"
+#include "icons/icons-manager.h"
 #include "icons/kadu-icon.h"
 #include "message/unread-message-repository.h"
 #include "misc/misc.h"
+#include "plugin/plugin-injected-factory.h"
 #include "activate.h"
-#include "kadu-application.h"
 
 #include "tab-bar.h"
 #include "tabs.h"
@@ -56,6 +51,44 @@
 #include "tab-widget.h"
 
 TabWidget::TabWidget(TabsManager *manager) : Manager(manager)
+{
+}
+
+TabWidget::~TabWidget()
+{
+}
+
+void TabWidget::setApplication(Application *application)
+{
+	m_application = application;
+}
+
+void TabWidget::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void TabWidget::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void TabWidget::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void TabWidget::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void TabWidget::setOpenChatWithService(OpenChatWithService *openChatWithService)
+{
+	m_openChatWithService = openChatWithService;
+}
+
+void TabWidget::init()
 {
 	setWindowRole("kadu-tabs");
 
@@ -67,12 +100,6 @@ TabWidget::TabWidget(TabsManager *manager) : Manager(manager)
 
 	setDocumentMode(true);
 
-#ifdef Q_OS_MAC
-	/* Dorr: on Mac make the tabs look like the ones from terminal or safari */
-	setAttribute(Qt::WA_MacBrushedMetal);
-	setStyleSheet("QToolButton { background: transparent; }");
-#endif
-
 	connect(tabbar, SIGNAL(contextMenu(int, const QPoint &)),
 			SLOT(onContextMenu(int, const QPoint &)));
 	connect(tabbar, SIGNAL(tabCloseRequested(int)),
@@ -92,19 +119,19 @@ TabWidget::TabWidget(TabsManager *manager) : Manager(manager)
 
 	//button for new chat from last conversations
 	OpenRecentChatButton = new QToolButton(OpenChatButtonsWidget);
-	OpenRecentChatButton->setIcon(KaduIcon("internet-group-chat").icon());
+	OpenRecentChatButton->setIcon(m_iconsManager->iconByPath(KaduIcon("internet-group-chat")));
 	OpenRecentChatButton->setToolTip(tr("Recent Chats"));
 	OpenRecentChatButton->setAutoRaise(true);
 	connect(OpenRecentChatButton, SIGNAL(clicked()), SLOT(openRecentChatsMenu()));
 
 	//menu for recent chats
-	RecentChatsMenuWidget = new RecentChatsMenu(OpenRecentChatButton);
+	RecentChatsMenuWidget = m_pluginInjectedFactory->makeInjected<RecentChatsMenu>(OpenRecentChatButton);
 	connect(RecentChatsMenuWidget, SIGNAL(triggered(QAction *)), this, SLOT(openRecentChat(QAction *)));
 	connect(RecentChatsMenuWidget, SIGNAL(chatsListAvailable(bool)), OpenRecentChatButton, SLOT(setEnabled(bool)));
 
 	//button for opening chat
 	QToolButton *openChatButton = new QToolButton(OpenChatButtonsWidget);
-	openChatButton->setIcon(KaduIcon("mail-message-new").icon());
+	openChatButton->setIcon(m_iconsManager->iconByPath(KaduIcon("mail-message-new")));
 	openChatButton->setToolTip(tr("Open Chat with..."));
 	openChatButton->setAutoRaise(true);
 	connect(openChatButton, SIGNAL(clicked()), SLOT(newChat()));
@@ -124,7 +151,7 @@ TabWidget::TabWidget(TabsManager *manager) : Manager(manager)
 	TabsMenu = new QMenu(this);
 	connect(TabsMenu, SIGNAL(triggered(QAction *)), this, SLOT(tabsMenuSelected(QAction *)));
 	TabsListButton = new QToolButton(RightCornerWidget);
-	TabsListButton->setIcon(KaduIcon("internet-group-chat").icon());
+	TabsListButton->setIcon(m_iconsManager->iconByPath(KaduIcon("internet-group-chat")));
 	TabsListButton->setToolTip(tr("Tabs"));
 	TabsListButton->setAutoRaise(true);
 	TabsListButton->setVisible(false);
@@ -135,7 +162,7 @@ TabWidget::TabWidget(TabsManager *manager) : Manager(manager)
 
 	//przycisk zamkniecia aktywnej karty znajdujacy sie w prawym gornym rogu
 	CloseChatButton = new QToolButton(this);
-	CloseChatButton->setIcon(KaduIcon("kadu_icons/tab-remove").icon());
+	CloseChatButton->setIcon(m_iconsManager->iconByPath(KaduIcon("kadu_icons/tab-remove")));
 	CloseChatButton->setToolTip(tr("Close Tab"));
 	CloseChatButton->setAutoRaise(true);
 	CloseChatButton->setVisible(false);
@@ -148,10 +175,6 @@ TabWidget::TabWidget(TabsManager *manager) : Manager(manager)
 	configurationUpdated();
 }
 
-TabWidget::~TabWidget()
-{
-}
-
 bool TabWidget::isTabVisible(int index)
 {
 	QRect visibleTabRect = tabBar()->rect().intersected(tabBar()->tabRect(index));
@@ -198,26 +221,35 @@ void TabWidget::tryActivateChatWidget(ChatWidget *chatWidget)
 	if (index < 0)
 		return;
 
-	_activateWindow(this);
+	_activateWindow(m_configuration, this);
 
 	setCurrentIndex(index);
 	chatWidget->edit()->setFocus();
 }
 
-void TabWidget::closeTab(QWidget *tabWidget)
+void TabWidget::tryMinimizeChatWidget(ChatWidget *chatWidget)
+{
+	int index = indexOf(chatWidget);
+	if (index < 0)
+		return;
+
+	if (count() == 1)
+		window()->showMinimized();
+}
+
+void TabWidget::closeTab(ChatWidget *chatWidget)
 {
-	ChatWidget *chatWidget = qobject_cast<ChatWidget *>(tabWidget);
 	if (!chatWidget)
 		return;
 
-	if (config_file.readBoolEntry("Chat", "ChatCloseTimer"))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Chat", "ChatCloseTimer"))
 	{
-		unsigned int period = config_file.readUnsignedNumEntry("Chat",
+		unsigned int period = m_configuration->deprecatedApi()->readUnsignedNumEntry("Chat",
 			"ChatCloseTimerPeriod", 2);
 
 		if (QDateTime::currentDateTime() < chatWidget->lastReceivedMessageTime().addSecs(period))
 		{
-			MessageDialog *dialog = MessageDialog::create(KaduIcon("dialog-question"), tr("Kadu"), tr("New message received, close window anyway?"));
+			MessageDialog *dialog = MessageDialog::create(m_iconsManager->iconByPath(KaduIcon("dialog-question")), tr("Kadu"), tr("New message received, close window anyway?"));
 			dialog->addButton(QMessageBox::Yes, tr("Close window"));
 			dialog->addButton(QMessageBox::No, tr("Cancel"));
 
@@ -226,7 +258,7 @@ void TabWidget::closeTab(QWidget *tabWidget)
 		}
 	}
 
-	chatWidget->requestClose();
+	delete chatWidget;
 }
 
 bool TabWidget::isChatWidgetActive(const ChatWidget *chatWidget)
@@ -237,7 +269,7 @@ bool TabWidget::isChatWidgetActive(const ChatWidget *chatWidget)
 void TabWidget::closeEvent(QCloseEvent *e)
 {
 	// do not block window closing when session is about to close
-	if (Core::instance()->application()->isSavingSession())
+	if (m_application->isSavingSession())
 	{
 		QTabWidget::closeEvent(e);
 		return;
@@ -245,10 +277,10 @@ void TabWidget::closeEvent(QCloseEvent *e)
 
 	//w zaleznosci od opcji w konfiguracji zamykamy wszystkie karty, lub tylko aktywna
 	if (config_oldStyleClosing)
-		closeTab(currentWidget());
+		closeTab(static_cast<ChatWidget *>(currentWidget()));
 	else
 		for (int i = count() - 1; i >= 0; i--)
-			closeTab(widget(i));
+			closeTab(static_cast<ChatWidget *>(widget(i)));
 
 	if (count() > 0)
 		e->ignore();
@@ -265,40 +297,40 @@ void TabWidget::chatKeyPressed(QKeyEvent *e, CustomInput *k, bool &handled)
 
 	handled = true;
 	// obsluga skrotow klawiszowych
-	if (HotKey::shortCut(e, "ShortCuts", "MoveTabLeft"))
+	if (HotKey::shortCut(m_configuration, e, "ShortCuts", "MoveTabLeft"))
 		moveTabLeft();
-	else if (HotKey::shortCut(e, "ShortCuts", "MoveTabRight"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "MoveTabRight"))
 		moveTabRight();
-	else if (HotKey::shortCut(e, "ShortCuts", "SwitchTabLeft"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "SwitchTabLeft"))
 		switchTabLeft();
-	else if (HotKey::shortCut(e, "ShortCuts", "SwitchTabRight"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "SwitchTabRight"))
 		switchTabRight();
-	else if (HotKey::shortCut(e, "ShortCuts", "ReopenClosedTab"))
+	else if (HotKey::shortCut(m_configuration, e, "ShortCuts", "ReopenClosedTab"))
 		Manager->reopenClosedChat();
-	#if defined(Q_OS_WIN32) || defined(Q_OS_MAC)
+	#if defined(Q_OS_WIN)
 		#define TAB_SWITCH_MODIFIER "Ctrl"
 	#else
 		#define TAB_SWITCH_MODIFIER "Alt"
 	#endif
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+0")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+0")
 		setCurrentIndex(count() - 1);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+1")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+1")
 		setCurrentIndex(0);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+2")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+2")
 		setCurrentIndex(1);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+3")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+3")
 		setCurrentIndex(2);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+4")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+4")
 		setCurrentIndex(3);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+5")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+5")
 		setCurrentIndex(4);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+6")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+6")
 		setCurrentIndex(5);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+7")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+7")
 		setCurrentIndex(6);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+8")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+8")
 		setCurrentIndex(7);
-	else if (HotKey::keyEventToString(e) == TAB_SWITCH_MODIFIER "+9")
+	else if (HotKey::keyEventToString(e, QKeySequence::PortableText) == TAB_SWITCH_MODIFIER "+9")
 		setCurrentIndex(8);
 	else
 		// skrot nie zostal znaleziony i wykonany. Przekazujemy zdarzenie dalej
@@ -332,7 +364,7 @@ void TabWidget::moveTab(int from, int to)
 
 void TabWidget::onDeleteTab(int id)
 {
-	closeTab(widget(id));
+	closeTab(static_cast<ChatWidget *>(widget(id)));
 }
 
 void TabWidget::switchTabLeft()
@@ -428,7 +460,7 @@ void TabWidget::mouseDoubleClickEvent(QMouseEvent *e)
 
 void TabWidget::newChat()
 {
-	OpenChatWith::instance()->show();
+	m_openChatWithService->show();
 }
 
 void TabWidget::openRecentChatsMenu()
@@ -445,22 +477,23 @@ void TabWidget::openTabsList()
 
 void TabWidget::openRecentChat(QAction *action)
 {
-	Core::instance()->chatWidgetManager()->openChat(action->data().value<Chat>(), OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(action->data().value<Chat>(), OpenChatActivation::Activate);
 }
 
 void TabWidget::deleteTab()
 {
-	closeTab(currentWidget());
+	closeTab(static_cast<ChatWidget *>(currentWidget()));
 }
 
 void TabWidget::tabInserted(int index)
 {
 	Q_UNUSED(index)
 
+	auto chatWidget = static_cast<ChatWidget *>(widget(index));
+	connect(chatWidget, SIGNAL(closeRequested(ChatWidget*)), this, SLOT(closeTab(ChatWidget*)));
+
 	updateTabsListButton();
 	updateTabsMenu();
-
-	show();
 }
 
 void TabWidget::tabRemoved(int index)
@@ -476,7 +509,7 @@ void TabWidget::tabRemoved(int index)
 
 void TabWidget::compositingEnabled()
 {
-	if (config_file.readBoolEntry("Chat", "UseTransparency", false))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Chat", "UseTransparency", false))
 	{
 		setAutoFillBackground(false);
 		setAttribute(Qt::WA_TranslucentBackground, true);
@@ -496,15 +529,15 @@ void TabWidget::configurationUpdated()
 {
 	triggerCompositingStateChanged();
 
-	CloseChatButton->setIcon(KaduIcon("kadu_icons/tab-remove").icon());
+	CloseChatButton->setIcon(m_iconsManager->iconByPath(KaduIcon("kadu_icons/tab-remove")));
 
-	setTabsClosable(config_file.readBoolEntry("Tabs", "CloseButtonOnTab"));
-	config_oldStyleClosing = config_file.readBoolEntry("Tabs", "OldStyleClosing");
+	setTabsClosable(m_configuration->deprecatedApi()->readBoolEntry("Tabs", "CloseButtonOnTab"));
+	config_oldStyleClosing = m_configuration->deprecatedApi()->readBoolEntry("Tabs", "OldStyleClosing");
 
 	bool isOpenChatButtonEnabled = (cornerWidget(Qt::TopLeftCorner) == OpenChatButtonsWidget);
-	bool shouldEnableOpenChatButton = config_file.readBoolEntry("Tabs", "OpenChatButton");
-	bool isCloseButtonEnabled = (cornerWidget(Qt::TopRightCorner) == CloseChatButton);
-	bool shouldEnableCloseButton = config_file.readBoolEntry("Tabs", "CloseButton");
+	bool shouldEnableOpenChatButton = m_configuration->deprecatedApi()->readBoolEntry("Tabs", "OpenChatButton");
+	bool isCloseButtonEnabled = CloseChatButton->isVisible();
+	bool shouldEnableCloseButton = m_configuration->deprecatedApi()->readBoolEntry("Tabs", "CloseButton");
 
 	if (isOpenChatButtonEnabled != shouldEnableOpenChatButton)
 	{
