@@ -1,13 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 koudy (koudy@koudy-Aspire-3820.(none))
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2012 Vladimir Kloucek (kelmhell@gmail.com)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,16 +19,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TABS_TABWIDGET_H
-#define TABS_TABWIDGET_H
+#pragma once
 
 #include <QtGui/QCursor>
-#include <QtGui/QMenu>
 #include <QtGui/QMouseEvent>
-#include <QtGui/QTabBar>
-#include <QtGui/QTabWidget>
-#include <QtGui/QToolButton>
-#include <QtGui/QWidget>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QTabBar>
+#include <QtWidgets/QTabWidget>
+#include <QtWidgets/QToolButton>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
 
 #include "gui/widgets/custom-input.h"
 
@@ -41,7 +36,13 @@
 
 #include "debug.h"
 
+class Application;
+class ChatWidgetManager;
 class ChatWidget;
+class Configuration;
+class IconsManager;
+class PluginInjectedFactory;
+class OpenChatWithService;
 class RecentChatsMenu;
 class TabsManager;
 
@@ -49,6 +50,13 @@ class TabWidget : public QTabWidget, CompositingAwareObject
 {
 	Q_OBJECT
 
+	QPointer<Application> m_application;
+	QPointer<ChatWidgetManager> m_chatWidgetManager;
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<OpenChatWithService> m_openChatWithService;
+
 	QToolButton *CloseChatButton;
 	QToolButton *TabsListButton;
 	QWidget *OpenChatButtonsWidget;
@@ -61,12 +69,19 @@ class TabWidget : public QTabWidget, CompositingAwareObject
 
 	bool config_oldStyleClosing;
 
-	void closeTab(QWidget *tabWidget);
 	void updateTabsMenu();
 	void updateTabsListButton();
 	bool isTabVisible(int index);
 
 private slots:
+	INJEQT_SET void setApplication(Application *application);
+	INJEQT_SET void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setOpenChatWithService(OpenChatWithService *openChatWithService);
+	INJEQT_INIT void init();
+
 	void onContextMenu(int id, const QPoint &pos);
 
 	/**
@@ -101,16 +116,14 @@ private slots:
 	*/
 	void openRecentChat(QAction *action);
 
-	/**
-	* Slot zostaje wywołany w celu zmiany pozycji karty.
-	* @param from pozycja karty źródłowej.
-	* @param to pozycja karty docelowej.
-	*/
 	void deleteTab();
 
 	void openTabsList();
 	void currentTabChanged(int index);
 	void tabsMenuSelected(QAction *action);
+
+	void closeTab(ChatWidget *chatWidget);
+
 protected:
 	/**
 	* Metoda wywoływana w chwili naciśnięcia x na ?pasku dekoracji?
@@ -171,6 +184,7 @@ public:
 
 	bool isChatWidgetActive(const ChatWidget *chatWidget);
 	void tryActivateChatWidget(ChatWidget *chatWidget);
+	void tryMinimizeChatWidget(ChatWidget *chatWidget);
 
 public slots:
 	/**
@@ -195,5 +209,3 @@ signals:
 	void openTab(QStringList altnicks, int index);
 
 };
-
-#endif // TABS_TABWIDGET_H
