@@ -1,11 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,33 +21,41 @@
 #pragma once
 
 #include "gui/widgets/chat-widget/chat-widget-container-handler.h"
+#include "injeqt-type-roles.h"
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
+class ChatWidgetContainerHandlerRepository;
 class TabsManager;
-class TabWidget;
+enum class OpenChatActivation;
 
 class TabsChatWidgetContainerHandler : public ChatWidgetContainerHandler
 {
 	Q_OBJECT
+	INJEQT_TYPE_ROLE(SERVICE)
 
 public:
-	explicit TabsChatWidgetContainerHandler(QObject *parent = nullptr);
+	Q_INVOKABLE explicit TabsChatWidgetContainerHandler(QObject *parent = nullptr);
 	virtual ~TabsChatWidgetContainerHandler();
 
-	void setTabsManager(TabsManager *tabsManager);
-	void setTabWidget(TabWidget *tabWidget);
-
-	virtual bool acceptChatWidget(ChatWidget *chatWidget) const override;
-	virtual void addChatWidget(ChatWidget *chatWidget) override;
-	virtual void removeChatWidget(ChatWidget *chatWidget) override;
+	virtual bool acceptChat(Chat chat) const override;
+	virtual ChatWidget * addChat(Chat chat, OpenChatActivation activation) override;
+	virtual void removeChat(Chat chat) override;
 
 	virtual bool isChatWidgetActive(ChatWidget *chatWidget) override;
 	virtual void tryActivateChatWidget(ChatWidget *chatWidget) override;
+	virtual void tryMinimizeChatWidget(ChatWidget *chatWidget) override;
 
-public:
+private:
+	QPointer<ChatWidgetContainerHandlerRepository> m_chatWidgetContainerHandlerRepository;
 	QPointer<TabsManager> m_tabsManager;
-	QPointer<TabWidget> m_tabWidget;
+
+private slots:
+	INJEQT_SET void setChatWidgetContainerHandlerRepository(ChatWidgetContainerHandlerRepository *chatWidgetContainerHandlerRepository);
+	INJEQT_SET void setTabsManager(TabsManager *tabsManager);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
 
 };
