@@ -1,14 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010 Maciej Płaza (plaza.maciej@gmail.com)
- * Copyright 2009, 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  * Copyright Michal Podsiadlik (michal at gov.one.pl)
  *
@@ -26,8 +21,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtGui/QApplication>
-#include <QtGui/QMenu>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QMenu>
+#include <injeqt/injeqt.h>
 
 #include "accounts/account-manager.h"
 #include "accounts/account.h"
@@ -36,36 +32,49 @@
 #include "buddies/buddy-set.h"
 #include "buddies/buddy.h"
 #include "configuration/config-file-variant-wrapper.h"
-#include "configuration/configuration-file.h"
-#include "configuration/xml-configuration-file.h"
+#include "configuration/configuration-api.h"
+#include "configuration/configuration.h"
+#include "configuration/deprecated-configuration-api.h"
 #include "contacts/contact-set.h"
-#include "core/core.h"
+#include "core/session-service.h"
+#include "gui/actions/actions.h"
 #include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
+#include "gui/configuration/chat-configuration-holder.h"
 #include "gui/menu/menu-inventory.h"
 #include "gui/widgets/chat-edit-box.h"
+#include "gui/widgets/chat-widget/chat-widget-impl.h"
 #include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/chat-widget/chat-widget-repository.h"
-#include "gui/widgets/chat-widget/chat-widget.h"
+#include "gui/widgets/chat-widget/chat-widget-set-title.h"
+#include "gui/widgets/chat-widget/chat-widget-title.h"
 #include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/widgets/toolbar.h"
 #include "icons/kadu-icon.h"
 #include "message/unread-message-repository.h"
 #include "os/generic/window-geometry-manager.h"
+#include "plugin/plugin-injected-factory.h"
 #include "protocols/protocol-factory.h"
 #include "protocols/protocol.h"
 #include "protocols/protocols-manager.h"
 
+#include "core/core.h"
 #include "activate.h"
 #include "debug.h"
 
 #include "tabs.h"
 
-static void disableNewTab(Action *action)
+static void disableNewTab(Configuration *configuration, Action *action)
 {
+	if (action->context()->buddies().isAnyTemporary())
+	{
+		action->setEnabled(false);
+		return;
+	}
+
 	action->setEnabled(action->context()->chat());
 
-	if (config_file.readBoolEntry("Chat", "DefaultTabs"))
+	if (configuration->deprecatedApi()->readBoolEntry("Chat", "DefaultTabs"))
 		action->setText(QCoreApplication::translate("TabsManager", "Chat in New Window"));
 	else
 		action->setText(QCoreApplication::translate("TabsManager", "Chat in New Tab"));
@@ -74,7 +83,66 @@ static void disableNewTab(Action *action)
 }
 
 TabsManager::TabsManager(QObject *parent) :
-		ConfigurationUiHandler(parent), TargetTabs(-1)
+		StorableObject(parent), TargetTabs(-1)
+{
+	Title = new ChatWidgetSetTitle{this};
+}
+
+TabsManager::~TabsManager()
+{
+}
+
+void TabsManager::setActions(Actions *actions)
+{
+	m_actions = actions;
+}
+
+void TabsManager::setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder)
+{
+	m_chatConfigurationHolder = chatConfigurationHolder;
+}
+
+void TabsManager::setChatManager(ChatManager *chatManager)
+{
+	m_chatManager = chatManager;
+}
+
+void TabsManager::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
+{
+	m_chatWidgetRepository = chatWidgetRepository;
+}
+
+void TabsManager::setChatWidgetManager(ChatWidgetManager *chatWidgetManager)
+{
+	m_chatWidgetManager = chatWidgetManager;
+}
+
+void TabsManager::setConfiguration(Configuration *configuration)
+{
+	m_configuration = configuration;
+}
+
+void TabsManager::setIconsManager(IconsManager *iconsManager)
+{
+	m_iconsManager = iconsManager;
+}
+
+void TabsManager::setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory)
+{
+	m_pluginInjectedFactory = pluginInjectedFactory;
+}
+
+void TabsManager::setMenuInventory(MenuInventory *menuInventory)
+{
+	m_menuInventory = menuInventory;
+}
+
+void TabsManager::setSessionService(SessionService *sessionService)
+{
+	m_sessionService = sessionService;
+}
+
+void TabsManager::init()
 {
 	kdebugf();
 
@@ -82,62 +150,69 @@ TabsManager::TabsManager(QObject *parent) :
 
 	createDefaultConfiguration();
 
-	connect(&Timer, SIGNAL(timeout()), this, SLOT(onTimer()));
+	connect(m_chatWidgetRepository, SIGNAL(chatWidgetRemoved(ChatWidget*)), this, SLOT(onDestroyingChat(ChatWidget *)));
 
-	TabDialog = new TabWidget(this);
+	TabDialog = m_pluginInjectedFactory->makeInjected<TabWidget>(this);
 	TabDialog->setContextMenuPolicy(Qt::CustomContextMenu);
 	connect(TabDialog, SIGNAL(currentChanged(int)), this, SLOT(onTabChange(int)));
 	connect(TabDialog, SIGNAL(contextMenu(QWidget *, const QPoint &)),
 			this, SLOT(onContextMenu(QWidget *, const QPoint &)));
 
-	new WindowGeometryManager(new ConfigFileVariantWrapper("Chat", "TabWindowsGeometry"), QRect(30, 30, 550, 400), TabDialog);
+	connect(Title, SIGNAL(titleChanged()), this, SLOT(onTitleChanged()));
+
+	new WindowGeometryManager(new ConfigFileVariantWrapper(m_configuration, "Chat", "TabWindowsGeometry"), QRect(30, 30, 550, 400), TabDialog);
 
 	makePopupMenu();
 
 	// pozycja tabów
 	configurationUpdated();
 
-	OpenInNewTabActionDescription = new ActionDescription(this,
+	OpenInNewTabActionDescription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeUser, "openInNewTabAction",
 		this, SLOT(onNewTab(QAction *, bool)),
-		KaduIcon("internet-group-chat"), tr("Chat in New Tab"), false, disableNewTab
+		KaduIcon("internet-group-chat"), tr("Chat in New Tab"), false,
+		[this](Action *action){ return disableNewTab(m_configuration, action); }
 	);
 
-	MenuInventory::instance()
+	m_menuInventory
 		->menu("buddy-list")
 		->addAction(OpenInNewTabActionDescription, KaduMenu::SectionChat, 20)
 		->update();
 
-	AttachToTabsActionDescription = new ActionDescription(this,
+	AttachToTabsActionDescription = m_pluginInjectedFactory->makeInjected<ActionDescription>(this,
 		ActionDescription::TypeChat, "attachToTabsAction",
 		this, SLOT(onTabAttach(QAction *, bool)),
 		KaduIcon("kadu_icons/tab-detach"), tr("Attach Chat to Tabs"), true
 	);
 	connect(AttachToTabsActionDescription, SIGNAL(actionCreated(Action *)), this, SLOT(attachToTabsActionCreated(Action *)));
 
+	openStoredChatTabs();
+
 	kdebugf2();
 }
 
-TabsManager::~TabsManager()
+void TabsManager::done()
 {
 	kdebugf();
 
-	MenuInventory::instance()
+	storeOpenedChatTabs();
+
+	m_menuInventory
 		->menu("buddy-list")
 		->removeAction(OpenInNewTabActionDescription)
 		->update();
 
-	Timer.stop();
-	disconnect(Core::instance()->chatWidgetManager(), 0, this, 0);
+	disconnect(m_chatWidgetManager, 0, this, 0);
 
 	if (m_chatWidgetRepository)
 		disconnect(m_chatWidgetRepository.data(), 0, this, 0);
 
 	// jesli kadu nie konczy dzialania to znaczy ze modul zostal tylko wyladowany wiec odlaczamy rozmowy z kart
-	if (!Core::instance()->isClosing())
+	if (!m_sessionService->isClosing())
 		for (int i = TabDialog->count() - 1; i >= 0; i--)
 			detachChat(static_cast<ChatWidget *>(TabDialog->widget(i)));
 
+	m_closing = true;
 	delete TabDialog;
 	TabDialog = 0;
 
@@ -147,53 +222,44 @@ TabsManager::~TabsManager()
 	kdebugf2();
 }
 
-void TabsManager::setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository)
-{
-	m_chatWidgetRepository = chatWidgetRepository;
-
-	if (m_chatWidgetRepository)
-	{
-		connect(m_chatWidgetRepository.data(), SIGNAL(chatWidgetRemoved(ChatWidget*)),
-				this, SLOT(onDestroyingChat(ChatWidget *)));
-	}
-}
-
 void TabsManager::openStoredChatTabs()
 {
-	if (config_file.readBoolEntry("Chat", "SaveOpenedWindows", true))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Chat", "SaveOpenedWindows", true))
 		ensureLoaded();
 }
 
 void TabsManager::storeOpenedChatTabs()
 {
-	if (config_file.readBoolEntry("Chat", "SaveOpenedWindows", true))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Chat", "SaveOpenedWindows", true))
 		ensureStored();
 }
 
-bool TabsManager::acceptChatWidget(ChatWidget *chatWidget) const
+bool TabsManager::acceptChat(Chat chat) const
 {
-	if (!chatWidget)
+	if (!chat)
 		return false;
 
-	if (chatWidget->chat().property("tabs:tmp-attached", false).toBool())
+	if (chat.property("tabs:tmp-attached", false).toBool())
 		return true;
-	if (chatWidget->chat().property("tabs:tmp-detached", false).toBool())
+	if (chat.property("tabs:tmp-detached", false).toBool())
 		return false;
-	if (chatWidget->chat().property("tabs:attached", false).toBool())
+	if (chat.property("tabs:attached", false).toBool())
 		return true;
-	if (chatWidget->chat().property("tabs:detached", false).toBool())
+	if (chat.property("tabs:detached", false).toBool())
 		return false;
 
 	return ConfigDefaultTabs;
 }
 
-void TabsManager::addChatWidget(ChatWidget *chatWidget)
+ChatWidget * TabsManager::addChat(Chat chat, OpenChatActivation activation)
 {
 	kdebugf();
 
-	auto chat = chatWidget->chat();
-	if (config_file.readBoolEntry("Chat", "SaveOpenedWindows", true))
-		chat.addProperty("tabs:fix2626", true, CustomProperties::Storable);
+	auto chatWidget = m_pluginInjectedFactory->makeInjected<ChatWidgetImpl>(chat, nullptr);
+	setConfiguration(chatWidget);
+
+	if (m_configuration->deprecatedApi()->readBoolEntry("Chat", "SaveOpenedWindows", true))
+		chatWidget->chat().addProperty("tabs:fix2626", true, CustomProperties::Storable);
 
 	auto tmpAttached = chat.property("tabs:tmp-attached", false).toBool();
 	auto tmpDetached =  chat.property("tabs:tmp-detached", false).toBool();
@@ -202,35 +268,57 @@ void TabsManager::addChatWidget(ChatWidget *chatWidget)
 
 	if (!tmpAttached && tmpDetached)
 	{
-		DetachedChats.append(chatWidget);
-		return;
+		DetachedChats.append(chat);
+		return chatWidget;
 	}
 
 	if (tmpAttached)
 	{
 		insertTab(chatWidget);
-		return;
 	}
-
-	if (!attached && detached)
+	else if (!attached && detached)
 	{
-		DetachedChats.append(chatWidget);
-		return;
+		DetachedChats.append(chat);
+	}
+	else if (attached || ConfigDefaultTabs)
+		insertTab(chatWidget);
+
+	if (TabDialog->count() == 1) // first tab
+	{
+		switch (activation)
+		{
+			case OpenChatActivation::Minimize:
+				TabDialog->showMinimized();
+				break;
+			default:
+				TabDialog->show();
+				break;
+		}
 	}
 
-	if (attached || ConfigDefaultTabs)
-		insertTab(chatWidget);
+	if (activation == OpenChatActivation::Activate)
+		_activateWindow(m_configuration, TabDialog);
+
+	return chatWidget;
 }
 
-void TabsManager::removeChatWidget(ChatWidget *chatWidget)
+void TabsManager::removeChat(Chat chat)
 {
-	if (!chatWidget)
+	// TODO: fix this whole thing
+	if (!chat || m_closing)
 		return;
 
-	chatWidget->setParent(nullptr);
-	auto index = TabDialog->indexOf(chatWidget);
-	if (index >= 0)
-		TabDialog->removeTab(index);
+	auto count = TabDialog->count();
+	for (auto i = 0; i < count; i++)
+	{
+		auto chatWidget = qobject_cast<ChatWidget *>(TabDialog->widget(i));
+		if (chatWidget && chatWidget->chat() == chat)
+		{
+			TabDialog->removeTab(i);
+			chatWidget->deleteLater();
+			return;
+		}
+	}
 }
 
 void TabsManager::onDestroyingChat(ChatWidget *chatWidget)
@@ -242,7 +330,7 @@ void TabsManager::onDestroyingChat(ChatWidget *chatWidget)
 	if (TabDialog->indexOf(chatWidget) != -1)
 		TabDialog->removeTab(TabDialog->indexOf(chatWidget));
 
-	DetachedChats.removeAll(chatWidget);
+	DetachedChats.removeAll(chatWidget->chat());
 
 	disconnect(chatWidget->edit(), 0, TabDialog, 0);
 	disconnect(chatWidget, 0, this, 0);
@@ -255,14 +343,7 @@ void TabsManager::onDestroyingChat(ChatWidget *chatWidget)
 	kdebugf2();
 }
 
-void TabsManager::onIconChanged()
-{
-	ChatWidget *chatWidget = static_cast<ChatWidget *>(sender());
-	if (chatWidget)
-		updateTabIcon(chatWidget);
-}
-
-void TabsManager::onTitleChanged(ChatWidget *chatWidget, const QString &newTitle)
+void TabsManager::onTitleChanged(ChatWidget *chatWidget)
 {
 	kdebugf();
 
@@ -271,26 +352,33 @@ void TabsManager::onTitleChanged(ChatWidget *chatWidget, const QString &newTitle
 	if (-1 == chatIndex || !chatWidget)
 		return;
 
-	updateTabName(chatWidget);
-	if (TabDialog->currentIndex() == chatIndex)
-		TabDialog->setWindowTitle(newTitle);
+	updateTabTitle(chatWidget);
+	//if (TabDialog->currentIndex() == chatIndex)
+		//TabDialog->setWindowTitle(TabDialog->tabText(chatIndex));
 
 	kdebugf2();
 }
 
+void TabsManager::onTitleChanged()
+{
+	TabDialog->setWindowTitle(Title->fullTitle());
+	TabDialog->setWindowIcon(Title->icon());
+}
+
 void TabsManager::onTabChange(int index)
 {
 	if (index < 0)
 		return;
 
 	ChatWidget *chatWidget = static_cast<ChatWidget *>(TabDialog->widget(index));
+	Title->setActiveChatWidget(chatWidget);
 
 	const Chat &chat = chatWidget->chat();
 	if (chat.unreadMessagesCount() > 0)
 		emit chatWidgetActivated(chatWidget);
 
-	TabDialog->setWindowTitle(chatWidget->title());
-	TabDialog->setWindowIcon(chatWidget->icon());
+	//TabDialog->setWindowTitle(chatWidget->title()->title());
+	//TabDialog->setWindowIcon(chatWidget->title()->icon());
 
 	chatWidget->edit()->setFocus();
 }
@@ -309,10 +397,10 @@ void TabsManager::onNewTab(QAction *sender, bool toggled)
 	if (!chat)
 		return;
 
-	auto chatWidget = Core::instance()->chatWidgetRepository()->widgetForChat(chat);
+	auto chatWidget = m_chatWidgetRepository->widgetForChat(chat);
 	if (!chatWidget)
 	{
-		if (config_file.readBoolEntry("Chat", "DefaultTabs"))
+		if (m_configuration->deprecatedApi()->readBoolEntry("Chat", "DefaultTabs"))
 		{
 			chat.addProperty("tabs:tmp-detached", true, CustomProperties::NonStorable);
 		}
@@ -322,7 +410,7 @@ void TabsManager::onNewTab(QAction *sender, bool toggled)
 		}
 	}
 
-	Core::instance()->chatWidgetManager()->openChat(chat, OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(chat, OpenChatActivation::Activate);
 
 	chat.removeProperty("tabs:tmp-attached");
 	chat.removeProperty("tabs:tmp-detached");
@@ -334,6 +422,8 @@ void TabsManager::insertTab(ChatWidget *chatWidget)
 {
 	kdebugf();
 
+	Title->addChatWidget(chatWidget);
+
 	bool restoreChatGeometry = true;
 
 	// jeśli jest otwarty chatwindow przypisany do chat to zostanie on zamknięty
@@ -345,7 +435,7 @@ void TabsManager::insertTab(ChatWidget *chatWidget)
 
 	ContactSet contacts = chatWidget->chat().contacts();
 
-	DetachedChats.removeAll(chatWidget);
+	DetachedChats.removeAll(chatWidget->chat());
 
 	for (Action *action : AttachToTabsActionDescription->actions())
 	{
@@ -354,95 +444,29 @@ void TabsManager::insertTab(ChatWidget *chatWidget)
 	}
 
 	// Ustawiam tytul karty w zaleznosci od tego czy mamy do czynienia z rozmowa czy z konferencja
-	TabDialog->insertTab(TargetTabs, chatWidget, chatWidget->icon(), QString());
+	TabDialog->insertTab(TargetTabs, chatWidget, chatWidget->title()->blinkingIcon(), QString());
 
 	if (restoreChatGeometry)
 		chatWidget->kaduRestoreGeometry();
 
-	updateTabName(chatWidget);
+	updateTabTitle(chatWidget);
 
 	TargetTabs = -1;
 
 	connect(chatWidget->edit(), SIGNAL(keyPressed(QKeyEvent*, CustomInput*, bool&)),
 			TabDialog, SLOT(chatKeyPressed(QKeyEvent*, CustomInput*, bool&)));
 
-	connect(chatWidget, SIGNAL(unreadMessagesCountChanged(ChatWidget*)),
-			this, SLOT(unreadMessagesCountChanged(ChatWidget*)));
-	connect(chatWidget, SIGNAL(iconChanged()), this, SLOT(onIconChanged()));
-	connect(chatWidget, SIGNAL(titleChanged(ChatWidget * , const QString &)),
-			this, SLOT(onTitleChanged(ChatWidget *, const QString &)));
+	connect(chatWidget->title(), SIGNAL(titleChanged(ChatWidget*)), this, SLOT(onTitleChanged(ChatWidget*)));
 
 	CloseOtherTabsMenuAction->setEnabled(TabDialog->count() > 1);
 
-	kdebugf2();
-}
-
-// uff, troche dziwne to ale dziala tak jak trzeba
-// TODO: review this!!!
-void TabsManager::onTimer()
-{
-	kdebugf();
-	static bool msg = true;
-
-	bool tabsActive = _isWindowActiveOrFullyVisible(TabDialog);
-	ChatWidget *currentChatWidget = static_cast<ChatWidget *>(TabDialog->currentWidget());
-	if (!currentChatWidget)
-	{
-		// that means we are closing window now
-		return;
-	}
-
-	auto unreadChatWidget = chatWidgetWithUnreadMessage();
-	if (unreadChatWidget && !tabsActive)
-	{
-		qApp->alert(TabDialog);
-
-		if (currentChatWidget->unreadMessagesCount() > 0)
-		{
-			if (ConfigBlinkChatTitle)
-				TabDialog->setWindowTitle(msg
-						? QString(currentChatWidget->title().length() + 5, ' ')
-						: currentChatWidget->title());
-			else if (ConfigShowNewMessagesNum)
-				TabDialog->setWindowTitle('[' + QString::number(currentChatWidget->chat().unreadMessagesCount()) + "] " + currentChatWidget->title());
-			else
-				TabDialog->setWindowTitle(currentChatWidget->title());
-		}
-		else if (ConfigBlinkChatTitle && !msg)
-			TabDialog->setWindowTitle(tr("NEW MESSAGE(S)"));
-		else
-			TabDialog->setWindowTitle(unreadChatWidget->title());
-	}
-	else
-		TabDialog->setWindowTitle(currentChatWidget->title());
-
-	msg = !msg;
-
-	if (unreadChatWidget && !Timer.isActive())
-		Timer.start(500);
-	else if (!unreadChatWidget && Timer.isActive())
-		Timer.stop();
+	// unreadMessagesCountChanged(chatWidget);
+	if (_isActiveWindow(TabDialog) && TabDialog->currentWidget() == chatWidget)
+		emit chatWidgetActivated(chatWidget);
 
 	kdebugf2();
 }
 
-ChatWidget * TabsManager::chatWidgetWithUnreadMessage() const
-{
-	auto count = TabDialog->count();
-	for (auto i = 0; i < count; i++)
-	{
-		auto chatWidget = qobject_cast<ChatWidget *>(TabDialog->widget(i));
-		if (chatWidget)
-		{
-			auto chat = chatWidget->chat();
-			if (chat.unreadMessagesCount() > 0)
-				return chatWidget;
-		}
-	}
-
-	return {};
-}
-
 void TabsManager::onTabAttach(QAction *sender, bool toggled)
 {
 	ChatEditBox *chatEditBox = qobject_cast<ChatEditBox *>(sender->parentWidget());
@@ -460,7 +484,7 @@ void TabsManager::onTabAttach(QAction *sender, bool toggled)
 		auto chat = chatWidget->chat();
 		chat.removeProperty("tabs:detached");
 		chat.addProperty("tabs:attached", true, CustomProperties::Storable);
-		emit chatWidgetAcceptanceChanged(chatWidget);
+		emit chatAcceptanceChanged(chat);
 	}
 }
 
@@ -477,16 +501,16 @@ void TabsManager::makePopupMenu()
 	kdebugf();
 
 	Menu = new QMenu();
-	DetachTabMenuAction = Menu->addAction(KaduIcon("kadu_icons/tab-detach").icon(), tr("Detach"), this, SLOT(onMenuActionDetach()));
+	DetachTabMenuAction = Menu->addAction(m_iconsManager->iconByPath(KaduIcon("kadu_icons/tab-detach")), tr("Detach"), this, SLOT(onMenuActionDetach()));
 	Menu->addAction(tr("Detach all"), this, SLOT(onMenuActionDetachAll()));
 	Menu->addSeparator();
-	CloseTabMenuAction = Menu->addAction(KaduIcon("kadu_icons/tab-close").icon(), tr("Close"), this, SLOT(onMenuActionClose()));
+	CloseTabMenuAction = Menu->addAction(m_iconsManager->iconByPath(KaduIcon("kadu_icons/tab-close")), tr("Close"), this, SLOT(onMenuActionClose()));
 	CloseOtherTabsMenuAction = Menu->addAction(tr("Close other tabs"), this, SLOT(onMenuActionCloseAllButActive()));
 	CloseOtherTabsMenuAction->setEnabled(TabDialog->count() > 1);
 	ReopenClosedTabMenuAction = Menu->addAction(tr("Reopen closed tab"), this, SLOT(reopenClosedChat()));
 	ReopenClosedTabMenuAction->setEnabled(false);
 
-	if (config_file.readBoolEntry("Tabs", "OldStyleClosing"))
+	if (m_configuration->deprecatedApi()->readBoolEntry("Tabs", "OldStyleClosing"))
 		Menu->addAction(tr("Close all"), this, SLOT(onMenuActionCloseAll()));
 
 	kdebugf2();
@@ -549,7 +573,7 @@ void TabsManager::detachChat(ChatWidget *chatWidget)
 	auto chat = chatWidget->chat();
 	chat.addProperty("tabs:detached", true, CustomProperties::Storable);
 	chat.removeProperty("tabs:attached");
-	emit chatWidgetAcceptanceChanged(chatWidget);
+	emit chatAcceptanceChanged(chat);
 }
 
 void TabsManager::load()
@@ -571,7 +595,7 @@ void TabsManager::load()
 		if (chatId.isNull())
 			continue;
 
-		Chat chat = ChatManager::instance()->byUuid(chatId);
+		Chat chat = m_chatManager->byUuid(chatId);
 		if (!chat)
 			continue;
 
@@ -580,7 +604,7 @@ void TabsManager::load()
 		else if (element.attribute("type") == "tab")
 			chat.addProperty("tabs:attached", true, CustomProperties::Storable);
 
-		Core::instance()->chatWidgetManager()->openChat(chat, OpenChatActivation::DoNotActivate);
+		m_chatWidgetManager->openChat(chat, OpenChatActivation::DoNotActivate);
 	}
 }
 
@@ -589,7 +613,7 @@ void TabsManager::store()
 	if (!isValidStorage())
 		return;
 
-	XmlConfigFile *storageFile = storage()->storage();
+	ConfigurationApi *storageFile = storage()->storage();
 	QDomElement point = storage()->point();
 
 	storageFile->removeChildren(point);
@@ -607,7 +631,7 @@ void TabsManager::store()
 		if (!chat)
 			continue;
 
-		if ((TabDialog->indexOf(chatWidget) == -1) && (DetachedChats.indexOf(chatWidget) == -1))
+		if ((TabDialog->indexOf(chatWidget) == -1) && (DetachedChats.indexOf(chat) == -1))
 			continue;
 
 		QDomElement window_elem = storageFile->createElement(point, "Tab");
@@ -615,49 +639,48 @@ void TabsManager::store()
 		window_elem.setAttribute("chat", chat.uuid().toString());
 		if (TabDialog->indexOf(chatWidget) != -1)
 			window_elem.setAttribute("type", "tab");
-		else if (DetachedChats.indexOf(chatWidget) != -1)
+		else if (DetachedChats.indexOf(chat) != -1)
 			window_elem.setAttribute("type", "detachedChat");
 	}
 }
 
 bool TabsManager::shouldStore()
 {
-	return StorableObject::shouldStore() && config_file.readBoolEntry("Chat", "SaveOpenedWindows", true);
-}
-
-void TabsManager::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
-{
-	Q_UNUSED(mainConfigurationWindow)
+	return StorableObject::shouldStore() && m_configuration->deprecatedApi()->readBoolEntry("Chat", "SaveOpenedWindows", true);
 }
 
 void TabsManager::configurationUpdated()
 {
 	kdebugf();
-	ConfigTabsBelowChats = config_file.readBoolEntry("Chat", "TabsBelowChats");
-	ConfigDefaultTabs = config_file.readBoolEntry("Chat", "DefaultTabs");
-	ConfigBlinkChatTitle = config_file.readBoolEntry("Chat", "BlinkChatTitle");
-	ConfigShowNewMessagesNum = config_file.readBoolEntry("Chat", "NewMessagesInChatTitle");
+
+	ConfigTabsBelowChats = m_configuration->deprecatedApi()->readBoolEntry("Chat", "TabsBelowChats");
+	ConfigDefaultTabs = m_configuration->deprecatedApi()->readBoolEntry("Chat", "DefaultTabs");
 
 	TabDialog->setTabPosition(ConfigTabsBelowChats ? QTabWidget::South : QTabWidget::North);
 
 	TabDialog->configurationUpdated();
 
-	DetachTabMenuAction->setIcon(KaduIcon("kadu_icons/tab-detach").icon());
-	CloseTabMenuAction->setIcon(KaduIcon("kadu_icons/tab-close").icon());
+	DetachTabMenuAction->setIcon(m_iconsManager->iconByPath(KaduIcon("kadu_icons/tab-detach")));
+	CloseTabMenuAction->setIcon(m_iconsManager->iconByPath(KaduIcon("kadu_icons/tab-close")));
+
+	auto count = TabDialog->count();
+	for (auto i = 0; i < count; i++)
+		setConfiguration(static_cast<ChatWidget *>(TabDialog->widget(i)));
 
 	kdebugf2();
 }
 
-void TabsManager::updateTabTextAndTooltip(int index, const QString &text, const QString &tooltip)
+void TabsManager::setConfiguration(ChatWidget* chatWidget)
 {
-	if (TabDialog->tabText(index) != text)
-		TabDialog->setTabText(index, text);
-	if (TabDialog->tabToolTip(index) != tooltip)
-		TabDialog->setTabToolTip(index, tooltip);
+	auto blinkChatTitle = m_configuration->deprecatedApi()->readBoolEntry("Chat", "BlinkChatTitle", false);
+	chatWidget->title()->setBlinkIconWhenUnreadMessages(blinkChatTitle);
+	chatWidget->title()->setBlinkTitleWhenUnreadMessages(blinkChatTitle);
+	chatWidget->title()->setComposingStatePosition(m_chatConfigurationHolder->composingStatePosition());
+	chatWidget->title()->setShowUnreadMessagesCount(m_configuration->deprecatedApi()->readBoolEntry("Chat", "NewMessagesInChatTitle", false));
 }
 
 // TODO: share with single_window
-void TabsManager::updateTabName(ChatWidget *chatWidget)
+void TabsManager::updateTabTitle(ChatWidget *chatWidget)
 {
 	if (!chatWidget)
 		return;
@@ -666,49 +689,11 @@ void TabsManager::updateTabName(ChatWidget *chatWidget)
 	if (-1 == index)
 		return;
 
-	auto chatTitle = shortChatTitle(defaultChatTitle(chatWidget->chat()));
-	if (chatWidget->unreadMessagesCount() > 0)
-		updateTabTextAndTooltip(index, QString("%1 [%2]").arg(chatTitle).arg(chatWidget->unreadMessagesCount()),
-				QString("%1\n%2 new message(s)").arg(chatWidget->title()).arg(chatWidget->unreadMessagesCount()));
-	else
-		updateTabTextAndTooltip(index, chatTitle, chatTitle);
-}
-
-QString TabsManager::defaultChatTitle(const Chat &chat) const
-{
-	if (!chat.display().isEmpty())
-		return chat.display();
-
-	auto contactsCount = chat.contacts().count();
-	return contactsCount > 1
-			? tr("Conference [%1]").arg(contactsCount)
-			: chat.name();
-}
-
-QString TabsManager::shortChatTitle(const QString &chatTitle) const
-{
-	auto const tabTextLimit = 15;
-	return  chatTitle.length() > tabTextLimit
-			? chatTitle.left(tabTextLimit) + "..."
-			: chatTitle;
-}
-
-void TabsManager::updateTabIcon(ChatWidget *chatWidget)
-{
-	if (!chatWidget)
-		return;
-
-	const int i = TabDialog->indexOf(chatWidget);
-	if (-1 == i)
-		return;
-
-	if (chatWidget->unreadMessagesCount() > 0)
-		TabDialog->setTabIcon(i, KaduIcon("protocols/common/message").icon());
-	else
-		TabDialog->setTabIcon(i, chatWidget->icon());
-
-	if (TabDialog->currentIndex() == i)
-		TabDialog->setWindowIcon(TabDialog->tabIcon(i));
+	TabDialog->setTabText(index, chatWidget->title()->shortTitle());
+	TabDialog->setTabToolTip(index, chatWidget->title()->tooltip());
+	TabDialog->setTabIcon(index, chatWidget->title()->blinkingIcon());
+	if (TabDialog->currentIndex() == index)
+		TabDialog->setWindowIcon(TabDialog->tabIcon(index));
 }
 
 void TabsManager::closeChat()
@@ -723,36 +708,23 @@ void TabsManager::reopenClosedChat()
 	if (ClosedChats.isEmpty())
 		return;
 
-	Core::instance()->chatWidgetManager()->openChat(ClosedChats.takeFirst(), OpenChatActivation::Activate);
+	m_chatWidgetManager->openChat(ClosedChats.takeFirst(), OpenChatActivation::Activate);
 	ReopenClosedTabMenuAction->setEnabled(ClosedChats.isEmpty());
 }
 
 void TabsManager::createDefaultConfiguration()
 {
-	config_file.addVariable("ShortCuts", "MoveTabLeft", "Ctrl+Alt+Left");
-	config_file.addVariable("ShortCuts", "MoveTabRight", "Ctrl+Alt+Right");
-	config_file.addVariable("ShortCuts", "SwitchTabLeft", "Alt+Left");
-	config_file.addVariable("ShortCuts", "SwitchTabRight", "Alt+Right");
-	config_file.addVariable("ShortCuts", "ReopenClosedTab", "Ctrl+Shift+T");
-	config_file.addVariable("Chat", "ConferencesInTabs", "true");
-	config_file.addVariable("Chat", "TabsBelowChats", "false");
-	config_file.addVariable("Chat", "DefaultTabs", "true");
-	config_file.addVariable("Tabs", "CloseButton", "true");
-	config_file.addVariable("Tabs", "OpenChatButton", "true");
-	config_file.addVariable("Tabs", "OldStyleClosing", "false");
-	config_file.addVariable("Tabs", "CloseButtonOnTab", "false");
-}
-
-void TabsManager::unreadMessagesCountChanged(ChatWidget *chatWidget)
-{
-	if (!chatWidget)
-		return;
-
-	updateTabIcon(chatWidget);
-	updateTabName(chatWidget);
-
-	if (chatWidget->unreadMessagesCount() > 0 && !Timer.isActive())
-		QMetaObject::invokeMethod(this, "onTimer", Qt::QueuedConnection);
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "MoveTabLeft", "Ctrl+Alt+Left");
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "MoveTabRight", "Ctrl+Alt+Right");
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "SwitchTabLeft", "Alt+Left");
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "SwitchTabRight", "Alt+Right");
+	m_configuration->deprecatedApi()->addVariable("ShortCuts", "ReopenClosedTab", "Ctrl+Shift+T");
+	m_configuration->deprecatedApi()->addVariable("Chat", "TabsBelowChats", "false");
+	m_configuration->deprecatedApi()->addVariable("Chat", "DefaultTabs", "true");
+	m_configuration->deprecatedApi()->addVariable("Tabs", "CloseButton", "true");
+	m_configuration->deprecatedApi()->addVariable("Tabs", "OpenChatButton", "true");
+	m_configuration->deprecatedApi()->addVariable("Tabs", "OldStyleClosing", "false");
+	m_configuration->deprecatedApi()->addVariable("Tabs", "CloseButtonOnTab", "false");
 }
 
 #include "moc_tabs.cpp"
