@@ -1,10 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2008, 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2012 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013, 2014, 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,42 +29,65 @@
 
 #include <QtCore/QObject>
 #include <QtCore/QTimer>
+#include <injeqt/injeqt.h>
 
 #include "chat/chat-manager.h"
 
 #include "configuration/configuration-aware-object.h"
-#include "gui/windows/main-configuration-window.h"
+#include "configuration/gui/configuration-ui-handler.h"
 #include "misc/misc.h"
 #include "storage/storable-object.h"
+#include "injeqt-type-roles.h"
 
 #include "gui/widgets/tab-widget.h"
 
 class QAction;
 class QMenu;
 
-class Action;
+class Actions;
 class ActionDescription;
-class ChatWidget;
+class Action;
+class ChatConfigurationHolder;
+class ChatManager;
+class ChatWidgetManager;
 class ChatWidgetRepository;
+class ChatWidgetSetTitle;
+class ChatWidget;
+class IconsManager;
+class PluginInjectedFactory;
+class MenuInventory;
+class SessionService;
 
-class TabsManager : public ConfigurationUiHandler, ConfigurationAwareObject, StorableObject
+enum class OpenChatActivation;
+
+class TabsManager : public StorableObject, ConfigurationAwareObject
 {
 	Q_OBJECT
+	INJEQT_TYPE_ROLE(SERVICE)
 
 	// just for fun, this code is so bad already
 	// that one more friend class wont do a difference
 	friend class TabWidget;
 
+	QPointer<Actions> m_actions;
+	QPointer<ChatConfigurationHolder> m_chatConfigurationHolder;
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatWidgetManager> m_chatWidgetManager;
 	QPointer<ChatWidgetRepository> m_chatWidgetRepository;
+	QPointer<Configuration> m_configuration;
+	QPointer<IconsManager> m_iconsManager;
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
+	QPointer<MenuInventory> m_menuInventory;
+	QPointer<SessionService> m_sessionService;
 
 	void createDefaultConfiguration();
 
 	ActionDescription *OpenInNewTabActionDescription;
 	ActionDescription *AttachToTabsActionDescription;
 	TabWidget *TabDialog;
-	QTimer Timer;
-	QList<ChatWidget *> DetachedChats;
+	QList<Chat> DetachedChats;
 	QList<Chat> ClosedChats;
+	bool m_closing {false};
 
 	int TargetTabs;
 	void insertTab(ChatWidget *chatWidget);
@@ -77,25 +98,32 @@ class TabsManager : public ConfigurationUiHandler, ConfigurationAwareObject, Sto
 	QAction *CloseTabMenuAction;
 	QAction *CloseOtherTabsMenuAction;
 	QAction *ReopenClosedTabMenuAction;
+	ChatWidgetSetTitle *Title;
 
-	void updateTabName(ChatWidget *chatWidget);
-	void updateTabIcon(ChatWidget *chatWidget);
+	void updateTabTitle(ChatWidget *chatWidget);
 
 	/**
 	* Zmienne konfiguracyjne.
 	*/
 	bool ConfigTabsBelowChats;
 	bool ConfigDefaultTabs;
-	bool ConfigBlinkChatTitle;
-	bool ConfigShowNewMessagesNum;
 
-	ChatWidget * chatWidgetWithUnreadMessage() const;
-
-	QString defaultChatTitle(const Chat &chat) const;
-	QString shortChatTitle(const QString &chatTitle) const;
+	void setConfiguration(ChatWidget *chatWidget);
 
 private slots:
-	void onTimer();
+	INJEQT_SET void setActions(Actions *actions);
+	INJEQT_SET void setChatConfigurationHolder(ChatConfigurationHolder *chatConfigurationHolder);
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+	INJEQT_SET void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+	INJEQT_SET void setMenuInventory(MenuInventory *menuInventory);
+	INJEQT_SET void setSessionService(SessionService *sessionService);
+	INJEQT_INIT void init();
+	INJEQT_DONE void done();
+
 	void onContextMenu(QWidget *w, const QPoint &pos);
 	void onMenuActionDetach();
 	void onMenuActionDetachAll();
@@ -111,7 +139,7 @@ protected:
 	virtual bool shouldStore();
 
 public:
-	explicit TabsManager(QObject *parent = 0);
+	Q_INVOKABLE explicit TabsManager(QObject *parent = nullptr);
 	virtual ~TabsManager();
 
 	TabWidget * tabWidget() { return TabDialog; }
@@ -119,25 +147,19 @@ public:
 	void openStoredChatTabs();
 	void storeOpenedChatTabs();
 
-	void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
-
-	virtual void mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow);
-
 	void detachChat(ChatWidget *chatWidget);
 
 	virtual StorableObject * storageParent() { return 0; }
-	virtual QString storageNodeName() { return QLatin1String("ModuleTabs"); }
+	virtual QString storageNodeName() { return QStringLiteral("ModuleTabs"); }
 
-	void updateTabTextAndTooltip(int index, const QString &text, const QString &tooltip);
-
-	bool acceptChatWidget(ChatWidget *chatWidget) const;
-	void addChatWidget(ChatWidget *chatWidget);
-	void removeChatWidget(ChatWidget *chatWidget);
+	bool acceptChat(Chat chat) const;
+	ChatWidget * addChat(Chat chat, OpenChatActivation activation);
+	void removeChat(Chat chat);
 
 public slots:
 	void onDestroyingChat(ChatWidget *chatWidget);
-	void onIconChanged();
-	void onTitleChanged(ChatWidget *chatWidget, const QString &newTitle);
+	void onTitleChanged(ChatWidget *chatWidget);
+	void onTitleChanged();
 
 	void onTabChange(int index);
 
@@ -148,10 +170,9 @@ public slots:
 	void attachToTabsActionCreated(Action *action);
 
 	void closeChat();
-	void unreadMessagesCountChanged(ChatWidget *chatWidget);
 
 signals:
 	void chatWidgetActivated(ChatWidget *chatWidget);
-	void chatWidgetAcceptanceChanged(ChatWidget *chatWidget);
+	void chatAcceptanceChanged(Chat chat);
 
 };
