@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -139,10 +139,6 @@
         <source>Attach Chat to Tabs</source>
         <translation>Verbinde Chat mit Reitern</translation>
     </message>
-    <message>
-        <source>NEW MESSAGE(S)</source>
-        <translation>-&gt;Neue Nachrichten&lt;-</translation>
-    </message>
     <message>
         <source>Detach</source>
         <translation>Abtrennen</translation>
@@ -159,10 +155,6 @@
         <source>Close all</source>
         <translation>Alle schließen</translation>
     </message>
-    <message>
-        <source>Conference [%1]</source>
-        <translation>Konferenz [%1]</translation>
-    </message>
     <message>
         <source>Close other tabs</source>
         <translation type="unfinished"/>
