@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -7,15 +7,15 @@
     </message>
     <message>
         <source>General</source>
-        <translation type="unfinished"/>
+        <translation>Geral</translation>
     </message>
     <message>
         <source>Look</source>
-        <translation type="unfinished"/>
+        <translation>Olhe</translation>
     </message>
     <message>
         <source>Shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Atalhos</translation>
     </message>
     <message>
         <source>Move tab left</source>
@@ -27,15 +27,15 @@
     </message>
     <message>
         <source>Switch to previous tab</source>
-        <translation type="unfinished"/>
+        <translation>Mudar para aba anterior</translation>
     </message>
     <message>
         <source>Switch to next tab</source>
-        <translation type="unfinished"/>
+        <translation>Mudar para próxima aba</translation>
     </message>
     <message>
         <source>Chat</source>
-        <translation type="unfinished"/>
+        <translation>Conversa</translation>
     </message>
     <message>
         <source>Enable tabs in chat window</source>
@@ -63,15 +63,15 @@
     </message>
     <message>
         <source>Top</source>
-        <translation type="unfinished"/>
+        <translation>Cima</translation>
     </message>
     <message>
         <source>Bottom</source>
-        <translation type="unfinished"/>
+        <translation>Baixo</translation>
     </message>
     <message>
         <source>Behavior</source>
-        <translation type="unfinished"/>
+        <translation>Comportamento</translation>
     </message>
     <message>
         <source>Reopen closed tab</source>
@@ -94,7 +94,7 @@
     <name>TabWidget</name>
     <message>
         <source>Kadu</source>
-        <translation type="unfinished"/>
+        <translation>Kadu</translation>
     </message>
     <message>
         <source>New message received, close window anyway?</source>
@@ -122,7 +122,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Cancelar</translation>
     </message>
 </context>
 <context>
@@ -139,10 +139,6 @@
         <source>Attach Chat to Tabs</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>NEW MESSAGE(S)</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Detach</source>
         <translation type="unfinished"/>
@@ -153,16 +149,12 @@
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished"/>
+        <translation>Fechar</translation>
     </message>
     <message>
         <source>Close all</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Conference [%1]</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Close other tabs</source>
         <translation type="unfinished"/>
