@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
 <context>
     <name>@default</name>
     <message>
@@ -139,10 +139,6 @@
         <source>Attach Chat to Tabs</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>NEW MESSAGE(S)</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Detach</source>
         <translation type="unfinished"/>
@@ -159,10 +155,6 @@
         <source>Close all</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Conference [%1]</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Close other tabs</source>
         <translation type="unfinished"/>
