@@ -19,7 +19,7 @@
     </message>
 </context>
 <context>
-    <name>WordFix</name>
+    <name>WordFixConfigurationUiHandler</name>
     <message>
         <source>A word to be replaced</source>
         <translation>Slovo, které se má nahradit</translation>
