@@ -19,34 +19,34 @@
     </message>
 </context>
 <context>
-    <name>WordFix</name>
+    <name>WordFixConfigurationUiHandler</name>
     <message>
         <source>A word to be replaced</source>
-        <translation>Слово для замены</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Value to replace with</source>
-        <translation>Изменяемое значение</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Add</source>
-        <translation>Добавить</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Change</source>
-        <translation>Изменить</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Удалить</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Word</source>
-        <translation>слово</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Replace with</source>
-        <translation>Заменить на</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
