@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -85,7 +85,7 @@ QString WordFixFormattedStringVisitor::fixWords(const QString &content)
 
 void WordFixFormattedStringVisitor::visit(const FormattedStringTextBlock * const formattedStringTextBlock)
 {
-	cloned(make_unique<FormattedStringTextBlock>(
+	cloned(std::make_unique<FormattedStringTextBlock>(
 		fixWords(formattedStringTextBlock->content()),
 		formattedStringTextBlock->bold(),
 		formattedStringTextBlock->italic(),
