@@ -19,26 +19,14 @@ function expand_version()
 
 function prepare_links()
 {
-	UNSTABLE_GDRIVE_FOLDER=
-
-	if [ $BRANCH == "STABLE" ];
-	then
-		GDRIVE_FOLDER=0B2Jon_7ucnshOFg5NTNzazdmdk0
-	else
-		GDRIVE_FOLDER=0B2Jon_7ucnshcGVYOExsUjVQQ1k
-	fi
-
-	export SOURCE_GDRIVE=https://googledrive.com/host/$GDRIVE_FOLDER/kadu-$VERSION.tar.bz2
-	export SOURCE_SF=http://sourceforge.net/projects/kadu/files/kadu/$VERSION/kadu-$VERSION.tar.bz2/download
+	export SOURCE_SF=https://sourceforge.net/projects/kadu/files/kadu/$VERSION/kadu-$VERSION.tar.bz2/download
 	export SOURCE_KADU=http://download.kadu.im/unstable/kadu-$VERSION.tar.bz2
 	export SOURCE_KADU_MD5=http://download.kadu.im/unstable/kadu-$VERSION.tar.bz2.md5
 	export SOURCE_KADU_SHA1=http://download.kadu.im/unstable/kadu-$VERSION.tar.bz2.sha1
-	export EXE_GDRIVE=https://googledrive.com/host/$GDRIVE_FOLDER/Kadu-$VERSION.x86.exe
-	export EXE_SF=http://sourceforge.net/projects/kadu/files/kadu/$VERSION/Kadu-$VERSION.x86.exe/download
+	export EXE_SF=https://sourceforge.net/projects/kadu/files/kadu/$VERSION/Kadu-$VERSION.x86.exe/download
 	export EXE_KADU=http://download.kadu.im/unstable/windows/Kadu-$VERSION.x86.exe
 	export EXE_KADU_MD5=http://download.kadu.im/unstable/windows/Kadu-$VERSION.x86.exe.md5
 	export EXE_KADU_SHA1=http://download.kadu.im/unstable/windows/Kadu-$VERSION.x86.exe.sha1
-	export EXTERNAL_PLUGINS=http://download.kadu.im/external-plugins/2.0/
 }
 
 function read_changelog()
@@ -105,22 +93,17 @@ function write_forum_entry()
 		$CHANGELOG
 
 		Instalator Windows i sumy kontrolne:
-		 $EXE_GDRIVE
 		 $EXE_SF
 		 $EXE_KADU
 		 $EXE_KADU_MD5
 		 $EXE_KADU_SHA1
 
 		Źródła i sumy kontrolne:
-		 $SOURCE_GDRIVE
 		 $SOURCE_SF
 		 $SOURCE_KADU
 		 $SOURCE_KADU_MD5
 		 $SOURCE_KADU_SHA1
 
-		Wtyczki zewnętrzne:
-		 $EXTERNAL_PLUGINS
-
 		Przed instalacją zalecane jest zrobienie kopii katalogu z danymi ~/.kadu lub C:\Users\..\AppData\Roaming\Kadu.
 		Błędy jak zawsze proszę zgłaszac na redmine: http://www.kadu.im/redmine/
 END
@@ -142,22 +125,17 @@ function write_mailing_list_entry()
 		$CHANGELOG
 
 		Windows installer and checksums:
-		 $EXE_GDRIVE
 		 $EXE_SF
 		 $EXE_KADU
 		 $EXE_KADU_MD5
 		 $EXE_KADU_SHA1
 
 		Source code:
-		 $SOURCE_GDRIVE
 		 $SOURCE_SF
 		 $SOURCE_KADU
 		 $SOURCE_KADU_MD5
 		 $SOURCE_KADU_SHA1
 
-		External plugins:
-		 $EXTERNAL_PLUGINS
-
 		Please create backup of data directory ~/.kadu or C:\Users\..\AppData\Roaming\Kadu before installing.
 		Please report all found bugs in redmine: http://www.kadu.im/redmine/
 
@@ -185,19 +163,15 @@ function write_pl_wiki_entry()
 
 		'''Pobierz''':
 		:: Źródła dla systemu Linux ([[Instalacja_ze_źródeł|opis instalacji tej wersji Kadu]]):
-		::: [$SOURCE_GDRIVE Pobierz źródła (Google Drive)]
 		::: [$SOURCE_SF Pobierz źródła (serwer SourceForge.net)]
 		::: [$SOURCE_KADU Pobierz źródła (serwer Kadu.im)]
 		::: [$SOURCE_KADU_MD5 Suma MD5]
 		::: [$SOURCE_KADU_SHA1 Suma SHA1]
 		:: Instalator Windows:
-		::: [$EXE_GDRIVE Pobierz Instalator Windows (Google Drive)]
 		::: [$EXE_SF Pobierz Instalator Windows (SourceForge.net)]
 		::: [$EXE_KADU Pobierz Instalator Windows (Kadu.im)]
 		::: [$EXE_KADU_MD5 Suma MD5]
 		::: [$EXE_KADU_SHA1 Suma SHA1]
-		:: Wtyczki zewnętrzne:
-		::: [$EXTERNAL_PLUGINS Źródła]
 
 		Zmiany:
 		$CHANGELOG
@@ -230,19 +204,15 @@ function write_en_wiki_entry()
 
 		'''Download''':
 		:: Source code:
-		::: [$SOURCE_GDRIVE Download Sources (Google Drive)]
 		::: [$SOURCE_SF Download Sources (SourceForge.net)]
 		::: [$SOURCE_KADU Download Sources (Kadu.im)]
 		::: [$SOURCE_KADU_MD5 MD5 Checksum]
 		::: [$SOURCE_KADU_SHA1 SHA1 Checksum]
 		:: Windows installer:
-		::: [$EXE_GDRIVE Download Windows Installer (Google Drive)]
 		::: [$EXE_SF Download Windows Installer (SourceForge.net)]
 		::: [$EXE_KADU  Download Windows Installer (Kadu.im)]
 		::: [$EXE_KADU_MD5 MD5 Checksum]
 		::: [$EXE_KADU_SHA1 SHA1 Checksum]
-		:: External plugins:
-		::: [$EXTERNAL_PLUGINS Sources]
 
 		Changes:
 		$CHANGELOG
